/*
 * Copyright (C) 2015 University of Dundee & Open Microscopy Environment.
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

package ome.formats.importer.exclusions;

import ome.formats.importer.ImportContainer;
import omero.ServerError;
import omero.api.ServiceFactoryPrx;

/**
 * Voter given the opportunity by the {@link ome.formats.importer.ImportLibrary}
 * to cancel the importing of a given file.
 *
 * @since 5.1
 */
public interface FileExclusion {

   /**
    * Given the current {@link ServiceFactoryPrx session} attempt to discover
    * if the given {@link ImportContainer container} should be skipped, i.e.
    * not imported.
    * @return
    *   null if no suggestion is being made. false if this implementation
    *   suggests skipping the given container, otherwise true.
    */
    Boolean
    suggestExclusion(ServiceFactoryPrx factory, ImportContainer container)
            throws ServerError;

}
