// **********************************************************************
//
// Copyright (c) 2003-2013 ZeroC, Inc. All rights reserved.
//
// This copy of Ice is licensed to you under the terms described in the
// ICE_LICENSE file included in this distribution.
//
// **********************************************************************
//
// Ice version 3.5.1
//
// <auto-generated>
//
// Generated from file `IProjection.ice'
//
// Warning: do not edit this file.
//
// </auto-generated>
//

package omero.api;

/**
 * Provides methods for performing projections of Pixels sets.
 **/
public interface IProjectionPrx extends ServiceInterfacePrx
{
    /**
     * Performs a projection through the optical sections of a
     * particular wavelength at a given time point of a Pixels set.
     * @param pixelsId The source Pixels set Id.
     * @param pixelsType The destination Pixels type. If
     * <code>null</code>, the source Pixels set
     * pixels type will be used.
     * @param algorithm <code>MAXIMUM_INTENSITY</code>,
     * <code>MEAN_INTENSITY</code> or
     * <code>SUM_INTENSITY</code>. <b>NOTE:</b>
     * When performing a
     * <code>SUM_INTENSITY</code> projection,
     * pixel values will be <i>pinned</i> to the
     * maximum pixel value of the destination
     * Pixels type.
     * @param timepoint Timepoint to perform the projection.
     * @param channelIndex Index of the channel to perform the
     * projection.
     * @param stepping Stepping value to use while calculating the
     * projection.
     * For example, <code>stepping=1</code> will
     * use every optical section from
     * <code>start</code> to <code>end</code> where
     * <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param start Optical section to start projecting from.
     * @param end Optical section to finish projecting.
     * @return A byte array of projected pixel values whose length
     * is equal to the Pixels set
     * 8         <code>sizeX * sizeY * bytesPerPixel</code> in
     * big-endian format.
     * @throws ValidationException Where:
     * <ul>
     * <li><code>algorithm</code> is unknown</li>
     * <li><code>timepoint</code> is out of range</li>
     * <li><code>channelIndex</code> is out of range</li>
     * <li><code>start</code> is out of range</li>
     * <li><code>end</code> is out of range</li>
     * <li><code>start > end</code></li>
     * <li>the Pixels set qualified by <code>pixelsId</code> is
     * unlocatable.</li>
     * </ul>
     * @see #projectPixels
     **/
    public byte[] projectStack(long pixelsId, omero.model.PixelsType pixelsType, omero.constants.projection.ProjectionType algorithm, int timepoint, int channelIndex, int stepping, int start, int end)
        throws omero.ServerError;

    /**
     * Performs a projection through the optical sections of a
     * particular wavelength at a given time point of a Pixels set.
     * @param pixelsId The source Pixels set Id.
     * @param pixelsType The destination Pixels type. If
     * <code>null</code>, the source Pixels set
     * pixels type will be used.
     * @param algorithm <code>MAXIMUM_INTENSITY</code>,
     * <code>MEAN_INTENSITY</code> or
     * <code>SUM_INTENSITY</code>. <b>NOTE:</b>
     * When performing a
     * <code>SUM_INTENSITY</code> projection,
     * pixel values will be <i>pinned</i> to the
     * maximum pixel value of the destination
     * Pixels type.
     * @param timepoint Timepoint to perform the projection.
     * @param channelIndex Index of the channel to perform the
     * projection.
     * @param stepping Stepping value to use while calculating the
     * projection.
     * For example, <code>stepping=1</code> will
     * use every optical section from
     * <code>start</code> to <code>end</code> where
     * <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param start Optical section to start projecting from.
     * @param end Optical section to finish projecting.
     * @param __ctx The Context map to send with the invocation.
     * @return A byte array of projected pixel values whose length
     * is equal to the Pixels set
     * 8         <code>sizeX * sizeY * bytesPerPixel</code> in
     * big-endian format.
     * @throws ValidationException Where:
     * <ul>
     * <li><code>algorithm</code> is unknown</li>
     * <li><code>timepoint</code> is out of range</li>
     * <li><code>channelIndex</code> is out of range</li>
     * <li><code>start</code> is out of range</li>
     * <li><code>end</code> is out of range</li>
     * <li><code>start > end</code></li>
     * <li>the Pixels set qualified by <code>pixelsId</code> is
     * unlocatable.</li>
     * </ul>
     * @see #projectPixels
     **/
    public byte[] projectStack(long pixelsId, omero.model.PixelsType pixelsType, omero.constants.projection.ProjectionType algorithm, int timepoint, int channelIndex, int stepping, int start, int end, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Performs a projection through the optical sections of a
     * particular wavelength at a given time point of a Pixels set.
     * @param pixelsId The source Pixels set Id.
     * @param algorithm <code>MAXIMUM_INTENSITY</code>,
     * <code>MEAN_INTENSITY</code> or
     * <code>SUM_INTENSITY</code>. <b>NOTE:</b>
     * When performing a
     * <code>SUM_INTENSITY</code> projection,
     * pixel values will be <i>pinned</i> to the
     * maximum pixel value of the destination
     * Pixels type.
     * @param timepoint Timepoint to perform the projection.
     * @param stepping Stepping value to use while calculating the
     * projection.
     * For example, <code>stepping=1</code> will
     * use every optical section from
     * <code>start</code> to <code>end</code> where
     * <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param start Optical section to start projecting from.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_projectStack(long pixelsId, omero.model.PixelsType pixelsType, omero.constants.projection.ProjectionType algorithm, int timepoint, int channelIndex, int stepping, int start, int end);

    /**
     * Performs a projection through the optical sections of a
     * particular wavelength at a given time point of a Pixels set.
     * @param pixelsId The source Pixels set Id.
     * @param algorithm <code>MAXIMUM_INTENSITY</code>,
     * <code>MEAN_INTENSITY</code> or
     * <code>SUM_INTENSITY</code>. <b>NOTE:</b>
     * When performing a
     * <code>SUM_INTENSITY</code> projection,
     * pixel values will be <i>pinned</i> to the
     * maximum pixel value of the destination
     * Pixels type.
     * @param timepoint Timepoint to perform the projection.
     * @param stepping Stepping value to use while calculating the
     * projection.
     * For example, <code>stepping=1</code> will
     * use every optical section from
     * <code>start</code> to <code>end</code> where
     * <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param start Optical section to start projecting from.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_projectStack(long pixelsId, omero.model.PixelsType pixelsType, omero.constants.projection.ProjectionType algorithm, int timepoint, int channelIndex, int stepping, int start, int end, java.util.Map<String, String> __ctx);

    /**
     * Performs a projection through the optical sections of a
     * particular wavelength at a given time point of a Pixels set.
     * @param pixelsId The source Pixels set Id.
     * @param algorithm <code>MAXIMUM_INTENSITY</code>,
     * <code>MEAN_INTENSITY</code> or
     * <code>SUM_INTENSITY</code>. <b>NOTE:</b>
     * When performing a
     * <code>SUM_INTENSITY</code> projection,
     * pixel values will be <i>pinned</i> to the
     * maximum pixel value of the destination
     * Pixels type.
     * @param timepoint Timepoint to perform the projection.
     * @param stepping Stepping value to use while calculating the
     * projection.
     * For example, <code>stepping=1</code> will
     * use every optical section from
     * <code>start</code> to <code>end</code> where
     * <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param start Optical section to start projecting from.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_projectStack(long pixelsId, omero.model.PixelsType pixelsType, omero.constants.projection.ProjectionType algorithm, int timepoint, int channelIndex, int stepping, int start, int end, Ice.Callback __cb);

    /**
     * Performs a projection through the optical sections of a
     * particular wavelength at a given time point of a Pixels set.
     * @param pixelsId The source Pixels set Id.
     * @param algorithm <code>MAXIMUM_INTENSITY</code>,
     * <code>MEAN_INTENSITY</code> or
     * <code>SUM_INTENSITY</code>. <b>NOTE:</b>
     * When performing a
     * <code>SUM_INTENSITY</code> projection,
     * pixel values will be <i>pinned</i> to the
     * maximum pixel value of the destination
     * Pixels type.
     * @param timepoint Timepoint to perform the projection.
     * @param stepping Stepping value to use while calculating the
     * projection.
     * For example, <code>stepping=1</code> will
     * use every optical section from
     * <code>start</code> to <code>end</code> where
     * <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param start Optical section to start projecting from.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_projectStack(long pixelsId, omero.model.PixelsType pixelsType, omero.constants.projection.ProjectionType algorithm, int timepoint, int channelIndex, int stepping, int start, int end, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Performs a projection through the optical sections of a
     * particular wavelength at a given time point of a Pixels set.
     * @param pixelsId The source Pixels set Id.
     * @param algorithm <code>MAXIMUM_INTENSITY</code>,
     * <code>MEAN_INTENSITY</code> or
     * <code>SUM_INTENSITY</code>. <b>NOTE:</b>
     * When performing a
     * <code>SUM_INTENSITY</code> projection,
     * pixel values will be <i>pinned</i> to the
     * maximum pixel value of the destination
     * Pixels type.
     * @param timepoint Timepoint to perform the projection.
     * @param stepping Stepping value to use while calculating the
     * projection.
     * For example, <code>stepping=1</code> will
     * use every optical section from
     * <code>start</code> to <code>end</code> where
     * <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param start Optical section to start projecting from.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_projectStack(long pixelsId, omero.model.PixelsType pixelsType, omero.constants.projection.ProjectionType algorithm, int timepoint, int channelIndex, int stepping, int start, int end, Callback_IProjection_projectStack __cb);

    /**
     * Performs a projection through the optical sections of a
     * particular wavelength at a given time point of a Pixels set.
     * @param pixelsId The source Pixels set Id.
     * @param algorithm <code>MAXIMUM_INTENSITY</code>,
     * <code>MEAN_INTENSITY</code> or
     * <code>SUM_INTENSITY</code>. <b>NOTE:</b>
     * When performing a
     * <code>SUM_INTENSITY</code> projection,
     * pixel values will be <i>pinned</i> to the
     * maximum pixel value of the destination
     * Pixels type.
     * @param timepoint Timepoint to perform the projection.
     * @param stepping Stepping value to use while calculating the
     * projection.
     * For example, <code>stepping=1</code> will
     * use every optical section from
     * <code>start</code> to <code>end</code> where
     * <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param start Optical section to start projecting from.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_projectStack(long pixelsId, omero.model.PixelsType pixelsType, omero.constants.projection.ProjectionType algorithm, int timepoint, int channelIndex, int stepping, int start, int end, java.util.Map<String, String> __ctx, Callback_IProjection_projectStack __cb);

    /**
     * Performs a projection through the optical sections of a
     * particular wavelength at a given time point of a Pixels set.
     * @param __result The asynchronous result object.
     * @return A byte array of projected pixel values whose length
     * is equal to the Pixels set
     * 8         <code>sizeX * sizeY * bytesPerPixel</code> in
     * big-endian format.
     * @throws ValidationException Where:
     * <ul>
     * <li><code>algorithm</code> is unknown</li>
     * <li><code>timepoint</code> is out of range</li>
     * <li><code>channelIndex</code> is out of range</li>
     * <li><code>start</code> is out of range</li>
     * <li><code>end</code> is out of range</li>
     * <li><code>start > end</code></li>
     * <li>the Pixels set qualified by <code>pixelsId</code> is
     * unlocatable.</li>
     * </ul>
     * @see #projectPixels
     **/
    public byte[] end_projectStack(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Performs a projection through the optical sections of a
     * particular wavelength at a given time point of a Pixels set.
     * @param __cb The callback object for the operation.
     * @param pixelsId The source Pixels set Id.
     * @param algorithm <code>MAXIMUM_INTENSITY</code>,
     * <code>MEAN_INTENSITY</code> or
     * <code>SUM_INTENSITY</code>. <b>NOTE:</b>
     * When performing a
     * <code>SUM_INTENSITY</code> projection,
     * pixel values will be <i>pinned</i> to the
     * maximum pixel value of the destination
     * Pixels type.
     * @param timepoint Timepoint to perform the projection.
     * @param stepping Stepping value to use while calculating the
     * projection.
     * For example, <code>stepping=1</code> will
     * use every optical section from
     * <code>start</code> to <code>end</code> where
     * <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param start Optical section to start projecting from.
     **/
    public boolean projectStack_async(AMI_IProjection_projectStack __cb, long pixelsId, omero.model.PixelsType pixelsType, omero.constants.projection.ProjectionType algorithm, int timepoint, int channelIndex, int stepping, int start, int end);

    /**
     * Performs a projection through the optical sections of a
     * particular wavelength at a given time point of a Pixels set.
     * @param __cb The callback object for the operation.
     * @param pixelsId The source Pixels set Id.
     * @param algorithm <code>MAXIMUM_INTENSITY</code>,
     * <code>MEAN_INTENSITY</code> or
     * <code>SUM_INTENSITY</code>. <b>NOTE:</b>
     * When performing a
     * <code>SUM_INTENSITY</code> projection,
     * pixel values will be <i>pinned</i> to the
     * maximum pixel value of the destination
     * Pixels type.
     * @param timepoint Timepoint to perform the projection.
     * @param stepping Stepping value to use while calculating the
     * projection.
     * For example, <code>stepping=1</code> will
     * use every optical section from
     * <code>start</code> to <code>end</code> where
     * <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param start Optical section to start projecting from.
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean projectStack_async(AMI_IProjection_projectStack __cb, long pixelsId, omero.model.PixelsType pixelsType, omero.constants.projection.ProjectionType algorithm, int timepoint, int channelIndex, int stepping, int start, int end, java.util.Map<String, String> __ctx);

    /**
     * Performs a projection through selected optical sections and
     * optical sections for a given set of time points of a Pixels
     * set. The Image which is linked to the Pixels set will be
     * copied using
     * {@link omero.api.IPixels#copyAndResizeImage}.
     * 
     * @param pixelsId The source Pixels set Id.
     * @param pixelsType The destination Pixels type. If
     * <code>null</code>, the source Pixels set
     * pixels type will be used.
     * @param algorithm <code>MAXIMUM_INTENSITY</code>,
     * <code>MEAN_INTENSITY</code> or
     * <code>SUM_INTENSITY</code>. <b>NOTE:</b>
     * When performing a
     * <code>SUM_INTENSITY</code> projection,
     * pixel values will be <i>pinned</i> to the
     * maximum pixel value of the destination
     * Pixels type.
     * @param tStart Timepoint to start projecting from.
     * @param tEnd Timepoint to finish projecting.
     * @param channels List of the channel indexes to use while
     * calculating the projection.
     * @param stepping Stepping value to use while calculating the
     * projection. For example,
     * <code>stepping=1</code> will use every
     * optical section from <code>start</code> to
     * <code>end</code> where
     * <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param zStart Optical section to start projecting from.
     * @param zEnd Optical section to finish projecting.
     * @param name Name for the newly created image. If
     * <code>null</code> the name of the Image linked
     * to the Pixels qualified by
     * <code>pixelsId</code> will be used with a
     * <i>Projection</i> suffix. For example,
     * <i>GFP-H2B Image of HeLa Cells</i> will have an
     * Image name of
     * <i>GFP-H2B Image of HeLa Cells Projection</i>
     * used for the projection.
     * @return The Id of the newly created Image which has been
     * projected.
     * @throws ValidationException Where:
     * <ul>
     * <li><code>algorithm</code> is unknown</li>
     * <li><code>tStart</code> is out of range</li>
     * <li><code>tEnd</code> is out of range</li>
     * <li><code>tStart > tEnd</code></li>
     * <li><code>channels</code> is null or has indexes out of
     * range</li>
     * <li><code>zStart</code> is out of range</li>
     * <li><code>zEnd</code> is out of range</li>
     * <li><code>zStart > zEnd</code></li>
     * <li>the Pixels set qualified by <code>pixelsId</code> is
     * unlocatable.</li>
     * </ul>
     * @see #projectStack
     **/
    public long projectPixels(long pixelsId, omero.model.PixelsType pixelsType, omero.constants.projection.ProjectionType algorithm, int tStart, int tEnd, java.util.List<Integer> channelList, int stepping, int zStart, int zEnd, String name)
        throws omero.ServerError;

    /**
     * Performs a projection through selected optical sections and
     * optical sections for a given set of time points of a Pixels
     * set. The Image which is linked to the Pixels set will be
     * copied using
     * {@link omero.api.IPixels#copyAndResizeImage}.
     * 
     * @param pixelsId The source Pixels set Id.
     * @param pixelsType The destination Pixels type. If
     * <code>null</code>, the source Pixels set
     * pixels type will be used.
     * @param algorithm <code>MAXIMUM_INTENSITY</code>,
     * <code>MEAN_INTENSITY</code> or
     * <code>SUM_INTENSITY</code>. <b>NOTE:</b>
     * When performing a
     * <code>SUM_INTENSITY</code> projection,
     * pixel values will be <i>pinned</i> to the
     * maximum pixel value of the destination
     * Pixels type.
     * @param tStart Timepoint to start projecting from.
     * @param tEnd Timepoint to finish projecting.
     * @param channels List of the channel indexes to use while
     * calculating the projection.
     * @param stepping Stepping value to use while calculating the
     * projection. For example,
     * <code>stepping=1</code> will use every
     * optical section from <code>start</code> to
     * <code>end</code> where
     * <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param zStart Optical section to start projecting from.
     * @param zEnd Optical section to finish projecting.
     * @param name Name for the newly created image. If
     * <code>null</code> the name of the Image linked
     * to the Pixels qualified by
     * <code>pixelsId</code> will be used with a
     * <i>Projection</i> suffix. For example,
     * <i>GFP-H2B Image of HeLa Cells</i> will have an
     * Image name of
     * <i>GFP-H2B Image of HeLa Cells Projection</i>
     * used for the projection.
     * @param __ctx The Context map to send with the invocation.
     * @return The Id of the newly created Image which has been
     * projected.
     * @throws ValidationException Where:
     * <ul>
     * <li><code>algorithm</code> is unknown</li>
     * <li><code>tStart</code> is out of range</li>
     * <li><code>tEnd</code> is out of range</li>
     * <li><code>tStart > tEnd</code></li>
     * <li><code>channels</code> is null or has indexes out of
     * range</li>
     * <li><code>zStart</code> is out of range</li>
     * <li><code>zEnd</code> is out of range</li>
     * <li><code>zStart > zEnd</code></li>
     * <li>the Pixels set qualified by <code>pixelsId</code> is
     * unlocatable.</li>
     * </ul>
     * @see #projectStack
     **/
    public long projectPixels(long pixelsId, omero.model.PixelsType pixelsType, omero.constants.projection.ProjectionType algorithm, int tStart, int tEnd, java.util.List<Integer> channelList, int stepping, int zStart, int zEnd, String name, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Performs a projection through selected optical sections and
     * optical sections for a given set of time points of a Pixels
     * set. The Image which is linked to the Pixels set will be
     * copied using
     * {@link omero.api.IPixels#copyAndResizeImage}.
     * 
     * @param pixelsId The source Pixels set Id.
     * @param algorithm <code>MAXIMUM_INTENSITY</code>,
     * <code>MEAN_INTENSITY</code> or
     * <code>SUM_INTENSITY</code>. <b>NOTE:</b>
     * When performing a
     * <code>SUM_INTENSITY</code> projection,
     * pixel values will be <i>pinned</i> to the
     * maximum pixel value of the destination
     * Pixels type.
     * @param tStart Timepoint to start projecting from.
     * @param stepping Stepping value to use while calculating the
     * projection. For example,
     * <code>stepping=1</code> will use every
     * optical section from <code>start</code> to
     * <code>end</code> where
     * <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param zStart Optical section to start projecting from.
     * @param name Name for the newly created image. If
     * <code>null</code> the name of the Image linked
     * to the Pixels qualified by
     * <code>pixelsId</code> will be used with a
     * <i>Projection</i> suffix. For example,
     * <i>GFP-H2B Image of HeLa Cells</i> will have an
     * Image name of
     * <i>GFP-H2B Image of HeLa Cells Projection</i>
     * used for the projection.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_projectPixels(long pixelsId, omero.model.PixelsType pixelsType, omero.constants.projection.ProjectionType algorithm, int tStart, int tEnd, java.util.List<Integer> channelList, int stepping, int zStart, int zEnd, String name);

    /**
     * Performs a projection through selected optical sections and
     * optical sections for a given set of time points of a Pixels
     * set. The Image which is linked to the Pixels set will be
     * copied using
     * {@link omero.api.IPixels#copyAndResizeImage}.
     * 
     * @param pixelsId The source Pixels set Id.
     * @param algorithm <code>MAXIMUM_INTENSITY</code>,
     * <code>MEAN_INTENSITY</code> or
     * <code>SUM_INTENSITY</code>. <b>NOTE:</b>
     * When performing a
     * <code>SUM_INTENSITY</code> projection,
     * pixel values will be <i>pinned</i> to the
     * maximum pixel value of the destination
     * Pixels type.
     * @param tStart Timepoint to start projecting from.
     * @param stepping Stepping value to use while calculating the
     * projection. For example,
     * <code>stepping=1</code> will use every
     * optical section from <code>start</code> to
     * <code>end</code> where
     * <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param zStart Optical section to start projecting from.
     * @param name Name for the newly created image. If
     * <code>null</code> the name of the Image linked
     * to the Pixels qualified by
     * <code>pixelsId</code> will be used with a
     * <i>Projection</i> suffix. For example,
     * <i>GFP-H2B Image of HeLa Cells</i> will have an
     * Image name of
     * <i>GFP-H2B Image of HeLa Cells Projection</i>
     * used for the projection.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_projectPixels(long pixelsId, omero.model.PixelsType pixelsType, omero.constants.projection.ProjectionType algorithm, int tStart, int tEnd, java.util.List<Integer> channelList, int stepping, int zStart, int zEnd, String name, java.util.Map<String, String> __ctx);

    /**
     * Performs a projection through selected optical sections and
     * optical sections for a given set of time points of a Pixels
     * set. The Image which is linked to the Pixels set will be
     * copied using
     * {@link omero.api.IPixels#copyAndResizeImage}.
     * 
     * @param pixelsId The source Pixels set Id.
     * @param algorithm <code>MAXIMUM_INTENSITY</code>,
     * <code>MEAN_INTENSITY</code> or
     * <code>SUM_INTENSITY</code>. <b>NOTE:</b>
     * When performing a
     * <code>SUM_INTENSITY</code> projection,
     * pixel values will be <i>pinned</i> to the
     * maximum pixel value of the destination
     * Pixels type.
     * @param tStart Timepoint to start projecting from.
     * @param stepping Stepping value to use while calculating the
     * projection. For example,
     * <code>stepping=1</code> will use every
     * optical section from <code>start</code> to
     * <code>end</code> where
     * <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param zStart Optical section to start projecting from.
     * @param name Name for the newly created image. If
     * <code>null</code> the name of the Image linked
     * to the Pixels qualified by
     * <code>pixelsId</code> will be used with a
     * <i>Projection</i> suffix. For example,
     * <i>GFP-H2B Image of HeLa Cells</i> will have an
     * Image name of
     * <i>GFP-H2B Image of HeLa Cells Projection</i>
     * used for the projection.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_projectPixels(long pixelsId, omero.model.PixelsType pixelsType, omero.constants.projection.ProjectionType algorithm, int tStart, int tEnd, java.util.List<Integer> channelList, int stepping, int zStart, int zEnd, String name, Ice.Callback __cb);

    /**
     * Performs a projection through selected optical sections and
     * optical sections for a given set of time points of a Pixels
     * set. The Image which is linked to the Pixels set will be
     * copied using
     * {@link omero.api.IPixels#copyAndResizeImage}.
     * 
     * @param pixelsId The source Pixels set Id.
     * @param algorithm <code>MAXIMUM_INTENSITY</code>,
     * <code>MEAN_INTENSITY</code> or
     * <code>SUM_INTENSITY</code>. <b>NOTE:</b>
     * When performing a
     * <code>SUM_INTENSITY</code> projection,
     * pixel values will be <i>pinned</i> to the
     * maximum pixel value of the destination
     * Pixels type.
     * @param tStart Timepoint to start projecting from.
     * @param stepping Stepping value to use while calculating the
     * projection. For example,
     * <code>stepping=1</code> will use every
     * optical section from <code>start</code> to
     * <code>end</code> where
     * <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param zStart Optical section to start projecting from.
     * @param name Name for the newly created image. If
     * <code>null</code> the name of the Image linked
     * to the Pixels qualified by
     * <code>pixelsId</code> will be used with a
     * <i>Projection</i> suffix. For example,
     * <i>GFP-H2B Image of HeLa Cells</i> will have an
     * Image name of
     * <i>GFP-H2B Image of HeLa Cells Projection</i>
     * used for the projection.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_projectPixels(long pixelsId, omero.model.PixelsType pixelsType, omero.constants.projection.ProjectionType algorithm, int tStart, int tEnd, java.util.List<Integer> channelList, int stepping, int zStart, int zEnd, String name, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Performs a projection through selected optical sections and
     * optical sections for a given set of time points of a Pixels
     * set. The Image which is linked to the Pixels set will be
     * copied using
     * {@link omero.api.IPixels#copyAndResizeImage}.
     * 
     * @param pixelsId The source Pixels set Id.
     * @param algorithm <code>MAXIMUM_INTENSITY</code>,
     * <code>MEAN_INTENSITY</code> or
     * <code>SUM_INTENSITY</code>. <b>NOTE:</b>
     * When performing a
     * <code>SUM_INTENSITY</code> projection,
     * pixel values will be <i>pinned</i> to the
     * maximum pixel value of the destination
     * Pixels type.
     * @param tStart Timepoint to start projecting from.
     * @param stepping Stepping value to use while calculating the
     * projection. For example,
     * <code>stepping=1</code> will use every
     * optical section from <code>start</code> to
     * <code>end</code> where
     * <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param zStart Optical section to start projecting from.
     * @param name Name for the newly created image. If
     * <code>null</code> the name of the Image linked
     * to the Pixels qualified by
     * <code>pixelsId</code> will be used with a
     * <i>Projection</i> suffix. For example,
     * <i>GFP-H2B Image of HeLa Cells</i> will have an
     * Image name of
     * <i>GFP-H2B Image of HeLa Cells Projection</i>
     * used for the projection.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_projectPixels(long pixelsId, omero.model.PixelsType pixelsType, omero.constants.projection.ProjectionType algorithm, int tStart, int tEnd, java.util.List<Integer> channelList, int stepping, int zStart, int zEnd, String name, Callback_IProjection_projectPixels __cb);

    /**
     * Performs a projection through selected optical sections and
     * optical sections for a given set of time points of a Pixels
     * set. The Image which is linked to the Pixels set will be
     * copied using
     * {@link omero.api.IPixels#copyAndResizeImage}.
     * 
     * @param pixelsId The source Pixels set Id.
     * @param algorithm <code>MAXIMUM_INTENSITY</code>,
     * <code>MEAN_INTENSITY</code> or
     * <code>SUM_INTENSITY</code>. <b>NOTE:</b>
     * When performing a
     * <code>SUM_INTENSITY</code> projection,
     * pixel values will be <i>pinned</i> to the
     * maximum pixel value of the destination
     * Pixels type.
     * @param tStart Timepoint to start projecting from.
     * @param stepping Stepping value to use while calculating the
     * projection. For example,
     * <code>stepping=1</code> will use every
     * optical section from <code>start</code> to
     * <code>end</code> where
     * <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param zStart Optical section to start projecting from.
     * @param name Name for the newly created image. If
     * <code>null</code> the name of the Image linked
     * to the Pixels qualified by
     * <code>pixelsId</code> will be used with a
     * <i>Projection</i> suffix. For example,
     * <i>GFP-H2B Image of HeLa Cells</i> will have an
     * Image name of
     * <i>GFP-H2B Image of HeLa Cells Projection</i>
     * used for the projection.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_projectPixels(long pixelsId, omero.model.PixelsType pixelsType, omero.constants.projection.ProjectionType algorithm, int tStart, int tEnd, java.util.List<Integer> channelList, int stepping, int zStart, int zEnd, String name, java.util.Map<String, String> __ctx, Callback_IProjection_projectPixels __cb);

    /**
     * Performs a projection through selected optical sections and
     * optical sections for a given set of time points of a Pixels
     * set. The Image which is linked to the Pixels set will be
     * copied using
     * {@link omero.api.IPixels#copyAndResizeImage}.
     * 
     * @param __result The asynchronous result object.
     * @return The Id of the newly created Image which has been
     * projected.
     * @throws ValidationException Where:
     * <ul>
     * <li><code>algorithm</code> is unknown</li>
     * <li><code>tStart</code> is out of range</li>
     * <li><code>tEnd</code> is out of range</li>
     * <li><code>tStart > tEnd</code></li>
     * <li><code>channels</code> is null or has indexes out of
     * range</li>
     * <li><code>zStart</code> is out of range</li>
     * <li><code>zEnd</code> is out of range</li>
     * <li><code>zStart > zEnd</code></li>
     * <li>the Pixels set qualified by <code>pixelsId</code> is
     * unlocatable.</li>
     * </ul>
     * @see #projectStack
     **/
    public long end_projectPixels(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Performs a projection through selected optical sections and
     * optical sections for a given set of time points of a Pixels
     * set. The Image which is linked to the Pixels set will be
     * copied using
     * {@link omero.api.IPixels#copyAndResizeImage}.
     * 
     * @param __cb The callback object for the operation.
     * @param pixelsId The source Pixels set Id.
     * @param algorithm <code>MAXIMUM_INTENSITY</code>,
     * <code>MEAN_INTENSITY</code> or
     * <code>SUM_INTENSITY</code>. <b>NOTE:</b>
     * When performing a
     * <code>SUM_INTENSITY</code> projection,
     * pixel values will be <i>pinned</i> to the
     * maximum pixel value of the destination
     * Pixels type.
     * @param tStart Timepoint to start projecting from.
     * @param stepping Stepping value to use while calculating the
     * projection. For example,
     * <code>stepping=1</code> will use every
     * optical section from <code>start</code> to
     * <code>end</code> where
     * <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param zStart Optical section to start projecting from.
     * @param name Name for the newly created image. If
     * <code>null</code> the name of the Image linked
     * to the Pixels qualified by
     * <code>pixelsId</code> will be used with a
     * <i>Projection</i> suffix. For example,
     * <i>GFP-H2B Image of HeLa Cells</i> will have an
     * Image name of
     * <i>GFP-H2B Image of HeLa Cells Projection</i>
     * used for the projection.
     **/
    public boolean projectPixels_async(AMI_IProjection_projectPixels __cb, long pixelsId, omero.model.PixelsType pixelsType, omero.constants.projection.ProjectionType algorithm, int tStart, int tEnd, java.util.List<Integer> channelList, int stepping, int zStart, int zEnd, String name);

    /**
     * Performs a projection through selected optical sections and
     * optical sections for a given set of time points of a Pixels
     * set. The Image which is linked to the Pixels set will be
     * copied using
     * {@link omero.api.IPixels#copyAndResizeImage}.
     * 
     * @param __cb The callback object for the operation.
     * @param pixelsId The source Pixels set Id.
     * @param algorithm <code>MAXIMUM_INTENSITY</code>,
     * <code>MEAN_INTENSITY</code> or
     * <code>SUM_INTENSITY</code>. <b>NOTE:</b>
     * When performing a
     * <code>SUM_INTENSITY</code> projection,
     * pixel values will be <i>pinned</i> to the
     * maximum pixel value of the destination
     * Pixels type.
     * @param tStart Timepoint to start projecting from.
     * @param stepping Stepping value to use while calculating the
     * projection. For example,
     * <code>stepping=1</code> will use every
     * optical section from <code>start</code> to
     * <code>end</code> where
     * <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param zStart Optical section to start projecting from.
     * @param name Name for the newly created image. If
     * <code>null</code> the name of the Image linked
     * to the Pixels qualified by
     * <code>pixelsId</code> will be used with a
     * <i>Projection</i> suffix. For example,
     * <i>GFP-H2B Image of HeLa Cells</i> will have an
     * Image name of
     * <i>GFP-H2B Image of HeLa Cells Projection</i>
     * used for the projection.
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean projectPixels_async(AMI_IProjection_projectPixels __cb, long pixelsId, omero.model.PixelsType pixelsType, omero.constants.projection.ProjectionType algorithm, int tStart, int tEnd, java.util.List<Integer> channelList, int stepping, int zStart, int zEnd, String name, java.util.Map<String, String> __ctx);
}
