// **********************************************************************
//
// Copyright (c) 2003-2013 ZeroC, Inc. All rights reserved.
//
// This copy of Ice is licensed to you under the terms described in the
// ICE_LICENSE file included in this distribution.
//
// **********************************************************************
//
// Ice version 3.5.1
//
// <auto-generated>
//
// Generated from file `IScript.ice'
//
// Warning: do not edit this file.
//
// </auto-generated>
//

package omero.api;

/**
 * Utility service for managing and launching scripts for execution by the Processor API.
 * 
 * Typical usage might include (PYTHON):
 * <pre>
 * 
 * sf = client.createSession()
 * svc = sf.getScriptService()
 * scripts = svc.getScripts()
 * 
 * if len(scripts) >= 1:
 * script_id = svc.keys()\[-1]
 * else:
 * script_id = svc.uploadScript('/test/my_script.py', SCRIPT_TEXT)
 * 
 * params = svc.getParams(script_id)
 * 
 * # You will need to parse the params to create the proper input
 * inputs = {}
 * 
 * # The last parameter is how long to wait as an RInt
 * proc = svc.runScript(script_id, inputs, None)
 * try:
 * cb = omero.scripts.ProcessCallbackI(client, proc)
 * while not cb.block(1000): # ms.
 * pass
 * cb.close()
 * rv = proc.getResults(0)
 * finally:
 * proc.close(False)
 * 
 * </pre>
 * See <a href="http://www.openmicroscopy.org/site/support/omero5.2/developers/scripts/">OMERO.scripts</a> for more information.
 **/
public interface IScriptPrx extends ServiceInterfacePrx
{
    /**
     * This method returns official server scripts as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts()
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * # First character is a "/" symbol
     * path = script.path.val\[1:\]
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @return see above.
     * @throws ApiUsageException
     * @throws SecurityViolation
     **/
    public java.util.List<omero.model.OriginalFile> getScripts()
        throws omero.ServerError;

    /**
     * This method returns official server scripts as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts()
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * # First character is a "/" symbol
     * path = script.path.val\[1:\]
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param __ctx The Context map to send with the invocation.
     * @return see above.
     * @throws ApiUsageException
     * @throws SecurityViolation
     **/
    public java.util.List<omero.model.OriginalFile> getScripts(java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * This method returns official server scripts as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts()
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * # First character is a "/" symbol
     * path = script.path.val\[1:\]
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getScripts();

    /**
     * This method returns official server scripts as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts()
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * # First character is a "/" symbol
     * path = script.path.val\[1:\]
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getScripts(java.util.Map<String, String> __ctx);

    /**
     * This method returns official server scripts as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts()
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * # First character is a "/" symbol
     * path = script.path.val\[1:\]
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getScripts(Ice.Callback __cb);

    /**
     * This method returns official server scripts as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts()
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * # First character is a "/" symbol
     * path = script.path.val\[1:\]
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getScripts(java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * This method returns official server scripts as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts()
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * # First character is a "/" symbol
     * path = script.path.val\[1:\]
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getScripts(Callback_IScript_getScripts __cb);

    /**
     * This method returns official server scripts as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts()
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * # First character is a "/" symbol
     * path = script.path.val\[1:\]
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getScripts(java.util.Map<String, String> __ctx, Callback_IScript_getScripts __cb);

    /**
     * This method returns official server scripts as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts()
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * # First character is a "/" symbol
     * path = script.path.val\[1:\]
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param __result The asynchronous result object.
     * @return see above.
     * @throws ApiUsageException
     * @throws SecurityViolation
     **/
    public java.util.List<omero.model.OriginalFile> end_getScripts(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * This method returns official server scripts as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts()
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * # First character is a "/" symbol
     * path = script.path.val\[1:\]
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param __cb The callback object for the operation.
     **/
    public boolean getScripts_async(AMI_IScript_getScripts __cb);

    /**
     * This method returns official server scripts as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts()
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * # First character is a "/" symbol
     * path = script.path.val\[1:\]
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean getScripts_async(AMI_IScript_getScripts __cb, java.util.Map<String, String> __ctx);

    /**
     * This method returns official server scripts identified
     * with the specified extension as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts("py")
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * path = script.path.val\[1:\] # First symbol is a "/"
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param mimetype the mimetype identifying the scripts.
     * @return see above.
     * @throws ApiUsageException
     * @throws SecurityViolation
     **/
    public java.util.List<omero.model.OriginalFile> getScriptsByMimetype(String mimetype)
        throws omero.ServerError;

    /**
     * This method returns official server scripts identified
     * with the specified extension as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts("py")
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * path = script.path.val\[1:\] # First symbol is a "/"
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param mimetype the mimetype identifying the scripts.
     * @param __ctx The Context map to send with the invocation.
     * @return see above.
     * @throws ApiUsageException
     * @throws SecurityViolation
     **/
    public java.util.List<omero.model.OriginalFile> getScriptsByMimetype(String mimetype, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * This method returns official server scripts identified
     * with the specified extension as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts("py")
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * path = script.path.val\[1:\] # First symbol is a "/"
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param mimetype the mimetype identifying the scripts.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getScriptsByMimetype(String mimetype);

    /**
     * This method returns official server scripts identified
     * with the specified extension as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts("py")
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * path = script.path.val\[1:\] # First symbol is a "/"
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param mimetype the mimetype identifying the scripts.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getScriptsByMimetype(String mimetype, java.util.Map<String, String> __ctx);

    /**
     * This method returns official server scripts identified
     * with the specified extension as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts("py")
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * path = script.path.val\[1:\] # First symbol is a "/"
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param mimetype the mimetype identifying the scripts.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getScriptsByMimetype(String mimetype, Ice.Callback __cb);

    /**
     * This method returns official server scripts identified
     * with the specified extension as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts("py")
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * path = script.path.val\[1:\] # First symbol is a "/"
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param mimetype the mimetype identifying the scripts.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getScriptsByMimetype(String mimetype, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * This method returns official server scripts identified
     * with the specified extension as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts("py")
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * path = script.path.val\[1:\] # First symbol is a "/"
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param mimetype the mimetype identifying the scripts.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getScriptsByMimetype(String mimetype, Callback_IScript_getScriptsByMimetype __cb);

    /**
     * This method returns official server scripts identified
     * with the specified extension as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts("py")
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * path = script.path.val\[1:\] # First symbol is a "/"
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param mimetype the mimetype identifying the scripts.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getScriptsByMimetype(String mimetype, java.util.Map<String, String> __ctx, Callback_IScript_getScriptsByMimetype __cb);

    /**
     * This method returns official server scripts identified
     * with the specified extension as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts("py")
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * path = script.path.val\[1:\] # First symbol is a "/"
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param __result The asynchronous result object.
     * @return see above.
     * @throws ApiUsageException
     * @throws SecurityViolation
     **/
    public java.util.List<omero.model.OriginalFile> end_getScriptsByMimetype(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * This method returns official server scripts identified
     * with the specified extension as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts("py")
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * path = script.path.val\[1:\] # First symbol is a "/"
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param __cb The callback object for the operation.
     * @param mimetype the mimetype identifying the scripts.
     **/
    public boolean getScriptsByMimetype_async(AMI_IScript_getScriptsByMimetype __cb, String mimetype);

    /**
     * This method returns official server scripts identified
     * with the specified extension as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts("py")
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * path = script.path.val\[1:\] # First symbol is a "/"
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param __cb The callback object for the operation.
     * @param mimetype the mimetype identifying the scripts.
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean getScriptsByMimetype_async(AMI_IScript_getScriptsByMimetype __cb, String mimetype, java.util.Map<String, String> __ctx);

    /**
     * Returns non-official scripts which have been uploaded by individual users.
     * These scripts will <em>not</me> be run by the server, though a user can
     * start a personal <i>usermode processor</i> which will allow the scripts to be
     * executed. This is particularly useful for testing new scripts.
     **/
    public java.util.List<omero.model.OriginalFile> getUserScripts(java.util.List<omero.model.IObject> acceptsList)
        throws omero.ServerError;

    /**
     * Returns non-official scripts which have been uploaded by individual users.
     * These scripts will <em>not</me> be run by the server, though a user can
     * start a personal <i>usermode processor</i> which will allow the scripts to be
     * executed. This is particularly useful for testing new scripts.
     * @param __ctx The Context map to send with the invocation.
     **/
    public java.util.List<omero.model.OriginalFile> getUserScripts(java.util.List<omero.model.IObject> acceptsList, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Returns non-official scripts which have been uploaded by individual users.
     * These scripts will <em>not</me> be run by the server, though a user can
     * start a personal <i>usermode processor</i> which will allow the scripts to be
     * executed. This is particularly useful for testing new scripts.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getUserScripts(java.util.List<omero.model.IObject> acceptsList);

    /**
     * Returns non-official scripts which have been uploaded by individual users.
     * These scripts will <em>not</me> be run by the server, though a user can
     * start a personal <i>usermode processor</i> which will allow the scripts to be
     * executed. This is particularly useful for testing new scripts.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getUserScripts(java.util.List<omero.model.IObject> acceptsList, java.util.Map<String, String> __ctx);

    /**
     * Returns non-official scripts which have been uploaded by individual users.
     * These scripts will <em>not</me> be run by the server, though a user can
     * start a personal <i>usermode processor</i> which will allow the scripts to be
     * executed. This is particularly useful for testing new scripts.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getUserScripts(java.util.List<omero.model.IObject> acceptsList, Ice.Callback __cb);

    /**
     * Returns non-official scripts which have been uploaded by individual users.
     * These scripts will <em>not</me> be run by the server, though a user can
     * start a personal <i>usermode processor</i> which will allow the scripts to be
     * executed. This is particularly useful for testing new scripts.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getUserScripts(java.util.List<omero.model.IObject> acceptsList, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Returns non-official scripts which have been uploaded by individual users.
     * These scripts will <em>not</me> be run by the server, though a user can
     * start a personal <i>usermode processor</i> which will allow the scripts to be
     * executed. This is particularly useful for testing new scripts.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getUserScripts(java.util.List<omero.model.IObject> acceptsList, Callback_IScript_getUserScripts __cb);

    /**
     * Returns non-official scripts which have been uploaded by individual users.
     * These scripts will <em>not</me> be run by the server, though a user can
     * start a personal <i>usermode processor</i> which will allow the scripts to be
     * executed. This is particularly useful for testing new scripts.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getUserScripts(java.util.List<omero.model.IObject> acceptsList, java.util.Map<String, String> __ctx, Callback_IScript_getUserScripts __cb);

    /**
     * Returns non-official scripts which have been uploaded by individual users.
     * These scripts will <em>not</me> be run by the server, though a user can
     * start a personal <i>usermode processor</i> which will allow the scripts to be
     * executed. This is particularly useful for testing new scripts.
     * @param __result The asynchronous result object.
     **/
    public java.util.List<omero.model.OriginalFile> end_getUserScripts(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Returns non-official scripts which have been uploaded by individual users.
     * These scripts will <em>not</me> be run by the server, though a user can
     * start a personal <i>usermode processor</i> which will allow the scripts to be
     * executed. This is particularly useful for testing new scripts.
     * @param __cb The callback object for the operation.
     **/
    public boolean getUserScripts_async(AMI_IScript_getUserScripts __cb, java.util.List<omero.model.IObject> acceptsList);

    /**
     * Returns non-official scripts which have been uploaded by individual users.
     * These scripts will <em>not</me> be run by the server, though a user can
     * start a personal <i>usermode processor</i> which will allow the scripts to be
     * executed. This is particularly useful for testing new scripts.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean getUserScripts_async(AMI_IScript_getUserScripts __cb, java.util.List<omero.model.IObject> acceptsList, java.util.Map<String, String> __ctx);

    /**
     * Get the id of an official script by the script path.
     * The script service ensures that all script paths are unique.
     * 
     * Note: there is no similar method for user scripts (e.g. getUserScriptID)
     * since the path is not guaranteed to be unique.
     * 
     * @param scriptName The name of the script.
     * @return see above.
     * @throws ApiUsageException
     * @throws SecurityViolation
     **/
    public long getScriptID(String path)
        throws omero.ServerError;

    /**
     * Get the id of an official script by the script path.
     * The script service ensures that all script paths are unique.
     * 
     * Note: there is no similar method for user scripts (e.g. getUserScriptID)
     * since the path is not guaranteed to be unique.
     * 
     * @param scriptName The name of the script.
     * @param __ctx The Context map to send with the invocation.
     * @return see above.
     * @throws ApiUsageException
     * @throws SecurityViolation
     **/
    public long getScriptID(String path, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Get the id of an official script by the script path.
     * The script service ensures that all script paths are unique.
     * 
     * Note: there is no similar method for user scripts (e.g. getUserScriptID)
     * since the path is not guaranteed to be unique.
     * 
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getScriptID(String path);

    /**
     * Get the id of an official script by the script path.
     * The script service ensures that all script paths are unique.
     * 
     * Note: there is no similar method for user scripts (e.g. getUserScriptID)
     * since the path is not guaranteed to be unique.
     * 
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getScriptID(String path, java.util.Map<String, String> __ctx);

    /**
     * Get the id of an official script by the script path.
     * The script service ensures that all script paths are unique.
     * 
     * Note: there is no similar method for user scripts (e.g. getUserScriptID)
     * since the path is not guaranteed to be unique.
     * 
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getScriptID(String path, Ice.Callback __cb);

    /**
     * Get the id of an official script by the script path.
     * The script service ensures that all script paths are unique.
     * 
     * Note: there is no similar method for user scripts (e.g. getUserScriptID)
     * since the path is not guaranteed to be unique.
     * 
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getScriptID(String path, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Get the id of an official script by the script path.
     * The script service ensures that all script paths are unique.
     * 
     * Note: there is no similar method for user scripts (e.g. getUserScriptID)
     * since the path is not guaranteed to be unique.
     * 
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getScriptID(String path, Callback_IScript_getScriptID __cb);

    /**
     * Get the id of an official script by the script path.
     * The script service ensures that all script paths are unique.
     * 
     * Note: there is no similar method for user scripts (e.g. getUserScriptID)
     * since the path is not guaranteed to be unique.
     * 
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getScriptID(String path, java.util.Map<String, String> __ctx, Callback_IScript_getScriptID __cb);

    /**
     * Get the id of an official script by the script path.
     * The script service ensures that all script paths are unique.
     * 
     * Note: there is no similar method for user scripts (e.g. getUserScriptID)
     * since the path is not guaranteed to be unique.
     * 
     * @param __result The asynchronous result object.
     * @return see above.
     * @throws ApiUsageException
     * @throws SecurityViolation
     **/
    public long end_getScriptID(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Get the id of an official script by the script path.
     * The script service ensures that all script paths are unique.
     * 
     * Note: there is no similar method for user scripts (e.g. getUserScriptID)
     * since the path is not guaranteed to be unique.
     * 
     * @param __cb The callback object for the operation.
     **/
    public boolean getScriptID_async(AMI_IScript_getScriptID __cb, String path);

    /**
     * Get the id of an official script by the script path.
     * The script service ensures that all script paths are unique.
     * 
     * Note: there is no similar method for user scripts (e.g. getUserScriptID)
     * since the path is not guaranteed to be unique.
     * 
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean getScriptID_async(AMI_IScript_getScriptID __cb, String path, java.util.Map<String, String> __ctx);

    /**
     * Get the text from the server for the script with given id.
     * 
     * @param scriptID see above.
     * @return see above.
     * @throws ApiUsageException
     **/
    public String getScriptText(long scriptID)
        throws omero.ServerError;

    /**
     * Get the text from the server for the script with given id.
     * 
     * @param scriptID see above.
     * @param __ctx The Context map to send with the invocation.
     * @return see above.
     * @throws ApiUsageException
     **/
    public String getScriptText(long scriptID, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Get the text from the server for the script with given id.
     * 
     * @param scriptID see above.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getScriptText(long scriptID);

    /**
     * Get the text from the server for the script with given id.
     * 
     * @param scriptID see above.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getScriptText(long scriptID, java.util.Map<String, String> __ctx);

    /**
     * Get the text from the server for the script with given id.
     * 
     * @param scriptID see above.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getScriptText(long scriptID, Ice.Callback __cb);

    /**
     * Get the text from the server for the script with given id.
     * 
     * @param scriptID see above.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getScriptText(long scriptID, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Get the text from the server for the script with given id.
     * 
     * @param scriptID see above.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getScriptText(long scriptID, Callback_IScript_getScriptText __cb);

    /**
     * Get the text from the server for the script with given id.
     * 
     * @param scriptID see above.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getScriptText(long scriptID, java.util.Map<String, String> __ctx, Callback_IScript_getScriptText __cb);

    /**
     * Get the text from the server for the script with given id.
     * 
     * @param __result The asynchronous result object.
     * @return see above.
     * @throws ApiUsageException
     **/
    public String end_getScriptText(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Get the text from the server for the script with given id.
     * 
     * @param __cb The callback object for the operation.
     * @param scriptID see above.
     **/
    public boolean getScriptText_async(AMI_IScript_getScriptText __cb, long scriptID);

    /**
     * Get the text from the server for the script with given id.
     * 
     * @param __cb The callback object for the operation.
     * @param scriptID see above.
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean getScriptText_async(AMI_IScript_getScriptText __cb, long scriptID, java.util.Map<String, String> __ctx);

    /**
     * Upload a user script to the server and return the id. This method checks that
     * a script with that names does not exist and that the script has parameters
     * <em>if possible</em>, i.e. a usermode processor is running which for the
     * current user.
     * 
     * @param script see above.
     * @return The new id of the script.
     * @throws ApiUsageException
     * @throws SecurityViolation
     **/
    public long uploadScript(String path, String scriptText)
        throws omero.ServerError;

    /**
     * Upload a user script to the server and return the id. This method checks that
     * a script with that names does not exist and that the script has parameters
     * <em>if possible</em>, i.e. a usermode processor is running which for the
     * current user.
     * 
     * @param script see above.
     * @param __ctx The Context map to send with the invocation.
     * @return The new id of the script.
     * @throws ApiUsageException
     * @throws SecurityViolation
     **/
    public long uploadScript(String path, String scriptText, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Upload a user script to the server and return the id. This method checks that
     * a script with that names does not exist and that the script has parameters
     * <em>if possible</em>, i.e. a usermode processor is running which for the
     * current user.
     * 
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_uploadScript(String path, String scriptText);

    /**
     * Upload a user script to the server and return the id. This method checks that
     * a script with that names does not exist and that the script has parameters
     * <em>if possible</em>, i.e. a usermode processor is running which for the
     * current user.
     * 
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_uploadScript(String path, String scriptText, java.util.Map<String, String> __ctx);

    /**
     * Upload a user script to the server and return the id. This method checks that
     * a script with that names does not exist and that the script has parameters
     * <em>if possible</em>, i.e. a usermode processor is running which for the
     * current user.
     * 
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_uploadScript(String path, String scriptText, Ice.Callback __cb);

    /**
     * Upload a user script to the server and return the id. This method checks that
     * a script with that names does not exist and that the script has parameters
     * <em>if possible</em>, i.e. a usermode processor is running which for the
     * current user.
     * 
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_uploadScript(String path, String scriptText, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Upload a user script to the server and return the id. This method checks that
     * a script with that names does not exist and that the script has parameters
     * <em>if possible</em>, i.e. a usermode processor is running which for the
     * current user.
     * 
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_uploadScript(String path, String scriptText, Callback_IScript_uploadScript __cb);

    /**
     * Upload a user script to the server and return the id. This method checks that
     * a script with that names does not exist and that the script has parameters
     * <em>if possible</em>, i.e. a usermode processor is running which for the
     * current user.
     * 
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_uploadScript(String path, String scriptText, java.util.Map<String, String> __ctx, Callback_IScript_uploadScript __cb);

    /**
     * Upload a user script to the server and return the id. This method checks that
     * a script with that names does not exist and that the script has parameters
     * <em>if possible</em>, i.e. a usermode processor is running which for the
     * current user.
     * 
     * @param __result The asynchronous result object.
     * @return The new id of the script.
     * @throws ApiUsageException
     * @throws SecurityViolation
     **/
    public long end_uploadScript(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Upload a user script to the server and return the id. This method checks that
     * a script with that names does not exist and that the script has parameters
     * <em>if possible</em>, i.e. a usermode processor is running which for the
     * current user.
     * 
     * @param __cb The callback object for the operation.
     **/
    public boolean uploadScript_async(AMI_IScript_uploadScript __cb, String path, String scriptText);

    /**
     * Upload a user script to the server and return the id. This method checks that
     * a script with that names does not exist and that the script has parameters
     * <em>if possible</em>, i.e. a usermode processor is running which for the
     * current user.
     * 
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean uploadScript_async(AMI_IScript_uploadScript __cb, String path, String scriptText, java.util.Map<String, String> __ctx);

    /**
     * Like {@link #uploadScript} but is only callable by
     * administrators. The parameters for the script are also
     * checked.
     **/
    public long uploadOfficialScript(String path, String scriptText)
        throws omero.ServerError;

    /**
     * Like {@link #uploadScript} but is only callable by
     * administrators. The parameters for the script are also
     * checked.
     * @param __ctx The Context map to send with the invocation.
     **/
    public long uploadOfficialScript(String path, String scriptText, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Like {@link #uploadScript} but is only callable by
     * administrators. The parameters for the script are also
     * checked.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_uploadOfficialScript(String path, String scriptText);

    /**
     * Like {@link #uploadScript} but is only callable by
     * administrators. The parameters for the script are also
     * checked.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_uploadOfficialScript(String path, String scriptText, java.util.Map<String, String> __ctx);

    /**
     * Like {@link #uploadScript} but is only callable by
     * administrators. The parameters for the script are also
     * checked.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_uploadOfficialScript(String path, String scriptText, Ice.Callback __cb);

    /**
     * Like {@link #uploadScript} but is only callable by
     * administrators. The parameters for the script are also
     * checked.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_uploadOfficialScript(String path, String scriptText, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Like {@link #uploadScript} but is only callable by
     * administrators. The parameters for the script are also
     * checked.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_uploadOfficialScript(String path, String scriptText, Callback_IScript_uploadOfficialScript __cb);

    /**
     * Like {@link #uploadScript} but is only callable by
     * administrators. The parameters for the script are also
     * checked.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_uploadOfficialScript(String path, String scriptText, java.util.Map<String, String> __ctx, Callback_IScript_uploadOfficialScript __cb);

    /**
     * Like {@link #uploadScript} but is only callable by
     * administrators. The parameters for the script are also
     * checked.
     * @param __result The asynchronous result object.
     **/
    public long end_uploadOfficialScript(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Like {@link #uploadScript} but is only callable by
     * administrators. The parameters for the script are also
     * checked.
     * @param __cb The callback object for the operation.
     **/
    public boolean uploadOfficialScript_async(AMI_IScript_uploadOfficialScript __cb, String path, String scriptText);

    /**
     * Like {@link #uploadScript} but is only callable by
     * administrators. The parameters for the script are also
     * checked.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean uploadOfficialScript_async(AMI_IScript_uploadOfficialScript __cb, String path, String scriptText, java.util.Map<String, String> __ctx);

    /**
     * Modify the text for the given script object.
     * 
     * @param script see above.
     * @throws ApiUsageException
     * @throws SecurityViolation
     **/
    public void editScript(omero.model.OriginalFile fileObject, String scriptText)
        throws omero.ServerError;

    /**
     * Modify the text for the given script object.
     * 
     * @param script see above.
     * @throws ApiUsageException
     * @throws SecurityViolation
     * @param __ctx The Context map to send with the invocation.
     **/
    public void editScript(omero.model.OriginalFile fileObject, String scriptText, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Modify the text for the given script object.
     * 
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_editScript(omero.model.OriginalFile fileObject, String scriptText);

    /**
     * Modify the text for the given script object.
     * 
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_editScript(omero.model.OriginalFile fileObject, String scriptText, java.util.Map<String, String> __ctx);

    /**
     * Modify the text for the given script object.
     * 
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_editScript(omero.model.OriginalFile fileObject, String scriptText, Ice.Callback __cb);

    /**
     * Modify the text for the given script object.
     * 
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_editScript(omero.model.OriginalFile fileObject, String scriptText, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Modify the text for the given script object.
     * 
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_editScript(omero.model.OriginalFile fileObject, String scriptText, Callback_IScript_editScript __cb);

    /**
     * Modify the text for the given script object.
     * 
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_editScript(omero.model.OriginalFile fileObject, String scriptText, java.util.Map<String, String> __ctx, Callback_IScript_editScript __cb);

    /**
     * Modify the text for the given script object.
     * 
     * @param __result The asynchronous result object.
     * @throws ApiUsageException
     * @throws SecurityViolation
     **/
    public void end_editScript(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Modify the text for the given script object.
     * 
     * @param __cb The callback object for the operation.
     **/
    public boolean editScript_async(AMI_IScript_editScript __cb, omero.model.OriginalFile fileObject, String scriptText);

    /**
     * Modify the text for the given script object.
     * 
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean editScript_async(AMI_IScript_editScript __cb, omero.model.OriginalFile fileObject, String scriptText, java.util.Map<String, String> __ctx);

    /**
     * Get the script from the server with details from OriginalFile
     * @param scriptID see above
     * @return see above
     * @throws ApiUsageException
     **/
    public java.util.Map<java.lang.String, omero.RType> getScriptWithDetails(long scriptID)
        throws omero.ServerError;

    /**
     * Get the script from the server with details from OriginalFile
     * @param scriptID see above
     * @param __ctx The Context map to send with the invocation.
     * @return see above
     * @throws ApiUsageException
     **/
    public java.util.Map<java.lang.String, omero.RType> getScriptWithDetails(long scriptID, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Get the script from the server with details from OriginalFile
     * @param scriptID see above
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getScriptWithDetails(long scriptID);

    /**
     * Get the script from the server with details from OriginalFile
     * @param scriptID see above
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getScriptWithDetails(long scriptID, java.util.Map<String, String> __ctx);

    /**
     * Get the script from the server with details from OriginalFile
     * @param scriptID see above
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getScriptWithDetails(long scriptID, Ice.Callback __cb);

    /**
     * Get the script from the server with details from OriginalFile
     * @param scriptID see above
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getScriptWithDetails(long scriptID, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Get the script from the server with details from OriginalFile
     * @param scriptID see above
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getScriptWithDetails(long scriptID, Callback_IScript_getScriptWithDetails __cb);

    /**
     * Get the script from the server with details from OriginalFile
     * @param scriptID see above
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getScriptWithDetails(long scriptID, java.util.Map<String, String> __ctx, Callback_IScript_getScriptWithDetails __cb);

    /**
     * Get the script from the server with details from OriginalFile
     * @param __result The asynchronous result object.
     * @return see above
     * @throws ApiUsageException
     **/
    public java.util.Map<java.lang.String, omero.RType> end_getScriptWithDetails(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Get the script from the server with details from OriginalFile
     * @param __cb The callback object for the operation.
     * @param scriptID see above
     **/
    public boolean getScriptWithDetails_async(AMI_IScript_getScriptWithDetails __cb, long scriptID);

    /**
     * Get the script from the server with details from OriginalFile
     * @param __cb The callback object for the operation.
     * @param scriptID see above
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean getScriptWithDetails_async(AMI_IScript_getScriptWithDetails __cb, long scriptID, java.util.Map<String, String> __ctx);

    /**
     * Get the parameters that the script takes and returns, along with
     * other metadata available from the script.
     * 
     * @param scriptID see above.
     * @return see above.
     * @throws ApiUsageException
     **/
    public omero.grid.JobParams getParams(long scriptID)
        throws omero.ServerError;

    /**
     * Get the parameters that the script takes and returns, along with
     * other metadata available from the script.
     * 
     * @param scriptID see above.
     * @param __ctx The Context map to send with the invocation.
     * @return see above.
     * @throws ApiUsageException
     **/
    public omero.grid.JobParams getParams(long scriptID, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Get the parameters that the script takes and returns, along with
     * other metadata available from the script.
     * 
     * @param scriptID see above.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getParams(long scriptID);

    /**
     * Get the parameters that the script takes and returns, along with
     * other metadata available from the script.
     * 
     * @param scriptID see above.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getParams(long scriptID, java.util.Map<String, String> __ctx);

    /**
     * Get the parameters that the script takes and returns, along with
     * other metadata available from the script.
     * 
     * @param scriptID see above.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getParams(long scriptID, Ice.Callback __cb);

    /**
     * Get the parameters that the script takes and returns, along with
     * other metadata available from the script.
     * 
     * @param scriptID see above.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getParams(long scriptID, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Get the parameters that the script takes and returns, along with
     * other metadata available from the script.
     * 
     * @param scriptID see above.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getParams(long scriptID, Callback_IScript_getParams __cb);

    /**
     * Get the parameters that the script takes and returns, along with
     * other metadata available from the script.
     * 
     * @param scriptID see above.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_getParams(long scriptID, java.util.Map<String, String> __ctx, Callback_IScript_getParams __cb);

    /**
     * Get the parameters that the script takes and returns, along with
     * other metadata available from the script.
     * 
     * @param __result The asynchronous result object.
     * @return see above.
     * @throws ApiUsageException
     **/
    public omero.grid.JobParams end_getParams(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Get the parameters that the script takes and returns, along with
     * other metadata available from the script.
     * 
     * @param __cb The callback object for the operation.
     * @param scriptID see above.
     **/
    public boolean getParams_async(AMI_IScript_getParams __cb, long scriptID);

    /**
     * Get the parameters that the script takes and returns, along with
     * other metadata available from the script.
     * 
     * @param __cb The callback object for the operation.
     * @param scriptID see above.
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean getParams_async(AMI_IScript_getParams __cb, long scriptID, java.util.Map<String, String> __ctx);

    /**
     * Delete the script on the server with id. The file will also be removed from disk.
     * 
     * @param scriptID Id of the script to delete.
     * @throws ApiUsageException
     * @throws SecurityViolation
     **/
    public void deleteScript(long scriptID)
        throws omero.ServerError;

    /**
     * Delete the script on the server with id. The file will also be removed from disk.
     * 
     * @param scriptID Id of the script to delete.
     * @throws ApiUsageException
     * @throws SecurityViolation
     * @param __ctx The Context map to send with the invocation.
     **/
    public void deleteScript(long scriptID, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Delete the script on the server with id. The file will also be removed from disk.
     * 
     * @param scriptID Id of the script to delete.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_deleteScript(long scriptID);

    /**
     * Delete the script on the server with id. The file will also be removed from disk.
     * 
     * @param scriptID Id of the script to delete.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_deleteScript(long scriptID, java.util.Map<String, String> __ctx);

    /**
     * Delete the script on the server with id. The file will also be removed from disk.
     * 
     * @param scriptID Id of the script to delete.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_deleteScript(long scriptID, Ice.Callback __cb);

    /**
     * Delete the script on the server with id. The file will also be removed from disk.
     * 
     * @param scriptID Id of the script to delete.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_deleteScript(long scriptID, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Delete the script on the server with id. The file will also be removed from disk.
     * 
     * @param scriptID Id of the script to delete.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_deleteScript(long scriptID, Callback_IScript_deleteScript __cb);

    /**
     * Delete the script on the server with id. The file will also be removed from disk.
     * 
     * @param scriptID Id of the script to delete.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_deleteScript(long scriptID, java.util.Map<String, String> __ctx, Callback_IScript_deleteScript __cb);

    /**
     * Delete the script on the server with id. The file will also be removed from disk.
     * 
     * @param __result The asynchronous result object.
     * @throws ApiUsageException
     * @throws SecurityViolation
     **/
    public void end_deleteScript(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Delete the script on the server with id. The file will also be removed from disk.
     * 
     * @param __cb The callback object for the operation.
     * @param scriptID Id of the script to delete.
     **/
    public boolean deleteScript_async(AMI_IScript_deleteScript __cb, long scriptID);

    /**
     * Delete the script on the server with id. The file will also be removed from disk.
     * 
     * @param __cb The callback object for the operation.
     * @param scriptID Id of the script to delete.
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean deleteScript_async(AMI_IScript_deleteScript __cb, long scriptID, java.util.Map<String, String> __ctx);

    /**
     * If {@link ResourceError} is thrown, then no
     * {@link Processor} is available. Use {@link #scheduleJob}
     * to create a {@link omero.model.ScriptJob} in the
     * <i>Waiting</i> state. A {@link Processor} may become
     * available.
     * 
     * <pre>
     * try:
     * proc = scriptService.runScript(1, {}, None)
     * except ResourceError:
     * job = scriptService.scheduleScript(1, {}, None)
     * </pre>
     * 
     * The {@link ScriptProcess} proxy MUST be closed before
     * exiting. If you would like the script execution to continue
     * in the background, pass <code>True</code> as the argument.
     * 
     * <pre>
     * try:
     * proc.poll()         # See if process is finished
     * finally:
     * proc.close(True)    # Detach and execution can continue
     * # proc.close(False) # OR script is immediately stopped.
     * </pre>
     **/
    public omero.grid.ScriptProcessPrx runScript(long scriptID, java.util.Map<java.lang.String, omero.RType> inputs, omero.RInt waitSecs)
        throws omero.ServerError;

    /**
     * If {@link ResourceError} is thrown, then no
     * {@link Processor} is available. Use {@link #scheduleJob}
     * to create a {@link omero.model.ScriptJob} in the
     * <i>Waiting</i> state. A {@link Processor} may become
     * available.
     * 
     * <pre>
     * try:
     * proc = scriptService.runScript(1, {}, None)
     * except ResourceError:
     * job = scriptService.scheduleScript(1, {}, None)
     * </pre>
     * 
     * The {@link ScriptProcess} proxy MUST be closed before
     * exiting. If you would like the script execution to continue
     * in the background, pass <code>True</code> as the argument.
     * 
     * <pre>
     * try:
     * proc.poll()         # See if process is finished
     * finally:
     * proc.close(True)    # Detach and execution can continue
     * # proc.close(False) # OR script is immediately stopped.
     * </pre>
     * @param __ctx The Context map to send with the invocation.
     **/
    public omero.grid.ScriptProcessPrx runScript(long scriptID, java.util.Map<java.lang.String, omero.RType> inputs, omero.RInt waitSecs, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * If {@link ResourceError} is thrown, then no
     * {@link Processor} is available. Use {@link #scheduleJob}
     * to create a {@link omero.model.ScriptJob} in the
     * <i>Waiting</i> state. A {@link Processor} may become
     * available.
     * 
     * <pre>
     * try:
     * proc = scriptService.runScript(1, {}, None)
     * except ResourceError:
     * job = scriptService.scheduleScript(1, {}, None)
     * </pre>
     * 
     * The {@link ScriptProcess} proxy MUST be closed before
     * exiting. If you would like the script execution to continue
     * in the background, pass <code>True</code> as the argument.
     * 
     * <pre>
     * try:
     * proc.poll()         # See if process is finished
     * finally:
     * proc.close(True)    # Detach and execution can continue
     * # proc.close(False) # OR script is immediately stopped.
     * </pre>
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_runScript(long scriptID, java.util.Map<java.lang.String, omero.RType> inputs, omero.RInt waitSecs);

    /**
     * If {@link ResourceError} is thrown, then no
     * {@link Processor} is available. Use {@link #scheduleJob}
     * to create a {@link omero.model.ScriptJob} in the
     * <i>Waiting</i> state. A {@link Processor} may become
     * available.
     * 
     * <pre>
     * try:
     * proc = scriptService.runScript(1, {}, None)
     * except ResourceError:
     * job = scriptService.scheduleScript(1, {}, None)
     * </pre>
     * 
     * The {@link ScriptProcess} proxy MUST be closed before
     * exiting. If you would like the script execution to continue
     * in the background, pass <code>True</code> as the argument.
     * 
     * <pre>
     * try:
     * proc.poll()         # See if process is finished
     * finally:
     * proc.close(True)    # Detach and execution can continue
     * # proc.close(False) # OR script is immediately stopped.
     * </pre>
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_runScript(long scriptID, java.util.Map<java.lang.String, omero.RType> inputs, omero.RInt waitSecs, java.util.Map<String, String> __ctx);

    /**
     * If {@link ResourceError} is thrown, then no
     * {@link Processor} is available. Use {@link #scheduleJob}
     * to create a {@link omero.model.ScriptJob} in the
     * <i>Waiting</i> state. A {@link Processor} may become
     * available.
     * 
     * <pre>
     * try:
     * proc = scriptService.runScript(1, {}, None)
     * except ResourceError:
     * job = scriptService.scheduleScript(1, {}, None)
     * </pre>
     * 
     * The {@link ScriptProcess} proxy MUST be closed before
     * exiting. If you would like the script execution to continue
     * in the background, pass <code>True</code> as the argument.
     * 
     * <pre>
     * try:
     * proc.poll()         # See if process is finished
     * finally:
     * proc.close(True)    # Detach and execution can continue
     * # proc.close(False) # OR script is immediately stopped.
     * </pre>
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_runScript(long scriptID, java.util.Map<java.lang.String, omero.RType> inputs, omero.RInt waitSecs, Ice.Callback __cb);

    /**
     * If {@link ResourceError} is thrown, then no
     * {@link Processor} is available. Use {@link #scheduleJob}
     * to create a {@link omero.model.ScriptJob} in the
     * <i>Waiting</i> state. A {@link Processor} may become
     * available.
     * 
     * <pre>
     * try:
     * proc = scriptService.runScript(1, {}, None)
     * except ResourceError:
     * job = scriptService.scheduleScript(1, {}, None)
     * </pre>
     * 
     * The {@link ScriptProcess} proxy MUST be closed before
     * exiting. If you would like the script execution to continue
     * in the background, pass <code>True</code> as the argument.
     * 
     * <pre>
     * try:
     * proc.poll()         # See if process is finished
     * finally:
     * proc.close(True)    # Detach and execution can continue
     * # proc.close(False) # OR script is immediately stopped.
     * </pre>
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_runScript(long scriptID, java.util.Map<java.lang.String, omero.RType> inputs, omero.RInt waitSecs, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * If {@link ResourceError} is thrown, then no
     * {@link Processor} is available. Use {@link #scheduleJob}
     * to create a {@link omero.model.ScriptJob} in the
     * <i>Waiting</i> state. A {@link Processor} may become
     * available.
     * 
     * <pre>
     * try:
     * proc = scriptService.runScript(1, {}, None)
     * except ResourceError:
     * job = scriptService.scheduleScript(1, {}, None)
     * </pre>
     * 
     * The {@link ScriptProcess} proxy MUST be closed before
     * exiting. If you would like the script execution to continue
     * in the background, pass <code>True</code> as the argument.
     * 
     * <pre>
     * try:
     * proc.poll()         # See if process is finished
     * finally:
     * proc.close(True)    # Detach and execution can continue
     * # proc.close(False) # OR script is immediately stopped.
     * </pre>
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_runScript(long scriptID, java.util.Map<java.lang.String, omero.RType> inputs, omero.RInt waitSecs, Callback_IScript_runScript __cb);

    /**
     * If {@link ResourceError} is thrown, then no
     * {@link Processor} is available. Use {@link #scheduleJob}
     * to create a {@link omero.model.ScriptJob} in the
     * <i>Waiting</i> state. A {@link Processor} may become
     * available.
     * 
     * <pre>
     * try:
     * proc = scriptService.runScript(1, {}, None)
     * except ResourceError:
     * job = scriptService.scheduleScript(1, {}, None)
     * </pre>
     * 
     * The {@link ScriptProcess} proxy MUST be closed before
     * exiting. If you would like the script execution to continue
     * in the background, pass <code>True</code> as the argument.
     * 
     * <pre>
     * try:
     * proc.poll()         # See if process is finished
     * finally:
     * proc.close(True)    # Detach and execution can continue
     * # proc.close(False) # OR script is immediately stopped.
     * </pre>
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_runScript(long scriptID, java.util.Map<java.lang.String, omero.RType> inputs, omero.RInt waitSecs, java.util.Map<String, String> __ctx, Callback_IScript_runScript __cb);

    /**
     * If {@link ResourceError} is thrown, then no
     * {@link Processor} is available. Use {@link #scheduleJob}
     * to create a {@link omero.model.ScriptJob} in the
     * <i>Waiting</i> state. A {@link Processor} may become
     * available.
     * 
     * <pre>
     * try:
     * proc = scriptService.runScript(1, {}, None)
     * except ResourceError:
     * job = scriptService.scheduleScript(1, {}, None)
     * </pre>
     * 
     * The {@link ScriptProcess} proxy MUST be closed before
     * exiting. If you would like the script execution to continue
     * in the background, pass <code>True</code> as the argument.
     * 
     * <pre>
     * try:
     * proc.poll()         # See if process is finished
     * finally:
     * proc.close(True)    # Detach and execution can continue
     * # proc.close(False) # OR script is immediately stopped.
     * </pre>
     * @param __result The asynchronous result object.
     **/
    public omero.grid.ScriptProcessPrx end_runScript(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * If {@link ResourceError} is thrown, then no
     * {@link Processor} is available. Use {@link #scheduleJob}
     * to create a {@link omero.model.ScriptJob} in the
     * <i>Waiting</i> state. A {@link Processor} may become
     * available.
     * 
     * <pre>
     * try:
     * proc = scriptService.runScript(1, {}, None)
     * except ResourceError:
     * job = scriptService.scheduleScript(1, {}, None)
     * </pre>
     * 
     * The {@link ScriptProcess} proxy MUST be closed before
     * exiting. If you would like the script execution to continue
     * in the background, pass <code>True</code> as the argument.
     * 
     * <pre>
     * try:
     * proc.poll()         # See if process is finished
     * finally:
     * proc.close(True)    # Detach and execution can continue
     * # proc.close(False) # OR script is immediately stopped.
     * </pre>
     * @param __cb The callback object for the operation.
     **/
    public boolean runScript_async(AMI_IScript_runScript __cb, long scriptID, java.util.Map<java.lang.String, omero.RType> inputs, omero.RInt waitSecs);

    /**
     * If {@link ResourceError} is thrown, then no
     * {@link Processor} is available. Use {@link #scheduleJob}
     * to create a {@link omero.model.ScriptJob} in the
     * <i>Waiting</i> state. A {@link Processor} may become
     * available.
     * 
     * <pre>
     * try:
     * proc = scriptService.runScript(1, {}, None)
     * except ResourceError:
     * job = scriptService.scheduleScript(1, {}, None)
     * </pre>
     * 
     * The {@link ScriptProcess} proxy MUST be closed before
     * exiting. If you would like the script execution to continue
     * in the background, pass <code>True</code> as the argument.
     * 
     * <pre>
     * try:
     * proc.poll()         # See if process is finished
     * finally:
     * proc.close(True)    # Detach and execution can continue
     * # proc.close(False) # OR script is immediately stopped.
     * </pre>
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean runScript_async(AMI_IScript_runScript __cb, long scriptID, java.util.Map<java.lang.String, omero.RType> inputs, omero.RInt waitSecs, java.util.Map<String, String> __ctx);

    /**
     * Returns true if there is a processor which will run the
     * given script.
     * 
     * <p>
     * Either the script is an official script and this method
     * will return true (though an individual invocation may fail
     * with an {@link omero.ResourceError} for some reason)
     * <em>or</em> this is a user script, and a usermode processor
     * must be active which takes the scripts user or group.
     * </p>
     * 
     **/
    public boolean canRunScript(long scriptID)
        throws omero.ServerError;

    /**
     * Returns true if there is a processor which will run the
     * given script.
     * 
     * <p>
     * Either the script is an official script and this method
     * will return true (though an individual invocation may fail
     * with an {@link omero.ResourceError} for some reason)
     * <em>or</em> this is a user script, and a usermode processor
     * must be active which takes the scripts user or group.
     * </p>
     * 
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean canRunScript(long scriptID, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Returns true if there is a processor which will run the
     * given script.
     * 
     * <p>
     * Either the script is an official script and this method
     * will return true (though an individual invocation may fail
     * with an {@link omero.ResourceError} for some reason)
     * <em>or</em> this is a user script, and a usermode processor
     * must be active which takes the scripts user or group.
     * </p>
     * 
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_canRunScript(long scriptID);

    /**
     * Returns true if there is a processor which will run the
     * given script.
     * 
     * <p>
     * Either the script is an official script and this method
     * will return true (though an individual invocation may fail
     * with an {@link omero.ResourceError} for some reason)
     * <em>or</em> this is a user script, and a usermode processor
     * must be active which takes the scripts user or group.
     * </p>
     * 
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_canRunScript(long scriptID, java.util.Map<String, String> __ctx);

    /**
     * Returns true if there is a processor which will run the
     * given script.
     * 
     * <p>
     * Either the script is an official script and this method
     * will return true (though an individual invocation may fail
     * with an {@link omero.ResourceError} for some reason)
     * <em>or</em> this is a user script, and a usermode processor
     * must be active which takes the scripts user or group.
     * </p>
     * 
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_canRunScript(long scriptID, Ice.Callback __cb);

    /**
     * Returns true if there is a processor which will run the
     * given script.
     * 
     * <p>
     * Either the script is an official script and this method
     * will return true (though an individual invocation may fail
     * with an {@link omero.ResourceError} for some reason)
     * <em>or</em> this is a user script, and a usermode processor
     * must be active which takes the scripts user or group.
     * </p>
     * 
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_canRunScript(long scriptID, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Returns true if there is a processor which will run the
     * given script.
     * 
     * <p>
     * Either the script is an official script and this method
     * will return true (though an individual invocation may fail
     * with an {@link omero.ResourceError} for some reason)
     * <em>or</em> this is a user script, and a usermode processor
     * must be active which takes the scripts user or group.
     * </p>
     * 
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_canRunScript(long scriptID, Callback_IScript_canRunScript __cb);

    /**
     * Returns true if there is a processor which will run the
     * given script.
     * 
     * <p>
     * Either the script is an official script and this method
     * will return true (though an individual invocation may fail
     * with an {@link omero.ResourceError} for some reason)
     * <em>or</em> this is a user script, and a usermode processor
     * must be active which takes the scripts user or group.
     * </p>
     * 
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_canRunScript(long scriptID, java.util.Map<String, String> __ctx, Callback_IScript_canRunScript __cb);

    /**
     * Returns true if there is a processor which will run the
     * given script.
     * 
     * <p>
     * Either the script is an official script and this method
     * will return true (though an individual invocation may fail
     * with an {@link omero.ResourceError} for some reason)
     * <em>or</em> this is a user script, and a usermode processor
     * must be active which takes the scripts user or group.
     * </p>
     * 
     * @param __result The asynchronous result object.
     **/
    public boolean end_canRunScript(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Returns true if there is a processor which will run the
     * given script.
     * 
     * <p>
     * Either the script is an official script and this method
     * will return true (though an individual invocation may fail
     * with an {@link omero.ResourceError} for some reason)
     * <em>or</em> this is a user script, and a usermode processor
     * must be active which takes the scripts user or group.
     * </p>
     * 
     * @param __cb The callback object for the operation.
     **/
    public boolean canRunScript_async(AMI_IScript_canRunScript __cb, long scriptID);

    /**
     * Returns true if there is a processor which will run the
     * given script.
     * 
     * <p>
     * Either the script is an official script and this method
     * will return true (though an individual invocation may fail
     * with an {@link omero.ResourceError} for some reason)
     * <em>or</em> this is a user script, and a usermode processor
     * must be active which takes the scripts user or group.
     * </p>
     * 
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean canRunScript_async(AMI_IScript_canRunScript __cb, long scriptID, java.util.Map<String, String> __ctx);

    /**
     * Used internally by processor.py to check if the script
     * attached to the {@link omero.model.Job} has a valid script
     * attached, based on the {@link #acceptsList} and the current
     * security context.
     * 
     * An example of an acceptsList might be <pre>Experimenter(myUserId, False)</pre>, meaning that
     * only scripts belonging to me should be trusted. An empty list implies that the server should
     * return what it would by default trust.
     * 
     * A valid script will be returned if it exists; otherwise null.
     **/
    public omero.model.OriginalFile validateScript(omero.model.Job j, java.util.List<omero.model.IObject> acceptsList)
        throws omero.ServerError;

    /**
     * Used internally by processor.py to check if the script
     * attached to the {@link omero.model.Job} has a valid script
     * attached, based on the {@link #acceptsList} and the current
     * security context.
     * 
     * An example of an acceptsList might be <pre>Experimenter(myUserId, False)</pre>, meaning that
     * only scripts belonging to me should be trusted. An empty list implies that the server should
     * return what it would by default trust.
     * 
     * A valid script will be returned if it exists; otherwise null.
     * @param __ctx The Context map to send with the invocation.
     **/
    public omero.model.OriginalFile validateScript(omero.model.Job j, java.util.List<omero.model.IObject> acceptsList, java.util.Map<String, String> __ctx)
        throws omero.ServerError;

    /**
     * Used internally by processor.py to check if the script
     * attached to the {@link omero.model.Job} has a valid script
     * attached, based on the {@link #acceptsList} and the current
     * security context.
     * 
     * An example of an acceptsList might be <pre>Experimenter(myUserId, False)</pre>, meaning that
     * only scripts belonging to me should be trusted. An empty list implies that the server should
     * return what it would by default trust.
     * 
     * A valid script will be returned if it exists; otherwise null.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_validateScript(omero.model.Job j, java.util.List<omero.model.IObject> acceptsList);

    /**
     * Used internally by processor.py to check if the script
     * attached to the {@link omero.model.Job} has a valid script
     * attached, based on the {@link #acceptsList} and the current
     * security context.
     * 
     * An example of an acceptsList might be <pre>Experimenter(myUserId, False)</pre>, meaning that
     * only scripts belonging to me should be trusted. An empty list implies that the server should
     * return what it would by default trust.
     * 
     * A valid script will be returned if it exists; otherwise null.
     * @param __ctx The Context map to send with the invocation.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_validateScript(omero.model.Job j, java.util.List<omero.model.IObject> acceptsList, java.util.Map<String, String> __ctx);

    /**
     * Used internally by processor.py to check if the script
     * attached to the {@link omero.model.Job} has a valid script
     * attached, based on the {@link #acceptsList} and the current
     * security context.
     * 
     * An example of an acceptsList might be <pre>Experimenter(myUserId, False)</pre>, meaning that
     * only scripts belonging to me should be trusted. An empty list implies that the server should
     * return what it would by default trust.
     * 
     * A valid script will be returned if it exists; otherwise null.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_validateScript(omero.model.Job j, java.util.List<omero.model.IObject> acceptsList, Ice.Callback __cb);

    /**
     * Used internally by processor.py to check if the script
     * attached to the {@link omero.model.Job} has a valid script
     * attached, based on the {@link #acceptsList} and the current
     * security context.
     * 
     * An example of an acceptsList might be <pre>Experimenter(myUserId, False)</pre>, meaning that
     * only scripts belonging to me should be trusted. An empty list implies that the server should
     * return what it would by default trust.
     * 
     * A valid script will be returned if it exists; otherwise null.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_validateScript(omero.model.Job j, java.util.List<omero.model.IObject> acceptsList, java.util.Map<String, String> __ctx, Ice.Callback __cb);

    /**
     * Used internally by processor.py to check if the script
     * attached to the {@link omero.model.Job} has a valid script
     * attached, based on the {@link #acceptsList} and the current
     * security context.
     * 
     * An example of an acceptsList might be <pre>Experimenter(myUserId, False)</pre>, meaning that
     * only scripts belonging to me should be trusted. An empty list implies that the server should
     * return what it would by default trust.
     * 
     * A valid script will be returned if it exists; otherwise null.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_validateScript(omero.model.Job j, java.util.List<omero.model.IObject> acceptsList, Callback_IScript_validateScript __cb);

    /**
     * Used internally by processor.py to check if the script
     * attached to the {@link omero.model.Job} has a valid script
     * attached, based on the {@link #acceptsList} and the current
     * security context.
     * 
     * An example of an acceptsList might be <pre>Experimenter(myUserId, False)</pre>, meaning that
     * only scripts belonging to me should be trusted. An empty list implies that the server should
     * return what it would by default trust.
     * 
     * A valid script will be returned if it exists; otherwise null.
     * @param __ctx The Context map to send with the invocation.
     * @param __cb The asynchronous callback object.
     * @return The asynchronous result object.
     **/
    public Ice.AsyncResult begin_validateScript(omero.model.Job j, java.util.List<omero.model.IObject> acceptsList, java.util.Map<String, String> __ctx, Callback_IScript_validateScript __cb);

    /**
     * Used internally by processor.py to check if the script
     * attached to the {@link omero.model.Job} has a valid script
     * attached, based on the {@link #acceptsList} and the current
     * security context.
     * 
     * An example of an acceptsList might be <pre>Experimenter(myUserId, False)</pre>, meaning that
     * only scripts belonging to me should be trusted. An empty list implies that the server should
     * return what it would by default trust.
     * 
     * A valid script will be returned if it exists; otherwise null.
     * @param __result The asynchronous result object.
     **/
    public omero.model.OriginalFile end_validateScript(Ice.AsyncResult __result)
        throws omero.ServerError;

    /**
     * Used internally by processor.py to check if the script
     * attached to the {@link omero.model.Job} has a valid script
     * attached, based on the {@link #acceptsList} and the current
     * security context.
     * 
     * An example of an acceptsList might be <pre>Experimenter(myUserId, False)</pre>, meaning that
     * only scripts belonging to me should be trusted. An empty list implies that the server should
     * return what it would by default trust.
     * 
     * A valid script will be returned if it exists; otherwise null.
     * @param __cb The callback object for the operation.
     **/
    public boolean validateScript_async(AMI_IScript_validateScript __cb, omero.model.Job j, java.util.List<omero.model.IObject> acceptsList);

    /**
     * Used internally by processor.py to check if the script
     * attached to the {@link omero.model.Job} has a valid script
     * attached, based on the {@link #acceptsList} and the current
     * security context.
     * 
     * An example of an acceptsList might be <pre>Experimenter(myUserId, False)</pre>, meaning that
     * only scripts belonging to me should be trusted. An empty list implies that the server should
     * return what it would by default trust.
     * 
     * A valid script will be returned if it exists; otherwise null.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean validateScript_async(AMI_IScript_validateScript __cb, omero.model.Job j, java.util.List<omero.model.IObject> acceptsList, java.util.Map<String, String> __ctx);
}
