// **********************************************************************
//
// Copyright (c) 2003-2013 ZeroC, Inc. All rights reserved.
//
// This copy of Ice is licensed to you under the terms described in the
// ICE_LICENSE file included in this distribution.
//
// **********************************************************************
//
// Ice version 3.5.1
//
// <auto-generated>
//
// Generated from file `IScript.ice'
//
// Warning: do not edit this file.
//
// </auto-generated>
//

package omero.api;

/**
 * Utility service for managing and launching scripts for execution by the Processor API.
 * 
 * Typical usage might include (PYTHON):
 * <pre>
 * 
 * sf = client.createSession()
 * svc = sf.getScriptService()
 * scripts = svc.getScripts()
 * 
 * if len(scripts) >= 1:
 * script_id = svc.keys()\[-1]
 * else:
 * script_id = svc.uploadScript('/test/my_script.py', SCRIPT_TEXT)
 * 
 * params = svc.getParams(script_id)
 * 
 * # You will need to parse the params to create the proper input
 * inputs = {}
 * 
 * # The last parameter is how long to wait as an RInt
 * proc = svc.runScript(script_id, inputs, None)
 * try:
 * cb = omero.scripts.ProcessCallbackI(client, proc)
 * while not cb.block(1000): # ms.
 * pass
 * cb.close()
 * rv = proc.getResults(0)
 * finally:
 * proc.close(False)
 * 
 * </pre>
 * See <a href="http://www.openmicroscopy.org/site/support/omero5.2/developers/scripts/">OMERO.scripts</a> for more information.
 **/
public final class IScriptPrxHelper extends Ice.ObjectPrxHelperBase implements IScriptPrx
{
    private static final String __canRunScript_name = "canRunScript";

    /**
     * Returns true if there is a processor which will run the
     * given script.
     * 
     * <p>
     * Either the script is an official script and this method
     * will return true (though an individual invocation may fail
     * with an {@link omero.ResourceError} for some reason)
     * <em>or</em> this is a user script, and a usermode processor
     * must be active which takes the scripts user or group.
     * </p>
     * 
     **/
    public boolean canRunScript(long scriptID)
        throws omero.ServerError
    {
        return canRunScript(scriptID, null, false);
    }

    /**
     * Returns true if there is a processor which will run the
     * given script.
     * 
     * <p>
     * Either the script is an official script and this method
     * will return true (though an individual invocation may fail
     * with an {@link omero.ResourceError} for some reason)
     * <em>or</em> this is a user script, and a usermode processor
     * must be active which takes the scripts user or group.
     * </p>
     * 
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean canRunScript(long scriptID, java.util.Map<String, String> __ctx)
        throws omero.ServerError
    {
        return canRunScript(scriptID, __ctx, true);
    }

    private boolean canRunScript(long scriptID, java.util.Map<String, String> __ctx, boolean __explicitCtx)
        throws omero.ServerError
    {
        if(__explicitCtx && __ctx == null)
        {
            __ctx = _emptyContext;
        }
        final Ice.Instrumentation.InvocationObserver __observer = IceInternal.ObserverHelper.get(this, "canRunScript", __ctx);
        int __cnt = 0;
        try
        {
            while(true)
            {
                Ice._ObjectDel __delBase = null;
                try
                {
                    __checkTwowayOnly("canRunScript");
                    __delBase = __getDelegate(false);
                    _IScriptDel __del = (_IScriptDel)__delBase;
                    return __del.canRunScript(scriptID, __ctx, __observer);
                }
                catch(IceInternal.LocalExceptionWrapper __ex)
                {
                    __cnt = __handleExceptionWrapperRelaxed(__delBase, __ex, null, __cnt, __observer);
                }
                catch(Ice.LocalException __ex)
                {
                    __cnt = __handleException(__delBase, __ex, null, __cnt, __observer);
                }
            }
        }
        finally
        {
            if(__observer != null)
            {
                __observer.detach();
            }
        }
    }

    /**
     * Returns true if there is a processor which will run the
     * given script.
     * 
     * <p>
     * Either the script is an official script and this method
     * will return true (though an individual invocation may fail
     * with an {@link omero.ResourceError} for some reason)
     * <em>or</em> this is a user script, and a usermode processor
     * must be active which takes the scripts user or group.
     * </p>
     * 
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_canRunScript(long scriptID)
    {
        return begin_canRunScript(scriptID, null, false, null);
    }

    /**
     * Returns true if there is a processor which will run the
     * given script.
     * 
     * <p>
     * Either the script is an official script and this method
     * will return true (though an individual invocation may fail
     * with an {@link omero.ResourceError} for some reason)
     * <em>or</em> this is a user script, and a usermode processor
     * must be active which takes the scripts user or group.
     * </p>
     * 
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_canRunScript(long scriptID, java.util.Map<String, String> __ctx)
    {
        return begin_canRunScript(scriptID, __ctx, true, null);
    }

    /**
     * Returns true if there is a processor which will run the
     * given script.
     * 
     * <p>
     * Either the script is an official script and this method
     * will return true (though an individual invocation may fail
     * with an {@link omero.ResourceError} for some reason)
     * <em>or</em> this is a user script, and a usermode processor
     * must be active which takes the scripts user or group.
     * </p>
     * 
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_canRunScript(long scriptID, Ice.Callback __cb)
    {
        return begin_canRunScript(scriptID, null, false, __cb);
    }

    /**
     * Returns true if there is a processor which will run the
     * given script.
     * 
     * <p>
     * Either the script is an official script and this method
     * will return true (though an individual invocation may fail
     * with an {@link omero.ResourceError} for some reason)
     * <em>or</em> this is a user script, and a usermode processor
     * must be active which takes the scripts user or group.
     * </p>
     * 
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_canRunScript(long scriptID, java.util.Map<String, String> __ctx, Ice.Callback __cb)
    {
        return begin_canRunScript(scriptID, __ctx, true, __cb);
    }

    /**
     * Returns true if there is a processor which will run the
     * given script.
     * 
     * <p>
     * Either the script is an official script and this method
     * will return true (though an individual invocation may fail
     * with an {@link omero.ResourceError} for some reason)
     * <em>or</em> this is a user script, and a usermode processor
     * must be active which takes the scripts user or group.
     * </p>
     * 
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_canRunScript(long scriptID, Callback_IScript_canRunScript __cb)
    {
        return begin_canRunScript(scriptID, null, false, __cb);
    }

    /**
     * Returns true if there is a processor which will run the
     * given script.
     * 
     * <p>
     * Either the script is an official script and this method
     * will return true (though an individual invocation may fail
     * with an {@link omero.ResourceError} for some reason)
     * <em>or</em> this is a user script, and a usermode processor
     * must be active which takes the scripts user or group.
     * </p>
     * 
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_canRunScript(long scriptID, java.util.Map<String, String> __ctx, Callback_IScript_canRunScript __cb)
    {
        return begin_canRunScript(scriptID, __ctx, true, __cb);
    }

    private Ice.AsyncResult begin_canRunScript(long scriptID, java.util.Map<String, String> __ctx, boolean __explicitCtx, IceInternal.CallbackBase __cb)
    {
        __checkAsyncTwowayOnly(__canRunScript_name);
        IceInternal.OutgoingAsync __result = new IceInternal.OutgoingAsync(this, __canRunScript_name, __cb);
        try
        {
            __result.__prepare(__canRunScript_name, Ice.OperationMode.Idempotent, __ctx, __explicitCtx);
            IceInternal.BasicStream __os = __result.__startWriteParams(Ice.FormatType.DefaultFormat);
            __os.writeLong(scriptID);
            __result.__endWriteParams();
            __result.__send(true);
        }
        catch(Ice.LocalException __ex)
        {
            __result.__exceptionAsync(__ex);
        }
        return __result;
    }

    /**
     * ice_response indicates that
     * the operation completed successfully.
     **/
    public boolean end_canRunScript(Ice.AsyncResult __result)
        throws omero.ServerError
    {
        Ice.AsyncResult.__check(__result, this, __canRunScript_name);
        boolean __ok = __result.__wait();
        try
        {
            if(!__ok)
            {
                try
                {
                    __result.__throwUserException();
                }
                catch(omero.ServerError __ex)
                {
                    throw __ex;
                }
                catch(Ice.UserException __ex)
                {
                    throw new Ice.UnknownUserException(__ex.ice_name(), __ex);
                }
            }
            IceInternal.BasicStream __is = __result.__startReadParams();
            boolean __ret;
            __ret = __is.readBool();
            __result.__endReadParams();
            return __ret;
        }
        catch(Ice.LocalException ex)
        {
            Ice.Instrumentation.InvocationObserver __obsv = __result.__getObserver();
            if(__obsv != null)
            {
                __obsv.failed(ex.ice_name());
            }
            throw ex;
        }
    }

    /**
     * Returns true if there is a processor which will run the
     * given script.
     * 
     * <p>
     * Either the script is an official script and this method
     * will return true (though an individual invocation may fail
     * with an {@link omero.ResourceError} for some reason)
     * <em>or</em> this is a user script, and a usermode processor
     * must be active which takes the scripts user or group.
     * </p>
     * 
     * @param __cb The callback object for the operation.
     **/
    public boolean canRunScript_async(AMI_IScript_canRunScript __cb, long scriptID)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__canRunScript_name);
            __r = begin_canRunScript(scriptID, null, false, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __canRunScript_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    /**
     * Returns true if there is a processor which will run the
     * given script.
     * 
     * <p>
     * Either the script is an official script and this method
     * will return true (though an individual invocation may fail
     * with an {@link omero.ResourceError} for some reason)
     * <em>or</em> this is a user script, and a usermode processor
     * must be active which takes the scripts user or group.
     * </p>
     * 
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean canRunScript_async(AMI_IScript_canRunScript __cb, long scriptID, java.util.Map<String, String> __ctx)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__canRunScript_name);
            __r = begin_canRunScript(scriptID, __ctx, true, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __canRunScript_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    private static final String __deleteScript_name = "deleteScript";

    /**
     * Delete the script on the server with id. The file will also be removed from disk.
     * 
     * @param scriptID Id of the script to delete.
     * @throws ApiUsageException
     * @throws SecurityViolation
     **/
    public void deleteScript(long scriptID)
        throws omero.ServerError
    {
        deleteScript(scriptID, null, false);
    }

    /**
     * Delete the script on the server with id. The file will also be removed from disk.
     * 
     * @param scriptID Id of the script to delete.
     * @throws ApiUsageException
     * @throws SecurityViolation
     * @param __ctx The Context map to send with the invocation.
     **/
    public void deleteScript(long scriptID, java.util.Map<String, String> __ctx)
        throws omero.ServerError
    {
        deleteScript(scriptID, __ctx, true);
    }

    private void deleteScript(long scriptID, java.util.Map<String, String> __ctx, boolean __explicitCtx)
        throws omero.ServerError
    {
        if(__explicitCtx && __ctx == null)
        {
            __ctx = _emptyContext;
        }
        final Ice.Instrumentation.InvocationObserver __observer = IceInternal.ObserverHelper.get(this, "deleteScript", __ctx);
        int __cnt = 0;
        try
        {
            while(true)
            {
                Ice._ObjectDel __delBase = null;
                try
                {
                    __checkTwowayOnly("deleteScript");
                    __delBase = __getDelegate(false);
                    _IScriptDel __del = (_IScriptDel)__delBase;
                    __del.deleteScript(scriptID, __ctx, __observer);
                    return;
                }
                catch(IceInternal.LocalExceptionWrapper __ex)
                {
                    __handleExceptionWrapper(__delBase, __ex, __observer);
                }
                catch(Ice.LocalException __ex)
                {
                    __cnt = __handleException(__delBase, __ex, null, __cnt, __observer);
                }
            }
        }
        finally
        {
            if(__observer != null)
            {
                __observer.detach();
            }
        }
    }

    /**
     * Delete the script on the server with id. The file will also be removed from disk.
     * 
     * @param __cb The callback object for the operation.
     * @param scriptID Id of the script to delete.
     **/
    public Ice.AsyncResult begin_deleteScript(long scriptID)
    {
        return begin_deleteScript(scriptID, null, false, null);
    }

    /**
     * Delete the script on the server with id. The file will also be removed from disk.
     * 
     * @param __cb The callback object for the operation.
     * @param scriptID Id of the script to delete.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_deleteScript(long scriptID, java.util.Map<String, String> __ctx)
    {
        return begin_deleteScript(scriptID, __ctx, true, null);
    }

    /**
     * Delete the script on the server with id. The file will also be removed from disk.
     * 
     * @param __cb The callback object for the operation.
     * @param scriptID Id of the script to delete.
     **/
    public Ice.AsyncResult begin_deleteScript(long scriptID, Ice.Callback __cb)
    {
        return begin_deleteScript(scriptID, null, false, __cb);
    }

    /**
     * Delete the script on the server with id. The file will also be removed from disk.
     * 
     * @param __cb The callback object for the operation.
     * @param scriptID Id of the script to delete.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_deleteScript(long scriptID, java.util.Map<String, String> __ctx, Ice.Callback __cb)
    {
        return begin_deleteScript(scriptID, __ctx, true, __cb);
    }

    /**
     * Delete the script on the server with id. The file will also be removed from disk.
     * 
     * @param __cb The callback object for the operation.
     * @param scriptID Id of the script to delete.
     **/
    public Ice.AsyncResult begin_deleteScript(long scriptID, Callback_IScript_deleteScript __cb)
    {
        return begin_deleteScript(scriptID, null, false, __cb);
    }

    /**
     * Delete the script on the server with id. The file will also be removed from disk.
     * 
     * @param __cb The callback object for the operation.
     * @param scriptID Id of the script to delete.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_deleteScript(long scriptID, java.util.Map<String, String> __ctx, Callback_IScript_deleteScript __cb)
    {
        return begin_deleteScript(scriptID, __ctx, true, __cb);
    }

    private Ice.AsyncResult begin_deleteScript(long scriptID, java.util.Map<String, String> __ctx, boolean __explicitCtx, IceInternal.CallbackBase __cb)
    {
        __checkAsyncTwowayOnly(__deleteScript_name);
        IceInternal.OutgoingAsync __result = new IceInternal.OutgoingAsync(this, __deleteScript_name, __cb);
        try
        {
            __result.__prepare(__deleteScript_name, Ice.OperationMode.Normal, __ctx, __explicitCtx);
            IceInternal.BasicStream __os = __result.__startWriteParams(Ice.FormatType.DefaultFormat);
            __os.writeLong(scriptID);
            __result.__endWriteParams();
            __result.__send(true);
        }
        catch(Ice.LocalException __ex)
        {
            __result.__exceptionAsync(__ex);
        }
        return __result;
    }

    /**
     * ice_response indicates that
     * the operation completed successfully.
     **/
    public void end_deleteScript(Ice.AsyncResult __result)
        throws omero.ServerError
    {
        Ice.AsyncResult.__check(__result, this, __deleteScript_name);
        boolean __ok = __result.__wait();
        try
        {
            if(!__ok)
            {
                try
                {
                    __result.__throwUserException();
                }
                catch(omero.ServerError __ex)
                {
                    throw __ex;
                }
                catch(Ice.UserException __ex)
                {
                    throw new Ice.UnknownUserException(__ex.ice_name(), __ex);
                }
            }
            __result.__readEmptyParams();
        }
        catch(Ice.LocalException ex)
        {
            Ice.Instrumentation.InvocationObserver __obsv = __result.__getObserver();
            if(__obsv != null)
            {
                __obsv.failed(ex.ice_name());
            }
            throw ex;
        }
    }

    /**
     * Delete the script on the server with id. The file will also be removed from disk.
     * 
     * @param __cb The callback object for the operation.
     * @param scriptID Id of the script to delete.
     **/
    public boolean deleteScript_async(AMI_IScript_deleteScript __cb, long scriptID)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__deleteScript_name);
            __r = begin_deleteScript(scriptID, null, false, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __deleteScript_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    /**
     * Delete the script on the server with id. The file will also be removed from disk.
     * 
     * @param __cb The callback object for the operation.
     * @param scriptID Id of the script to delete.
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean deleteScript_async(AMI_IScript_deleteScript __cb, long scriptID, java.util.Map<String, String> __ctx)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__deleteScript_name);
            __r = begin_deleteScript(scriptID, __ctx, true, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __deleteScript_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    private static final String __editScript_name = "editScript";

    /**
     * Modify the text for the given script object.
     * 
     * @param script see above.
     * @throws ApiUsageException
     * @throws SecurityViolation
     **/
    public void editScript(omero.model.OriginalFile fileObject, String scriptText)
        throws omero.ServerError
    {
        editScript(fileObject, scriptText, null, false);
    }

    /**
     * Modify the text for the given script object.
     * 
     * @param script see above.
     * @throws ApiUsageException
     * @throws SecurityViolation
     * @param __ctx The Context map to send with the invocation.
     **/
    public void editScript(omero.model.OriginalFile fileObject, String scriptText, java.util.Map<String, String> __ctx)
        throws omero.ServerError
    {
        editScript(fileObject, scriptText, __ctx, true);
    }

    private void editScript(omero.model.OriginalFile fileObject, String scriptText, java.util.Map<String, String> __ctx, boolean __explicitCtx)
        throws omero.ServerError
    {
        if(__explicitCtx && __ctx == null)
        {
            __ctx = _emptyContext;
        }
        final Ice.Instrumentation.InvocationObserver __observer = IceInternal.ObserverHelper.get(this, "editScript", __ctx);
        int __cnt = 0;
        try
        {
            while(true)
            {
                Ice._ObjectDel __delBase = null;
                try
                {
                    __checkTwowayOnly("editScript");
                    __delBase = __getDelegate(false);
                    _IScriptDel __del = (_IScriptDel)__delBase;
                    __del.editScript(fileObject, scriptText, __ctx, __observer);
                    return;
                }
                catch(IceInternal.LocalExceptionWrapper __ex)
                {
                    __handleExceptionWrapper(__delBase, __ex, __observer);
                }
                catch(Ice.LocalException __ex)
                {
                    __cnt = __handleException(__delBase, __ex, null, __cnt, __observer);
                }
            }
        }
        finally
        {
            if(__observer != null)
            {
                __observer.detach();
            }
        }
    }

    /**
     * Modify the text for the given script object.
     * 
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_editScript(omero.model.OriginalFile fileObject, String scriptText)
    {
        return begin_editScript(fileObject, scriptText, null, false, null);
    }

    /**
     * Modify the text for the given script object.
     * 
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_editScript(omero.model.OriginalFile fileObject, String scriptText, java.util.Map<String, String> __ctx)
    {
        return begin_editScript(fileObject, scriptText, __ctx, true, null);
    }

    /**
     * Modify the text for the given script object.
     * 
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_editScript(omero.model.OriginalFile fileObject, String scriptText, Ice.Callback __cb)
    {
        return begin_editScript(fileObject, scriptText, null, false, __cb);
    }

    /**
     * Modify the text for the given script object.
     * 
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_editScript(omero.model.OriginalFile fileObject, String scriptText, java.util.Map<String, String> __ctx, Ice.Callback __cb)
    {
        return begin_editScript(fileObject, scriptText, __ctx, true, __cb);
    }

    /**
     * Modify the text for the given script object.
     * 
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_editScript(omero.model.OriginalFile fileObject, String scriptText, Callback_IScript_editScript __cb)
    {
        return begin_editScript(fileObject, scriptText, null, false, __cb);
    }

    /**
     * Modify the text for the given script object.
     * 
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_editScript(omero.model.OriginalFile fileObject, String scriptText, java.util.Map<String, String> __ctx, Callback_IScript_editScript __cb)
    {
        return begin_editScript(fileObject, scriptText, __ctx, true, __cb);
    }

    private Ice.AsyncResult begin_editScript(omero.model.OriginalFile fileObject, String scriptText, java.util.Map<String, String> __ctx, boolean __explicitCtx, IceInternal.CallbackBase __cb)
    {
        __checkAsyncTwowayOnly(__editScript_name);
        IceInternal.OutgoingAsync __result = new IceInternal.OutgoingAsync(this, __editScript_name, __cb);
        try
        {
            __result.__prepare(__editScript_name, Ice.OperationMode.Normal, __ctx, __explicitCtx);
            IceInternal.BasicStream __os = __result.__startWriteParams(Ice.FormatType.DefaultFormat);
            __os.writeObject(fileObject);
            __os.writeString(scriptText);
            __os.writePendingObjects();
            __result.__endWriteParams();
            __result.__send(true);
        }
        catch(Ice.LocalException __ex)
        {
            __result.__exceptionAsync(__ex);
        }
        return __result;
    }

    /**
     * ice_response indicates that
     * the operation completed successfully.
     **/
    public void end_editScript(Ice.AsyncResult __result)
        throws omero.ServerError
    {
        Ice.AsyncResult.__check(__result, this, __editScript_name);
        boolean __ok = __result.__wait();
        try
        {
            if(!__ok)
            {
                try
                {
                    __result.__throwUserException();
                }
                catch(omero.ServerError __ex)
                {
                    throw __ex;
                }
                catch(Ice.UserException __ex)
                {
                    throw new Ice.UnknownUserException(__ex.ice_name(), __ex);
                }
            }
            __result.__readEmptyParams();
        }
        catch(Ice.LocalException ex)
        {
            Ice.Instrumentation.InvocationObserver __obsv = __result.__getObserver();
            if(__obsv != null)
            {
                __obsv.failed(ex.ice_name());
            }
            throw ex;
        }
    }

    /**
     * Modify the text for the given script object.
     * 
     * @param __cb The callback object for the operation.
     **/
    public boolean editScript_async(AMI_IScript_editScript __cb, omero.model.OriginalFile fileObject, String scriptText)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__editScript_name);
            __r = begin_editScript(fileObject, scriptText, null, false, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __editScript_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    /**
     * Modify the text for the given script object.
     * 
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean editScript_async(AMI_IScript_editScript __cb, omero.model.OriginalFile fileObject, String scriptText, java.util.Map<String, String> __ctx)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__editScript_name);
            __r = begin_editScript(fileObject, scriptText, __ctx, true, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __editScript_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    private static final String __getParams_name = "getParams";

    /**
     * Get the parameters that the script takes and returns, along with
     * other metadata available from the script.
     * 
     * @param scriptID see above.
     * @return see above.
     * @throws ApiUsageException
     **/
    public omero.grid.JobParams getParams(long scriptID)
        throws omero.ServerError
    {
        return getParams(scriptID, null, false);
    }

    /**
     * Get the parameters that the script takes and returns, along with
     * other metadata available from the script.
     * 
     * @param scriptID see above.
     * @param __ctx The Context map to send with the invocation.
     * @return see above.
     * @throws ApiUsageException
     **/
    public omero.grid.JobParams getParams(long scriptID, java.util.Map<String, String> __ctx)
        throws omero.ServerError
    {
        return getParams(scriptID, __ctx, true);
    }

    private omero.grid.JobParams getParams(long scriptID, java.util.Map<String, String> __ctx, boolean __explicitCtx)
        throws omero.ServerError
    {
        if(__explicitCtx && __ctx == null)
        {
            __ctx = _emptyContext;
        }
        final Ice.Instrumentation.InvocationObserver __observer = IceInternal.ObserverHelper.get(this, "getParams", __ctx);
        int __cnt = 0;
        try
        {
            while(true)
            {
                Ice._ObjectDel __delBase = null;
                try
                {
                    __checkTwowayOnly("getParams");
                    __delBase = __getDelegate(false);
                    _IScriptDel __del = (_IScriptDel)__delBase;
                    return __del.getParams(scriptID, __ctx, __observer);
                }
                catch(IceInternal.LocalExceptionWrapper __ex)
                {
                    __cnt = __handleExceptionWrapperRelaxed(__delBase, __ex, null, __cnt, __observer);
                }
                catch(Ice.LocalException __ex)
                {
                    __cnt = __handleException(__delBase, __ex, null, __cnt, __observer);
                }
            }
        }
        finally
        {
            if(__observer != null)
            {
                __observer.detach();
            }
        }
    }

    /**
     * Get the parameters that the script takes and returns, along with
     * other metadata available from the script.
     * 
     * @param __cb The callback object for the operation.
     * @param scriptID see above.
     **/
    public Ice.AsyncResult begin_getParams(long scriptID)
    {
        return begin_getParams(scriptID, null, false, null);
    }

    /**
     * Get the parameters that the script takes and returns, along with
     * other metadata available from the script.
     * 
     * @param __cb The callback object for the operation.
     * @param scriptID see above.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_getParams(long scriptID, java.util.Map<String, String> __ctx)
    {
        return begin_getParams(scriptID, __ctx, true, null);
    }

    /**
     * Get the parameters that the script takes and returns, along with
     * other metadata available from the script.
     * 
     * @param __cb The callback object for the operation.
     * @param scriptID see above.
     **/
    public Ice.AsyncResult begin_getParams(long scriptID, Ice.Callback __cb)
    {
        return begin_getParams(scriptID, null, false, __cb);
    }

    /**
     * Get the parameters that the script takes and returns, along with
     * other metadata available from the script.
     * 
     * @param __cb The callback object for the operation.
     * @param scriptID see above.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_getParams(long scriptID, java.util.Map<String, String> __ctx, Ice.Callback __cb)
    {
        return begin_getParams(scriptID, __ctx, true, __cb);
    }

    /**
     * Get the parameters that the script takes and returns, along with
     * other metadata available from the script.
     * 
     * @param __cb The callback object for the operation.
     * @param scriptID see above.
     **/
    public Ice.AsyncResult begin_getParams(long scriptID, Callback_IScript_getParams __cb)
    {
        return begin_getParams(scriptID, null, false, __cb);
    }

    /**
     * Get the parameters that the script takes and returns, along with
     * other metadata available from the script.
     * 
     * @param __cb The callback object for the operation.
     * @param scriptID see above.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_getParams(long scriptID, java.util.Map<String, String> __ctx, Callback_IScript_getParams __cb)
    {
        return begin_getParams(scriptID, __ctx, true, __cb);
    }

    private Ice.AsyncResult begin_getParams(long scriptID, java.util.Map<String, String> __ctx, boolean __explicitCtx, IceInternal.CallbackBase __cb)
    {
        __checkAsyncTwowayOnly(__getParams_name);
        IceInternal.OutgoingAsync __result = new IceInternal.OutgoingAsync(this, __getParams_name, __cb);
        try
        {
            __result.__prepare(__getParams_name, Ice.OperationMode.Idempotent, __ctx, __explicitCtx);
            IceInternal.BasicStream __os = __result.__startWriteParams(Ice.FormatType.DefaultFormat);
            __os.writeLong(scriptID);
            __result.__endWriteParams();
            __result.__send(true);
        }
        catch(Ice.LocalException __ex)
        {
            __result.__exceptionAsync(__ex);
        }
        return __result;
    }

    /**
     * ice_response indicates that
     * the operation completed successfully.
     * @param __ret (return value) see above.
     **/
    public omero.grid.JobParams end_getParams(Ice.AsyncResult __result)
        throws omero.ServerError
    {
        Ice.AsyncResult.__check(__result, this, __getParams_name);
        boolean __ok = __result.__wait();
        try
        {
            if(!__ok)
            {
                try
                {
                    __result.__throwUserException();
                }
                catch(omero.ServerError __ex)
                {
                    throw __ex;
                }
                catch(Ice.UserException __ex)
                {
                    throw new Ice.UnknownUserException(__ex.ice_name(), __ex);
                }
            }
            IceInternal.BasicStream __is = __result.__startReadParams();
            omero.grid.JobParamsHolder __ret = new omero.grid.JobParamsHolder();
            __is.readObject(__ret);
            __is.readPendingObjects();
            __result.__endReadParams();
            return __ret.value;
        }
        catch(Ice.LocalException ex)
        {
            Ice.Instrumentation.InvocationObserver __obsv = __result.__getObserver();
            if(__obsv != null)
            {
                __obsv.failed(ex.ice_name());
            }
            throw ex;
        }
    }

    /**
     * Get the parameters that the script takes and returns, along with
     * other metadata available from the script.
     * 
     * @param __cb The callback object for the operation.
     * @param scriptID see above.
     **/
    public boolean getParams_async(AMI_IScript_getParams __cb, long scriptID)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__getParams_name);
            __r = begin_getParams(scriptID, null, false, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __getParams_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    /**
     * Get the parameters that the script takes and returns, along with
     * other metadata available from the script.
     * 
     * @param __cb The callback object for the operation.
     * @param scriptID see above.
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean getParams_async(AMI_IScript_getParams __cb, long scriptID, java.util.Map<String, String> __ctx)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__getParams_name);
            __r = begin_getParams(scriptID, __ctx, true, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __getParams_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    private static final String __getScriptID_name = "getScriptID";

    /**
     * Get the id of an official script by the script path.
     * The script service ensures that all script paths are unique.
     * 
     * Note: there is no similar method for user scripts (e.g. getUserScriptID)
     * since the path is not guaranteed to be unique.
     * 
     * @param scriptName The name of the script.
     * @return see above.
     * @throws ApiUsageException
     * @throws SecurityViolation
     **/
    public long getScriptID(String path)
        throws omero.ServerError
    {
        return getScriptID(path, null, false);
    }

    /**
     * Get the id of an official script by the script path.
     * The script service ensures that all script paths are unique.
     * 
     * Note: there is no similar method for user scripts (e.g. getUserScriptID)
     * since the path is not guaranteed to be unique.
     * 
     * @param scriptName The name of the script.
     * @param __ctx The Context map to send with the invocation.
     * @return see above.
     * @throws ApiUsageException
     * @throws SecurityViolation
     **/
    public long getScriptID(String path, java.util.Map<String, String> __ctx)
        throws omero.ServerError
    {
        return getScriptID(path, __ctx, true);
    }

    private long getScriptID(String path, java.util.Map<String, String> __ctx, boolean __explicitCtx)
        throws omero.ServerError
    {
        if(__explicitCtx && __ctx == null)
        {
            __ctx = _emptyContext;
        }
        final Ice.Instrumentation.InvocationObserver __observer = IceInternal.ObserverHelper.get(this, "getScriptID", __ctx);
        int __cnt = 0;
        try
        {
            while(true)
            {
                Ice._ObjectDel __delBase = null;
                try
                {
                    __checkTwowayOnly("getScriptID");
                    __delBase = __getDelegate(false);
                    _IScriptDel __del = (_IScriptDel)__delBase;
                    return __del.getScriptID(path, __ctx, __observer);
                }
                catch(IceInternal.LocalExceptionWrapper __ex)
                {
                    __cnt = __handleExceptionWrapperRelaxed(__delBase, __ex, null, __cnt, __observer);
                }
                catch(Ice.LocalException __ex)
                {
                    __cnt = __handleException(__delBase, __ex, null, __cnt, __observer);
                }
            }
        }
        finally
        {
            if(__observer != null)
            {
                __observer.detach();
            }
        }
    }

    /**
     * Get the id of an official script by the script path.
     * The script service ensures that all script paths are unique.
     * 
     * Note: there is no similar method for user scripts (e.g. getUserScriptID)
     * since the path is not guaranteed to be unique.
     * 
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_getScriptID(String path)
    {
        return begin_getScriptID(path, null, false, null);
    }

    /**
     * Get the id of an official script by the script path.
     * The script service ensures that all script paths are unique.
     * 
     * Note: there is no similar method for user scripts (e.g. getUserScriptID)
     * since the path is not guaranteed to be unique.
     * 
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_getScriptID(String path, java.util.Map<String, String> __ctx)
    {
        return begin_getScriptID(path, __ctx, true, null);
    }

    /**
     * Get the id of an official script by the script path.
     * The script service ensures that all script paths are unique.
     * 
     * Note: there is no similar method for user scripts (e.g. getUserScriptID)
     * since the path is not guaranteed to be unique.
     * 
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_getScriptID(String path, Ice.Callback __cb)
    {
        return begin_getScriptID(path, null, false, __cb);
    }

    /**
     * Get the id of an official script by the script path.
     * The script service ensures that all script paths are unique.
     * 
     * Note: there is no similar method for user scripts (e.g. getUserScriptID)
     * since the path is not guaranteed to be unique.
     * 
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_getScriptID(String path, java.util.Map<String, String> __ctx, Ice.Callback __cb)
    {
        return begin_getScriptID(path, __ctx, true, __cb);
    }

    /**
     * Get the id of an official script by the script path.
     * The script service ensures that all script paths are unique.
     * 
     * Note: there is no similar method for user scripts (e.g. getUserScriptID)
     * since the path is not guaranteed to be unique.
     * 
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_getScriptID(String path, Callback_IScript_getScriptID __cb)
    {
        return begin_getScriptID(path, null, false, __cb);
    }

    /**
     * Get the id of an official script by the script path.
     * The script service ensures that all script paths are unique.
     * 
     * Note: there is no similar method for user scripts (e.g. getUserScriptID)
     * since the path is not guaranteed to be unique.
     * 
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_getScriptID(String path, java.util.Map<String, String> __ctx, Callback_IScript_getScriptID __cb)
    {
        return begin_getScriptID(path, __ctx, true, __cb);
    }

    private Ice.AsyncResult begin_getScriptID(String path, java.util.Map<String, String> __ctx, boolean __explicitCtx, IceInternal.CallbackBase __cb)
    {
        __checkAsyncTwowayOnly(__getScriptID_name);
        IceInternal.OutgoingAsync __result = new IceInternal.OutgoingAsync(this, __getScriptID_name, __cb);
        try
        {
            __result.__prepare(__getScriptID_name, Ice.OperationMode.Idempotent, __ctx, __explicitCtx);
            IceInternal.BasicStream __os = __result.__startWriteParams(Ice.FormatType.DefaultFormat);
            __os.writeString(path);
            __result.__endWriteParams();
            __result.__send(true);
        }
        catch(Ice.LocalException __ex)
        {
            __result.__exceptionAsync(__ex);
        }
        return __result;
    }

    /**
     * ice_response indicates that
     * the operation completed successfully.
     * @param __ret (return value) see above.
     **/
    public long end_getScriptID(Ice.AsyncResult __result)
        throws omero.ServerError
    {
        Ice.AsyncResult.__check(__result, this, __getScriptID_name);
        boolean __ok = __result.__wait();
        try
        {
            if(!__ok)
            {
                try
                {
                    __result.__throwUserException();
                }
                catch(omero.ServerError __ex)
                {
                    throw __ex;
                }
                catch(Ice.UserException __ex)
                {
                    throw new Ice.UnknownUserException(__ex.ice_name(), __ex);
                }
            }
            IceInternal.BasicStream __is = __result.__startReadParams();
            long __ret;
            __ret = __is.readLong();
            __result.__endReadParams();
            return __ret;
        }
        catch(Ice.LocalException ex)
        {
            Ice.Instrumentation.InvocationObserver __obsv = __result.__getObserver();
            if(__obsv != null)
            {
                __obsv.failed(ex.ice_name());
            }
            throw ex;
        }
    }

    /**
     * Get the id of an official script by the script path.
     * The script service ensures that all script paths are unique.
     * 
     * Note: there is no similar method for user scripts (e.g. getUserScriptID)
     * since the path is not guaranteed to be unique.
     * 
     * @param __cb The callback object for the operation.
     **/
    public boolean getScriptID_async(AMI_IScript_getScriptID __cb, String path)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__getScriptID_name);
            __r = begin_getScriptID(path, null, false, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __getScriptID_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    /**
     * Get the id of an official script by the script path.
     * The script service ensures that all script paths are unique.
     * 
     * Note: there is no similar method for user scripts (e.g. getUserScriptID)
     * since the path is not guaranteed to be unique.
     * 
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean getScriptID_async(AMI_IScript_getScriptID __cb, String path, java.util.Map<String, String> __ctx)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__getScriptID_name);
            __r = begin_getScriptID(path, __ctx, true, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __getScriptID_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    private static final String __getScriptText_name = "getScriptText";

    /**
     * Get the text from the server for the script with given id.
     * 
     * @param scriptID see above.
     * @return see above.
     * @throws ApiUsageException
     **/
    public String getScriptText(long scriptID)
        throws omero.ServerError
    {
        return getScriptText(scriptID, null, false);
    }

    /**
     * Get the text from the server for the script with given id.
     * 
     * @param scriptID see above.
     * @param __ctx The Context map to send with the invocation.
     * @return see above.
     * @throws ApiUsageException
     **/
    public String getScriptText(long scriptID, java.util.Map<String, String> __ctx)
        throws omero.ServerError
    {
        return getScriptText(scriptID, __ctx, true);
    }

    private String getScriptText(long scriptID, java.util.Map<String, String> __ctx, boolean __explicitCtx)
        throws omero.ServerError
    {
        if(__explicitCtx && __ctx == null)
        {
            __ctx = _emptyContext;
        }
        final Ice.Instrumentation.InvocationObserver __observer = IceInternal.ObserverHelper.get(this, "getScriptText", __ctx);
        int __cnt = 0;
        try
        {
            while(true)
            {
                Ice._ObjectDel __delBase = null;
                try
                {
                    __checkTwowayOnly("getScriptText");
                    __delBase = __getDelegate(false);
                    _IScriptDel __del = (_IScriptDel)__delBase;
                    return __del.getScriptText(scriptID, __ctx, __observer);
                }
                catch(IceInternal.LocalExceptionWrapper __ex)
                {
                    __cnt = __handleExceptionWrapperRelaxed(__delBase, __ex, null, __cnt, __observer);
                }
                catch(Ice.LocalException __ex)
                {
                    __cnt = __handleException(__delBase, __ex, null, __cnt, __observer);
                }
            }
        }
        finally
        {
            if(__observer != null)
            {
                __observer.detach();
            }
        }
    }

    /**
     * Get the text from the server for the script with given id.
     * 
     * @param __cb The callback object for the operation.
     * @param scriptID see above.
     **/
    public Ice.AsyncResult begin_getScriptText(long scriptID)
    {
        return begin_getScriptText(scriptID, null, false, null);
    }

    /**
     * Get the text from the server for the script with given id.
     * 
     * @param __cb The callback object for the operation.
     * @param scriptID see above.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_getScriptText(long scriptID, java.util.Map<String, String> __ctx)
    {
        return begin_getScriptText(scriptID, __ctx, true, null);
    }

    /**
     * Get the text from the server for the script with given id.
     * 
     * @param __cb The callback object for the operation.
     * @param scriptID see above.
     **/
    public Ice.AsyncResult begin_getScriptText(long scriptID, Ice.Callback __cb)
    {
        return begin_getScriptText(scriptID, null, false, __cb);
    }

    /**
     * Get the text from the server for the script with given id.
     * 
     * @param __cb The callback object for the operation.
     * @param scriptID see above.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_getScriptText(long scriptID, java.util.Map<String, String> __ctx, Ice.Callback __cb)
    {
        return begin_getScriptText(scriptID, __ctx, true, __cb);
    }

    /**
     * Get the text from the server for the script with given id.
     * 
     * @param __cb The callback object for the operation.
     * @param scriptID see above.
     **/
    public Ice.AsyncResult begin_getScriptText(long scriptID, Callback_IScript_getScriptText __cb)
    {
        return begin_getScriptText(scriptID, null, false, __cb);
    }

    /**
     * Get the text from the server for the script with given id.
     * 
     * @param __cb The callback object for the operation.
     * @param scriptID see above.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_getScriptText(long scriptID, java.util.Map<String, String> __ctx, Callback_IScript_getScriptText __cb)
    {
        return begin_getScriptText(scriptID, __ctx, true, __cb);
    }

    private Ice.AsyncResult begin_getScriptText(long scriptID, java.util.Map<String, String> __ctx, boolean __explicitCtx, IceInternal.CallbackBase __cb)
    {
        __checkAsyncTwowayOnly(__getScriptText_name);
        IceInternal.OutgoingAsync __result = new IceInternal.OutgoingAsync(this, __getScriptText_name, __cb);
        try
        {
            __result.__prepare(__getScriptText_name, Ice.OperationMode.Idempotent, __ctx, __explicitCtx);
            IceInternal.BasicStream __os = __result.__startWriteParams(Ice.FormatType.DefaultFormat);
            __os.writeLong(scriptID);
            __result.__endWriteParams();
            __result.__send(true);
        }
        catch(Ice.LocalException __ex)
        {
            __result.__exceptionAsync(__ex);
        }
        return __result;
    }

    /**
     * ice_response indicates that
     * the operation completed successfully.
     * @param __ret (return value) see above.
     **/
    public String end_getScriptText(Ice.AsyncResult __result)
        throws omero.ServerError
    {
        Ice.AsyncResult.__check(__result, this, __getScriptText_name);
        boolean __ok = __result.__wait();
        try
        {
            if(!__ok)
            {
                try
                {
                    __result.__throwUserException();
                }
                catch(omero.ServerError __ex)
                {
                    throw __ex;
                }
                catch(Ice.UserException __ex)
                {
                    throw new Ice.UnknownUserException(__ex.ice_name(), __ex);
                }
            }
            IceInternal.BasicStream __is = __result.__startReadParams();
            String __ret;
            __ret = __is.readString();
            __result.__endReadParams();
            return __ret;
        }
        catch(Ice.LocalException ex)
        {
            Ice.Instrumentation.InvocationObserver __obsv = __result.__getObserver();
            if(__obsv != null)
            {
                __obsv.failed(ex.ice_name());
            }
            throw ex;
        }
    }

    /**
     * Get the text from the server for the script with given id.
     * 
     * @param __cb The callback object for the operation.
     * @param scriptID see above.
     **/
    public boolean getScriptText_async(AMI_IScript_getScriptText __cb, long scriptID)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__getScriptText_name);
            __r = begin_getScriptText(scriptID, null, false, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __getScriptText_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    /**
     * Get the text from the server for the script with given id.
     * 
     * @param __cb The callback object for the operation.
     * @param scriptID see above.
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean getScriptText_async(AMI_IScript_getScriptText __cb, long scriptID, java.util.Map<String, String> __ctx)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__getScriptText_name);
            __r = begin_getScriptText(scriptID, __ctx, true, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __getScriptText_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    private static final String __getScriptWithDetails_name = "getScriptWithDetails";

    /**
     * Get the script from the server with details from OriginalFile
     * @param scriptID see above
     * @return see above
     * @throws ApiUsageException
     **/
    public java.util.Map<java.lang.String, omero.RType> getScriptWithDetails(long scriptID)
        throws omero.ServerError
    {
        return getScriptWithDetails(scriptID, null, false);
    }

    /**
     * Get the script from the server with details from OriginalFile
     * @param scriptID see above
     * @param __ctx The Context map to send with the invocation.
     * @return see above
     * @throws ApiUsageException
     **/
    public java.util.Map<java.lang.String, omero.RType> getScriptWithDetails(long scriptID, java.util.Map<String, String> __ctx)
        throws omero.ServerError
    {
        return getScriptWithDetails(scriptID, __ctx, true);
    }

    private java.util.Map<java.lang.String, omero.RType> getScriptWithDetails(long scriptID, java.util.Map<String, String> __ctx, boolean __explicitCtx)
        throws omero.ServerError
    {
        if(__explicitCtx && __ctx == null)
        {
            __ctx = _emptyContext;
        }
        final Ice.Instrumentation.InvocationObserver __observer = IceInternal.ObserverHelper.get(this, "getScriptWithDetails", __ctx);
        int __cnt = 0;
        try
        {
            while(true)
            {
                Ice._ObjectDel __delBase = null;
                try
                {
                    __checkTwowayOnly("getScriptWithDetails");
                    __delBase = __getDelegate(false);
                    _IScriptDel __del = (_IScriptDel)__delBase;
                    return __del.getScriptWithDetails(scriptID, __ctx, __observer);
                }
                catch(IceInternal.LocalExceptionWrapper __ex)
                {
                    __cnt = __handleExceptionWrapperRelaxed(__delBase, __ex, null, __cnt, __observer);
                }
                catch(Ice.LocalException __ex)
                {
                    __cnt = __handleException(__delBase, __ex, null, __cnt, __observer);
                }
            }
        }
        finally
        {
            if(__observer != null)
            {
                __observer.detach();
            }
        }
    }

    /**
     * Get the script from the server with details from OriginalFile
     * @param __cb The callback object for the operation.
     * @param scriptID see above
     **/
    public Ice.AsyncResult begin_getScriptWithDetails(long scriptID)
    {
        return begin_getScriptWithDetails(scriptID, null, false, null);
    }

    /**
     * Get the script from the server with details from OriginalFile
     * @param __cb The callback object for the operation.
     * @param scriptID see above
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_getScriptWithDetails(long scriptID, java.util.Map<String, String> __ctx)
    {
        return begin_getScriptWithDetails(scriptID, __ctx, true, null);
    }

    /**
     * Get the script from the server with details from OriginalFile
     * @param __cb The callback object for the operation.
     * @param scriptID see above
     **/
    public Ice.AsyncResult begin_getScriptWithDetails(long scriptID, Ice.Callback __cb)
    {
        return begin_getScriptWithDetails(scriptID, null, false, __cb);
    }

    /**
     * Get the script from the server with details from OriginalFile
     * @param __cb The callback object for the operation.
     * @param scriptID see above
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_getScriptWithDetails(long scriptID, java.util.Map<String, String> __ctx, Ice.Callback __cb)
    {
        return begin_getScriptWithDetails(scriptID, __ctx, true, __cb);
    }

    /**
     * Get the script from the server with details from OriginalFile
     * @param __cb The callback object for the operation.
     * @param scriptID see above
     **/
    public Ice.AsyncResult begin_getScriptWithDetails(long scriptID, Callback_IScript_getScriptWithDetails __cb)
    {
        return begin_getScriptWithDetails(scriptID, null, false, __cb);
    }

    /**
     * Get the script from the server with details from OriginalFile
     * @param __cb The callback object for the operation.
     * @param scriptID see above
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_getScriptWithDetails(long scriptID, java.util.Map<String, String> __ctx, Callback_IScript_getScriptWithDetails __cb)
    {
        return begin_getScriptWithDetails(scriptID, __ctx, true, __cb);
    }

    private Ice.AsyncResult begin_getScriptWithDetails(long scriptID, java.util.Map<String, String> __ctx, boolean __explicitCtx, IceInternal.CallbackBase __cb)
    {
        __checkAsyncTwowayOnly(__getScriptWithDetails_name);
        IceInternal.OutgoingAsync __result = new IceInternal.OutgoingAsync(this, __getScriptWithDetails_name, __cb);
        try
        {
            __result.__prepare(__getScriptWithDetails_name, Ice.OperationMode.Idempotent, __ctx, __explicitCtx);
            IceInternal.BasicStream __os = __result.__startWriteParams(Ice.FormatType.DefaultFormat);
            __os.writeLong(scriptID);
            __result.__endWriteParams();
            __result.__send(true);
        }
        catch(Ice.LocalException __ex)
        {
            __result.__exceptionAsync(__ex);
        }
        return __result;
    }

    /**
     * ice_response indicates that
     * the operation completed successfully.
     * @param __ret (return value) see above
     **/
    public java.util.Map<java.lang.String, omero.RType> end_getScriptWithDetails(Ice.AsyncResult __result)
        throws omero.ServerError
    {
        Ice.AsyncResult.__check(__result, this, __getScriptWithDetails_name);
        boolean __ok = __result.__wait();
        try
        {
            if(!__ok)
            {
                try
                {
                    __result.__throwUserException();
                }
                catch(omero.ServerError __ex)
                {
                    throw __ex;
                }
                catch(Ice.UserException __ex)
                {
                    throw new Ice.UnknownUserException(__ex.ice_name(), __ex);
                }
            }
            IceInternal.BasicStream __is = __result.__startReadParams();
            java.util.Map<java.lang.String, omero.RType> __ret;
            __ret = omero.RTypeDictHelper.read(__is);
            __is.readPendingObjects();
            __result.__endReadParams();
            return __ret;
        }
        catch(Ice.LocalException ex)
        {
            Ice.Instrumentation.InvocationObserver __obsv = __result.__getObserver();
            if(__obsv != null)
            {
                __obsv.failed(ex.ice_name());
            }
            throw ex;
        }
    }

    /**
     * Get the script from the server with details from OriginalFile
     * @param __cb The callback object for the operation.
     * @param scriptID see above
     **/
    public boolean getScriptWithDetails_async(AMI_IScript_getScriptWithDetails __cb, long scriptID)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__getScriptWithDetails_name);
            __r = begin_getScriptWithDetails(scriptID, null, false, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __getScriptWithDetails_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    /**
     * Get the script from the server with details from OriginalFile
     * @param __cb The callback object for the operation.
     * @param scriptID see above
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean getScriptWithDetails_async(AMI_IScript_getScriptWithDetails __cb, long scriptID, java.util.Map<String, String> __ctx)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__getScriptWithDetails_name);
            __r = begin_getScriptWithDetails(scriptID, __ctx, true, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __getScriptWithDetails_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    private static final String __getScripts_name = "getScripts";

    /**
     * This method returns official server scripts as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts()
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * # First character is a "/" symbol
     * path = script.path.val\[1:\]
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @return see above.
     * @throws ApiUsageException
     * @throws SecurityViolation
     **/
    public java.util.List<omero.model.OriginalFile> getScripts()
        throws omero.ServerError
    {
        return getScripts(null, false);
    }

    /**
     * This method returns official server scripts as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts()
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * # First character is a "/" symbol
     * path = script.path.val\[1:\]
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param __ctx The Context map to send with the invocation.
     * @return see above.
     * @throws ApiUsageException
     * @throws SecurityViolation
     **/
    public java.util.List<omero.model.OriginalFile> getScripts(java.util.Map<String, String> __ctx)
        throws omero.ServerError
    {
        return getScripts(__ctx, true);
    }

    private java.util.List<omero.model.OriginalFile> getScripts(java.util.Map<String, String> __ctx, boolean __explicitCtx)
        throws omero.ServerError
    {
        if(__explicitCtx && __ctx == null)
        {
            __ctx = _emptyContext;
        }
        final Ice.Instrumentation.InvocationObserver __observer = IceInternal.ObserverHelper.get(this, "getScripts", __ctx);
        int __cnt = 0;
        try
        {
            while(true)
            {
                Ice._ObjectDel __delBase = null;
                try
                {
                    __checkTwowayOnly("getScripts");
                    __delBase = __getDelegate(false);
                    _IScriptDel __del = (_IScriptDel)__delBase;
                    return __del.getScripts(__ctx, __observer);
                }
                catch(IceInternal.LocalExceptionWrapper __ex)
                {
                    __cnt = __handleExceptionWrapperRelaxed(__delBase, __ex, null, __cnt, __observer);
                }
                catch(Ice.LocalException __ex)
                {
                    __cnt = __handleException(__delBase, __ex, null, __cnt, __observer);
                }
            }
        }
        finally
        {
            if(__observer != null)
            {
                __observer.detach();
            }
        }
    }

    /**
     * This method returns official server scripts as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts()
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * # First character is a "/" symbol
     * path = script.path.val\[1:\]
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_getScripts()
    {
        return begin_getScripts(null, false, null);
    }

    /**
     * This method returns official server scripts as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts()
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * # First character is a "/" symbol
     * path = script.path.val\[1:\]
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_getScripts(java.util.Map<String, String> __ctx)
    {
        return begin_getScripts(__ctx, true, null);
    }

    /**
     * This method returns official server scripts as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts()
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * # First character is a "/" symbol
     * path = script.path.val\[1:\]
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_getScripts(Ice.Callback __cb)
    {
        return begin_getScripts(null, false, __cb);
    }

    /**
     * This method returns official server scripts as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts()
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * # First character is a "/" symbol
     * path = script.path.val\[1:\]
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_getScripts(java.util.Map<String, String> __ctx, Ice.Callback __cb)
    {
        return begin_getScripts(__ctx, true, __cb);
    }

    /**
     * This method returns official server scripts as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts()
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * # First character is a "/" symbol
     * path = script.path.val\[1:\]
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_getScripts(Callback_IScript_getScripts __cb)
    {
        return begin_getScripts(null, false, __cb);
    }

    /**
     * This method returns official server scripts as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts()
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * # First character is a "/" symbol
     * path = script.path.val\[1:\]
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_getScripts(java.util.Map<String, String> __ctx, Callback_IScript_getScripts __cb)
    {
        return begin_getScripts(__ctx, true, __cb);
    }

    private Ice.AsyncResult begin_getScripts(java.util.Map<String, String> __ctx, boolean __explicitCtx, IceInternal.CallbackBase __cb)
    {
        __checkAsyncTwowayOnly(__getScripts_name);
        IceInternal.OutgoingAsync __result = new IceInternal.OutgoingAsync(this, __getScripts_name, __cb);
        try
        {
            __result.__prepare(__getScripts_name, Ice.OperationMode.Idempotent, __ctx, __explicitCtx);
            __result.__writeEmptyParams();
            __result.__send(true);
        }
        catch(Ice.LocalException __ex)
        {
            __result.__exceptionAsync(__ex);
        }
        return __result;
    }

    /**
     * ice_response indicates that
     * the operation completed successfully.
     * @param __ret (return value) see above.
     **/
    public java.util.List<omero.model.OriginalFile> end_getScripts(Ice.AsyncResult __result)
        throws omero.ServerError
    {
        Ice.AsyncResult.__check(__result, this, __getScripts_name);
        boolean __ok = __result.__wait();
        try
        {
            if(!__ok)
            {
                try
                {
                    __result.__throwUserException();
                }
                catch(omero.ServerError __ex)
                {
                    throw __ex;
                }
                catch(Ice.UserException __ex)
                {
                    throw new Ice.UnknownUserException(__ex.ice_name(), __ex);
                }
            }
            IceInternal.BasicStream __is = __result.__startReadParams();
            java.util.List<omero.model.OriginalFile> __ret;
            __ret = OriginalFileListHelper.read(__is);
            __is.readPendingObjects();
            __result.__endReadParams();
            return __ret;
        }
        catch(Ice.LocalException ex)
        {
            Ice.Instrumentation.InvocationObserver __obsv = __result.__getObserver();
            if(__obsv != null)
            {
                __obsv.failed(ex.ice_name());
            }
            throw ex;
        }
    }

    /**
     * This method returns official server scripts as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts()
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * # First character is a "/" symbol
     * path = script.path.val\[1:\]
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param __cb The callback object for the operation.
     **/
    public boolean getScripts_async(AMI_IScript_getScripts __cb)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__getScripts_name);
            __r = begin_getScripts(null, false, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __getScripts_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    /**
     * This method returns official server scripts as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts()
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * # First character is a "/" symbol
     * path = script.path.val\[1:\]
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean getScripts_async(AMI_IScript_getScripts __cb, java.util.Map<String, String> __ctx)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__getScripts_name);
            __r = begin_getScripts(__ctx, true, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __getScripts_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    private static final String __getScriptsByMimetype_name = "getScriptsByMimetype";

    /**
     * This method returns official server scripts identified
     * with the specified extension as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts("py")
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * path = script.path.val\[1:\] # First symbol is a "/"
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param mimetype the mimetype identifying the scripts.
     * @return see above.
     * @throws ApiUsageException
     * @throws SecurityViolation
     **/
    public java.util.List<omero.model.OriginalFile> getScriptsByMimetype(String mimetype)
        throws omero.ServerError
    {
        return getScriptsByMimetype(mimetype, null, false);
    }

    /**
     * This method returns official server scripts identified
     * with the specified extension as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts("py")
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * path = script.path.val\[1:\] # First symbol is a "/"
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param mimetype the mimetype identifying the scripts.
     * @param __ctx The Context map to send with the invocation.
     * @return see above.
     * @throws ApiUsageException
     * @throws SecurityViolation
     **/
    public java.util.List<omero.model.OriginalFile> getScriptsByMimetype(String mimetype, java.util.Map<String, String> __ctx)
        throws omero.ServerError
    {
        return getScriptsByMimetype(mimetype, __ctx, true);
    }

    private java.util.List<omero.model.OriginalFile> getScriptsByMimetype(String mimetype, java.util.Map<String, String> __ctx, boolean __explicitCtx)
        throws omero.ServerError
    {
        if(__explicitCtx && __ctx == null)
        {
            __ctx = _emptyContext;
        }
        final Ice.Instrumentation.InvocationObserver __observer = IceInternal.ObserverHelper.get(this, "getScriptsByMimetype", __ctx);
        int __cnt = 0;
        try
        {
            while(true)
            {
                Ice._ObjectDel __delBase = null;
                try
                {
                    __checkTwowayOnly("getScriptsByMimetype");
                    __delBase = __getDelegate(false);
                    _IScriptDel __del = (_IScriptDel)__delBase;
                    return __del.getScriptsByMimetype(mimetype, __ctx, __observer);
                }
                catch(IceInternal.LocalExceptionWrapper __ex)
                {
                    __cnt = __handleExceptionWrapperRelaxed(__delBase, __ex, null, __cnt, __observer);
                }
                catch(Ice.LocalException __ex)
                {
                    __cnt = __handleException(__delBase, __ex, null, __cnt, __observer);
                }
            }
        }
        finally
        {
            if(__observer != null)
            {
                __observer.detach();
            }
        }
    }

    /**
     * This method returns official server scripts identified
     * with the specified extension as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts("py")
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * path = script.path.val\[1:\] # First symbol is a "/"
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param __cb The callback object for the operation.
     * @param mimetype the mimetype identifying the scripts.
     **/
    public Ice.AsyncResult begin_getScriptsByMimetype(String mimetype)
    {
        return begin_getScriptsByMimetype(mimetype, null, false, null);
    }

    /**
     * This method returns official server scripts identified
     * with the specified extension as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts("py")
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * path = script.path.val\[1:\] # First symbol is a "/"
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param __cb The callback object for the operation.
     * @param mimetype the mimetype identifying the scripts.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_getScriptsByMimetype(String mimetype, java.util.Map<String, String> __ctx)
    {
        return begin_getScriptsByMimetype(mimetype, __ctx, true, null);
    }

    /**
     * This method returns official server scripts identified
     * with the specified extension as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts("py")
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * path = script.path.val\[1:\] # First symbol is a "/"
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param __cb The callback object for the operation.
     * @param mimetype the mimetype identifying the scripts.
     **/
    public Ice.AsyncResult begin_getScriptsByMimetype(String mimetype, Ice.Callback __cb)
    {
        return begin_getScriptsByMimetype(mimetype, null, false, __cb);
    }

    /**
     * This method returns official server scripts identified
     * with the specified extension as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts("py")
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * path = script.path.val\[1:\] # First symbol is a "/"
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param __cb The callback object for the operation.
     * @param mimetype the mimetype identifying the scripts.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_getScriptsByMimetype(String mimetype, java.util.Map<String, String> __ctx, Ice.Callback __cb)
    {
        return begin_getScriptsByMimetype(mimetype, __ctx, true, __cb);
    }

    /**
     * This method returns official server scripts identified
     * with the specified extension as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts("py")
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * path = script.path.val\[1:\] # First symbol is a "/"
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param __cb The callback object for the operation.
     * @param mimetype the mimetype identifying the scripts.
     **/
    public Ice.AsyncResult begin_getScriptsByMimetype(String mimetype, Callback_IScript_getScriptsByMimetype __cb)
    {
        return begin_getScriptsByMimetype(mimetype, null, false, __cb);
    }

    /**
     * This method returns official server scripts identified
     * with the specified extension as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts("py")
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * path = script.path.val\[1:\] # First symbol is a "/"
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param __cb The callback object for the operation.
     * @param mimetype the mimetype identifying the scripts.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_getScriptsByMimetype(String mimetype, java.util.Map<String, String> __ctx, Callback_IScript_getScriptsByMimetype __cb)
    {
        return begin_getScriptsByMimetype(mimetype, __ctx, true, __cb);
    }

    private Ice.AsyncResult begin_getScriptsByMimetype(String mimetype, java.util.Map<String, String> __ctx, boolean __explicitCtx, IceInternal.CallbackBase __cb)
    {
        __checkAsyncTwowayOnly(__getScriptsByMimetype_name);
        IceInternal.OutgoingAsync __result = new IceInternal.OutgoingAsync(this, __getScriptsByMimetype_name, __cb);
        try
        {
            __result.__prepare(__getScriptsByMimetype_name, Ice.OperationMode.Idempotent, __ctx, __explicitCtx);
            IceInternal.BasicStream __os = __result.__startWriteParams(Ice.FormatType.DefaultFormat);
            __os.writeString(mimetype);
            __result.__endWriteParams();
            __result.__send(true);
        }
        catch(Ice.LocalException __ex)
        {
            __result.__exceptionAsync(__ex);
        }
        return __result;
    }

    /**
     * ice_response indicates that
     * the operation completed successfully.
     * @param __ret (return value) see above.
     **/
    public java.util.List<omero.model.OriginalFile> end_getScriptsByMimetype(Ice.AsyncResult __result)
        throws omero.ServerError
    {
        Ice.AsyncResult.__check(__result, this, __getScriptsByMimetype_name);
        boolean __ok = __result.__wait();
        try
        {
            if(!__ok)
            {
                try
                {
                    __result.__throwUserException();
                }
                catch(omero.ServerError __ex)
                {
                    throw __ex;
                }
                catch(Ice.UserException __ex)
                {
                    throw new Ice.UnknownUserException(__ex.ice_name(), __ex);
                }
            }
            IceInternal.BasicStream __is = __result.__startReadParams();
            java.util.List<omero.model.OriginalFile> __ret;
            __ret = OriginalFileListHelper.read(__is);
            __is.readPendingObjects();
            __result.__endReadParams();
            return __ret;
        }
        catch(Ice.LocalException ex)
        {
            Ice.Instrumentation.InvocationObserver __obsv = __result.__getObserver();
            if(__obsv != null)
            {
                __obsv.failed(ex.ice_name());
            }
            throw ex;
        }
    }

    /**
     * This method returns official server scripts identified
     * with the specified extension as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts("py")
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * path = script.path.val\[1:\] # First symbol is a "/"
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param __cb The callback object for the operation.
     * @param mimetype the mimetype identifying the scripts.
     **/
    public boolean getScriptsByMimetype_async(AMI_IScript_getScriptsByMimetype __cb, String mimetype)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__getScriptsByMimetype_name);
            __r = begin_getScriptsByMimetype(mimetype, null, false, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __getScriptsByMimetype_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    /**
     * This method returns official server scripts identified
     * with the specified extension as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts("py")
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * path = script.path.val\[1:\] # First symbol is a "/"
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param __cb The callback object for the operation.
     * @param mimetype the mimetype identifying the scripts.
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean getScriptsByMimetype_async(AMI_IScript_getScriptsByMimetype __cb, String mimetype, java.util.Map<String, String> __ctx)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__getScriptsByMimetype_name);
            __r = begin_getScriptsByMimetype(mimetype, __ctx, true, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __getScriptsByMimetype_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    private static final String __getUserScripts_name = "getUserScripts";

    /**
     * Returns non-official scripts which have been uploaded by individual users.
     * These scripts will <em>not</me> be run by the server, though a user can
     * start a personal <i>usermode processor</i> which will allow the scripts to be
     * executed. This is particularly useful for testing new scripts.
     **/
    public java.util.List<omero.model.OriginalFile> getUserScripts(java.util.List<omero.model.IObject> acceptsList)
        throws omero.ServerError
    {
        return getUserScripts(acceptsList, null, false);
    }

    /**
     * Returns non-official scripts which have been uploaded by individual users.
     * These scripts will <em>not</me> be run by the server, though a user can
     * start a personal <i>usermode processor</i> which will allow the scripts to be
     * executed. This is particularly useful for testing new scripts.
     * @param __ctx The Context map to send with the invocation.
     **/
    public java.util.List<omero.model.OriginalFile> getUserScripts(java.util.List<omero.model.IObject> acceptsList, java.util.Map<String, String> __ctx)
        throws omero.ServerError
    {
        return getUserScripts(acceptsList, __ctx, true);
    }

    private java.util.List<omero.model.OriginalFile> getUserScripts(java.util.List<omero.model.IObject> acceptsList, java.util.Map<String, String> __ctx, boolean __explicitCtx)
        throws omero.ServerError
    {
        if(__explicitCtx && __ctx == null)
        {
            __ctx = _emptyContext;
        }
        final Ice.Instrumentation.InvocationObserver __observer = IceInternal.ObserverHelper.get(this, "getUserScripts", __ctx);
        int __cnt = 0;
        try
        {
            while(true)
            {
                Ice._ObjectDel __delBase = null;
                try
                {
                    __checkTwowayOnly("getUserScripts");
                    __delBase = __getDelegate(false);
                    _IScriptDel __del = (_IScriptDel)__delBase;
                    return __del.getUserScripts(acceptsList, __ctx, __observer);
                }
                catch(IceInternal.LocalExceptionWrapper __ex)
                {
                    __cnt = __handleExceptionWrapperRelaxed(__delBase, __ex, null, __cnt, __observer);
                }
                catch(Ice.LocalException __ex)
                {
                    __cnt = __handleException(__delBase, __ex, null, __cnt, __observer);
                }
            }
        }
        finally
        {
            if(__observer != null)
            {
                __observer.detach();
            }
        }
    }

    /**
     * Returns non-official scripts which have been uploaded by individual users.
     * These scripts will <em>not</me> be run by the server, though a user can
     * start a personal <i>usermode processor</i> which will allow the scripts to be
     * executed. This is particularly useful for testing new scripts.
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_getUserScripts(java.util.List<omero.model.IObject> acceptsList)
    {
        return begin_getUserScripts(acceptsList, null, false, null);
    }

    /**
     * Returns non-official scripts which have been uploaded by individual users.
     * These scripts will <em>not</me> be run by the server, though a user can
     * start a personal <i>usermode processor</i> which will allow the scripts to be
     * executed. This is particularly useful for testing new scripts.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_getUserScripts(java.util.List<omero.model.IObject> acceptsList, java.util.Map<String, String> __ctx)
    {
        return begin_getUserScripts(acceptsList, __ctx, true, null);
    }

    /**
     * Returns non-official scripts which have been uploaded by individual users.
     * These scripts will <em>not</me> be run by the server, though a user can
     * start a personal <i>usermode processor</i> which will allow the scripts to be
     * executed. This is particularly useful for testing new scripts.
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_getUserScripts(java.util.List<omero.model.IObject> acceptsList, Ice.Callback __cb)
    {
        return begin_getUserScripts(acceptsList, null, false, __cb);
    }

    /**
     * Returns non-official scripts which have been uploaded by individual users.
     * These scripts will <em>not</me> be run by the server, though a user can
     * start a personal <i>usermode processor</i> which will allow the scripts to be
     * executed. This is particularly useful for testing new scripts.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_getUserScripts(java.util.List<omero.model.IObject> acceptsList, java.util.Map<String, String> __ctx, Ice.Callback __cb)
    {
        return begin_getUserScripts(acceptsList, __ctx, true, __cb);
    }

    /**
     * Returns non-official scripts which have been uploaded by individual users.
     * These scripts will <em>not</me> be run by the server, though a user can
     * start a personal <i>usermode processor</i> which will allow the scripts to be
     * executed. This is particularly useful for testing new scripts.
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_getUserScripts(java.util.List<omero.model.IObject> acceptsList, Callback_IScript_getUserScripts __cb)
    {
        return begin_getUserScripts(acceptsList, null, false, __cb);
    }

    /**
     * Returns non-official scripts which have been uploaded by individual users.
     * These scripts will <em>not</me> be run by the server, though a user can
     * start a personal <i>usermode processor</i> which will allow the scripts to be
     * executed. This is particularly useful for testing new scripts.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_getUserScripts(java.util.List<omero.model.IObject> acceptsList, java.util.Map<String, String> __ctx, Callback_IScript_getUserScripts __cb)
    {
        return begin_getUserScripts(acceptsList, __ctx, true, __cb);
    }

    private Ice.AsyncResult begin_getUserScripts(java.util.List<omero.model.IObject> acceptsList, java.util.Map<String, String> __ctx, boolean __explicitCtx, IceInternal.CallbackBase __cb)
    {
        __checkAsyncTwowayOnly(__getUserScripts_name);
        IceInternal.OutgoingAsync __result = new IceInternal.OutgoingAsync(this, __getUserScripts_name, __cb);
        try
        {
            __result.__prepare(__getUserScripts_name, Ice.OperationMode.Idempotent, __ctx, __explicitCtx);
            IceInternal.BasicStream __os = __result.__startWriteParams(Ice.FormatType.DefaultFormat);
            IObjectListHelper.write(__os, acceptsList);
            __os.writePendingObjects();
            __result.__endWriteParams();
            __result.__send(true);
        }
        catch(Ice.LocalException __ex)
        {
            __result.__exceptionAsync(__ex);
        }
        return __result;
    }

    /**
     * ice_response indicates that
     * the operation completed successfully.
     **/
    public java.util.List<omero.model.OriginalFile> end_getUserScripts(Ice.AsyncResult __result)
        throws omero.ServerError
    {
        Ice.AsyncResult.__check(__result, this, __getUserScripts_name);
        boolean __ok = __result.__wait();
        try
        {
            if(!__ok)
            {
                try
                {
                    __result.__throwUserException();
                }
                catch(omero.ServerError __ex)
                {
                    throw __ex;
                }
                catch(Ice.UserException __ex)
                {
                    throw new Ice.UnknownUserException(__ex.ice_name(), __ex);
                }
            }
            IceInternal.BasicStream __is = __result.__startReadParams();
            java.util.List<omero.model.OriginalFile> __ret;
            __ret = OriginalFileListHelper.read(__is);
            __is.readPendingObjects();
            __result.__endReadParams();
            return __ret;
        }
        catch(Ice.LocalException ex)
        {
            Ice.Instrumentation.InvocationObserver __obsv = __result.__getObserver();
            if(__obsv != null)
            {
                __obsv.failed(ex.ice_name());
            }
            throw ex;
        }
    }

    /**
     * Returns non-official scripts which have been uploaded by individual users.
     * These scripts will <em>not</me> be run by the server, though a user can
     * start a personal <i>usermode processor</i> which will allow the scripts to be
     * executed. This is particularly useful for testing new scripts.
     * @param __cb The callback object for the operation.
     **/
    public boolean getUserScripts_async(AMI_IScript_getUserScripts __cb, java.util.List<omero.model.IObject> acceptsList)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__getUserScripts_name);
            __r = begin_getUserScripts(acceptsList, null, false, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __getUserScripts_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    /**
     * Returns non-official scripts which have been uploaded by individual users.
     * These scripts will <em>not</me> be run by the server, though a user can
     * start a personal <i>usermode processor</i> which will allow the scripts to be
     * executed. This is particularly useful for testing new scripts.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean getUserScripts_async(AMI_IScript_getUserScripts __cb, java.util.List<omero.model.IObject> acceptsList, java.util.Map<String, String> __ctx)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__getUserScripts_name);
            __r = begin_getUserScripts(acceptsList, __ctx, true, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __getUserScripts_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    private static final String __runScript_name = "runScript";

    /**
     * If {@link ResourceError} is thrown, then no
     * {@link Processor} is available. Use {@link #scheduleJob}
     * to create a {@link omero.model.ScriptJob} in the
     * <i>Waiting</i> state. A {@link Processor} may become
     * available.
     * 
     * <pre>
     * try:
     * proc = scriptService.runScript(1, {}, None)
     * except ResourceError:
     * job = scriptService.scheduleScript(1, {}, None)
     * </pre>
     * 
     * The {@link ScriptProcess} proxy MUST be closed before
     * exiting. If you would like the script execution to continue
     * in the background, pass <code>True</code> as the argument.
     * 
     * <pre>
     * try:
     * proc.poll()         # See if process is finished
     * finally:
     * proc.close(True)    # Detach and execution can continue
     * # proc.close(False) # OR script is immediately stopped.
     * </pre>
     **/
    public omero.grid.ScriptProcessPrx runScript(long scriptID, java.util.Map<java.lang.String, omero.RType> inputs, omero.RInt waitSecs)
        throws omero.ServerError
    {
        return runScript(scriptID, inputs, waitSecs, null, false);
    }

    /**
     * If {@link ResourceError} is thrown, then no
     * {@link Processor} is available. Use {@link #scheduleJob}
     * to create a {@link omero.model.ScriptJob} in the
     * <i>Waiting</i> state. A {@link Processor} may become
     * available.
     * 
     * <pre>
     * try:
     * proc = scriptService.runScript(1, {}, None)
     * except ResourceError:
     * job = scriptService.scheduleScript(1, {}, None)
     * </pre>
     * 
     * The {@link ScriptProcess} proxy MUST be closed before
     * exiting. If you would like the script execution to continue
     * in the background, pass <code>True</code> as the argument.
     * 
     * <pre>
     * try:
     * proc.poll()         # See if process is finished
     * finally:
     * proc.close(True)    # Detach and execution can continue
     * # proc.close(False) # OR script is immediately stopped.
     * </pre>
     * @param __ctx The Context map to send with the invocation.
     **/
    public omero.grid.ScriptProcessPrx runScript(long scriptID, java.util.Map<java.lang.String, omero.RType> inputs, omero.RInt waitSecs, java.util.Map<String, String> __ctx)
        throws omero.ServerError
    {
        return runScript(scriptID, inputs, waitSecs, __ctx, true);
    }

    private omero.grid.ScriptProcessPrx runScript(long scriptID, java.util.Map<java.lang.String, omero.RType> inputs, omero.RInt waitSecs, java.util.Map<String, String> __ctx, boolean __explicitCtx)
        throws omero.ServerError
    {
        if(__explicitCtx && __ctx == null)
        {
            __ctx = _emptyContext;
        }
        final Ice.Instrumentation.InvocationObserver __observer = IceInternal.ObserverHelper.get(this, "runScript", __ctx);
        int __cnt = 0;
        try
        {
            while(true)
            {
                Ice._ObjectDel __delBase = null;
                try
                {
                    __checkTwowayOnly("runScript");
                    __delBase = __getDelegate(false);
                    _IScriptDel __del = (_IScriptDel)__delBase;
                    return __del.runScript(scriptID, inputs, waitSecs, __ctx, __observer);
                }
                catch(IceInternal.LocalExceptionWrapper __ex)
                {
                    __handleExceptionWrapper(__delBase, __ex, __observer);
                }
                catch(Ice.LocalException __ex)
                {
                    __cnt = __handleException(__delBase, __ex, null, __cnt, __observer);
                }
            }
        }
        finally
        {
            if(__observer != null)
            {
                __observer.detach();
            }
        }
    }

    /**
     * If {@link ResourceError} is thrown, then no
     * {@link Processor} is available. Use {@link #scheduleJob}
     * to create a {@link omero.model.ScriptJob} in the
     * <i>Waiting</i> state. A {@link Processor} may become
     * available.
     * 
     * <pre>
     * try:
     * proc = scriptService.runScript(1, {}, None)
     * except ResourceError:
     * job = scriptService.scheduleScript(1, {}, None)
     * </pre>
     * 
     * The {@link ScriptProcess} proxy MUST be closed before
     * exiting. If you would like the script execution to continue
     * in the background, pass <code>True</code> as the argument.
     * 
     * <pre>
     * try:
     * proc.poll()         # See if process is finished
     * finally:
     * proc.close(True)    # Detach and execution can continue
     * # proc.close(False) # OR script is immediately stopped.
     * </pre>
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_runScript(long scriptID, java.util.Map<java.lang.String, omero.RType> inputs, omero.RInt waitSecs)
    {
        return begin_runScript(scriptID, inputs, waitSecs, null, false, null);
    }

    /**
     * If {@link ResourceError} is thrown, then no
     * {@link Processor} is available. Use {@link #scheduleJob}
     * to create a {@link omero.model.ScriptJob} in the
     * <i>Waiting</i> state. A {@link Processor} may become
     * available.
     * 
     * <pre>
     * try:
     * proc = scriptService.runScript(1, {}, None)
     * except ResourceError:
     * job = scriptService.scheduleScript(1, {}, None)
     * </pre>
     * 
     * The {@link ScriptProcess} proxy MUST be closed before
     * exiting. If you would like the script execution to continue
     * in the background, pass <code>True</code> as the argument.
     * 
     * <pre>
     * try:
     * proc.poll()         # See if process is finished
     * finally:
     * proc.close(True)    # Detach and execution can continue
     * # proc.close(False) # OR script is immediately stopped.
     * </pre>
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_runScript(long scriptID, java.util.Map<java.lang.String, omero.RType> inputs, omero.RInt waitSecs, java.util.Map<String, String> __ctx)
    {
        return begin_runScript(scriptID, inputs, waitSecs, __ctx, true, null);
    }

    /**
     * If {@link ResourceError} is thrown, then no
     * {@link Processor} is available. Use {@link #scheduleJob}
     * to create a {@link omero.model.ScriptJob} in the
     * <i>Waiting</i> state. A {@link Processor} may become
     * available.
     * 
     * <pre>
     * try:
     * proc = scriptService.runScript(1, {}, None)
     * except ResourceError:
     * job = scriptService.scheduleScript(1, {}, None)
     * </pre>
     * 
     * The {@link ScriptProcess} proxy MUST be closed before
     * exiting. If you would like the script execution to continue
     * in the background, pass <code>True</code> as the argument.
     * 
     * <pre>
     * try:
     * proc.poll()         # See if process is finished
     * finally:
     * proc.close(True)    # Detach and execution can continue
     * # proc.close(False) # OR script is immediately stopped.
     * </pre>
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_runScript(long scriptID, java.util.Map<java.lang.String, omero.RType> inputs, omero.RInt waitSecs, Ice.Callback __cb)
    {
        return begin_runScript(scriptID, inputs, waitSecs, null, false, __cb);
    }

    /**
     * If {@link ResourceError} is thrown, then no
     * {@link Processor} is available. Use {@link #scheduleJob}
     * to create a {@link omero.model.ScriptJob} in the
     * <i>Waiting</i> state. A {@link Processor} may become
     * available.
     * 
     * <pre>
     * try:
     * proc = scriptService.runScript(1, {}, None)
     * except ResourceError:
     * job = scriptService.scheduleScript(1, {}, None)
     * </pre>
     * 
     * The {@link ScriptProcess} proxy MUST be closed before
     * exiting. If you would like the script execution to continue
     * in the background, pass <code>True</code> as the argument.
     * 
     * <pre>
     * try:
     * proc.poll()         # See if process is finished
     * finally:
     * proc.close(True)    # Detach and execution can continue
     * # proc.close(False) # OR script is immediately stopped.
     * </pre>
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_runScript(long scriptID, java.util.Map<java.lang.String, omero.RType> inputs, omero.RInt waitSecs, java.util.Map<String, String> __ctx, Ice.Callback __cb)
    {
        return begin_runScript(scriptID, inputs, waitSecs, __ctx, true, __cb);
    }

    /**
     * If {@link ResourceError} is thrown, then no
     * {@link Processor} is available. Use {@link #scheduleJob}
     * to create a {@link omero.model.ScriptJob} in the
     * <i>Waiting</i> state. A {@link Processor} may become
     * available.
     * 
     * <pre>
     * try:
     * proc = scriptService.runScript(1, {}, None)
     * except ResourceError:
     * job = scriptService.scheduleScript(1, {}, None)
     * </pre>
     * 
     * The {@link ScriptProcess} proxy MUST be closed before
     * exiting. If you would like the script execution to continue
     * in the background, pass <code>True</code> as the argument.
     * 
     * <pre>
     * try:
     * proc.poll()         # See if process is finished
     * finally:
     * proc.close(True)    # Detach and execution can continue
     * # proc.close(False) # OR script is immediately stopped.
     * </pre>
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_runScript(long scriptID, java.util.Map<java.lang.String, omero.RType> inputs, omero.RInt waitSecs, Callback_IScript_runScript __cb)
    {
        return begin_runScript(scriptID, inputs, waitSecs, null, false, __cb);
    }

    /**
     * If {@link ResourceError} is thrown, then no
     * {@link Processor} is available. Use {@link #scheduleJob}
     * to create a {@link omero.model.ScriptJob} in the
     * <i>Waiting</i> state. A {@link Processor} may become
     * available.
     * 
     * <pre>
     * try:
     * proc = scriptService.runScript(1, {}, None)
     * except ResourceError:
     * job = scriptService.scheduleScript(1, {}, None)
     * </pre>
     * 
     * The {@link ScriptProcess} proxy MUST be closed before
     * exiting. If you would like the script execution to continue
     * in the background, pass <code>True</code> as the argument.
     * 
     * <pre>
     * try:
     * proc.poll()         # See if process is finished
     * finally:
     * proc.close(True)    # Detach and execution can continue
     * # proc.close(False) # OR script is immediately stopped.
     * </pre>
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_runScript(long scriptID, java.util.Map<java.lang.String, omero.RType> inputs, omero.RInt waitSecs, java.util.Map<String, String> __ctx, Callback_IScript_runScript __cb)
    {
        return begin_runScript(scriptID, inputs, waitSecs, __ctx, true, __cb);
    }

    private Ice.AsyncResult begin_runScript(long scriptID, java.util.Map<java.lang.String, omero.RType> inputs, omero.RInt waitSecs, java.util.Map<String, String> __ctx, boolean __explicitCtx, IceInternal.CallbackBase __cb)
    {
        __checkAsyncTwowayOnly(__runScript_name);
        IceInternal.OutgoingAsync __result = new IceInternal.OutgoingAsync(this, __runScript_name, __cb);
        try
        {
            __result.__prepare(__runScript_name, Ice.OperationMode.Normal, __ctx, __explicitCtx);
            IceInternal.BasicStream __os = __result.__startWriteParams(Ice.FormatType.DefaultFormat);
            __os.writeLong(scriptID);
            omero.RTypeDictHelper.write(__os, inputs);
            __os.writeObject(waitSecs);
            __os.writePendingObjects();
            __result.__endWriteParams();
            __result.__send(true);
        }
        catch(Ice.LocalException __ex)
        {
            __result.__exceptionAsync(__ex);
        }
        return __result;
    }

    /**
     * ice_response indicates that
     * the operation completed successfully.
     **/
    public omero.grid.ScriptProcessPrx end_runScript(Ice.AsyncResult __result)
        throws omero.ServerError
    {
        Ice.AsyncResult.__check(__result, this, __runScript_name);
        boolean __ok = __result.__wait();
        try
        {
            if(!__ok)
            {
                try
                {
                    __result.__throwUserException();
                }
                catch(omero.ServerError __ex)
                {
                    throw __ex;
                }
                catch(Ice.UserException __ex)
                {
                    throw new Ice.UnknownUserException(__ex.ice_name(), __ex);
                }
            }
            IceInternal.BasicStream __is = __result.__startReadParams();
            omero.grid.ScriptProcessPrx __ret;
            __ret = omero.grid.ScriptProcessPrxHelper.__read(__is);
            __result.__endReadParams();
            return __ret;
        }
        catch(Ice.LocalException ex)
        {
            Ice.Instrumentation.InvocationObserver __obsv = __result.__getObserver();
            if(__obsv != null)
            {
                __obsv.failed(ex.ice_name());
            }
            throw ex;
        }
    }

    /**
     * If {@link ResourceError} is thrown, then no
     * {@link Processor} is available. Use {@link #scheduleJob}
     * to create a {@link omero.model.ScriptJob} in the
     * <i>Waiting</i> state. A {@link Processor} may become
     * available.
     * 
     * <pre>
     * try:
     * proc = scriptService.runScript(1, {}, None)
     * except ResourceError:
     * job = scriptService.scheduleScript(1, {}, None)
     * </pre>
     * 
     * The {@link ScriptProcess} proxy MUST be closed before
     * exiting. If you would like the script execution to continue
     * in the background, pass <code>True</code> as the argument.
     * 
     * <pre>
     * try:
     * proc.poll()         # See if process is finished
     * finally:
     * proc.close(True)    # Detach and execution can continue
     * # proc.close(False) # OR script is immediately stopped.
     * </pre>
     * @param __cb The callback object for the operation.
     **/
    public boolean runScript_async(AMI_IScript_runScript __cb, long scriptID, java.util.Map<java.lang.String, omero.RType> inputs, omero.RInt waitSecs)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__runScript_name);
            __r = begin_runScript(scriptID, inputs, waitSecs, null, false, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __runScript_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    /**
     * If {@link ResourceError} is thrown, then no
     * {@link Processor} is available. Use {@link #scheduleJob}
     * to create a {@link omero.model.ScriptJob} in the
     * <i>Waiting</i> state. A {@link Processor} may become
     * available.
     * 
     * <pre>
     * try:
     * proc = scriptService.runScript(1, {}, None)
     * except ResourceError:
     * job = scriptService.scheduleScript(1, {}, None)
     * </pre>
     * 
     * The {@link ScriptProcess} proxy MUST be closed before
     * exiting. If you would like the script execution to continue
     * in the background, pass <code>True</code> as the argument.
     * 
     * <pre>
     * try:
     * proc.poll()         # See if process is finished
     * finally:
     * proc.close(True)    # Detach and execution can continue
     * # proc.close(False) # OR script is immediately stopped.
     * </pre>
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean runScript_async(AMI_IScript_runScript __cb, long scriptID, java.util.Map<java.lang.String, omero.RType> inputs, omero.RInt waitSecs, java.util.Map<String, String> __ctx)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__runScript_name);
            __r = begin_runScript(scriptID, inputs, waitSecs, __ctx, true, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __runScript_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    private static final String __uploadOfficialScript_name = "uploadOfficialScript";

    /**
     * Like {@link #uploadScript} but is only callable by
     * administrators. The parameters for the script are also
     * checked.
     **/
    public long uploadOfficialScript(String path, String scriptText)
        throws omero.ServerError
    {
        return uploadOfficialScript(path, scriptText, null, false);
    }

    /**
     * Like {@link #uploadScript} but is only callable by
     * administrators. The parameters for the script are also
     * checked.
     * @param __ctx The Context map to send with the invocation.
     **/
    public long uploadOfficialScript(String path, String scriptText, java.util.Map<String, String> __ctx)
        throws omero.ServerError
    {
        return uploadOfficialScript(path, scriptText, __ctx, true);
    }

    private long uploadOfficialScript(String path, String scriptText, java.util.Map<String, String> __ctx, boolean __explicitCtx)
        throws omero.ServerError
    {
        if(__explicitCtx && __ctx == null)
        {
            __ctx = _emptyContext;
        }
        final Ice.Instrumentation.InvocationObserver __observer = IceInternal.ObserverHelper.get(this, "uploadOfficialScript", __ctx);
        int __cnt = 0;
        try
        {
            while(true)
            {
                Ice._ObjectDel __delBase = null;
                try
                {
                    __checkTwowayOnly("uploadOfficialScript");
                    __delBase = __getDelegate(false);
                    _IScriptDel __del = (_IScriptDel)__delBase;
                    return __del.uploadOfficialScript(path, scriptText, __ctx, __observer);
                }
                catch(IceInternal.LocalExceptionWrapper __ex)
                {
                    __handleExceptionWrapper(__delBase, __ex, __observer);
                }
                catch(Ice.LocalException __ex)
                {
                    __cnt = __handleException(__delBase, __ex, null, __cnt, __observer);
                }
            }
        }
        finally
        {
            if(__observer != null)
            {
                __observer.detach();
            }
        }
    }

    /**
     * Like {@link #uploadScript} but is only callable by
     * administrators. The parameters for the script are also
     * checked.
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_uploadOfficialScript(String path, String scriptText)
    {
        return begin_uploadOfficialScript(path, scriptText, null, false, null);
    }

    /**
     * Like {@link #uploadScript} but is only callable by
     * administrators. The parameters for the script are also
     * checked.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_uploadOfficialScript(String path, String scriptText, java.util.Map<String, String> __ctx)
    {
        return begin_uploadOfficialScript(path, scriptText, __ctx, true, null);
    }

    /**
     * Like {@link #uploadScript} but is only callable by
     * administrators. The parameters for the script are also
     * checked.
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_uploadOfficialScript(String path, String scriptText, Ice.Callback __cb)
    {
        return begin_uploadOfficialScript(path, scriptText, null, false, __cb);
    }

    /**
     * Like {@link #uploadScript} but is only callable by
     * administrators. The parameters for the script are also
     * checked.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_uploadOfficialScript(String path, String scriptText, java.util.Map<String, String> __ctx, Ice.Callback __cb)
    {
        return begin_uploadOfficialScript(path, scriptText, __ctx, true, __cb);
    }

    /**
     * Like {@link #uploadScript} but is only callable by
     * administrators. The parameters for the script are also
     * checked.
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_uploadOfficialScript(String path, String scriptText, Callback_IScript_uploadOfficialScript __cb)
    {
        return begin_uploadOfficialScript(path, scriptText, null, false, __cb);
    }

    /**
     * Like {@link #uploadScript} but is only callable by
     * administrators. The parameters for the script are also
     * checked.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_uploadOfficialScript(String path, String scriptText, java.util.Map<String, String> __ctx, Callback_IScript_uploadOfficialScript __cb)
    {
        return begin_uploadOfficialScript(path, scriptText, __ctx, true, __cb);
    }

    private Ice.AsyncResult begin_uploadOfficialScript(String path, String scriptText, java.util.Map<String, String> __ctx, boolean __explicitCtx, IceInternal.CallbackBase __cb)
    {
        __checkAsyncTwowayOnly(__uploadOfficialScript_name);
        IceInternal.OutgoingAsync __result = new IceInternal.OutgoingAsync(this, __uploadOfficialScript_name, __cb);
        try
        {
            __result.__prepare(__uploadOfficialScript_name, Ice.OperationMode.Normal, __ctx, __explicitCtx);
            IceInternal.BasicStream __os = __result.__startWriteParams(Ice.FormatType.DefaultFormat);
            __os.writeString(path);
            __os.writeString(scriptText);
            __result.__endWriteParams();
            __result.__send(true);
        }
        catch(Ice.LocalException __ex)
        {
            __result.__exceptionAsync(__ex);
        }
        return __result;
    }

    /**
     * ice_response indicates that
     * the operation completed successfully.
     **/
    public long end_uploadOfficialScript(Ice.AsyncResult __result)
        throws omero.ServerError
    {
        Ice.AsyncResult.__check(__result, this, __uploadOfficialScript_name);
        boolean __ok = __result.__wait();
        try
        {
            if(!__ok)
            {
                try
                {
                    __result.__throwUserException();
                }
                catch(omero.ServerError __ex)
                {
                    throw __ex;
                }
                catch(Ice.UserException __ex)
                {
                    throw new Ice.UnknownUserException(__ex.ice_name(), __ex);
                }
            }
            IceInternal.BasicStream __is = __result.__startReadParams();
            long __ret;
            __ret = __is.readLong();
            __result.__endReadParams();
            return __ret;
        }
        catch(Ice.LocalException ex)
        {
            Ice.Instrumentation.InvocationObserver __obsv = __result.__getObserver();
            if(__obsv != null)
            {
                __obsv.failed(ex.ice_name());
            }
            throw ex;
        }
    }

    /**
     * Like {@link #uploadScript} but is only callable by
     * administrators. The parameters for the script are also
     * checked.
     * @param __cb The callback object for the operation.
     **/
    public boolean uploadOfficialScript_async(AMI_IScript_uploadOfficialScript __cb, String path, String scriptText)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__uploadOfficialScript_name);
            __r = begin_uploadOfficialScript(path, scriptText, null, false, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __uploadOfficialScript_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    /**
     * Like {@link #uploadScript} but is only callable by
     * administrators. The parameters for the script are also
     * checked.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean uploadOfficialScript_async(AMI_IScript_uploadOfficialScript __cb, String path, String scriptText, java.util.Map<String, String> __ctx)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__uploadOfficialScript_name);
            __r = begin_uploadOfficialScript(path, scriptText, __ctx, true, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __uploadOfficialScript_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    private static final String __uploadScript_name = "uploadScript";

    /**
     * Upload a user script to the server and return the id. This method checks that
     * a script with that names does not exist and that the script has parameters
     * <em>if possible</em>, i.e. a usermode processor is running which for the
     * current user.
     * 
     * @param script see above.
     * @return The new id of the script.
     * @throws ApiUsageException
     * @throws SecurityViolation
     **/
    public long uploadScript(String path, String scriptText)
        throws omero.ServerError
    {
        return uploadScript(path, scriptText, null, false);
    }

    /**
     * Upload a user script to the server and return the id. This method checks that
     * a script with that names does not exist and that the script has parameters
     * <em>if possible</em>, i.e. a usermode processor is running which for the
     * current user.
     * 
     * @param script see above.
     * @param __ctx The Context map to send with the invocation.
     * @return The new id of the script.
     * @throws ApiUsageException
     * @throws SecurityViolation
     **/
    public long uploadScript(String path, String scriptText, java.util.Map<String, String> __ctx)
        throws omero.ServerError
    {
        return uploadScript(path, scriptText, __ctx, true);
    }

    private long uploadScript(String path, String scriptText, java.util.Map<String, String> __ctx, boolean __explicitCtx)
        throws omero.ServerError
    {
        if(__explicitCtx && __ctx == null)
        {
            __ctx = _emptyContext;
        }
        final Ice.Instrumentation.InvocationObserver __observer = IceInternal.ObserverHelper.get(this, "uploadScript", __ctx);
        int __cnt = 0;
        try
        {
            while(true)
            {
                Ice._ObjectDel __delBase = null;
                try
                {
                    __checkTwowayOnly("uploadScript");
                    __delBase = __getDelegate(false);
                    _IScriptDel __del = (_IScriptDel)__delBase;
                    return __del.uploadScript(path, scriptText, __ctx, __observer);
                }
                catch(IceInternal.LocalExceptionWrapper __ex)
                {
                    __handleExceptionWrapper(__delBase, __ex, __observer);
                }
                catch(Ice.LocalException __ex)
                {
                    __cnt = __handleException(__delBase, __ex, null, __cnt, __observer);
                }
            }
        }
        finally
        {
            if(__observer != null)
            {
                __observer.detach();
            }
        }
    }

    /**
     * Upload a user script to the server and return the id. This method checks that
     * a script with that names does not exist and that the script has parameters
     * <em>if possible</em>, i.e. a usermode processor is running which for the
     * current user.
     * 
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_uploadScript(String path, String scriptText)
    {
        return begin_uploadScript(path, scriptText, null, false, null);
    }

    /**
     * Upload a user script to the server and return the id. This method checks that
     * a script with that names does not exist and that the script has parameters
     * <em>if possible</em>, i.e. a usermode processor is running which for the
     * current user.
     * 
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_uploadScript(String path, String scriptText, java.util.Map<String, String> __ctx)
    {
        return begin_uploadScript(path, scriptText, __ctx, true, null);
    }

    /**
     * Upload a user script to the server and return the id. This method checks that
     * a script with that names does not exist and that the script has parameters
     * <em>if possible</em>, i.e. a usermode processor is running which for the
     * current user.
     * 
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_uploadScript(String path, String scriptText, Ice.Callback __cb)
    {
        return begin_uploadScript(path, scriptText, null, false, __cb);
    }

    /**
     * Upload a user script to the server and return the id. This method checks that
     * a script with that names does not exist and that the script has parameters
     * <em>if possible</em>, i.e. a usermode processor is running which for the
     * current user.
     * 
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_uploadScript(String path, String scriptText, java.util.Map<String, String> __ctx, Ice.Callback __cb)
    {
        return begin_uploadScript(path, scriptText, __ctx, true, __cb);
    }

    /**
     * Upload a user script to the server and return the id. This method checks that
     * a script with that names does not exist and that the script has parameters
     * <em>if possible</em>, i.e. a usermode processor is running which for the
     * current user.
     * 
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_uploadScript(String path, String scriptText, Callback_IScript_uploadScript __cb)
    {
        return begin_uploadScript(path, scriptText, null, false, __cb);
    }

    /**
     * Upload a user script to the server and return the id. This method checks that
     * a script with that names does not exist and that the script has parameters
     * <em>if possible</em>, i.e. a usermode processor is running which for the
     * current user.
     * 
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_uploadScript(String path, String scriptText, java.util.Map<String, String> __ctx, Callback_IScript_uploadScript __cb)
    {
        return begin_uploadScript(path, scriptText, __ctx, true, __cb);
    }

    private Ice.AsyncResult begin_uploadScript(String path, String scriptText, java.util.Map<String, String> __ctx, boolean __explicitCtx, IceInternal.CallbackBase __cb)
    {
        __checkAsyncTwowayOnly(__uploadScript_name);
        IceInternal.OutgoingAsync __result = new IceInternal.OutgoingAsync(this, __uploadScript_name, __cb);
        try
        {
            __result.__prepare(__uploadScript_name, Ice.OperationMode.Normal, __ctx, __explicitCtx);
            IceInternal.BasicStream __os = __result.__startWriteParams(Ice.FormatType.DefaultFormat);
            __os.writeString(path);
            __os.writeString(scriptText);
            __result.__endWriteParams();
            __result.__send(true);
        }
        catch(Ice.LocalException __ex)
        {
            __result.__exceptionAsync(__ex);
        }
        return __result;
    }

    /**
     * ice_response indicates that
     * the operation completed successfully.
     * @param __ret (return value) The new id of the script.
     **/
    public long end_uploadScript(Ice.AsyncResult __result)
        throws omero.ServerError
    {
        Ice.AsyncResult.__check(__result, this, __uploadScript_name);
        boolean __ok = __result.__wait();
        try
        {
            if(!__ok)
            {
                try
                {
                    __result.__throwUserException();
                }
                catch(omero.ServerError __ex)
                {
                    throw __ex;
                }
                catch(Ice.UserException __ex)
                {
                    throw new Ice.UnknownUserException(__ex.ice_name(), __ex);
                }
            }
            IceInternal.BasicStream __is = __result.__startReadParams();
            long __ret;
            __ret = __is.readLong();
            __result.__endReadParams();
            return __ret;
        }
        catch(Ice.LocalException ex)
        {
            Ice.Instrumentation.InvocationObserver __obsv = __result.__getObserver();
            if(__obsv != null)
            {
                __obsv.failed(ex.ice_name());
            }
            throw ex;
        }
    }

    /**
     * Upload a user script to the server and return the id. This method checks that
     * a script with that names does not exist and that the script has parameters
     * <em>if possible</em>, i.e. a usermode processor is running which for the
     * current user.
     * 
     * @param __cb The callback object for the operation.
     **/
    public boolean uploadScript_async(AMI_IScript_uploadScript __cb, String path, String scriptText)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__uploadScript_name);
            __r = begin_uploadScript(path, scriptText, null, false, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __uploadScript_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    /**
     * Upload a user script to the server and return the id. This method checks that
     * a script with that names does not exist and that the script has parameters
     * <em>if possible</em>, i.e. a usermode processor is running which for the
     * current user.
     * 
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean uploadScript_async(AMI_IScript_uploadScript __cb, String path, String scriptText, java.util.Map<String, String> __ctx)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__uploadScript_name);
            __r = begin_uploadScript(path, scriptText, __ctx, true, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __uploadScript_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    private static final String __validateScript_name = "validateScript";

    /**
     * Used internally by processor.py to check if the script
     * attached to the {@link omero.model.Job} has a valid script
     * attached, based on the {@link #acceptsList} and the current
     * security context.
     * 
     * An example of an acceptsList might be <pre>Experimenter(myUserId, False)</pre>, meaning that
     * only scripts belonging to me should be trusted. An empty list implies that the server should
     * return what it would by default trust.
     * 
     * A valid script will be returned if it exists; otherwise null.
     **/
    public omero.model.OriginalFile validateScript(omero.model.Job j, java.util.List<omero.model.IObject> acceptsList)
        throws omero.ServerError
    {
        return validateScript(j, acceptsList, null, false);
    }

    /**
     * Used internally by processor.py to check if the script
     * attached to the {@link omero.model.Job} has a valid script
     * attached, based on the {@link #acceptsList} and the current
     * security context.
     * 
     * An example of an acceptsList might be <pre>Experimenter(myUserId, False)</pre>, meaning that
     * only scripts belonging to me should be trusted. An empty list implies that the server should
     * return what it would by default trust.
     * 
     * A valid script will be returned if it exists; otherwise null.
     * @param __ctx The Context map to send with the invocation.
     **/
    public omero.model.OriginalFile validateScript(omero.model.Job j, java.util.List<omero.model.IObject> acceptsList, java.util.Map<String, String> __ctx)
        throws omero.ServerError
    {
        return validateScript(j, acceptsList, __ctx, true);
    }

    private omero.model.OriginalFile validateScript(omero.model.Job j, java.util.List<omero.model.IObject> acceptsList, java.util.Map<String, String> __ctx, boolean __explicitCtx)
        throws omero.ServerError
    {
        if(__explicitCtx && __ctx == null)
        {
            __ctx = _emptyContext;
        }
        final Ice.Instrumentation.InvocationObserver __observer = IceInternal.ObserverHelper.get(this, "validateScript", __ctx);
        int __cnt = 0;
        try
        {
            while(true)
            {
                Ice._ObjectDel __delBase = null;
                try
                {
                    __checkTwowayOnly("validateScript");
                    __delBase = __getDelegate(false);
                    _IScriptDel __del = (_IScriptDel)__delBase;
                    return __del.validateScript(j, acceptsList, __ctx, __observer);
                }
                catch(IceInternal.LocalExceptionWrapper __ex)
                {
                    __cnt = __handleExceptionWrapperRelaxed(__delBase, __ex, null, __cnt, __observer);
                }
                catch(Ice.LocalException __ex)
                {
                    __cnt = __handleException(__delBase, __ex, null, __cnt, __observer);
                }
            }
        }
        finally
        {
            if(__observer != null)
            {
                __observer.detach();
            }
        }
    }

    /**
     * Used internally by processor.py to check if the script
     * attached to the {@link omero.model.Job} has a valid script
     * attached, based on the {@link #acceptsList} and the current
     * security context.
     * 
     * An example of an acceptsList might be <pre>Experimenter(myUserId, False)</pre>, meaning that
     * only scripts belonging to me should be trusted. An empty list implies that the server should
     * return what it would by default trust.
     * 
     * A valid script will be returned if it exists; otherwise null.
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_validateScript(omero.model.Job j, java.util.List<omero.model.IObject> acceptsList)
    {
        return begin_validateScript(j, acceptsList, null, false, null);
    }

    /**
     * Used internally by processor.py to check if the script
     * attached to the {@link omero.model.Job} has a valid script
     * attached, based on the {@link #acceptsList} and the current
     * security context.
     * 
     * An example of an acceptsList might be <pre>Experimenter(myUserId, False)</pre>, meaning that
     * only scripts belonging to me should be trusted. An empty list implies that the server should
     * return what it would by default trust.
     * 
     * A valid script will be returned if it exists; otherwise null.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_validateScript(omero.model.Job j, java.util.List<omero.model.IObject> acceptsList, java.util.Map<String, String> __ctx)
    {
        return begin_validateScript(j, acceptsList, __ctx, true, null);
    }

    /**
     * Used internally by processor.py to check if the script
     * attached to the {@link omero.model.Job} has a valid script
     * attached, based on the {@link #acceptsList} and the current
     * security context.
     * 
     * An example of an acceptsList might be <pre>Experimenter(myUserId, False)</pre>, meaning that
     * only scripts belonging to me should be trusted. An empty list implies that the server should
     * return what it would by default trust.
     * 
     * A valid script will be returned if it exists; otherwise null.
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_validateScript(omero.model.Job j, java.util.List<omero.model.IObject> acceptsList, Ice.Callback __cb)
    {
        return begin_validateScript(j, acceptsList, null, false, __cb);
    }

    /**
     * Used internally by processor.py to check if the script
     * attached to the {@link omero.model.Job} has a valid script
     * attached, based on the {@link #acceptsList} and the current
     * security context.
     * 
     * An example of an acceptsList might be <pre>Experimenter(myUserId, False)</pre>, meaning that
     * only scripts belonging to me should be trusted. An empty list implies that the server should
     * return what it would by default trust.
     * 
     * A valid script will be returned if it exists; otherwise null.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_validateScript(omero.model.Job j, java.util.List<omero.model.IObject> acceptsList, java.util.Map<String, String> __ctx, Ice.Callback __cb)
    {
        return begin_validateScript(j, acceptsList, __ctx, true, __cb);
    }

    /**
     * Used internally by processor.py to check if the script
     * attached to the {@link omero.model.Job} has a valid script
     * attached, based on the {@link #acceptsList} and the current
     * security context.
     * 
     * An example of an acceptsList might be <pre>Experimenter(myUserId, False)</pre>, meaning that
     * only scripts belonging to me should be trusted. An empty list implies that the server should
     * return what it would by default trust.
     * 
     * A valid script will be returned if it exists; otherwise null.
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_validateScript(omero.model.Job j, java.util.List<omero.model.IObject> acceptsList, Callback_IScript_validateScript __cb)
    {
        return begin_validateScript(j, acceptsList, null, false, __cb);
    }

    /**
     * Used internally by processor.py to check if the script
     * attached to the {@link omero.model.Job} has a valid script
     * attached, based on the {@link #acceptsList} and the current
     * security context.
     * 
     * An example of an acceptsList might be <pre>Experimenter(myUserId, False)</pre>, meaning that
     * only scripts belonging to me should be trusted. An empty list implies that the server should
     * return what it would by default trust.
     * 
     * A valid script will be returned if it exists; otherwise null.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_validateScript(omero.model.Job j, java.util.List<omero.model.IObject> acceptsList, java.util.Map<String, String> __ctx, Callback_IScript_validateScript __cb)
    {
        return begin_validateScript(j, acceptsList, __ctx, true, __cb);
    }

    private Ice.AsyncResult begin_validateScript(omero.model.Job j, java.util.List<omero.model.IObject> acceptsList, java.util.Map<String, String> __ctx, boolean __explicitCtx, IceInternal.CallbackBase __cb)
    {
        __checkAsyncTwowayOnly(__validateScript_name);
        IceInternal.OutgoingAsync __result = new IceInternal.OutgoingAsync(this, __validateScript_name, __cb);
        try
        {
            __result.__prepare(__validateScript_name, Ice.OperationMode.Idempotent, __ctx, __explicitCtx);
            IceInternal.BasicStream __os = __result.__startWriteParams(Ice.FormatType.DefaultFormat);
            __os.writeObject(j);
            IObjectListHelper.write(__os, acceptsList);
            __os.writePendingObjects();
            __result.__endWriteParams();
            __result.__send(true);
        }
        catch(Ice.LocalException __ex)
        {
            __result.__exceptionAsync(__ex);
        }
        return __result;
    }

    /**
     * ice_response indicates that
     * the operation completed successfully.
     **/
    public omero.model.OriginalFile end_validateScript(Ice.AsyncResult __result)
        throws omero.ServerError
    {
        Ice.AsyncResult.__check(__result, this, __validateScript_name);
        boolean __ok = __result.__wait();
        try
        {
            if(!__ok)
            {
                try
                {
                    __result.__throwUserException();
                }
                catch(omero.ServerError __ex)
                {
                    throw __ex;
                }
                catch(Ice.UserException __ex)
                {
                    throw new Ice.UnknownUserException(__ex.ice_name(), __ex);
                }
            }
            IceInternal.BasicStream __is = __result.__startReadParams();
            omero.model.OriginalFileHolder __ret = new omero.model.OriginalFileHolder();
            __is.readObject(__ret);
            __is.readPendingObjects();
            __result.__endReadParams();
            return __ret.value;
        }
        catch(Ice.LocalException ex)
        {
            Ice.Instrumentation.InvocationObserver __obsv = __result.__getObserver();
            if(__obsv != null)
            {
                __obsv.failed(ex.ice_name());
            }
            throw ex;
        }
    }

    /**
     * Used internally by processor.py to check if the script
     * attached to the {@link omero.model.Job} has a valid script
     * attached, based on the {@link #acceptsList} and the current
     * security context.
     * 
     * An example of an acceptsList might be <pre>Experimenter(myUserId, False)</pre>, meaning that
     * only scripts belonging to me should be trusted. An empty list implies that the server should
     * return what it would by default trust.
     * 
     * A valid script will be returned if it exists; otherwise null.
     * @param __cb The callback object for the operation.
     **/
    public boolean validateScript_async(AMI_IScript_validateScript __cb, omero.model.Job j, java.util.List<omero.model.IObject> acceptsList)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__validateScript_name);
            __r = begin_validateScript(j, acceptsList, null, false, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __validateScript_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    /**
     * Used internally by processor.py to check if the script
     * attached to the {@link omero.model.Job} has a valid script
     * attached, based on the {@link #acceptsList} and the current
     * security context.
     * 
     * An example of an acceptsList might be <pre>Experimenter(myUserId, False)</pre>, meaning that
     * only scripts belonging to me should be trusted. An empty list implies that the server should
     * return what it would by default trust.
     * 
     * A valid script will be returned if it exists; otherwise null.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean validateScript_async(AMI_IScript_validateScript __cb, omero.model.Job j, java.util.List<omero.model.IObject> acceptsList, java.util.Map<String, String> __ctx)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__validateScript_name);
            __r = begin_validateScript(j, acceptsList, __ctx, true, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __validateScript_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    public static IScriptPrx checkedCast(Ice.ObjectPrx __obj)
    {
        IScriptPrx __d = null;
        if(__obj != null)
        {
            if(__obj instanceof IScriptPrx)
            {
                __d = (IScriptPrx)__obj;
            }
            else
            {
                if(__obj.ice_isA(ice_staticId()))
                {
                    IScriptPrxHelper __h = new IScriptPrxHelper();
                    __h.__copyFrom(__obj);
                    __d = __h;
                }
            }
        }
        return __d;
    }

    public static IScriptPrx checkedCast(Ice.ObjectPrx __obj, java.util.Map<String, String> __ctx)
    {
        IScriptPrx __d = null;
        if(__obj != null)
        {
            if(__obj instanceof IScriptPrx)
            {
                __d = (IScriptPrx)__obj;
            }
            else
            {
                if(__obj.ice_isA(ice_staticId(), __ctx))
                {
                    IScriptPrxHelper __h = new IScriptPrxHelper();
                    __h.__copyFrom(__obj);
                    __d = __h;
                }
            }
        }
        return __d;
    }

    public static IScriptPrx checkedCast(Ice.ObjectPrx __obj, String __facet)
    {
        IScriptPrx __d = null;
        if(__obj != null)
        {
            Ice.ObjectPrx __bb = __obj.ice_facet(__facet);
            try
            {
                if(__bb.ice_isA(ice_staticId()))
                {
                    IScriptPrxHelper __h = new IScriptPrxHelper();
                    __h.__copyFrom(__bb);
                    __d = __h;
                }
            }
            catch(Ice.FacetNotExistException ex)
            {
            }
        }
        return __d;
    }

    public static IScriptPrx checkedCast(Ice.ObjectPrx __obj, String __facet, java.util.Map<String, String> __ctx)
    {
        IScriptPrx __d = null;
        if(__obj != null)
        {
            Ice.ObjectPrx __bb = __obj.ice_facet(__facet);
            try
            {
                if(__bb.ice_isA(ice_staticId(), __ctx))
                {
                    IScriptPrxHelper __h = new IScriptPrxHelper();
                    __h.__copyFrom(__bb);
                    __d = __h;
                }
            }
            catch(Ice.FacetNotExistException ex)
            {
            }
        }
        return __d;
    }

    public static IScriptPrx uncheckedCast(Ice.ObjectPrx __obj)
    {
        IScriptPrx __d = null;
        if(__obj != null)
        {
            if(__obj instanceof IScriptPrx)
            {
                __d = (IScriptPrx)__obj;
            }
            else
            {
                IScriptPrxHelper __h = new IScriptPrxHelper();
                __h.__copyFrom(__obj);
                __d = __h;
            }
        }
        return __d;
    }

    public static IScriptPrx uncheckedCast(Ice.ObjectPrx __obj, String __facet)
    {
        IScriptPrx __d = null;
        if(__obj != null)
        {
            Ice.ObjectPrx __bb = __obj.ice_facet(__facet);
            IScriptPrxHelper __h = new IScriptPrxHelper();
            __h.__copyFrom(__bb);
            __d = __h;
        }
        return __d;
    }

    public static final String[] __ids =
    {
        "::Ice::Object",
        "::omero::api::IScript",
        "::omero::api::ServiceInterface"
    };

    public static String ice_staticId()
    {
        return __ids[1];
    }

    protected Ice._ObjectDelM __createDelegateM()
    {
        return new _IScriptDelM();
    }

    protected Ice._ObjectDelD __createDelegateD()
    {
        return new _IScriptDelD();
    }

    public static void __write(IceInternal.BasicStream __os, IScriptPrx v)
    {
        __os.writeProxy(v);
    }

    public static IScriptPrx __read(IceInternal.BasicStream __is)
    {
        Ice.ObjectPrx proxy = __is.readProxy();
        if(proxy != null)
        {
            IScriptPrxHelper result = new IScriptPrxHelper();
            result.__copyFrom(proxy);
            return result;
        }
        return null;
    }

    public static final long serialVersionUID = 0L;
}
