// **********************************************************************
//
// Copyright (c) 2003-2013 ZeroC, Inc. All rights reserved.
//
// This copy of Ice is licensed to you under the terms described in the
// ICE_LICENSE file included in this distribution.
//
// **********************************************************************
//
// Ice version 3.5.1
//
// <auto-generated>
//
// Generated from file `ITimeline.ice'
//
// Warning: do not edit this file.
//
// </auto-generated>
//

package omero.api;

/**
 * Service for the querying of OMERO metadata based on creation and
 * modification time. Currently supported types for querying include:
 * <ul>
 * <li>{@link omero.model.Annotation}</li>
 * <li>{@link omero.model.Dataset}</li>
 * <li>{@link omero.model.Image}</li>
 * <li>{@link omero.model.Project}</li>
 * <li>{@link omero.model.RenderingDef}</li>
 * </ul>
 * 
 * <h4>Return maps</h4>
 * 
 * The map return values will be indexed by the short type name above:
 * <i>Project</i>, <i>Image</i>, ... All keys which are passed in the
 * StringSet argument will be included in the returned map, even if
 * they have no values. A default value of 0 or the empty list \[]
 * will be used.
 * The only exception to this rule is that the null or empty StringSet
 * implies all valid keys.
 * 
 * <h4>Parameters</h4>
 * 
 * All methods take a omero::sys::Parameters object and will apply the filter
 * object for paging through the data in order to prevent loading too
 * many objects. If the parameters argument is null or no paging is activated,
 * then the default will be: OFFSET=0, LIMIT=50. Filter.ownerId and
 * Filter.groupId will also be AND'ed to the query if either value is present.
 * If both are null, then the current user id will be used. To retrieve for
 * all users, use <code>ownerId == rlong(-1)</code> and
 * <code>groupId == null</code>.
 * 
 * <h4>Merging</h4>
 * 
 * The methods which take a StringSet and a Parameters object, also
 * have a <i>bool merge</i> argument. This argument defines whether or
 * not the LIMIT applies to each object independently
 * (<code>["a","b"] @ 100 == 200</code>) or merges the lists together
 * chronologically (<code>["a","b"] @ 100 merged == 100</code>).
 * 
 * <h4>Time used</h4>
 * 
 * Except for Image, IObject.details.updateEvent is used in all cases
 * for determining most recent events. Images are compared via
 * Image.acquisitionDate which is unlike the other properties is
 * modifiable by the user.
 * 
 * 
 * 
 * A typical invocation might look like (in Python):
 * <pre>
 * timeline = sf.getTimelineService()
 * params = ParametersI().page(0,100)
 * types = \["Project","Dataset"])
 * map = timeline.getByPeriod(types, params, False)
 * </pre>
 * At this point, map will not contain more than 200 objects.
 * 
 * This service is defined only in Blitz and so no javadoc is available
 * in the ome.api package.
 * 
 * TODOS: binning, stateful caching, ...
 **/
public final class ITimelinePrxHelper extends Ice.ObjectPrxHelperBase implements ITimelinePrx
{
    private static final String __countByPeriod_name = "countByPeriod";

    /**
     * Queries the same information as getByPeriod, but only returns the counts
     * for the given objects.
     **/
    public java.util.Map<java.lang.String, java.lang.Long> countByPeriod(java.util.List<String> types, omero.RTime start, omero.RTime end, omero.sys.Parameters p)
        throws omero.ServerError
    {
        return countByPeriod(types, start, end, p, null, false);
    }

    /**
     * Queries the same information as getByPeriod, but only returns the counts
     * for the given objects.
     * @param __ctx The Context map to send with the invocation.
     **/
    public java.util.Map<java.lang.String, java.lang.Long> countByPeriod(java.util.List<String> types, omero.RTime start, omero.RTime end, omero.sys.Parameters p, java.util.Map<String, String> __ctx)
        throws omero.ServerError
    {
        return countByPeriod(types, start, end, p, __ctx, true);
    }

    private java.util.Map<java.lang.String, java.lang.Long> countByPeriod(java.util.List<String> types, omero.RTime start, omero.RTime end, omero.sys.Parameters p, java.util.Map<String, String> __ctx, boolean __explicitCtx)
        throws omero.ServerError
    {
        if(__explicitCtx && __ctx == null)
        {
            __ctx = _emptyContext;
        }
        final Ice.Instrumentation.InvocationObserver __observer = IceInternal.ObserverHelper.get(this, "countByPeriod", __ctx);
        int __cnt = 0;
        try
        {
            while(true)
            {
                Ice._ObjectDel __delBase = null;
                try
                {
                    __checkTwowayOnly("countByPeriod");
                    __delBase = __getDelegate(false);
                    _ITimelineDel __del = (_ITimelineDel)__delBase;
                    return __del.countByPeriod(types, start, end, p, __ctx, __observer);
                }
                catch(IceInternal.LocalExceptionWrapper __ex)
                {
                    __cnt = __handleExceptionWrapperRelaxed(__delBase, __ex, null, __cnt, __observer);
                }
                catch(Ice.LocalException __ex)
                {
                    __cnt = __handleException(__delBase, __ex, null, __cnt, __observer);
                }
            }
        }
        finally
        {
            if(__observer != null)
            {
                __observer.detach();
            }
        }
    }

    /**
     * Queries the same information as getByPeriod, but only returns the counts
     * for the given objects.
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_countByPeriod(java.util.List<String> types, omero.RTime start, omero.RTime end, omero.sys.Parameters p)
    {
        return begin_countByPeriod(types, start, end, p, null, false, null);
    }

    /**
     * Queries the same information as getByPeriod, but only returns the counts
     * for the given objects.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_countByPeriod(java.util.List<String> types, omero.RTime start, omero.RTime end, omero.sys.Parameters p, java.util.Map<String, String> __ctx)
    {
        return begin_countByPeriod(types, start, end, p, __ctx, true, null);
    }

    /**
     * Queries the same information as getByPeriod, but only returns the counts
     * for the given objects.
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_countByPeriod(java.util.List<String> types, omero.RTime start, omero.RTime end, omero.sys.Parameters p, Ice.Callback __cb)
    {
        return begin_countByPeriod(types, start, end, p, null, false, __cb);
    }

    /**
     * Queries the same information as getByPeriod, but only returns the counts
     * for the given objects.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_countByPeriod(java.util.List<String> types, omero.RTime start, omero.RTime end, omero.sys.Parameters p, java.util.Map<String, String> __ctx, Ice.Callback __cb)
    {
        return begin_countByPeriod(types, start, end, p, __ctx, true, __cb);
    }

    /**
     * Queries the same information as getByPeriod, but only returns the counts
     * for the given objects.
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_countByPeriod(java.util.List<String> types, omero.RTime start, omero.RTime end, omero.sys.Parameters p, Callback_ITimeline_countByPeriod __cb)
    {
        return begin_countByPeriod(types, start, end, p, null, false, __cb);
    }

    /**
     * Queries the same information as getByPeriod, but only returns the counts
     * for the given objects.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_countByPeriod(java.util.List<String> types, omero.RTime start, omero.RTime end, omero.sys.Parameters p, java.util.Map<String, String> __ctx, Callback_ITimeline_countByPeriod __cb)
    {
        return begin_countByPeriod(types, start, end, p, __ctx, true, __cb);
    }

    private Ice.AsyncResult begin_countByPeriod(java.util.List<String> types, omero.RTime start, omero.RTime end, omero.sys.Parameters p, java.util.Map<String, String> __ctx, boolean __explicitCtx, IceInternal.CallbackBase __cb)
    {
        __checkAsyncTwowayOnly(__countByPeriod_name);
        IceInternal.OutgoingAsync __result = new IceInternal.OutgoingAsync(this, __countByPeriod_name, __cb);
        try
        {
            __result.__prepare(__countByPeriod_name, Ice.OperationMode.Idempotent, __ctx, __explicitCtx);
            IceInternal.BasicStream __os = __result.__startWriteParams(Ice.FormatType.DefaultFormat);
            StringSetHelper.write(__os, types);
            __os.writeObject(start);
            __os.writeObject(end);
            __os.writeObject(p);
            __os.writePendingObjects();
            __result.__endWriteParams();
            __result.__send(true);
        }
        catch(Ice.LocalException __ex)
        {
            __result.__exceptionAsync(__ex);
        }
        return __result;
    }

    /**
     * ice_response indicates that
     * the operation completed successfully.
     **/
    public java.util.Map<java.lang.String, java.lang.Long> end_countByPeriod(Ice.AsyncResult __result)
        throws omero.ServerError
    {
        Ice.AsyncResult.__check(__result, this, __countByPeriod_name);
        boolean __ok = __result.__wait();
        try
        {
            if(!__ok)
            {
                try
                {
                    __result.__throwUserException();
                }
                catch(omero.ServerError __ex)
                {
                    throw __ex;
                }
                catch(Ice.UserException __ex)
                {
                    throw new Ice.UnknownUserException(__ex.ice_name(), __ex);
                }
            }
            IceInternal.BasicStream __is = __result.__startReadParams();
            java.util.Map<java.lang.String, java.lang.Long> __ret;
            __ret = StringLongMapHelper.read(__is);
            __result.__endReadParams();
            return __ret;
        }
        catch(Ice.LocalException ex)
        {
            Ice.Instrumentation.InvocationObserver __obsv = __result.__getObserver();
            if(__obsv != null)
            {
                __obsv.failed(ex.ice_name());
            }
            throw ex;
        }
    }

    /**
     * Queries the same information as getByPeriod, but only returns the counts
     * for the given objects.
     * @param __cb The callback object for the operation.
     **/
    public boolean countByPeriod_async(AMI_ITimeline_countByPeriod __cb, java.util.List<String> types, omero.RTime start, omero.RTime end, omero.sys.Parameters p)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__countByPeriod_name);
            __r = begin_countByPeriod(types, start, end, p, null, false, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __countByPeriod_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    /**
     * Queries the same information as getByPeriod, but only returns the counts
     * for the given objects.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean countByPeriod_async(AMI_ITimeline_countByPeriod __cb, java.util.List<String> types, omero.RTime start, omero.RTime end, omero.sys.Parameters p, java.util.Map<String, String> __ctx)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__countByPeriod_name);
            __r = begin_countByPeriod(types, start, end, p, __ctx, true, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __countByPeriod_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    private static final String __getByPeriod_name = "getByPeriod";

    /**
     * Returns the given LIMIT objects of TYPES as ordered by
     * creation/modification times in the Event table, but
     * within the given time window.
     **/
    public java.util.Map<java.lang.String, java.util.List<omero.model.IObject>> getByPeriod(java.util.List<String> types, omero.RTime start, omero.RTime end, omero.sys.Parameters p, boolean merge)
        throws omero.ServerError
    {
        return getByPeriod(types, start, end, p, merge, null, false);
    }

    /**
     * Returns the given LIMIT objects of TYPES as ordered by
     * creation/modification times in the Event table, but
     * within the given time window.
     * @param __ctx The Context map to send with the invocation.
     **/
    public java.util.Map<java.lang.String, java.util.List<omero.model.IObject>> getByPeriod(java.util.List<String> types, omero.RTime start, omero.RTime end, omero.sys.Parameters p, boolean merge, java.util.Map<String, String> __ctx)
        throws omero.ServerError
    {
        return getByPeriod(types, start, end, p, merge, __ctx, true);
    }

    private java.util.Map<java.lang.String, java.util.List<omero.model.IObject>> getByPeriod(java.util.List<String> types, omero.RTime start, omero.RTime end, omero.sys.Parameters p, boolean merge, java.util.Map<String, String> __ctx, boolean __explicitCtx)
        throws omero.ServerError
    {
        if(__explicitCtx && __ctx == null)
        {
            __ctx = _emptyContext;
        }
        final Ice.Instrumentation.InvocationObserver __observer = IceInternal.ObserverHelper.get(this, "getByPeriod", __ctx);
        int __cnt = 0;
        try
        {
            while(true)
            {
                Ice._ObjectDel __delBase = null;
                try
                {
                    __checkTwowayOnly("getByPeriod");
                    __delBase = __getDelegate(false);
                    _ITimelineDel __del = (_ITimelineDel)__delBase;
                    return __del.getByPeriod(types, start, end, p, merge, __ctx, __observer);
                }
                catch(IceInternal.LocalExceptionWrapper __ex)
                {
                    __cnt = __handleExceptionWrapperRelaxed(__delBase, __ex, null, __cnt, __observer);
                }
                catch(Ice.LocalException __ex)
                {
                    __cnt = __handleException(__delBase, __ex, null, __cnt, __observer);
                }
            }
        }
        finally
        {
            if(__observer != null)
            {
                __observer.detach();
            }
        }
    }

    /**
     * Returns the given LIMIT objects of TYPES as ordered by
     * creation/modification times in the Event table, but
     * within the given time window.
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_getByPeriod(java.util.List<String> types, omero.RTime start, omero.RTime end, omero.sys.Parameters p, boolean merge)
    {
        return begin_getByPeriod(types, start, end, p, merge, null, false, null);
    }

    /**
     * Returns the given LIMIT objects of TYPES as ordered by
     * creation/modification times in the Event table, but
     * within the given time window.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_getByPeriod(java.util.List<String> types, omero.RTime start, omero.RTime end, omero.sys.Parameters p, boolean merge, java.util.Map<String, String> __ctx)
    {
        return begin_getByPeriod(types, start, end, p, merge, __ctx, true, null);
    }

    /**
     * Returns the given LIMIT objects of TYPES as ordered by
     * creation/modification times in the Event table, but
     * within the given time window.
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_getByPeriod(java.util.List<String> types, omero.RTime start, omero.RTime end, omero.sys.Parameters p, boolean merge, Ice.Callback __cb)
    {
        return begin_getByPeriod(types, start, end, p, merge, null, false, __cb);
    }

    /**
     * Returns the given LIMIT objects of TYPES as ordered by
     * creation/modification times in the Event table, but
     * within the given time window.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_getByPeriod(java.util.List<String> types, omero.RTime start, omero.RTime end, omero.sys.Parameters p, boolean merge, java.util.Map<String, String> __ctx, Ice.Callback __cb)
    {
        return begin_getByPeriod(types, start, end, p, merge, __ctx, true, __cb);
    }

    /**
     * Returns the given LIMIT objects of TYPES as ordered by
     * creation/modification times in the Event table, but
     * within the given time window.
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_getByPeriod(java.util.List<String> types, omero.RTime start, omero.RTime end, omero.sys.Parameters p, boolean merge, Callback_ITimeline_getByPeriod __cb)
    {
        return begin_getByPeriod(types, start, end, p, merge, null, false, __cb);
    }

    /**
     * Returns the given LIMIT objects of TYPES as ordered by
     * creation/modification times in the Event table, but
     * within the given time window.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_getByPeriod(java.util.List<String> types, omero.RTime start, omero.RTime end, omero.sys.Parameters p, boolean merge, java.util.Map<String, String> __ctx, Callback_ITimeline_getByPeriod __cb)
    {
        return begin_getByPeriod(types, start, end, p, merge, __ctx, true, __cb);
    }

    private Ice.AsyncResult begin_getByPeriod(java.util.List<String> types, omero.RTime start, omero.RTime end, omero.sys.Parameters p, boolean merge, java.util.Map<String, String> __ctx, boolean __explicitCtx, IceInternal.CallbackBase __cb)
    {
        __checkAsyncTwowayOnly(__getByPeriod_name);
        IceInternal.OutgoingAsync __result = new IceInternal.OutgoingAsync(this, __getByPeriod_name, __cb);
        try
        {
            __result.__prepare(__getByPeriod_name, Ice.OperationMode.Idempotent, __ctx, __explicitCtx);
            IceInternal.BasicStream __os = __result.__startWriteParams(Ice.FormatType.DefaultFormat);
            StringSetHelper.write(__os, types);
            __os.writeObject(start);
            __os.writeObject(end);
            __os.writeObject(p);
            __os.writeBool(merge);
            __os.writePendingObjects();
            __result.__endWriteParams();
            __result.__send(true);
        }
        catch(Ice.LocalException __ex)
        {
            __result.__exceptionAsync(__ex);
        }
        return __result;
    }

    /**
     * ice_response indicates that
     * the operation completed successfully.
     **/
    public java.util.Map<java.lang.String, java.util.List<omero.model.IObject>> end_getByPeriod(Ice.AsyncResult __result)
        throws omero.ServerError
    {
        Ice.AsyncResult.__check(__result, this, __getByPeriod_name);
        boolean __ok = __result.__wait();
        try
        {
            if(!__ok)
            {
                try
                {
                    __result.__throwUserException();
                }
                catch(omero.ServerError __ex)
                {
                    throw __ex;
                }
                catch(Ice.UserException __ex)
                {
                    throw new Ice.UnknownUserException(__ex.ice_name(), __ex);
                }
            }
            IceInternal.BasicStream __is = __result.__startReadParams();
            java.util.Map<java.lang.String, java.util.List<omero.model.IObject>> __ret;
            __ret = IObjectListMapHelper.read(__is);
            __is.readPendingObjects();
            __result.__endReadParams();
            return __ret;
        }
        catch(Ice.LocalException ex)
        {
            Ice.Instrumentation.InvocationObserver __obsv = __result.__getObserver();
            if(__obsv != null)
            {
                __obsv.failed(ex.ice_name());
            }
            throw ex;
        }
    }

    /**
     * Returns the given LIMIT objects of TYPES as ordered by
     * creation/modification times in the Event table, but
     * within the given time window.
     * @param __cb The callback object for the operation.
     **/
    public boolean getByPeriod_async(AMI_ITimeline_getByPeriod __cb, java.util.List<String> types, omero.RTime start, omero.RTime end, omero.sys.Parameters p, boolean merge)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__getByPeriod_name);
            __r = begin_getByPeriod(types, start, end, p, merge, null, false, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __getByPeriod_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    /**
     * Returns the given LIMIT objects of TYPES as ordered by
     * creation/modification times in the Event table, but
     * within the given time window.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean getByPeriod_async(AMI_ITimeline_getByPeriod __cb, java.util.List<String> types, omero.RTime start, omero.RTime end, omero.sys.Parameters p, boolean merge, java.util.Map<String, String> __ctx)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__getByPeriod_name);
            __r = begin_getByPeriod(types, start, end, p, merge, __ctx, true, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __getByPeriod_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    private static final String __getEventLogsByPeriod_name = "getEventLogsByPeriod";

    /**
     * Returns the EventLog table objects which are queried to produce the counts above.
     * Note the concept of <i>period inclusion</i> mentioned above.
     * 
     * WORKAROUND WARNING: this method returns non-managed EventLogs (i.e.
     * eventLog.getId() == null) for <i>Image acquisitions</i>.
     **/
    public java.util.List<omero.model.EventLog> getEventLogsByPeriod(omero.RTime start, omero.RTime end, omero.sys.Parameters p)
        throws omero.ServerError
    {
        return getEventLogsByPeriod(start, end, p, null, false);
    }

    /**
     * Returns the EventLog table objects which are queried to produce the counts above.
     * Note the concept of <i>period inclusion</i> mentioned above.
     * 
     * WORKAROUND WARNING: this method returns non-managed EventLogs (i.e.
     * eventLog.getId() == null) for <i>Image acquisitions</i>.
     * @param __ctx The Context map to send with the invocation.
     **/
    public java.util.List<omero.model.EventLog> getEventLogsByPeriod(omero.RTime start, omero.RTime end, omero.sys.Parameters p, java.util.Map<String, String> __ctx)
        throws omero.ServerError
    {
        return getEventLogsByPeriod(start, end, p, __ctx, true);
    }

    private java.util.List<omero.model.EventLog> getEventLogsByPeriod(omero.RTime start, omero.RTime end, omero.sys.Parameters p, java.util.Map<String, String> __ctx, boolean __explicitCtx)
        throws omero.ServerError
    {
        if(__explicitCtx && __ctx == null)
        {
            __ctx = _emptyContext;
        }
        final Ice.Instrumentation.InvocationObserver __observer = IceInternal.ObserverHelper.get(this, "getEventLogsByPeriod", __ctx);
        int __cnt = 0;
        try
        {
            while(true)
            {
                Ice._ObjectDel __delBase = null;
                try
                {
                    __checkTwowayOnly("getEventLogsByPeriod");
                    __delBase = __getDelegate(false);
                    _ITimelineDel __del = (_ITimelineDel)__delBase;
                    return __del.getEventLogsByPeriod(start, end, p, __ctx, __observer);
                }
                catch(IceInternal.LocalExceptionWrapper __ex)
                {
                    __cnt = __handleExceptionWrapperRelaxed(__delBase, __ex, null, __cnt, __observer);
                }
                catch(Ice.LocalException __ex)
                {
                    __cnt = __handleException(__delBase, __ex, null, __cnt, __observer);
                }
            }
        }
        finally
        {
            if(__observer != null)
            {
                __observer.detach();
            }
        }
    }

    /**
     * Returns the EventLog table objects which are queried to produce the counts above.
     * Note the concept of <i>period inclusion</i> mentioned above.
     * 
     * WORKAROUND WARNING: this method returns non-managed EventLogs (i.e.
     * eventLog.getId() == null) for <i>Image acquisitions</i>.
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_getEventLogsByPeriod(omero.RTime start, omero.RTime end, omero.sys.Parameters p)
    {
        return begin_getEventLogsByPeriod(start, end, p, null, false, null);
    }

    /**
     * Returns the EventLog table objects which are queried to produce the counts above.
     * Note the concept of <i>period inclusion</i> mentioned above.
     * 
     * WORKAROUND WARNING: this method returns non-managed EventLogs (i.e.
     * eventLog.getId() == null) for <i>Image acquisitions</i>.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_getEventLogsByPeriod(omero.RTime start, omero.RTime end, omero.sys.Parameters p, java.util.Map<String, String> __ctx)
    {
        return begin_getEventLogsByPeriod(start, end, p, __ctx, true, null);
    }

    /**
     * Returns the EventLog table objects which are queried to produce the counts above.
     * Note the concept of <i>period inclusion</i> mentioned above.
     * 
     * WORKAROUND WARNING: this method returns non-managed EventLogs (i.e.
     * eventLog.getId() == null) for <i>Image acquisitions</i>.
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_getEventLogsByPeriod(omero.RTime start, omero.RTime end, omero.sys.Parameters p, Ice.Callback __cb)
    {
        return begin_getEventLogsByPeriod(start, end, p, null, false, __cb);
    }

    /**
     * Returns the EventLog table objects which are queried to produce the counts above.
     * Note the concept of <i>period inclusion</i> mentioned above.
     * 
     * WORKAROUND WARNING: this method returns non-managed EventLogs (i.e.
     * eventLog.getId() == null) for <i>Image acquisitions</i>.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_getEventLogsByPeriod(omero.RTime start, omero.RTime end, omero.sys.Parameters p, java.util.Map<String, String> __ctx, Ice.Callback __cb)
    {
        return begin_getEventLogsByPeriod(start, end, p, __ctx, true, __cb);
    }

    /**
     * Returns the EventLog table objects which are queried to produce the counts above.
     * Note the concept of <i>period inclusion</i> mentioned above.
     * 
     * WORKAROUND WARNING: this method returns non-managed EventLogs (i.e.
     * eventLog.getId() == null) for <i>Image acquisitions</i>.
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_getEventLogsByPeriod(omero.RTime start, omero.RTime end, omero.sys.Parameters p, Callback_ITimeline_getEventLogsByPeriod __cb)
    {
        return begin_getEventLogsByPeriod(start, end, p, null, false, __cb);
    }

    /**
     * Returns the EventLog table objects which are queried to produce the counts above.
     * Note the concept of <i>period inclusion</i> mentioned above.
     * 
     * WORKAROUND WARNING: this method returns non-managed EventLogs (i.e.
     * eventLog.getId() == null) for <i>Image acquisitions</i>.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_getEventLogsByPeriod(omero.RTime start, omero.RTime end, omero.sys.Parameters p, java.util.Map<String, String> __ctx, Callback_ITimeline_getEventLogsByPeriod __cb)
    {
        return begin_getEventLogsByPeriod(start, end, p, __ctx, true, __cb);
    }

    private Ice.AsyncResult begin_getEventLogsByPeriod(omero.RTime start, omero.RTime end, omero.sys.Parameters p, java.util.Map<String, String> __ctx, boolean __explicitCtx, IceInternal.CallbackBase __cb)
    {
        __checkAsyncTwowayOnly(__getEventLogsByPeriod_name);
        IceInternal.OutgoingAsync __result = new IceInternal.OutgoingAsync(this, __getEventLogsByPeriod_name, __cb);
        try
        {
            __result.__prepare(__getEventLogsByPeriod_name, Ice.OperationMode.Idempotent, __ctx, __explicitCtx);
            IceInternal.BasicStream __os = __result.__startWriteParams(Ice.FormatType.DefaultFormat);
            __os.writeObject(start);
            __os.writeObject(end);
            __os.writeObject(p);
            __os.writePendingObjects();
            __result.__endWriteParams();
            __result.__send(true);
        }
        catch(Ice.LocalException __ex)
        {
            __result.__exceptionAsync(__ex);
        }
        return __result;
    }

    /**
     * ice_response indicates that
     * the operation completed successfully.
     **/
    public java.util.List<omero.model.EventLog> end_getEventLogsByPeriod(Ice.AsyncResult __result)
        throws omero.ServerError
    {
        Ice.AsyncResult.__check(__result, this, __getEventLogsByPeriod_name);
        boolean __ok = __result.__wait();
        try
        {
            if(!__ok)
            {
                try
                {
                    __result.__throwUserException();
                }
                catch(omero.ServerError __ex)
                {
                    throw __ex;
                }
                catch(Ice.UserException __ex)
                {
                    throw new Ice.UnknownUserException(__ex.ice_name(), __ex);
                }
            }
            IceInternal.BasicStream __is = __result.__startReadParams();
            java.util.List<omero.model.EventLog> __ret;
            __ret = EventLogListHelper.read(__is);
            __is.readPendingObjects();
            __result.__endReadParams();
            return __ret;
        }
        catch(Ice.LocalException ex)
        {
            Ice.Instrumentation.InvocationObserver __obsv = __result.__getObserver();
            if(__obsv != null)
            {
                __obsv.failed(ex.ice_name());
            }
            throw ex;
        }
    }

    /**
     * Returns the EventLog table objects which are queried to produce the counts above.
     * Note the concept of <i>period inclusion</i> mentioned above.
     * 
     * WORKAROUND WARNING: this method returns non-managed EventLogs (i.e.
     * eventLog.getId() == null) for <i>Image acquisitions</i>.
     * @param __cb The callback object for the operation.
     **/
    public boolean getEventLogsByPeriod_async(AMI_ITimeline_getEventLogsByPeriod __cb, omero.RTime start, omero.RTime end, omero.sys.Parameters p)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__getEventLogsByPeriod_name);
            __r = begin_getEventLogsByPeriod(start, end, p, null, false, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __getEventLogsByPeriod_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    /**
     * Returns the EventLog table objects which are queried to produce the counts above.
     * Note the concept of <i>period inclusion</i> mentioned above.
     * 
     * WORKAROUND WARNING: this method returns non-managed EventLogs (i.e.
     * eventLog.getId() == null) for <i>Image acquisitions</i>.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean getEventLogsByPeriod_async(AMI_ITimeline_getEventLogsByPeriod __cb, omero.RTime start, omero.RTime end, omero.sys.Parameters p, java.util.Map<String, String> __ctx)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__getEventLogsByPeriod_name);
            __r = begin_getEventLogsByPeriod(start, end, p, __ctx, true, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __getEventLogsByPeriod_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    private static final String __getMostRecentAnnotationLinks_name = "getMostRecentAnnotationLinks";

    /**
     * Return the last LIMIT annotation __Links__ whose parent (IAnnotated)
     * matches one of the parentTypes, whose child (Annotation) matches one
     * of the childTypes (limit of one for the moment), and who namespace
     * matches via ILIKE.
     * 
     * The parents and children will be unloaded. The link will have
     * its creation/update events loaded.
     * 
     * If Parameters.theFilter.ownerId or groupId are set, they will be
     * AND'ed to the query to filter results.
     * 
     * Merges by default based on parentType.
     **/
    public java.util.List<omero.model.IObject> getMostRecentAnnotationLinks(java.util.List<String> parentTypes, java.util.List<String> childTypes, java.util.List<String> namespaces, omero.sys.Parameters p)
        throws omero.ServerError
    {
        return getMostRecentAnnotationLinks(parentTypes, childTypes, namespaces, p, null, false);
    }

    /**
     * Return the last LIMIT annotation __Links__ whose parent (IAnnotated)
     * matches one of the parentTypes, whose child (Annotation) matches one
     * of the childTypes (limit of one for the moment), and who namespace
     * matches via ILIKE.
     * 
     * The parents and children will be unloaded. The link will have
     * its creation/update events loaded.
     * 
     * If Parameters.theFilter.ownerId or groupId are set, they will be
     * AND'ed to the query to filter results.
     * 
     * Merges by default based on parentType.
     * @param __ctx The Context map to send with the invocation.
     **/
    public java.util.List<omero.model.IObject> getMostRecentAnnotationLinks(java.util.List<String> parentTypes, java.util.List<String> childTypes, java.util.List<String> namespaces, omero.sys.Parameters p, java.util.Map<String, String> __ctx)
        throws omero.ServerError
    {
        return getMostRecentAnnotationLinks(parentTypes, childTypes, namespaces, p, __ctx, true);
    }

    private java.util.List<omero.model.IObject> getMostRecentAnnotationLinks(java.util.List<String> parentTypes, java.util.List<String> childTypes, java.util.List<String> namespaces, omero.sys.Parameters p, java.util.Map<String, String> __ctx, boolean __explicitCtx)
        throws omero.ServerError
    {
        if(__explicitCtx && __ctx == null)
        {
            __ctx = _emptyContext;
        }
        final Ice.Instrumentation.InvocationObserver __observer = IceInternal.ObserverHelper.get(this, "getMostRecentAnnotationLinks", __ctx);
        int __cnt = 0;
        try
        {
            while(true)
            {
                Ice._ObjectDel __delBase = null;
                try
                {
                    __checkTwowayOnly("getMostRecentAnnotationLinks");
                    __delBase = __getDelegate(false);
                    _ITimelineDel __del = (_ITimelineDel)__delBase;
                    return __del.getMostRecentAnnotationLinks(parentTypes, childTypes, namespaces, p, __ctx, __observer);
                }
                catch(IceInternal.LocalExceptionWrapper __ex)
                {
                    __cnt = __handleExceptionWrapperRelaxed(__delBase, __ex, null, __cnt, __observer);
                }
                catch(Ice.LocalException __ex)
                {
                    __cnt = __handleException(__delBase, __ex, null, __cnt, __observer);
                }
            }
        }
        finally
        {
            if(__observer != null)
            {
                __observer.detach();
            }
        }
    }

    /**
     * Return the last LIMIT annotation __Links__ whose parent (IAnnotated)
     * matches one of the parentTypes, whose child (Annotation) matches one
     * of the childTypes (limit of one for the moment), and who namespace
     * matches via ILIKE.
     * 
     * The parents and children will be unloaded. The link will have
     * its creation/update events loaded.
     * 
     * If Parameters.theFilter.ownerId or groupId are set, they will be
     * AND'ed to the query to filter results.
     * 
     * Merges by default based on parentType.
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_getMostRecentAnnotationLinks(java.util.List<String> parentTypes, java.util.List<String> childTypes, java.util.List<String> namespaces, omero.sys.Parameters p)
    {
        return begin_getMostRecentAnnotationLinks(parentTypes, childTypes, namespaces, p, null, false, null);
    }

    /**
     * Return the last LIMIT annotation __Links__ whose parent (IAnnotated)
     * matches one of the parentTypes, whose child (Annotation) matches one
     * of the childTypes (limit of one for the moment), and who namespace
     * matches via ILIKE.
     * 
     * The parents and children will be unloaded. The link will have
     * its creation/update events loaded.
     * 
     * If Parameters.theFilter.ownerId or groupId are set, they will be
     * AND'ed to the query to filter results.
     * 
     * Merges by default based on parentType.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_getMostRecentAnnotationLinks(java.util.List<String> parentTypes, java.util.List<String> childTypes, java.util.List<String> namespaces, omero.sys.Parameters p, java.util.Map<String, String> __ctx)
    {
        return begin_getMostRecentAnnotationLinks(parentTypes, childTypes, namespaces, p, __ctx, true, null);
    }

    /**
     * Return the last LIMIT annotation __Links__ whose parent (IAnnotated)
     * matches one of the parentTypes, whose child (Annotation) matches one
     * of the childTypes (limit of one for the moment), and who namespace
     * matches via ILIKE.
     * 
     * The parents and children will be unloaded. The link will have
     * its creation/update events loaded.
     * 
     * If Parameters.theFilter.ownerId or groupId are set, they will be
     * AND'ed to the query to filter results.
     * 
     * Merges by default based on parentType.
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_getMostRecentAnnotationLinks(java.util.List<String> parentTypes, java.util.List<String> childTypes, java.util.List<String> namespaces, omero.sys.Parameters p, Ice.Callback __cb)
    {
        return begin_getMostRecentAnnotationLinks(parentTypes, childTypes, namespaces, p, null, false, __cb);
    }

    /**
     * Return the last LIMIT annotation __Links__ whose parent (IAnnotated)
     * matches one of the parentTypes, whose child (Annotation) matches one
     * of the childTypes (limit of one for the moment), and who namespace
     * matches via ILIKE.
     * 
     * The parents and children will be unloaded. The link will have
     * its creation/update events loaded.
     * 
     * If Parameters.theFilter.ownerId or groupId are set, they will be
     * AND'ed to the query to filter results.
     * 
     * Merges by default based on parentType.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_getMostRecentAnnotationLinks(java.util.List<String> parentTypes, java.util.List<String> childTypes, java.util.List<String> namespaces, omero.sys.Parameters p, java.util.Map<String, String> __ctx, Ice.Callback __cb)
    {
        return begin_getMostRecentAnnotationLinks(parentTypes, childTypes, namespaces, p, __ctx, true, __cb);
    }

    /**
     * Return the last LIMIT annotation __Links__ whose parent (IAnnotated)
     * matches one of the parentTypes, whose child (Annotation) matches one
     * of the childTypes (limit of one for the moment), and who namespace
     * matches via ILIKE.
     * 
     * The parents and children will be unloaded. The link will have
     * its creation/update events loaded.
     * 
     * If Parameters.theFilter.ownerId or groupId are set, they will be
     * AND'ed to the query to filter results.
     * 
     * Merges by default based on parentType.
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_getMostRecentAnnotationLinks(java.util.List<String> parentTypes, java.util.List<String> childTypes, java.util.List<String> namespaces, omero.sys.Parameters p, Callback_ITimeline_getMostRecentAnnotationLinks __cb)
    {
        return begin_getMostRecentAnnotationLinks(parentTypes, childTypes, namespaces, p, null, false, __cb);
    }

    /**
     * Return the last LIMIT annotation __Links__ whose parent (IAnnotated)
     * matches one of the parentTypes, whose child (Annotation) matches one
     * of the childTypes (limit of one for the moment), and who namespace
     * matches via ILIKE.
     * 
     * The parents and children will be unloaded. The link will have
     * its creation/update events loaded.
     * 
     * If Parameters.theFilter.ownerId or groupId are set, they will be
     * AND'ed to the query to filter results.
     * 
     * Merges by default based on parentType.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_getMostRecentAnnotationLinks(java.util.List<String> parentTypes, java.util.List<String> childTypes, java.util.List<String> namespaces, omero.sys.Parameters p, java.util.Map<String, String> __ctx, Callback_ITimeline_getMostRecentAnnotationLinks __cb)
    {
        return begin_getMostRecentAnnotationLinks(parentTypes, childTypes, namespaces, p, __ctx, true, __cb);
    }

    private Ice.AsyncResult begin_getMostRecentAnnotationLinks(java.util.List<String> parentTypes, java.util.List<String> childTypes, java.util.List<String> namespaces, omero.sys.Parameters p, java.util.Map<String, String> __ctx, boolean __explicitCtx, IceInternal.CallbackBase __cb)
    {
        __checkAsyncTwowayOnly(__getMostRecentAnnotationLinks_name);
        IceInternal.OutgoingAsync __result = new IceInternal.OutgoingAsync(this, __getMostRecentAnnotationLinks_name, __cb);
        try
        {
            __result.__prepare(__getMostRecentAnnotationLinks_name, Ice.OperationMode.Idempotent, __ctx, __explicitCtx);
            IceInternal.BasicStream __os = __result.__startWriteParams(Ice.FormatType.DefaultFormat);
            StringSetHelper.write(__os, parentTypes);
            StringSetHelper.write(__os, childTypes);
            StringSetHelper.write(__os, namespaces);
            __os.writeObject(p);
            __os.writePendingObjects();
            __result.__endWriteParams();
            __result.__send(true);
        }
        catch(Ice.LocalException __ex)
        {
            __result.__exceptionAsync(__ex);
        }
        return __result;
    }

    /**
     * ice_response indicates that
     * the operation completed successfully.
     **/
    public java.util.List<omero.model.IObject> end_getMostRecentAnnotationLinks(Ice.AsyncResult __result)
        throws omero.ServerError
    {
        Ice.AsyncResult.__check(__result, this, __getMostRecentAnnotationLinks_name);
        boolean __ok = __result.__wait();
        try
        {
            if(!__ok)
            {
                try
                {
                    __result.__throwUserException();
                }
                catch(omero.ServerError __ex)
                {
                    throw __ex;
                }
                catch(Ice.UserException __ex)
                {
                    throw new Ice.UnknownUserException(__ex.ice_name(), __ex);
                }
            }
            IceInternal.BasicStream __is = __result.__startReadParams();
            java.util.List<omero.model.IObject> __ret;
            __ret = IObjectListHelper.read(__is);
            __is.readPendingObjects();
            __result.__endReadParams();
            return __ret;
        }
        catch(Ice.LocalException ex)
        {
            Ice.Instrumentation.InvocationObserver __obsv = __result.__getObserver();
            if(__obsv != null)
            {
                __obsv.failed(ex.ice_name());
            }
            throw ex;
        }
    }

    /**
     * Return the last LIMIT annotation __Links__ whose parent (IAnnotated)
     * matches one of the parentTypes, whose child (Annotation) matches one
     * of the childTypes (limit of one for the moment), and who namespace
     * matches via ILIKE.
     * 
     * The parents and children will be unloaded. The link will have
     * its creation/update events loaded.
     * 
     * If Parameters.theFilter.ownerId or groupId are set, they will be
     * AND'ed to the query to filter results.
     * 
     * Merges by default based on parentType.
     * @param __cb The callback object for the operation.
     **/
    public boolean getMostRecentAnnotationLinks_async(AMI_ITimeline_getMostRecentAnnotationLinks __cb, java.util.List<String> parentTypes, java.util.List<String> childTypes, java.util.List<String> namespaces, omero.sys.Parameters p)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__getMostRecentAnnotationLinks_name);
            __r = begin_getMostRecentAnnotationLinks(parentTypes, childTypes, namespaces, p, null, false, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __getMostRecentAnnotationLinks_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    /**
     * Return the last LIMIT annotation __Links__ whose parent (IAnnotated)
     * matches one of the parentTypes, whose child (Annotation) matches one
     * of the childTypes (limit of one for the moment), and who namespace
     * matches via ILIKE.
     * 
     * The parents and children will be unloaded. The link will have
     * its creation/update events loaded.
     * 
     * If Parameters.theFilter.ownerId or groupId are set, they will be
     * AND'ed to the query to filter results.
     * 
     * Merges by default based on parentType.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean getMostRecentAnnotationLinks_async(AMI_ITimeline_getMostRecentAnnotationLinks __cb, java.util.List<String> parentTypes, java.util.List<String> childTypes, java.util.List<String> namespaces, omero.sys.Parameters p, java.util.Map<String, String> __ctx)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__getMostRecentAnnotationLinks_name);
            __r = begin_getMostRecentAnnotationLinks(parentTypes, childTypes, namespaces, p, __ctx, true, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __getMostRecentAnnotationLinks_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    private static final String __getMostRecentObjects_name = "getMostRecentObjects";

    /**
     * Returns the last LIMIT objects of TYPES as ordered by
     * creation/modification times in the Event table.
     **/
    public java.util.Map<java.lang.String, java.util.List<omero.model.IObject>> getMostRecentObjects(java.util.List<String> types, omero.sys.Parameters p, boolean merge)
        throws omero.ServerError
    {
        return getMostRecentObjects(types, p, merge, null, false);
    }

    /**
     * Returns the last LIMIT objects of TYPES as ordered by
     * creation/modification times in the Event table.
     * @param __ctx The Context map to send with the invocation.
     **/
    public java.util.Map<java.lang.String, java.util.List<omero.model.IObject>> getMostRecentObjects(java.util.List<String> types, omero.sys.Parameters p, boolean merge, java.util.Map<String, String> __ctx)
        throws omero.ServerError
    {
        return getMostRecentObjects(types, p, merge, __ctx, true);
    }

    private java.util.Map<java.lang.String, java.util.List<omero.model.IObject>> getMostRecentObjects(java.util.List<String> types, omero.sys.Parameters p, boolean merge, java.util.Map<String, String> __ctx, boolean __explicitCtx)
        throws omero.ServerError
    {
        if(__explicitCtx && __ctx == null)
        {
            __ctx = _emptyContext;
        }
        final Ice.Instrumentation.InvocationObserver __observer = IceInternal.ObserverHelper.get(this, "getMostRecentObjects", __ctx);
        int __cnt = 0;
        try
        {
            while(true)
            {
                Ice._ObjectDel __delBase = null;
                try
                {
                    __checkTwowayOnly("getMostRecentObjects");
                    __delBase = __getDelegate(false);
                    _ITimelineDel __del = (_ITimelineDel)__delBase;
                    return __del.getMostRecentObjects(types, p, merge, __ctx, __observer);
                }
                catch(IceInternal.LocalExceptionWrapper __ex)
                {
                    __cnt = __handleExceptionWrapperRelaxed(__delBase, __ex, null, __cnt, __observer);
                }
                catch(Ice.LocalException __ex)
                {
                    __cnt = __handleException(__delBase, __ex, null, __cnt, __observer);
                }
            }
        }
        finally
        {
            if(__observer != null)
            {
                __observer.detach();
            }
        }
    }

    /**
     * Returns the last LIMIT objects of TYPES as ordered by
     * creation/modification times in the Event table.
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_getMostRecentObjects(java.util.List<String> types, omero.sys.Parameters p, boolean merge)
    {
        return begin_getMostRecentObjects(types, p, merge, null, false, null);
    }

    /**
     * Returns the last LIMIT objects of TYPES as ordered by
     * creation/modification times in the Event table.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_getMostRecentObjects(java.util.List<String> types, omero.sys.Parameters p, boolean merge, java.util.Map<String, String> __ctx)
    {
        return begin_getMostRecentObjects(types, p, merge, __ctx, true, null);
    }

    /**
     * Returns the last LIMIT objects of TYPES as ordered by
     * creation/modification times in the Event table.
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_getMostRecentObjects(java.util.List<String> types, omero.sys.Parameters p, boolean merge, Ice.Callback __cb)
    {
        return begin_getMostRecentObjects(types, p, merge, null, false, __cb);
    }

    /**
     * Returns the last LIMIT objects of TYPES as ordered by
     * creation/modification times in the Event table.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_getMostRecentObjects(java.util.List<String> types, omero.sys.Parameters p, boolean merge, java.util.Map<String, String> __ctx, Ice.Callback __cb)
    {
        return begin_getMostRecentObjects(types, p, merge, __ctx, true, __cb);
    }

    /**
     * Returns the last LIMIT objects of TYPES as ordered by
     * creation/modification times in the Event table.
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_getMostRecentObjects(java.util.List<String> types, omero.sys.Parameters p, boolean merge, Callback_ITimeline_getMostRecentObjects __cb)
    {
        return begin_getMostRecentObjects(types, p, merge, null, false, __cb);
    }

    /**
     * Returns the last LIMIT objects of TYPES as ordered by
     * creation/modification times in the Event table.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_getMostRecentObjects(java.util.List<String> types, omero.sys.Parameters p, boolean merge, java.util.Map<String, String> __ctx, Callback_ITimeline_getMostRecentObjects __cb)
    {
        return begin_getMostRecentObjects(types, p, merge, __ctx, true, __cb);
    }

    private Ice.AsyncResult begin_getMostRecentObjects(java.util.List<String> types, omero.sys.Parameters p, boolean merge, java.util.Map<String, String> __ctx, boolean __explicitCtx, IceInternal.CallbackBase __cb)
    {
        __checkAsyncTwowayOnly(__getMostRecentObjects_name);
        IceInternal.OutgoingAsync __result = new IceInternal.OutgoingAsync(this, __getMostRecentObjects_name, __cb);
        try
        {
            __result.__prepare(__getMostRecentObjects_name, Ice.OperationMode.Idempotent, __ctx, __explicitCtx);
            IceInternal.BasicStream __os = __result.__startWriteParams(Ice.FormatType.DefaultFormat);
            StringSetHelper.write(__os, types);
            __os.writeObject(p);
            __os.writeBool(merge);
            __os.writePendingObjects();
            __result.__endWriteParams();
            __result.__send(true);
        }
        catch(Ice.LocalException __ex)
        {
            __result.__exceptionAsync(__ex);
        }
        return __result;
    }

    /**
     * ice_response indicates that
     * the operation completed successfully.
     **/
    public java.util.Map<java.lang.String, java.util.List<omero.model.IObject>> end_getMostRecentObjects(Ice.AsyncResult __result)
        throws omero.ServerError
    {
        Ice.AsyncResult.__check(__result, this, __getMostRecentObjects_name);
        boolean __ok = __result.__wait();
        try
        {
            if(!__ok)
            {
                try
                {
                    __result.__throwUserException();
                }
                catch(omero.ServerError __ex)
                {
                    throw __ex;
                }
                catch(Ice.UserException __ex)
                {
                    throw new Ice.UnknownUserException(__ex.ice_name(), __ex);
                }
            }
            IceInternal.BasicStream __is = __result.__startReadParams();
            java.util.Map<java.lang.String, java.util.List<omero.model.IObject>> __ret;
            __ret = IObjectListMapHelper.read(__is);
            __is.readPendingObjects();
            __result.__endReadParams();
            return __ret;
        }
        catch(Ice.LocalException ex)
        {
            Ice.Instrumentation.InvocationObserver __obsv = __result.__getObserver();
            if(__obsv != null)
            {
                __obsv.failed(ex.ice_name());
            }
            throw ex;
        }
    }

    /**
     * Returns the last LIMIT objects of TYPES as ordered by
     * creation/modification times in the Event table.
     * @param __cb The callback object for the operation.
     **/
    public boolean getMostRecentObjects_async(AMI_ITimeline_getMostRecentObjects __cb, java.util.List<String> types, omero.sys.Parameters p, boolean merge)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__getMostRecentObjects_name);
            __r = begin_getMostRecentObjects(types, p, merge, null, false, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __getMostRecentObjects_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    /**
     * Returns the last LIMIT objects of TYPES as ordered by
     * creation/modification times in the Event table.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean getMostRecentObjects_async(AMI_ITimeline_getMostRecentObjects __cb, java.util.List<String> types, omero.sys.Parameters p, boolean merge, java.util.Map<String, String> __ctx)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__getMostRecentObjects_name);
            __r = begin_getMostRecentObjects(types, p, merge, __ctx, true, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __getMostRecentObjects_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    private static final String __getMostRecentShareCommentLinks_name = "getMostRecentShareCommentLinks";

    /**
     * Return the last LIMIT comment annotation links attached to a share by
     * __others__.
     * 
     * Note: Currently the storage of these objects is not optimal
     * and so this method may change.
     **/
    public java.util.List<omero.model.IObject> getMostRecentShareCommentLinks(omero.sys.Parameters p)
        throws omero.ServerError
    {
        return getMostRecentShareCommentLinks(p, null, false);
    }

    /**
     * Return the last LIMIT comment annotation links attached to a share by
     * __others__.
     * 
     * Note: Currently the storage of these objects is not optimal
     * and so this method may change.
     * @param __ctx The Context map to send with the invocation.
     **/
    public java.util.List<omero.model.IObject> getMostRecentShareCommentLinks(omero.sys.Parameters p, java.util.Map<String, String> __ctx)
        throws omero.ServerError
    {
        return getMostRecentShareCommentLinks(p, __ctx, true);
    }

    private java.util.List<omero.model.IObject> getMostRecentShareCommentLinks(omero.sys.Parameters p, java.util.Map<String, String> __ctx, boolean __explicitCtx)
        throws omero.ServerError
    {
        if(__explicitCtx && __ctx == null)
        {
            __ctx = _emptyContext;
        }
        final Ice.Instrumentation.InvocationObserver __observer = IceInternal.ObserverHelper.get(this, "getMostRecentShareCommentLinks", __ctx);
        int __cnt = 0;
        try
        {
            while(true)
            {
                Ice._ObjectDel __delBase = null;
                try
                {
                    __checkTwowayOnly("getMostRecentShareCommentLinks");
                    __delBase = __getDelegate(false);
                    _ITimelineDel __del = (_ITimelineDel)__delBase;
                    return __del.getMostRecentShareCommentLinks(p, __ctx, __observer);
                }
                catch(IceInternal.LocalExceptionWrapper __ex)
                {
                    __cnt = __handleExceptionWrapperRelaxed(__delBase, __ex, null, __cnt, __observer);
                }
                catch(Ice.LocalException __ex)
                {
                    __cnt = __handleException(__delBase, __ex, null, __cnt, __observer);
                }
            }
        }
        finally
        {
            if(__observer != null)
            {
                __observer.detach();
            }
        }
    }

    /**
     * Return the last LIMIT comment annotation links attached to a share by
     * __others__.
     * 
     * Note: Currently the storage of these objects is not optimal
     * and so this method may change.
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_getMostRecentShareCommentLinks(omero.sys.Parameters p)
    {
        return begin_getMostRecentShareCommentLinks(p, null, false, null);
    }

    /**
     * Return the last LIMIT comment annotation links attached to a share by
     * __others__.
     * 
     * Note: Currently the storage of these objects is not optimal
     * and so this method may change.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_getMostRecentShareCommentLinks(omero.sys.Parameters p, java.util.Map<String, String> __ctx)
    {
        return begin_getMostRecentShareCommentLinks(p, __ctx, true, null);
    }

    /**
     * Return the last LIMIT comment annotation links attached to a share by
     * __others__.
     * 
     * Note: Currently the storage of these objects is not optimal
     * and so this method may change.
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_getMostRecentShareCommentLinks(omero.sys.Parameters p, Ice.Callback __cb)
    {
        return begin_getMostRecentShareCommentLinks(p, null, false, __cb);
    }

    /**
     * Return the last LIMIT comment annotation links attached to a share by
     * __others__.
     * 
     * Note: Currently the storage of these objects is not optimal
     * and so this method may change.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_getMostRecentShareCommentLinks(omero.sys.Parameters p, java.util.Map<String, String> __ctx, Ice.Callback __cb)
    {
        return begin_getMostRecentShareCommentLinks(p, __ctx, true, __cb);
    }

    /**
     * Return the last LIMIT comment annotation links attached to a share by
     * __others__.
     * 
     * Note: Currently the storage of these objects is not optimal
     * and so this method may change.
     * @param __cb The callback object for the operation.
     **/
    public Ice.AsyncResult begin_getMostRecentShareCommentLinks(omero.sys.Parameters p, Callback_ITimeline_getMostRecentShareCommentLinks __cb)
    {
        return begin_getMostRecentShareCommentLinks(p, null, false, __cb);
    }

    /**
     * Return the last LIMIT comment annotation links attached to a share by
     * __others__.
     * 
     * Note: Currently the storage of these objects is not optimal
     * and so this method may change.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public Ice.AsyncResult begin_getMostRecentShareCommentLinks(omero.sys.Parameters p, java.util.Map<String, String> __ctx, Callback_ITimeline_getMostRecentShareCommentLinks __cb)
    {
        return begin_getMostRecentShareCommentLinks(p, __ctx, true, __cb);
    }

    private Ice.AsyncResult begin_getMostRecentShareCommentLinks(omero.sys.Parameters p, java.util.Map<String, String> __ctx, boolean __explicitCtx, IceInternal.CallbackBase __cb)
    {
        __checkAsyncTwowayOnly(__getMostRecentShareCommentLinks_name);
        IceInternal.OutgoingAsync __result = new IceInternal.OutgoingAsync(this, __getMostRecentShareCommentLinks_name, __cb);
        try
        {
            __result.__prepare(__getMostRecentShareCommentLinks_name, Ice.OperationMode.Idempotent, __ctx, __explicitCtx);
            IceInternal.BasicStream __os = __result.__startWriteParams(Ice.FormatType.DefaultFormat);
            __os.writeObject(p);
            __os.writePendingObjects();
            __result.__endWriteParams();
            __result.__send(true);
        }
        catch(Ice.LocalException __ex)
        {
            __result.__exceptionAsync(__ex);
        }
        return __result;
    }

    /**
     * ice_response indicates that
     * the operation completed successfully.
     **/
    public java.util.List<omero.model.IObject> end_getMostRecentShareCommentLinks(Ice.AsyncResult __result)
        throws omero.ServerError
    {
        Ice.AsyncResult.__check(__result, this, __getMostRecentShareCommentLinks_name);
        boolean __ok = __result.__wait();
        try
        {
            if(!__ok)
            {
                try
                {
                    __result.__throwUserException();
                }
                catch(omero.ServerError __ex)
                {
                    throw __ex;
                }
                catch(Ice.UserException __ex)
                {
                    throw new Ice.UnknownUserException(__ex.ice_name(), __ex);
                }
            }
            IceInternal.BasicStream __is = __result.__startReadParams();
            java.util.List<omero.model.IObject> __ret;
            __ret = IObjectListHelper.read(__is);
            __is.readPendingObjects();
            __result.__endReadParams();
            return __ret;
        }
        catch(Ice.LocalException ex)
        {
            Ice.Instrumentation.InvocationObserver __obsv = __result.__getObserver();
            if(__obsv != null)
            {
                __obsv.failed(ex.ice_name());
            }
            throw ex;
        }
    }

    /**
     * Return the last LIMIT comment annotation links attached to a share by
     * __others__.
     * 
     * Note: Currently the storage of these objects is not optimal
     * and so this method may change.
     * @param __cb The callback object for the operation.
     **/
    public boolean getMostRecentShareCommentLinks_async(AMI_ITimeline_getMostRecentShareCommentLinks __cb, omero.sys.Parameters p)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__getMostRecentShareCommentLinks_name);
            __r = begin_getMostRecentShareCommentLinks(p, null, false, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __getMostRecentShareCommentLinks_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    /**
     * Return the last LIMIT comment annotation links attached to a share by
     * __others__.
     * 
     * Note: Currently the storage of these objects is not optimal
     * and so this method may change.
     * @param __cb The callback object for the operation.
     * @param __ctx The Context map to send with the invocation.
     **/
    public boolean getMostRecentShareCommentLinks_async(AMI_ITimeline_getMostRecentShareCommentLinks __cb, omero.sys.Parameters p, java.util.Map<String, String> __ctx)
    {
        Ice.AsyncResult __r;
        try
        {
            __checkTwowayOnly(__getMostRecentShareCommentLinks_name);
            __r = begin_getMostRecentShareCommentLinks(p, __ctx, true, __cb);
        }
        catch(Ice.TwowayOnlyException ex)
        {
            __r = new IceInternal.OutgoingAsync(this, __getMostRecentShareCommentLinks_name, __cb);
            __r.__exceptionAsync(ex);
        }
        return __r.sentSynchronously();
    }

    public static ITimelinePrx checkedCast(Ice.ObjectPrx __obj)
    {
        ITimelinePrx __d = null;
        if(__obj != null)
        {
            if(__obj instanceof ITimelinePrx)
            {
                __d = (ITimelinePrx)__obj;
            }
            else
            {
                if(__obj.ice_isA(ice_staticId()))
                {
                    ITimelinePrxHelper __h = new ITimelinePrxHelper();
                    __h.__copyFrom(__obj);
                    __d = __h;
                }
            }
        }
        return __d;
    }

    public static ITimelinePrx checkedCast(Ice.ObjectPrx __obj, java.util.Map<String, String> __ctx)
    {
        ITimelinePrx __d = null;
        if(__obj != null)
        {
            if(__obj instanceof ITimelinePrx)
            {
                __d = (ITimelinePrx)__obj;
            }
            else
            {
                if(__obj.ice_isA(ice_staticId(), __ctx))
                {
                    ITimelinePrxHelper __h = new ITimelinePrxHelper();
                    __h.__copyFrom(__obj);
                    __d = __h;
                }
            }
        }
        return __d;
    }

    public static ITimelinePrx checkedCast(Ice.ObjectPrx __obj, String __facet)
    {
        ITimelinePrx __d = null;
        if(__obj != null)
        {
            Ice.ObjectPrx __bb = __obj.ice_facet(__facet);
            try
            {
                if(__bb.ice_isA(ice_staticId()))
                {
                    ITimelinePrxHelper __h = new ITimelinePrxHelper();
                    __h.__copyFrom(__bb);
                    __d = __h;
                }
            }
            catch(Ice.FacetNotExistException ex)
            {
            }
        }
        return __d;
    }

    public static ITimelinePrx checkedCast(Ice.ObjectPrx __obj, String __facet, java.util.Map<String, String> __ctx)
    {
        ITimelinePrx __d = null;
        if(__obj != null)
        {
            Ice.ObjectPrx __bb = __obj.ice_facet(__facet);
            try
            {
                if(__bb.ice_isA(ice_staticId(), __ctx))
                {
                    ITimelinePrxHelper __h = new ITimelinePrxHelper();
                    __h.__copyFrom(__bb);
                    __d = __h;
                }
            }
            catch(Ice.FacetNotExistException ex)
            {
            }
        }
        return __d;
    }

    public static ITimelinePrx uncheckedCast(Ice.ObjectPrx __obj)
    {
        ITimelinePrx __d = null;
        if(__obj != null)
        {
            if(__obj instanceof ITimelinePrx)
            {
                __d = (ITimelinePrx)__obj;
            }
            else
            {
                ITimelinePrxHelper __h = new ITimelinePrxHelper();
                __h.__copyFrom(__obj);
                __d = __h;
            }
        }
        return __d;
    }

    public static ITimelinePrx uncheckedCast(Ice.ObjectPrx __obj, String __facet)
    {
        ITimelinePrx __d = null;
        if(__obj != null)
        {
            Ice.ObjectPrx __bb = __obj.ice_facet(__facet);
            ITimelinePrxHelper __h = new ITimelinePrxHelper();
            __h.__copyFrom(__bb);
            __d = __h;
        }
        return __d;
    }

    public static final String[] __ids =
    {
        "::Ice::Object",
        "::omero::api::ITimeline",
        "::omero::api::ServiceInterface"
    };

    public static String ice_staticId()
    {
        return __ids[1];
    }

    protected Ice._ObjectDelM __createDelegateM()
    {
        return new _ITimelineDelM();
    }

    protected Ice._ObjectDelD __createDelegateD()
    {
        return new _ITimelineDelD();
    }

    public static void __write(IceInternal.BasicStream __os, ITimelinePrx v)
    {
        __os.writeProxy(v);
    }

    public static ITimelinePrx __read(IceInternal.BasicStream __is)
    {
        Ice.ObjectPrx proxy = __is.readProxy();
        if(proxy != null)
        {
            ITimelinePrxHelper result = new ITimelinePrxHelper();
            result.__copyFrom(proxy);
            return result;
        }
        return null;
    }

    public static final long serialVersionUID = 0L;
}
