// **********************************************************************
//
// Copyright (c) 2003-2013 ZeroC, Inc. All rights reserved.
//
// This copy of Ice is licensed to you under the terms described in the
// ICE_LICENSE file included in this distribution.
//
// **********************************************************************
//
// Ice version 3.5.1
//
// <auto-generated>
//
// Generated from file `IConfig.ice'
//
// Warning: do not edit this file.
//
// </auto-generated>
//

package omero.api;

/**
 * Access to server configuration. These methods provide access to the
 * state and configuration of the server and its components (e.g. the
 * database). However, it should not be assumed that two subsequent
 * calls to a proxy for this service will go to the same server due to
 * clustering.
 * 
 * Not all possible server configuration is available through this
 * API. Some values (such as DB connection info, ports, etc.) must
 * naturally be set before this service is accessible.
 * 
 * Manages synchronization of the various configuration sources
 * internally. It is therefore important that as far as possible all
 * configuration changes take place via this interface and not, for
 * example, directly via java.util.prefs.Preferences.
 * 
 * Also used as the main developer example for developing (stateless)
 * ome.api interfaces. See source code documentation for more.
 **/
public interface _IConfigOperations extends _ServiceInterfaceOperations
{
    /**
     * Provides the release version. OMERO-internal values will be
     * in the form Major.minor.patch, starting with the value
     * 4.0.0 for the 4.0 release, Spring 2009.
     * 
     * Customized values should begin with a alphabetic sequence
     * followed by a hyphen: ACME-0.0.1 and any build information
     * should follow the patch number also with a hyphen:
     * 4.0.0-RC1. These values will be removed by
     * {@link #getVersion}
     * @param __cb The callback object for the operation.
     * @param __current The Current object for the invocation.
     **/
    void getVersion_async(AMD_IConfig_getVersion __cb, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Retrieves a configuration value from the backend store.
     * Permissions applied to the configuration value may cause a
     * {@link SecurityViolation} to be thrown.
     * 
     * @param __cb The callback object for the operation.
     * @param key The non-null name of the desired configuration
     * value
     * @param __current The Current object for the invocation.
     **/
    void getConfigValue_async(AMD_IConfig_getConfigValue __cb, String key, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Retrieves configuration values from the backend store which
     * match the given regex. Any configuration value which would
     * throw an exception on being loaded is omitted.
     * 
     * @param __cb The callback object for the operation.
     * @param keyRegex The non-null regex of the desired
     * configuration values
     * @param __current The Current object for the invocation.
     **/
    void getConfigValues_async(AMD_IConfig_getConfigValues __cb, String keyRegex, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Reads the etc/omero.properties file and returns all the
     * key/value pairs that are found there. Since this file is
     * not to be edited its assumed that these values are in the
     * public domain and so there's no need to protect them.
     * 
     * @param __cb The callback object for the operation.
     * @param __current The Current object for the invocation.
     **/
    void getConfigDefaults_async(AMD_IConfig_getConfigDefaults __cb, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Retrieves configuration values like {@link #getConfigValues}
     * but only those with the prefix <i>omero.client</i>.
     * 
     * @param __cb The callback object for the operation.
     * @param __current The Current object for the invocation.
     **/
    void getClientConfigValues_async(AMD_IConfig_getClientConfigValues __cb, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Reads the etc/omero.properties file and returns all the
     * key/value pairs that are found there which match the prefix
     * <i>omero.client</i>.
     * 
     * @param __cb The callback object for the operation.
     * @param __current The Current object for the invocation.
     **/
    void getClientConfigDefaults_async(AMD_IConfig_getClientConfigDefaults __cb, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Sets a configuration value in the backend store.
     * Permissions applied to the configuration value may cause a
     * {@link SecurityViolation} to be thrown. If the value is
     * null or empty, then the configuration will be removed in
     * all writable configuration sources. If the configuration is
     * set in a non-modifiable source (e.g. in a property file on
     * the classpath), then a subsequent call to
     * {@link #getConfigValue} will return that value.
     * 
     * @param __cb The callback object for the operation.
     * @param key The non-null name of the desired configuration
     * value
     * @param value The string value to assign to the given key.
     * @param __current The Current object for the invocation.
     **/
    void setConfigValue_async(AMD_IConfig_setConfigValue __cb, String key, String value, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Calls {@link #setConfigValue} if and only if the
     * configuration property is currently equal to the test
     * argument. If the test is null or empty, then the
     * configuration property will be set only if missing.
     * 
     * @param __cb The callback object for the operation.
     * @param key
     * @param __current The Current object for the invocation.
     **/
    void setConfigValueIfEquals_async(AMD_IConfig_setConfigValueIfEquals __cb, String key, String value, String test, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Provides the UUID for this OMERO (database) instance. To
     * make imports and exports function properly, only one
     * physical database should be active with a given instance
     * UUID. All other copies of the database with that UUID are
     * invalid as soon as one modification is made.
     * 
     * This value is stored in the configuration table under the
     * key <i>omero.db.uuid</i>.
     * 
     * @param __cb The callback object for the operation.
     * @param __current The Current object for the invocation.
     **/
    void getDatabaseUuid_async(AMD_IConfig_getDatabaseUuid __cb, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Checks the database for its time using a SELECT statement.
     * 
     * @param __cb The callback object for the operation.
     * @param __current The Current object for the invocation.
     **/
    void getDatabaseTime_async(AMD_IConfig_getDatabaseTime __cb, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Checks the current server for its time. This value may be
     * variant depending on whether the service is clustered or
     * not.
     * 
     * @param __cb The callback object for the operation.
     * @param __current The Current object for the invocation.
     **/
    void getServerTime_async(AMD_IConfig_getServerTime __cb, Ice.Current __current)
        throws omero.ServerError;
}
