// **********************************************************************
//
// Copyright (c) 2003-2013 ZeroC, Inc. All rights reserved.
//
// This copy of Ice is licensed to you under the terms described in the
// ICE_LICENSE file included in this distribution.
//
// **********************************************************************
//
// Ice version 3.5.1
//
// <auto-generated>
//
// Generated from file `IRenderingSettings.ice'
//
// Warning: do not edit this file.
//
// </auto-generated>
//

package omero.api;

/**
 * Provides method to apply rendering settings to a collection of
 * images.
 * All methods will receive the id of the pixels set to copy the
 * rendering settings from.
 **/
public interface _IRenderingSettingsOperations extends _ServiceInterfaceOperations
{
    /**
     * Checks if the specified sets of pixels are compatible.
     * Returns <code>true</code> if the pixels set is valid,
     * <code>false</code> otherwise.
     * 
     * @param __cb The callback object for the operation.
     * @param pFrom The pixels set to copy the settings from.
     * @param __current The Current object for the invocation.
     **/
    void sanityCheckPixels_async(AMD_IRenderingSettings_sanityCheckPixels __cb, omero.model.Pixels pFrom, omero.model.Pixels pTo, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Returns the default rendering settings for a given pixels
     * for the current user.
     * 
     * @param __cb The callback object for the operation.
     * @param pixelsId The Id of the Pixels
     * @param __current The Current object for the invocation.
     **/
    void getRenderingSettings_async(AMD_IRenderingSettings_getRenderingSettings __cb, long pixelsId, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Creates a new rendering definition object along with its
     * sub-objects.
     * 
     * @param __cb The callback object for the operation.
     * @param pixels The Pixels set to link to the rendering
     * definition.
     * @param __current The Current object for the invocation.
     **/
    void createNewRenderingDef_async(AMD_IRenderingSettings_createNewRenderingDef __cb, omero.model.Pixels pixels, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Resets the given rendering settings to those that are
     * specified by the rendering engine intelligent <i>pretty
     * good image (PG)</i> logic for the pixels set linked to that
     * set of rendering settings. <b>NOTE:</b> This method should
     * only be used to reset a rendering definition that has been
     * retrieved via {@link #getRenderingSettings} as it
     * relies on certain objects being loaded. The rendering
     * settings are saved upon completion.
     * 
     * @param __cb The callback object for the operation.
     * @param def A RenderingDef to reset. It is expected that
     * def.pixels will be <i>unloaded</i> and that the
     * actual linked Pixels set will be provided in the
     * <code>pixels</code> argument.
     * @param pixels The Pixels set for <code>def</code>.
     * @param __current The Current object for the invocation.
     **/
    void resetDefaults_async(AMD_IRenderingSettings_resetDefaults __cb, omero.model.RenderingDef def, omero.model.Pixels pixels, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Resets the given rendering settings to those that are
     * specified by the rendering engine intelligent <i>pretty
     * good image (PG)</i> logic for the pixels set linked to that
     * set of rendering settings. <b>NOTE:</b> This method should
     * only be used to reset a rendering definition that has been
     * retrieved via {@link #getRenderingSettings(long)} as it
     * relies on certain objects being loaded. The rendering
     * settings are not saved.
     * 
     * @param __cb The callback object for the operation.
     * @param def A RenderingDef to reset. It is expected that
     * def.pixels will be <i>unloaded</i> and that the
     * actual linked Pixels set will be provided in the
     * <code>pixels</code> argument.
     * @param pixels The Pixels set for <code>def</code>.
     * @param __current The Current object for the invocation.
     **/
    void resetDefaultsNoSave_async(AMD_IRenderingSettings_resetDefaultsNoSave __cb, omero.model.RenderingDef def, omero.model.Pixels pixels, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Resets an image's default rendering settings back to those
     * that are specified by the rendering engine intelligent
     * <i>pretty good image (PG)</i> logic.
     * 
     * @param __cb The callback object for the operation.
     * @param imageId The Id of the Image.
     * @param __current The Current object for the invocation.
     **/
    void resetDefaultsInImage_async(AMD_IRenderingSettings_resetDefaultsInImage __cb, long imageId, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Resets a Pixels' default rendering settings back to those
     * that are specified by the rendering engine intelligent
     * <i>pretty good image (PG)</i> logic.
     * 
     * @param __cb The callback object for the operation.
     * @param pixelsId The Id of the Pixels.
     * @param __current The Current object for the invocation.
     **/
    void resetDefaultsForPixels_async(AMD_IRenderingSettings_resetDefaultsForPixels __cb, long pixelsId, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Resets a dataset's rendering settings back to those that
     * are specified by the rendering engine intelligent <i>pretty
     * good image (PG)</i> logic.
     * 
     * @param __cb The callback object for the operation.
     * @param dataSetId The Id of the Dataset.
     * @param __current The Current object for the invocation.
     **/
    void resetDefaultsInDataset_async(AMD_IRenderingSettings_resetDefaultsInDataset __cb, long dataSetId, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Resets a rendering settings back to one or many containers
     * that are specified by the rendering engine intelligent
     * <i>pretty good image (PG)</i> logic. Supported container
     * types are:
     * <ul>
     * <li>{@link omero.model.Project}</li>
     * <li>{@link omero.model.Dataset}</li>
     * <li>{@link omero.model.Image}</li>
     * <li>{@link omero.model.Plate}</li>
     * <li>{@link omero.model.Pixels}</li>
     * </ul>
     * @param __cb The callback object for the operation.
     * @param type The type of nodes to handle.
     * @param __current The Current object for the invocation.
     **/
    void resetDefaultsInSet_async(AMD_IRenderingSettings_resetDefaultsInSet __cb, String type, java.util.List<Long> nodeIds, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Resets the rendering settings of a given group of
     * containers based on the owner's (essentially a copy).
     * Supported container types are:
     * <ul>
     * <li>{@link omero.model.Project}</li>
     * <li>{@link omero.model.Dataset}</li>
     * <li>{@link omero.model.Image}</li>
     * <li>{@link omero.model.Plate}</li>
     * <li>{@link omero.model.Pixels}</li>
     * </ul>
     * @param __cb The callback object for the operation.
     * @param type The type of nodes to handle.
     * @param __current The Current object for the invocation.
     **/
    void resetDefaultsByOwnerInSet_async(AMD_IRenderingSettings_resetDefaultsByOwnerInSet __cb, String type, java.util.List<Long> nodeIds, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Resets a the channel windows for one or many containers
     * back to their global minimum and global maximum for the
     * channel. Supported container types are:
     * <ul>
     * <li>{@link omero.model.Project}</li>
     * <li>{@link omero.model.Dataset}</li>
     * <li>{@link omero.model.Image}</li>
     * <li>{@link omero.model.Plate}</li>
     * <li>{@link omero.model.Pixels}</li>
     * </ul>
     * @param __cb The callback object for the operation.
     * @param type The type of nodes to handle.
     * @param __current The Current object for the invocation.
     **/
    void resetMinMaxInSet_async(AMD_IRenderingSettings_resetMinMaxInSet __cb, String type, java.util.List<Long> nodeIds, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Applies rendering settings to one or many containers. If a
     * container such as Dataset is to be copied to, all images
     * within that Dataset will have the rendering settings
     * applied. Supported container types are:
     * <ul>
     * <li>{@link omero.model.Project}</li>
     * <li>{@link omero.model.Dataset}</li>
     * <li>{@link omero.model.Image}</li>
     * <li>{@link omero.model.Plate}</li>
     * <li>{@link omero.model.Screen}</li>
     * <li>{@link omero.model.Pixels}</li>
     * </ul>
     * 
     * @param __cb The callback object for the operation.
     * @param from The Id of the pixels set to copy the rendering
     * settings from.
     * @param toType The type of nodes to handle.
     * @param __current The Current object for the invocation.
     **/
    void applySettingsToSet_async(AMD_IRenderingSettings_applySettingsToSet __cb, long from, String toType, java.util.List<Long> nodeIds, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Applies rendering settings to all images in all Datasets of
     * a given Project.
     * 
     * @param __cb The callback object for the operation.
     * @param from The Id of the pixels set to copy the rendering
     * settings from.
     * @param to The Id of the project container to apply settings
     * to.
     * @param __current The Current object for the invocation.
     **/
    void applySettingsToProject_async(AMD_IRenderingSettings_applySettingsToProject __cb, long from, long to, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Applies rendering settings to all images in a given Dataset.
     * 
     * @param __cb The callback object for the operation.
     * @param from The Id of the pixels set to copy the rendering
     * settings from.
     * @param to The Id of the dataset container to apply settings
     * to.
     * @param __current The Current object for the invocation.
     **/
    void applySettingsToDataset_async(AMD_IRenderingSettings_applySettingsToDataset __cb, long from, long to, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Applies rendering settings to a given Image.
     * 
     * @param __cb The callback object for the operation.
     * @param from The Id of the pixels set to copy the rendering
     * settings from.
     * @param to The Id of the image container to apply settings
     * to.
     * @param __current The Current object for the invocation.
     **/
    void applySettingsToImages_async(AMD_IRenderingSettings_applySettingsToImages __cb, long from, java.util.List<Long> to, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Applies rendering settings to a given Image.
     * 
     * @param __cb The callback object for the operation.
     * @param from The Id of the pixels set to copy the rendering
     * settings from.
     * @param to The Id of the image container to apply settings
     * to.
     * @param __current The Current object for the invocation.
     **/
    void applySettingsToImage_async(AMD_IRenderingSettings_applySettingsToImage __cb, long from, long to, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Applies rendering settings to a given Pixels.
     * 
     * @param __cb The callback object for the operation.
     * @param from The Id of the pixels set to copy the rendering
     * settings from.
     * @param to The Id of the pixels container to apply settings
     * to.
     * @param __current The Current object for the invocation.
     **/
    void applySettingsToPixels_async(AMD_IRenderingSettings_applySettingsToPixels __cb, long from, long to, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Resets an image's default rendering settings back to
     * channel global minimum and maximum.
     * 
     * @param __cb The callback object for the operation.
     * @param imageId The Id of the Image.
     * @param __current The Current object for the invocation.
     **/
    void setOriginalSettingsInImage_async(AMD_IRenderingSettings_setOriginalSettingsInImage __cb, long imageId, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Resets an Pixels' default rendering settings back to
     * channel global minimum and maximum.
     * 
     * @param __cb The callback object for the operation.
     * @param pixelsId The Id of the Pixels set.
     * @param __current The Current object for the invocation.
     **/
    void setOriginalSettingsForPixels_async(AMD_IRenderingSettings_setOriginalSettingsForPixels __cb, long pixelsId, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Resets a dataset's rendering settings back to channel global
     * minimum and maximum.
     * 
     * @param __cb The callback object for the operation.
     * @param __current The Current object for the invocation.
     **/
    void setOriginalSettingsInDataset_async(AMD_IRenderingSettings_setOriginalSettingsInDataset __cb, long dataSetId, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Resets a rendering settings back to channel global minimum
     * and maximum for the specified containers. Supported
     * container types are:
     * <ul>
     * <li>{@link omero.model.Project}</li>
     * <li>{@link omero.model.Dataset}</li>
     * <li>{@link omero.model.Image}</li>
     * <li>{@link omero.model.Plate}</li>
     * <li>{@link omero.model.Pixels}</li>
     * </ul>
     * 
     * @param __cb The callback object for the operation.
     * @param type The type of nodes to handle.
     * @param __current The Current object for the invocation.
     **/
    void setOriginalSettingsInSet_async(AMD_IRenderingSettings_setOriginalSettingsInSet __cb, String type, java.util.List<Long> nodeIds, Ice.Current __current)
        throws omero.ServerError;
}
