// **********************************************************************
//
// Copyright (c) 2003-2013 ZeroC, Inc. All rights reserved.
//
// This copy of Ice is licensed to you under the terms described in the
// ICE_LICENSE file included in this distribution.
//
// **********************************************************************
//
// Ice version 3.5.1
//
// <auto-generated>
//
// Generated from file `IScript.ice'
//
// Warning: do not edit this file.
//
// </auto-generated>
//

package omero.api;

/**
 * Utility service for managing and launching scripts for execution by the Processor API.
 * 
 * Typical usage might include (PYTHON):
 * <pre>
 * 
 * sf = client.createSession()
 * svc = sf.getScriptService()
 * scripts = svc.getScripts()
 * 
 * if len(scripts) >= 1:
 * script_id = svc.keys()\[-1]
 * else:
 * script_id = svc.uploadScript('/test/my_script.py', SCRIPT_TEXT)
 * 
 * params = svc.getParams(script_id)
 * 
 * # You will need to parse the params to create the proper input
 * inputs = {}
 * 
 * # The last parameter is how long to wait as an RInt
 * proc = svc.runScript(script_id, inputs, None)
 * try:
 * cb = omero.scripts.ProcessCallbackI(client, proc)
 * while not cb.block(1000): # ms.
 * pass
 * cb.close()
 * rv = proc.getResults(0)
 * finally:
 * proc.close(False)
 * 
 * </pre>
 * See <a href="http://www.openmicroscopy.org/site/support/omero5.2/developers/scripts/">OMERO.scripts</a> for more information.
 **/
public abstract class _IScriptDisp extends Ice.ObjectImpl implements IScript
{
    protected void
    ice_copyStateFrom(Ice.Object __obj)
        throws java.lang.CloneNotSupportedException
    {
        throw new java.lang.CloneNotSupportedException();
    }

    public static final String[] __ids =
    {
        "::Ice::Object",
        "::omero::api::IScript",
        "::omero::api::ServiceInterface"
    };

    public boolean ice_isA(String s)
    {
        return java.util.Arrays.binarySearch(__ids, s) >= 0;
    }

    public boolean ice_isA(String s, Ice.Current __current)
    {
        return java.util.Arrays.binarySearch(__ids, s) >= 0;
    }

    public String[] ice_ids()
    {
        return __ids;
    }

    public String[] ice_ids(Ice.Current __current)
    {
        return __ids;
    }

    public String ice_id()
    {
        return __ids[1];
    }

    public String ice_id(Ice.Current __current)
    {
        return __ids[1];
    }

    public static String ice_staticId()
    {
        return __ids[1];
    }

    /**
     * Returns true if there is a processor which will run the
     * given script.
     * 
     * <p>
     * Either the script is an official script and this method
     * will return true (though an individual invocation may fail
     * with an {@link omero.ResourceError} for some reason)
     * <em>or</em> this is a user script, and a usermode processor
     * must be active which takes the scripts user or group.
     * </p>
     * 
     * @param __cb The callback object for the operation.
     **/
    public final void canRunScript_async(AMD_IScript_canRunScript __cb, long scriptID)
        throws omero.ServerError
    {
        canRunScript_async(__cb, scriptID, null);
    }

    /**
     * Delete the script on the server with id. The file will also be removed from disk.
     * 
     * @param __cb The callback object for the operation.
     * @param scriptID Id of the script to delete.
     **/
    public final void deleteScript_async(AMD_IScript_deleteScript __cb, long scriptID)
        throws omero.ServerError
    {
        deleteScript_async(__cb, scriptID, null);
    }

    /**
     * Modify the text for the given script object.
     * 
     * @param __cb The callback object for the operation.
     **/
    public final void editScript_async(AMD_IScript_editScript __cb, omero.model.OriginalFile fileObject, String scriptText)
        throws omero.ServerError
    {
        editScript_async(__cb, fileObject, scriptText, null);
    }

    /**
     * Get the parameters that the script takes and returns, along with
     * other metadata available from the script.
     * 
     * @param __cb The callback object for the operation.
     * @param scriptID see above.
     **/
    public final void getParams_async(AMD_IScript_getParams __cb, long scriptID)
        throws omero.ServerError
    {
        getParams_async(__cb, scriptID, null);
    }

    /**
     * Get the id of an official script by the script path.
     * The script service ensures that all script paths are unique.
     * 
     * Note: there is no similar method for user scripts (e.g. getUserScriptID)
     * since the path is not guaranteed to be unique.
     * 
     * @param __cb The callback object for the operation.
     **/
    public final void getScriptID_async(AMD_IScript_getScriptID __cb, String path)
        throws omero.ServerError
    {
        getScriptID_async(__cb, path, null);
    }

    /**
     * Get the text from the server for the script with given id.
     * 
     * @param __cb The callback object for the operation.
     * @param scriptID see above.
     **/
    public final void getScriptText_async(AMD_IScript_getScriptText __cb, long scriptID)
        throws omero.ServerError
    {
        getScriptText_async(__cb, scriptID, null);
    }

    /**
     * Get the script from the server with details from OriginalFile
     * @param __cb The callback object for the operation.
     * @param scriptID see above
     **/
    public final void getScriptWithDetails_async(AMD_IScript_getScriptWithDetails __cb, long scriptID)
        throws omero.ServerError
    {
        getScriptWithDetails_async(__cb, scriptID, null);
    }

    /**
     * This method returns official server scripts as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts()
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * # First character is a "/" symbol
     * path = script.path.val\[1:\]
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param __cb The callback object for the operation.
     **/
    public final void getScripts_async(AMD_IScript_getScripts __cb)
        throws omero.ServerError
    {
        getScripts_async(__cb, null);
    }

    /**
     * This method returns official server scripts identified
     * with the specified extension as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts("py")
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * path = script.path.val\[1:\] # First symbol is a "/"
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param __cb The callback object for the operation.
     * @param mimetype the mimetype identifying the scripts.
     **/
    public final void getScriptsByMimetype_async(AMD_IScript_getScriptsByMimetype __cb, String mimetype)
        throws omero.ServerError
    {
        getScriptsByMimetype_async(__cb, mimetype, null);
    }

    /**
     * Returns non-official scripts which have been uploaded by individual users.
     * These scripts will <em>not</me> be run by the server, though a user can
     * start a personal <i>usermode processor</i> which will allow the scripts to be
     * executed. This is particularly useful for testing new scripts.
     * @param __cb The callback object for the operation.
     **/
    public final void getUserScripts_async(AMD_IScript_getUserScripts __cb, java.util.List<omero.model.IObject> acceptsList)
        throws omero.ServerError
    {
        getUserScripts_async(__cb, acceptsList, null);
    }

    /**
     * If {@link ResourceError} is thrown, then no
     * {@link Processor} is available. Use {@link #scheduleJob}
     * to create a {@link omero.model.ScriptJob} in the
     * <i>Waiting</i> state. A {@link Processor} may become
     * available.
     * 
     * <pre>
     * try:
     * proc = scriptService.runScript(1, {}, None)
     * except ResourceError:
     * job = scriptService.scheduleScript(1, {}, None)
     * </pre>
     * 
     * The {@link ScriptProcess} proxy MUST be closed before
     * exiting. If you would like the script execution to continue
     * in the background, pass <code>True</code> as the argument.
     * 
     * <pre>
     * try:
     * proc.poll()         # See if process is finished
     * finally:
     * proc.close(True)    # Detach and execution can continue
     * # proc.close(False) # OR script is immediately stopped.
     * </pre>
     * @param __cb The callback object for the operation.
     **/
    public final void runScript_async(AMD_IScript_runScript __cb, long scriptID, java.util.Map<java.lang.String, omero.RType> inputs, omero.RInt waitSecs)
        throws omero.ServerError
    {
        runScript_async(__cb, scriptID, inputs, waitSecs, null);
    }

    /**
     * Like {@link #uploadScript} but is only callable by
     * administrators. The parameters for the script are also
     * checked.
     * @param __cb The callback object for the operation.
     **/
    public final void uploadOfficialScript_async(AMD_IScript_uploadOfficialScript __cb, String path, String scriptText)
        throws omero.ServerError
    {
        uploadOfficialScript_async(__cb, path, scriptText, null);
    }

    /**
     * Upload a user script to the server and return the id. This method checks that
     * a script with that names does not exist and that the script has parameters
     * <em>if possible</em>, i.e. a usermode processor is running which for the
     * current user.
     * 
     * @param __cb The callback object for the operation.
     **/
    public final void uploadScript_async(AMD_IScript_uploadScript __cb, String path, String scriptText)
        throws omero.ServerError
    {
        uploadScript_async(__cb, path, scriptText, null);
    }

    /**
     * Used internally by processor.py to check if the script
     * attached to the {@link omero.model.Job} has a valid script
     * attached, based on the {@link #acceptsList} and the current
     * security context.
     * 
     * An example of an acceptsList might be <pre>Experimenter(myUserId, False)</pre>, meaning that
     * only scripts belonging to me should be trusted. An empty list implies that the server should
     * return what it would by default trust.
     * 
     * A valid script will be returned if it exists; otherwise null.
     * @param __cb The callback object for the operation.
     **/
    public final void validateScript_async(AMD_IScript_validateScript __cb, omero.model.Job j, java.util.List<omero.model.IObject> acceptsList)
        throws omero.ServerError
    {
        validateScript_async(__cb, j, acceptsList, null);
    }

    public static Ice.DispatchStatus ___getScripts(IScript __obj, IceInternal.Incoming __inS, Ice.Current __current)
    {
        __checkMode(Ice.OperationMode.Idempotent, __current.mode);
        __inS.readEmptyParams();
        AMD_IScript_getScripts __cb = new _AMD_IScript_getScripts(__inS);
        try
        {
            __obj.getScripts_async(__cb, __current);
        }
        catch(java.lang.Exception ex)
        {
            __cb.ice_exception(ex);
        }
        return Ice.DispatchStatus.DispatchAsync;
    }

    public static Ice.DispatchStatus ___getScriptsByMimetype(IScript __obj, IceInternal.Incoming __inS, Ice.Current __current)
    {
        __checkMode(Ice.OperationMode.Idempotent, __current.mode);
        IceInternal.BasicStream __is = __inS.startReadParams();
        String mimetype;
        mimetype = __is.readString();
        __inS.endReadParams();
        AMD_IScript_getScriptsByMimetype __cb = new _AMD_IScript_getScriptsByMimetype(__inS);
        try
        {
            __obj.getScriptsByMimetype_async(__cb, mimetype, __current);
        }
        catch(java.lang.Exception ex)
        {
            __cb.ice_exception(ex);
        }
        return Ice.DispatchStatus.DispatchAsync;
    }

    public static Ice.DispatchStatus ___getUserScripts(IScript __obj, IceInternal.Incoming __inS, Ice.Current __current)
    {
        __checkMode(Ice.OperationMode.Idempotent, __current.mode);
        IceInternal.BasicStream __is = __inS.startReadParams();
        java.util.List<omero.model.IObject> acceptsList;
        acceptsList = IObjectListHelper.read(__is);
        __is.readPendingObjects();
        __inS.endReadParams();
        AMD_IScript_getUserScripts __cb = new _AMD_IScript_getUserScripts(__inS);
        try
        {
            __obj.getUserScripts_async(__cb, acceptsList, __current);
        }
        catch(java.lang.Exception ex)
        {
            __cb.ice_exception(ex);
        }
        return Ice.DispatchStatus.DispatchAsync;
    }

    public static Ice.DispatchStatus ___getScriptID(IScript __obj, IceInternal.Incoming __inS, Ice.Current __current)
    {
        __checkMode(Ice.OperationMode.Idempotent, __current.mode);
        IceInternal.BasicStream __is = __inS.startReadParams();
        String path;
        path = __is.readString();
        __inS.endReadParams();
        AMD_IScript_getScriptID __cb = new _AMD_IScript_getScriptID(__inS);
        try
        {
            __obj.getScriptID_async(__cb, path, __current);
        }
        catch(java.lang.Exception ex)
        {
            __cb.ice_exception(ex);
        }
        return Ice.DispatchStatus.DispatchAsync;
    }

    public static Ice.DispatchStatus ___getScriptText(IScript __obj, IceInternal.Incoming __inS, Ice.Current __current)
    {
        __checkMode(Ice.OperationMode.Idempotent, __current.mode);
        IceInternal.BasicStream __is = __inS.startReadParams();
        long scriptID;
        scriptID = __is.readLong();
        __inS.endReadParams();
        AMD_IScript_getScriptText __cb = new _AMD_IScript_getScriptText(__inS);
        try
        {
            __obj.getScriptText_async(__cb, scriptID, __current);
        }
        catch(java.lang.Exception ex)
        {
            __cb.ice_exception(ex);
        }
        return Ice.DispatchStatus.DispatchAsync;
    }

    public static Ice.DispatchStatus ___uploadScript(IScript __obj, IceInternal.Incoming __inS, Ice.Current __current)
    {
        __checkMode(Ice.OperationMode.Normal, __current.mode);
        IceInternal.BasicStream __is = __inS.startReadParams();
        String path;
        String scriptText;
        path = __is.readString();
        scriptText = __is.readString();
        __inS.endReadParams();
        AMD_IScript_uploadScript __cb = new _AMD_IScript_uploadScript(__inS);
        try
        {
            __obj.uploadScript_async(__cb, path, scriptText, __current);
        }
        catch(java.lang.Exception ex)
        {
            __cb.ice_exception(ex);
        }
        return Ice.DispatchStatus.DispatchAsync;
    }

    public static Ice.DispatchStatus ___uploadOfficialScript(IScript __obj, IceInternal.Incoming __inS, Ice.Current __current)
    {
        __checkMode(Ice.OperationMode.Normal, __current.mode);
        IceInternal.BasicStream __is = __inS.startReadParams();
        String path;
        String scriptText;
        path = __is.readString();
        scriptText = __is.readString();
        __inS.endReadParams();
        AMD_IScript_uploadOfficialScript __cb = new _AMD_IScript_uploadOfficialScript(__inS);
        try
        {
            __obj.uploadOfficialScript_async(__cb, path, scriptText, __current);
        }
        catch(java.lang.Exception ex)
        {
            __cb.ice_exception(ex);
        }
        return Ice.DispatchStatus.DispatchAsync;
    }

    public static Ice.DispatchStatus ___editScript(IScript __obj, IceInternal.Incoming __inS, Ice.Current __current)
    {
        __checkMode(Ice.OperationMode.Normal, __current.mode);
        IceInternal.BasicStream __is = __inS.startReadParams();
        omero.model.OriginalFileHolder fileObject = new omero.model.OriginalFileHolder();
        String scriptText;
        __is.readObject(fileObject);
        scriptText = __is.readString();
        __is.readPendingObjects();
        __inS.endReadParams();
        AMD_IScript_editScript __cb = new _AMD_IScript_editScript(__inS);
        try
        {
            __obj.editScript_async(__cb, fileObject.value, scriptText, __current);
        }
        catch(java.lang.Exception ex)
        {
            __cb.ice_exception(ex);
        }
        return Ice.DispatchStatus.DispatchAsync;
    }

    public static Ice.DispatchStatus ___getScriptWithDetails(IScript __obj, IceInternal.Incoming __inS, Ice.Current __current)
    {
        __checkMode(Ice.OperationMode.Idempotent, __current.mode);
        IceInternal.BasicStream __is = __inS.startReadParams();
        long scriptID;
        scriptID = __is.readLong();
        __inS.endReadParams();
        AMD_IScript_getScriptWithDetails __cb = new _AMD_IScript_getScriptWithDetails(__inS);
        try
        {
            __obj.getScriptWithDetails_async(__cb, scriptID, __current);
        }
        catch(java.lang.Exception ex)
        {
            __cb.ice_exception(ex);
        }
        return Ice.DispatchStatus.DispatchAsync;
    }

    public static Ice.DispatchStatus ___getParams(IScript __obj, IceInternal.Incoming __inS, Ice.Current __current)
    {
        __checkMode(Ice.OperationMode.Idempotent, __current.mode);
        IceInternal.BasicStream __is = __inS.startReadParams();
        long scriptID;
        scriptID = __is.readLong();
        __inS.endReadParams();
        AMD_IScript_getParams __cb = new _AMD_IScript_getParams(__inS);
        try
        {
            __obj.getParams_async(__cb, scriptID, __current);
        }
        catch(java.lang.Exception ex)
        {
            __cb.ice_exception(ex);
        }
        return Ice.DispatchStatus.DispatchAsync;
    }

    public static Ice.DispatchStatus ___deleteScript(IScript __obj, IceInternal.Incoming __inS, Ice.Current __current)
    {
        __checkMode(Ice.OperationMode.Normal, __current.mode);
        IceInternal.BasicStream __is = __inS.startReadParams();
        long scriptID;
        scriptID = __is.readLong();
        __inS.endReadParams();
        AMD_IScript_deleteScript __cb = new _AMD_IScript_deleteScript(__inS);
        try
        {
            __obj.deleteScript_async(__cb, scriptID, __current);
        }
        catch(java.lang.Exception ex)
        {
            __cb.ice_exception(ex);
        }
        return Ice.DispatchStatus.DispatchAsync;
    }

    public static Ice.DispatchStatus ___runScript(IScript __obj, IceInternal.Incoming __inS, Ice.Current __current)
    {
        __checkMode(Ice.OperationMode.Normal, __current.mode);
        IceInternal.BasicStream __is = __inS.startReadParams();
        long scriptID;
        java.util.Map<java.lang.String, omero.RType> inputs;
        omero.RIntHolder waitSecs = new omero.RIntHolder();
        scriptID = __is.readLong();
        inputs = omero.RTypeDictHelper.read(__is);
        __is.readObject(waitSecs);
        __is.readPendingObjects();
        __inS.endReadParams();
        AMD_IScript_runScript __cb = new _AMD_IScript_runScript(__inS);
        try
        {
            __obj.runScript_async(__cb, scriptID, inputs, waitSecs.value, __current);
        }
        catch(java.lang.Exception ex)
        {
            __cb.ice_exception(ex);
        }
        return Ice.DispatchStatus.DispatchAsync;
    }

    public static Ice.DispatchStatus ___canRunScript(IScript __obj, IceInternal.Incoming __inS, Ice.Current __current)
    {
        __checkMode(Ice.OperationMode.Idempotent, __current.mode);
        IceInternal.BasicStream __is = __inS.startReadParams();
        long scriptID;
        scriptID = __is.readLong();
        __inS.endReadParams();
        AMD_IScript_canRunScript __cb = new _AMD_IScript_canRunScript(__inS);
        try
        {
            __obj.canRunScript_async(__cb, scriptID, __current);
        }
        catch(java.lang.Exception ex)
        {
            __cb.ice_exception(ex);
        }
        return Ice.DispatchStatus.DispatchAsync;
    }

    public static Ice.DispatchStatus ___validateScript(IScript __obj, IceInternal.Incoming __inS, Ice.Current __current)
    {
        __checkMode(Ice.OperationMode.Idempotent, __current.mode);
        IceInternal.BasicStream __is = __inS.startReadParams();
        omero.model.JobHolder j = new omero.model.JobHolder();
        java.util.List<omero.model.IObject> acceptsList;
        __is.readObject(j);
        acceptsList = IObjectListHelper.read(__is);
        __is.readPendingObjects();
        __inS.endReadParams();
        AMD_IScript_validateScript __cb = new _AMD_IScript_validateScript(__inS);
        try
        {
            __obj.validateScript_async(__cb, j.value, acceptsList, __current);
        }
        catch(java.lang.Exception ex)
        {
            __cb.ice_exception(ex);
        }
        return Ice.DispatchStatus.DispatchAsync;
    }

    private final static String[] __all =
    {
        "canRunScript",
        "deleteScript",
        "editScript",
        "getParams",
        "getScriptID",
        "getScriptText",
        "getScriptWithDetails",
        "getScripts",
        "getScriptsByMimetype",
        "getUserScripts",
        "ice_id",
        "ice_ids",
        "ice_isA",
        "ice_ping",
        "runScript",
        "uploadOfficialScript",
        "uploadScript",
        "validateScript"
    };

    public Ice.DispatchStatus __dispatch(IceInternal.Incoming in, Ice.Current __current)
    {
        int pos = java.util.Arrays.binarySearch(__all, __current.operation);
        if(pos < 0)
        {
            throw new Ice.OperationNotExistException(__current.id, __current.facet, __current.operation);
        }

        switch(pos)
        {
            case 0:
            {
                return ___canRunScript(this, in, __current);
            }
            case 1:
            {
                return ___deleteScript(this, in, __current);
            }
            case 2:
            {
                return ___editScript(this, in, __current);
            }
            case 3:
            {
                return ___getParams(this, in, __current);
            }
            case 4:
            {
                return ___getScriptID(this, in, __current);
            }
            case 5:
            {
                return ___getScriptText(this, in, __current);
            }
            case 6:
            {
                return ___getScriptWithDetails(this, in, __current);
            }
            case 7:
            {
                return ___getScripts(this, in, __current);
            }
            case 8:
            {
                return ___getScriptsByMimetype(this, in, __current);
            }
            case 9:
            {
                return ___getUserScripts(this, in, __current);
            }
            case 10:
            {
                return ___ice_id(this, in, __current);
            }
            case 11:
            {
                return ___ice_ids(this, in, __current);
            }
            case 12:
            {
                return ___ice_isA(this, in, __current);
            }
            case 13:
            {
                return ___ice_ping(this, in, __current);
            }
            case 14:
            {
                return ___runScript(this, in, __current);
            }
            case 15:
            {
                return ___uploadOfficialScript(this, in, __current);
            }
            case 16:
            {
                return ___uploadScript(this, in, __current);
            }
            case 17:
            {
                return ___validateScript(this, in, __current);
            }
        }

        assert(false);
        throw new Ice.OperationNotExistException(__current.id, __current.facet, __current.operation);
    }

    protected void __writeImpl(IceInternal.BasicStream __os)
    {
        __os.startWriteSlice(ice_staticId(), -1, true);
        __os.endWriteSlice();
    }

    protected void __readImpl(IceInternal.BasicStream __is)
    {
        __is.startReadSlice();
        __is.endReadSlice();
    }

    public static final long serialVersionUID = 0L;
}
