// **********************************************************************
//
// Copyright (c) 2003-2013 ZeroC, Inc. All rights reserved.
//
// This copy of Ice is licensed to you under the terms described in the
// ICE_LICENSE file included in this distribution.
//
// **********************************************************************
//
// Ice version 3.5.1
//
// <auto-generated>
//
// Generated from file `IScript.ice'
//
// Warning: do not edit this file.
//
// </auto-generated>
//

package omero.api;

/**
 * Utility service for managing and launching scripts for execution by the Processor API.
 * 
 * Typical usage might include (PYTHON):
 * <pre>
 * 
 * sf = client.createSession()
 * svc = sf.getScriptService()
 * scripts = svc.getScripts()
 * 
 * if len(scripts) >= 1:
 * script_id = svc.keys()\[-1]
 * else:
 * script_id = svc.uploadScript('/test/my_script.py', SCRIPT_TEXT)
 * 
 * params = svc.getParams(script_id)
 * 
 * # You will need to parse the params to create the proper input
 * inputs = {}
 * 
 * # The last parameter is how long to wait as an RInt
 * proc = svc.runScript(script_id, inputs, None)
 * try:
 * cb = omero.scripts.ProcessCallbackI(client, proc)
 * while not cb.block(1000): # ms.
 * pass
 * cb.close()
 * rv = proc.getResults(0)
 * finally:
 * proc.close(False)
 * 
 * </pre>
 * See <a href="http://www.openmicroscopy.org/site/support/omero5.2/developers/scripts/">OMERO.scripts</a> for more information.
 **/
public interface _IScriptOperationsNC extends _ServiceInterfaceOperationsNC
{
    /**
     * This method returns official server scripts as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts()
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * # First character is a "/" symbol
     * path = script.path.val\[1:\]
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param __cb The callback object for the operation.
     **/
    void getScripts_async(AMD_IScript_getScripts __cb)
        throws omero.ServerError;

    /**
     * This method returns official server scripts identified
     * with the specified extension as a list of
     * {@link omero.model.OriginalFile} objects.
     * These scripts will be executed by the server if submitted
     * via {@link #runScript}. The input parameters
     * necessary for proper functioning can be retrieved via
     * {@link #getParams}.
     * 
     * The {@link omero.model.OriginalFile#path} value can be used
     * in other official scripts via the
     * language specific import command, since the script
     * directory will be placed on the appropriate
     * environment path variable.
     * <pre>
     * scripts = scriptService.getScripts("py")
     * for script in scripts:
     * text = scriptService.getScriptText(script.id.val)
     * path = script.path.val\[1:\] # First symbol is a "/"
     * path = path.replace("/",".")
     * print "Possible import: %s" % path
     * </pre>
     * 
     * @param __cb The callback object for the operation.
     * @param mimetype the mimetype identifying the scripts.
     **/
    void getScriptsByMimetype_async(AMD_IScript_getScriptsByMimetype __cb, String mimetype)
        throws omero.ServerError;

    /**
     * Returns non-official scripts which have been uploaded by individual users.
     * These scripts will <em>not</me> be run by the server, though a user can
     * start a personal <i>usermode processor</i> which will allow the scripts to be
     * executed. This is particularly useful for testing new scripts.
     * @param __cb The callback object for the operation.
     **/
    void getUserScripts_async(AMD_IScript_getUserScripts __cb, java.util.List<omero.model.IObject> acceptsList)
        throws omero.ServerError;

    /**
     * Get the id of an official script by the script path.
     * The script service ensures that all script paths are unique.
     * 
     * Note: there is no similar method for user scripts (e.g. getUserScriptID)
     * since the path is not guaranteed to be unique.
     * 
     * @param __cb The callback object for the operation.
     **/
    void getScriptID_async(AMD_IScript_getScriptID __cb, String path)
        throws omero.ServerError;

    /**
     * Get the text from the server for the script with given id.
     * 
     * @param __cb The callback object for the operation.
     * @param scriptID see above.
     **/
    void getScriptText_async(AMD_IScript_getScriptText __cb, long scriptID)
        throws omero.ServerError;

    /**
     * Upload a user script to the server and return the id. This method checks that
     * a script with that names does not exist and that the script has parameters
     * <em>if possible</em>, i.e. a usermode processor is running which for the
     * current user.
     * 
     * @param __cb The callback object for the operation.
     **/
    void uploadScript_async(AMD_IScript_uploadScript __cb, String path, String scriptText)
        throws omero.ServerError;

    /**
     * Like {@link #uploadScript} but is only callable by
     * administrators. The parameters for the script are also
     * checked.
     * @param __cb The callback object for the operation.
     **/
    void uploadOfficialScript_async(AMD_IScript_uploadOfficialScript __cb, String path, String scriptText)
        throws omero.ServerError;

    /**
     * Modify the text for the given script object.
     * 
     * @param __cb The callback object for the operation.
     **/
    void editScript_async(AMD_IScript_editScript __cb, omero.model.OriginalFile fileObject, String scriptText)
        throws omero.ServerError;

    /**
     * Get the script from the server with details from OriginalFile
     * @param __cb The callback object for the operation.
     * @param scriptID see above
     **/
    void getScriptWithDetails_async(AMD_IScript_getScriptWithDetails __cb, long scriptID)
        throws omero.ServerError;

    /**
     * Get the parameters that the script takes and returns, along with
     * other metadata available from the script.
     * 
     * @param __cb The callback object for the operation.
     * @param scriptID see above.
     **/
    void getParams_async(AMD_IScript_getParams __cb, long scriptID)
        throws omero.ServerError;

    /**
     * Delete the script on the server with id. The file will also be removed from disk.
     * 
     * @param __cb The callback object for the operation.
     * @param scriptID Id of the script to delete.
     **/
    void deleteScript_async(AMD_IScript_deleteScript __cb, long scriptID)
        throws omero.ServerError;

    /**
     * If {@link ResourceError} is thrown, then no
     * {@link Processor} is available. Use {@link #scheduleJob}
     * to create a {@link omero.model.ScriptJob} in the
     * <i>Waiting</i> state. A {@link Processor} may become
     * available.
     * 
     * <pre>
     * try:
     * proc = scriptService.runScript(1, {}, None)
     * except ResourceError:
     * job = scriptService.scheduleScript(1, {}, None)
     * </pre>
     * 
     * The {@link ScriptProcess} proxy MUST be closed before
     * exiting. If you would like the script execution to continue
     * in the background, pass <code>True</code> as the argument.
     * 
     * <pre>
     * try:
     * proc.poll()         # See if process is finished
     * finally:
     * proc.close(True)    # Detach and execution can continue
     * # proc.close(False) # OR script is immediately stopped.
     * </pre>
     * @param __cb The callback object for the operation.
     **/
    void runScript_async(AMD_IScript_runScript __cb, long scriptID, java.util.Map<java.lang.String, omero.RType> inputs, omero.RInt waitSecs)
        throws omero.ServerError;

    /**
     * Returns true if there is a processor which will run the
     * given script.
     * 
     * <p>
     * Either the script is an official script and this method
     * will return true (though an individual invocation may fail
     * with an {@link omero.ResourceError} for some reason)
     * <em>or</em> this is a user script, and a usermode processor
     * must be active which takes the scripts user or group.
     * </p>
     * 
     * @param __cb The callback object for the operation.
     **/
    void canRunScript_async(AMD_IScript_canRunScript __cb, long scriptID)
        throws omero.ServerError;

    /**
     * Used internally by processor.py to check if the script
     * attached to the {@link omero.model.Job} has a valid script
     * attached, based on the {@link #acceptsList} and the current
     * security context.
     * 
     * An example of an acceptsList might be <pre>Experimenter(myUserId, False)</pre>, meaning that
     * only scripts belonging to me should be trusted. An empty list implies that the server should
     * return what it would by default trust.
     * 
     * A valid script will be returned if it exists; otherwise null.
     * @param __cb The callback object for the operation.
     **/
    void validateScript_async(AMD_IScript_validateScript __cb, omero.model.Job j, java.util.List<omero.model.IObject> acceptsList)
        throws omero.ServerError;
}
