// **********************************************************************
//
// Copyright (c) 2003-2013 ZeroC, Inc. All rights reserved.
//
// This copy of Ice is licensed to you under the terms described in the
// ICE_LICENSE file included in this distribution.
//
// **********************************************************************
//
// Ice version 3.5.1
//
// <auto-generated>
//
// Generated from file `ISession.ice'
//
// Warning: do not edit this file.
//
// </auto-generated>
//

package omero.api;

/**
 * {@link omero.model.Session} creation service for OMERO. Access to
 * all other services is dependent upon a properly created and still
 * active {@link omero.model.Session}.
 * 
 * The session uuid ({@link omero.model.Session#getUuid}) can be
 * considered a capability token, or temporary single use password.
 * Simply by possessing it the client has access to all information
 * available to the {@link omero.model.Session}.
 * 
 * Note: Both the RMI <code>ome.system.ServiceFactory</code> as well
 * as the Ice {@link omero.api.ServiceFactory} use
 * {@link omero.api.ISession} to acquire a
 * {@link omero.model.Session}. In the Ice case, Glacier2
 * contacts {@link omero.api.ISession} itself and returns a
 * ServiceFactory remote proxy. From both ServiceFactory
 * instances, it is possible but not necessary to access
 * {@link omero.api.ISession}.
 **/
public interface _ISessionOperations extends _ServiceInterfaceOperations
{
    /**
     * Creates a new session and returns it to the user.
     * 
     * @param __cb The callback object for the operation.
     * @param __current The Current object for the invocation.
     **/
    void createSession_async(AMD_ISession_createSession __cb, omero.sys.Principal p, String credentials, Ice.Current __current)
        throws Glacier2.CannotCreateSessionException,
               omero.ServerError;

    /**
     * Allows a user to open up another session for him/herself with the given
     * defaults without needing to re-enter password.
     * @param __cb The callback object for the operation.
     * @param __current The Current object for the invocation.
     **/
    void createUserSession_async(AMD_ISession_createUserSession __cb, long timeToLiveMilliseconds, long timeToIdleMilliseconds, String defaultGroup, Ice.Current __current)
        throws Glacier2.CannotCreateSessionException,
               omero.ServerError;

    /**
     * Allows an admin to create a {@link Session} for the give
     * {@link omero.sys.Principal}.
     * 
     * @param __cb The callback object for the operation.
     * @param timeToLiveMilliseconds
     * The time that this {@link omero.model.Session}
     * has until destruction. This is useful to
     * override the server default so that an initial
     * delay before the user is given the token will
     * not be construed as idle time. A value less than
     * 1 will cause the default max timeToLive to be
     * used; but timeToIdle will be disabled.
     * @param __current The Current object for the invocation.
     **/
    void createSessionWithTimeout_async(AMD_ISession_createSessionWithTimeout __cb, omero.sys.Principal p, long timeToLiveMilliseconds, Ice.Current __current)
        throws Glacier2.CannotCreateSessionException,
               omero.ServerError;

    /**
     * Allows an admin to create a {@link omero.model.Session} for
     * the given {@link omero.sys.Principal}.
     * 
     * @param __cb The callback object for the operation.
     * @param timeToLiveMilliseconds
     * The time that this {@link omero.model.Session}
     * has until destruction. Setting the value to 0
     * will prevent destruction unless the session
     * remains idle.
     * @param timeToIdleMilliseconds
     * The time that this {@link omero.model.Session}
     * can remain idle before being destroyed. Setting
     * the value to 0 will prevent idleness based
     * destruction.
     * @param __current The Current object for the invocation.
     **/
    void createSessionWithTimeouts_async(AMD_ISession_createSessionWithTimeouts __cb, omero.sys.Principal p, long timeToLiveMilliseconds, long timeToIdleMilliseconds, Ice.Current __current)
        throws Glacier2.CannotCreateSessionException,
               omero.ServerError;

    /**
     * Retrieves the session associated with this uuid, updating
     * the last access time as well. Throws a
     * {@link RemovedSessionException} if not present, or
     * a {@link SessionTimeoutException} if expired.
     * 
     * This method can be used as a {@link Session} ping.
     * @param __cb The callback object for the operation.
     * @param __current The Current object for the invocation.
     **/
    void getSession_async(AMD_ISession_getSession __cb, String sessionUuid, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Retrieves the current reference count for the given uuid.
     * Has the same semantics as {@link #getSession}.
     * @param __cb The callback object for the operation.
     * @param __current The Current object for the invocation.
     **/
    void getReferenceCount_async(AMD_ISession_getReferenceCount __cb, String sessionUuid, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Closes session and releases all resources. It is preferred
     * that all clients call this method as soon as possible to
     * free memory, but it is possible to not call close, and
     * rejoin a session later.
     * 
     * The current reference count for the session is returned. If
     * the session does not exist, -1. If this call caused the
     * death of the session, then -2.
     * @param __cb The callback object for the operation.
     * @param __current The Current object for the invocation.
     **/
    void closeSession_async(AMD_ISession_closeSession __cb, omero.model.Session sess, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Returns a list of open sessions for the current user. The
     * list is ordered by session creation time, so that the last
     * item was created last.
     * @param __cb The callback object for the operation.
     * @param __current The Current object for the invocation.
     **/
    void getMyOpenSessions_async(AMD_ISession_getMyOpenSessions __cb, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Like {@link #getMyOpenSessions} but returns only those
     * sessions with the given agent string.
     * @param __cb The callback object for the operation.
     * @param __current The Current object for the invocation.
     **/
    void getMyOpenAgentSessions_async(AMD_ISession_getMyOpenAgentSessions __cb, String agent, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Like {@link #getMyOpenSessions} but returns only those
     * sessions started by official OMERO clients.
     * @param __cb The callback object for the operation.
     * @param __current The Current object for the invocation.
     **/
    void getMyOpenClientSessions_async(AMD_ISession_getMyOpenClientSessions __cb, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Retrieves an entry from the given
     * {@link omero.model.Session} input environment.
     * @param __cb The callback object for the operation.
     * @param __current The Current object for the invocation.
     **/
    void getInput_async(AMD_ISession_getInput __cb, String sess, String key, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Retrieves an entry from the {@link omero.model.Session}
     * output environment.
     * @param __cb The callback object for the operation.
     * @param __current The Current object for the invocation.
     **/
    void getOutput_async(AMD_ISession_getOutput __cb, String sess, String key, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Places an entry in the given {@link omero.model.Session}
     * input environment.
     * If the value is null, the key will be removed.
     * @param __cb The callback object for the operation.
     * @param __current The Current object for the invocation.
     **/
    void setInput_async(AMD_ISession_setInput __cb, String sess, String key, omero.RType value, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Places an entry in the given {@link omero.model.Session}
     * output environment. If the value is null, the key will be
     * removed.
     * @param __cb The callback object for the operation.
     * @param __current The Current object for the invocation.
     **/
    void setOutput_async(AMD_ISession_setOutput __cb, String sess, String key, omero.RType value, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Retrieves all keys in the {@link omero.model.Session} input
     * environment.
     * 
     * @param __cb The callback object for the operation.
     * @param __current The Current object for the invocation.
     **/
    void getInputKeys_async(AMD_ISession_getInputKeys __cb, String sess, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Retrieves all keys in the {@link omero.model.Session}
     * output environment.
     * @param __cb The callback object for the operation.
     * @param __current The Current object for the invocation.
     **/
    void getOutputKeys_async(AMD_ISession_getOutputKeys __cb, String sess, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Retrieves all inputs from the given
     * {@link omero.model.Session} input environment.
     * @param __cb The callback object for the operation.
     * @param __current The Current object for the invocation.
     **/
    void getInputs_async(AMD_ISession_getInputs __cb, String sess, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Retrieves all outputs from the given
     * {@link omero.model.Session} input environment.
     * @param __cb The callback object for the operation.
     * @param __current The Current object for the invocation.
     **/
    void getOutputs_async(AMD_ISession_getOutputs __cb, String sess, Ice.Current __current)
        throws omero.ServerError;
}
