// **********************************************************************
//
// Copyright (c) 2003-2013 ZeroC, Inc. All rights reserved.
//
// This copy of Ice is licensed to you under the terms described in the
// ICE_LICENSE file included in this distribution.
//
// **********************************************************************
//
// Ice version 3.5.1
//
// <auto-generated>
//
// Generated from file `IShare.ice'
//
// Warning: do not edit this file.
//
// </auto-generated>
//

package omero.api;

/**
 * Provides method for sharing - collaboration process for images,
 * datasets, projects.
 **/
public interface _IShareOperationsNC extends _ServiceInterfaceOperationsNC
{
    /**
     * Turns on the access control lists attached to the given
     * share for the current session. Warning: this will slow down
     * the execution of the current session for all database
     * reads. Writing to the database will not be allowed. If
     * share does not exist or is not accessible (non-members) or
     * is disabled, then an {@link ValidationException} is thrown.
     * @param __cb The callback object for the operation.
     **/
    void activate_async(AMD_IShare_activate __cb, long shareId)
        throws omero.ServerError;

    /**
     * Turns off the access control lists with the current share.
     * @param __cb The callback object for the operation.
     **/
    void deactivate_async(AMD_IShare_deactivate __cb)
        throws omero.ServerError;

    /**
     * Gets a share as a {@link omero.model.Session} with all
     * related: {@link omero.model.Annotation} comments,
     * {@link omero.model.Experimenter} members, fully loaded.
     * Unlike the other methods on this interface, if the
     * sessionId is unknown, does not throw a
     * {@link omero.ValidationException}.
     * 
     * @param __cb The callback object for the operation.
     **/
    void getShare_async(AMD_IShare_getShare __cb, long shareId)
        throws omero.ServerError;

    /**
     * Returns a map from share id to the count of total members
     * (including the owner). This is represented by
     * {@link omero.model.ShareMember} links.
     * 
     * @param __cb The callback object for the operation.
     * @param shareIds Not null.
     **/
    void getMemberCount_async(AMD_IShare_getMemberCount __cb, java.util.List<Long> shareIds)
        throws omero.ServerError;

    /**
     * Gets all owned shares for the current
     * {@link omero.model.Experimenter}.
     * 
     * @param __cb The callback object for the operation.
     **/
    void getOwnShares_async(AMD_IShare_getOwnShares __cb, boolean active)
        throws omero.ServerError;

    /**
     * Gets all shares where current
     * {@link omero.model.Experimenter} is a member.
     * 
     * @param __cb The callback object for the operation.
     **/
    void getMemberShares_async(AMD_IShare_getMemberShares __cb, boolean active)
        throws omero.ServerError;

    /**
     * Gets all shares owned by the given
     * {@link omero.model.Experimenter}.
     * 
     * @param __cb The callback object for the operation.
     **/
    void getSharesOwnedBy_async(AMD_IShare_getSharesOwnedBy __cb, omero.model.Experimenter user, boolean active)
        throws omero.ServerError;

    /**
     * Gets all shares where given
     * {@link omero.model.Experimenter} is a member.
     * 
     * @param __cb The callback object for the operation.
     **/
    void getMemberSharesFor_async(AMD_IShare_getMemberSharesFor __cb, omero.model.Experimenter user, boolean active)
        throws omero.ServerError;

    /**
     * Looks up all {@link omero.model.IObject} items belong to the
     * {@link omero.model.Session} share.
     * 
     * @param __cb The callback object for the operation.
     **/
    void getContents_async(AMD_IShare_getContents __cb, long shareId)
        throws omero.ServerError;

    /**
     * Returns a range of items from the share.
     * 
     * @param __cb The callback object for the operation.
     **/
    void getContentSubList_async(AMD_IShare_getContentSubList __cb, long shareId, int start, int finish)
        throws omero.ServerError;

    /**
     * Returns the number of items in the share.
     * @param __cb The callback object for the operation.
     **/
    void getContentSize_async(AMD_IShare_getContentSize __cb, long shareId)
        throws omero.ServerError;

    /**
     * Returns the contents of the share keyed by type.
     * @param __cb The callback object for the operation.
     **/
    void getContentMap_async(AMD_IShare_getContentMap __cb, long shareId)
        throws omero.ServerError;

    /**
     * Creates {@link omero.model.Session} share with all related:
     * {@link omero.model.IObject} itmes,
     * {@link omero.model.Experimenter} members, and guests.
     * 
     * @param __cb The callback object for the operation.
     * @param enabled
     * if true, then the share is immediately available
     * for use. If false, then the share is in draft
     * state. All methods on this interface will work
     * for shares <em>except</em> {@link #activate}.
     * Similarly, the share password cannot be used by
     * guests to login.
     **/
    void createShare_async(AMD_IShare_createShare __cb, String description, omero.RTime expiration, java.util.List<omero.model.IObject> items, java.util.List<omero.model.Experimenter> exps, java.util.List<String> guests, boolean enabled)
        throws omero.ServerError;

    void setDescription_async(AMD_IShare_setDescription __cb, long shareId, String description)
        throws omero.ServerError;

    void setExpiration_async(AMD_IShare_setExpiration __cb, long shareId, omero.RTime expiration)
        throws omero.ServerError;

    void setActive_async(AMD_IShare_setActive __cb, long shareId, boolean active)
        throws omero.ServerError;

    /**
     * Closes {@link omero.model.Session} share. No further logins
     * will be possible and all getters (e.g.
     * {@link #getMemberShares}, {@link #getOwnShares}, ...) will
     * filter these results if {@code onlyActive} is true.
     * @param __cb The callback object for the operation.
     **/
    void closeShare_async(AMD_IShare_closeShare __cb, long shareId)
        throws omero.ServerError;

    /**
     * Adds new {@link omero.model.IObject} items to
     * {@link omero.model.Session} share. Conceptually calls
     * {@link #addObjects} for every argument passed, but the
     * graphs will be merged.
     * @param __cb The callback object for the operation.
     **/
    void addObjects_async(AMD_IShare_addObjects __cb, long shareId, java.util.List<omero.model.IObject> iobjects)
        throws omero.ServerError;

    /**
     * Adds new {@link omero.model.IObject} item to
     * {@link omero.model.Session} share. The entire object graph
     * with the exception of all Details will be loaded into the
     * share. If you would like to load a single object, then pass
     * an unloaded reference.
     * @param __cb The callback object for the operation.
     **/
    void addObject_async(AMD_IShare_addObject __cb, long shareId, omero.model.IObject iobject)
        throws omero.ServerError;

    /**
     * Remove existing items from the share.
     * @param __cb The callback object for the operation.
     **/
    void removeObjects_async(AMD_IShare_removeObjects __cb, long shareId, java.util.List<omero.model.IObject> iobjects)
        throws omero.ServerError;

    /**
     * Removes existing {@link omero.model.IObject} object from the
     * {@link omero.model.Session} share.
     * @param __cb The callback object for the operation.
     **/
    void removeObject_async(AMD_IShare_removeObject __cb, long shareId, omero.model.IObject iobject)
        throws omero.ServerError;

    /**
     * Returns a map from share id to comment count.
     * 
     * @param __cb The callback object for the operation.
     * @param shareIds Not null.
     **/
    void getCommentCount_async(AMD_IShare_getCommentCount __cb, java.util.List<Long> shareIds)
        throws omero.ServerError;

    /**
     * Looks up all {@link omero.model.Annotation} comments which
     * belong to the {@link omero.model.Session} share.
     * 
     * @param __cb The callback object for the operation.
     **/
    void getComments_async(AMD_IShare_getComments __cb, long shareId)
        throws omero.ServerError;

    /**
     * Creates {@link omero.model.TextAnnotation} comment for
     * {@link omero.model.Session} share.
     * @param __cb The callback object for the operation.
     **/
    void addComment_async(AMD_IShare_addComment __cb, long shareId, String comment)
        throws omero.ServerError;

    /**
     * Creates {@link omero.model.TextAnnotation} comment which
     * replies to an existing comment.
     * 
     * @param __cb The callback object for the operation.
     **/
    void addReply_async(AMD_IShare_addReply __cb, long shareId, String comment, omero.model.TextAnnotation replyTo)
        throws omero.ServerError;

    /**
     * Deletes {@link omero.model.Annotation} comment from the
     * database.
     * @param __cb The callback object for the operation.
     **/
    void deleteComment_async(AMD_IShare_deleteComment __cb, omero.model.Annotation comment)
        throws omero.ServerError;

    /**
     * Get all {@link omero.model.Experimenter} users who are a
     * member of the share.
     * @param __cb The callback object for the operation.
     **/
    void getAllMembers_async(AMD_IShare_getAllMembers __cb, long shareId)
        throws omero.ServerError;

    /**
     * Get the email addresses for all share guests.
     * @param __cb The callback object for the operation.
     **/
    void getAllGuests_async(AMD_IShare_getAllGuests __cb, long shareId)
        throws omero.ServerError;

    /**
     * Get a single set containing the
     * {@link omero.model.Experimenter#getOmeName} login names
     * of the users as well email addresses for guests.
     * 
     * @param __cb The callback object for the operation.
     * @param shareId
     **/
    void getAllUsers_async(AMD_IShare_getAllUsers __cb, long shareId)
        throws omero.ServerError,
               omero.ValidationException;

    /**
     * Adds {@link omero.model.Experimenter} experimenters to
     * {@link omero.model.Session} share.
     * @param __cb The callback object for the operation.
     **/
    void addUsers_async(AMD_IShare_addUsers __cb, long shareId, java.util.List<omero.model.Experimenter> exps)
        throws omero.ServerError;

    /**
     * Adds guest email addresses to the share.
     * @param __cb The callback object for the operation.
     **/
    void addGuests_async(AMD_IShare_addGuests __cb, long shareId, java.util.List<String> emailAddresses)
        throws omero.ServerError;

    /**
     * Removes {@link omero.model.Experimenter} experimenters from
     * {@link omero.model.Session} share.
     * @param __cb The callback object for the operation.
     **/
    void removeUsers_async(AMD_IShare_removeUsers __cb, long shareId, java.util.List<omero.model.Experimenter> exps)
        throws omero.ServerError;

    /**
     * Removes guest email addresses from the share.
     * @param __cb The callback object for the operation.
     **/
    void removeGuests_async(AMD_IShare_removeGuests __cb, long shareId, java.util.List<String> emailAddresses)
        throws omero.ServerError;

    /**
     * Adds {@link omero.model.Experimenter} experimenter to
     * {@link omero.model.Session} share.
     * @param __cb The callback object for the operation.
     **/
    void addUser_async(AMD_IShare_addUser __cb, long shareId, omero.model.Experimenter exp)
        throws omero.ServerError;

    /**
     * Adds guest email address to the share.
     * @param __cb The callback object for the operation.
     **/
    void addGuest_async(AMD_IShare_addGuest __cb, long shareId, String emailAddress)
        throws omero.ServerError;

    /**
     * Removes {@link omero.model.Experimenter} experimenter from
     * {@link omero.model.Session} share.
     * @param __cb The callback object for the operation.
     **/
    void removeUser_async(AMD_IShare_removeUser __cb, long shareId, omero.model.Experimenter exp)
        throws omero.ServerError;

    /**
     * Removes guest email address from share.
     * @param __cb The callback object for the operation.
     **/
    void removeGuest_async(AMD_IShare_removeGuest __cb, long shareId, String emailAddress)
        throws omero.ServerError;

    /**
     * Gets actual active connections to
     * {@link omero.model.Session} share.
     * 
     * @param __cb The callback object for the operation.
     **/
    void getActiveConnections_async(AMD_IShare_getActiveConnections __cb, long shareId)
        throws omero.ServerError;

    /**
     * Gets previous connections to
     * {@link omero.model.Session} share.
     * 
     * @param __cb The callback object for the operation.
     **/
    void getPastConnections_async(AMD_IShare_getPastConnections __cb, long shareId)
        throws omero.ServerError;

    /**
     * Makes the connection invalid for
     * {@link omero.model.Session} share for specified user.
     * @param __cb The callback object for the operation.
     **/
    void invalidateConnection_async(AMD_IShare_invalidateConnection __cb, long shareId, omero.model.Experimenter exp)
        throws omero.ServerError;

    /**
     * Gets events for {@link omero.model.Session} share per
     * {@link omero.model.Experimenter} experimenter for period of
     * time.
     * @param __cb The callback object for the operation.
     **/
    void getEvents_async(AMD_IShare_getEvents __cb, long shareId, omero.model.Experimenter exp, omero.RTime from, omero.RTime to)
        throws omero.ServerError;

    /**
     * Notifies via email selected members of share.
     * @param __cb The callback object for the operation.
     **/
    void notifyMembersOfShare_async(AMD_IShare_notifyMembersOfShare __cb, long shareId, String subject, String message, boolean html)
        throws omero.ServerError;
}
