// **********************************************************************
//
// Copyright (c) 2003-2013 ZeroC, Inc. All rights reserved.
//
// This copy of Ice is licensed to you under the terms described in the
// ICE_LICENSE file included in this distribution.
//
// **********************************************************************
//
// Ice version 3.5.1
//
// <auto-generated>
//
// Generated from file `ITimeline.ice'
//
// Warning: do not edit this file.
//
// </auto-generated>
//

package omero.api;

/**
 * Service for the querying of OMERO metadata based on creation and
 * modification time. Currently supported types for querying include:
 * <ul>
 * <li>{@link omero.model.Annotation}</li>
 * <li>{@link omero.model.Dataset}</li>
 * <li>{@link omero.model.Image}</li>
 * <li>{@link omero.model.Project}</li>
 * <li>{@link omero.model.RenderingDef}</li>
 * </ul>
 * 
 * <h4>Return maps</h4>
 * 
 * The map return values will be indexed by the short type name above:
 * <i>Project</i>, <i>Image</i>, ... All keys which are passed in the
 * StringSet argument will be included in the returned map, even if
 * they have no values. A default value of 0 or the empty list \[]
 * will be used.
 * The only exception to this rule is that the null or empty StringSet
 * implies all valid keys.
 * 
 * <h4>Parameters</h4>
 * 
 * All methods take a omero::sys::Parameters object and will apply the filter
 * object for paging through the data in order to prevent loading too
 * many objects. If the parameters argument is null or no paging is activated,
 * then the default will be: OFFSET=0, LIMIT=50. Filter.ownerId and
 * Filter.groupId will also be AND'ed to the query if either value is present.
 * If both are null, then the current user id will be used. To retrieve for
 * all users, use <code>ownerId == rlong(-1)</code> and
 * <code>groupId == null</code>.
 * 
 * <h4>Merging</h4>
 * 
 * The methods which take a StringSet and a Parameters object, also
 * have a <i>bool merge</i> argument. This argument defines whether or
 * not the LIMIT applies to each object independently
 * (<code>["a","b"] @ 100 == 200</code>) or merges the lists together
 * chronologically (<code>["a","b"] @ 100 merged == 100</code>).
 * 
 * <h4>Time used</h4>
 * 
 * Except for Image, IObject.details.updateEvent is used in all cases
 * for determining most recent events. Images are compared via
 * Image.acquisitionDate which is unlike the other properties is
 * modifiable by the user.
 * 
 * 
 * 
 * A typical invocation might look like (in Python):
 * <pre>
 * timeline = sf.getTimelineService()
 * params = ParametersI().page(0,100)
 * types = \["Project","Dataset"])
 * map = timeline.getByPeriod(types, params, False)
 * </pre>
 * At this point, map will not contain more than 200 objects.
 * 
 * This service is defined only in Blitz and so no javadoc is available
 * in the ome.api package.
 * 
 * TODOS: binning, stateful caching, ...
 **/
public abstract class _ITimelineDisp extends Ice.ObjectImpl implements ITimeline
{
    protected void
    ice_copyStateFrom(Ice.Object __obj)
        throws java.lang.CloneNotSupportedException
    {
        throw new java.lang.CloneNotSupportedException();
    }

    public static final String[] __ids =
    {
        "::Ice::Object",
        "::omero::api::ITimeline",
        "::omero::api::ServiceInterface"
    };

    public boolean ice_isA(String s)
    {
        return java.util.Arrays.binarySearch(__ids, s) >= 0;
    }

    public boolean ice_isA(String s, Ice.Current __current)
    {
        return java.util.Arrays.binarySearch(__ids, s) >= 0;
    }

    public String[] ice_ids()
    {
        return __ids;
    }

    public String[] ice_ids(Ice.Current __current)
    {
        return __ids;
    }

    public String ice_id()
    {
        return __ids[1];
    }

    public String ice_id(Ice.Current __current)
    {
        return __ids[1];
    }

    public static String ice_staticId()
    {
        return __ids[1];
    }

    /**
     * Queries the same information as getByPeriod, but only returns the counts
     * for the given objects.
     * @param __cb The callback object for the operation.
     **/
    public final void countByPeriod_async(AMD_ITimeline_countByPeriod __cb, java.util.List<String> types, omero.RTime start, omero.RTime end, omero.sys.Parameters p)
        throws omero.ServerError
    {
        countByPeriod_async(__cb, types, start, end, p, null);
    }

    /**
     * Returns the given LIMIT objects of TYPES as ordered by
     * creation/modification times in the Event table, but
     * within the given time window.
     * @param __cb The callback object for the operation.
     **/
    public final void getByPeriod_async(AMD_ITimeline_getByPeriod __cb, java.util.List<String> types, omero.RTime start, omero.RTime end, omero.sys.Parameters p, boolean merge)
        throws omero.ServerError
    {
        getByPeriod_async(__cb, types, start, end, p, merge, null);
    }

    /**
     * Returns the EventLog table objects which are queried to produce the counts above.
     * Note the concept of <i>period inclusion</i> mentioned above.
     * 
     * WORKAROUND WARNING: this method returns non-managed EventLogs (i.e.
     * eventLog.getId() == null) for <i>Image acquisitions</i>.
     * @param __cb The callback object for the operation.
     **/
    public final void getEventLogsByPeriod_async(AMD_ITimeline_getEventLogsByPeriod __cb, omero.RTime start, omero.RTime end, omero.sys.Parameters p)
        throws omero.ServerError
    {
        getEventLogsByPeriod_async(__cb, start, end, p, null);
    }

    /**
     * Return the last LIMIT annotation __Links__ whose parent (IAnnotated)
     * matches one of the parentTypes, whose child (Annotation) matches one
     * of the childTypes (limit of one for the moment), and who namespace
     * matches via ILIKE.
     * 
     * The parents and children will be unloaded. The link will have
     * its creation/update events loaded.
     * 
     * If Parameters.theFilter.ownerId or groupId are set, they will be
     * AND'ed to the query to filter results.
     * 
     * Merges by default based on parentType.
     * @param __cb The callback object for the operation.
     **/
    public final void getMostRecentAnnotationLinks_async(AMD_ITimeline_getMostRecentAnnotationLinks __cb, java.util.List<String> parentTypes, java.util.List<String> childTypes, java.util.List<String> namespaces, omero.sys.Parameters p)
        throws omero.ServerError
    {
        getMostRecentAnnotationLinks_async(__cb, parentTypes, childTypes, namespaces, p, null);
    }

    /**
     * Returns the last LIMIT objects of TYPES as ordered by
     * creation/modification times in the Event table.
     * @param __cb The callback object for the operation.
     **/
    public final void getMostRecentObjects_async(AMD_ITimeline_getMostRecentObjects __cb, java.util.List<String> types, omero.sys.Parameters p, boolean merge)
        throws omero.ServerError
    {
        getMostRecentObjects_async(__cb, types, p, merge, null);
    }

    /**
     * Return the last LIMIT comment annotation links attached to a share by
     * __others__.
     * 
     * Note: Currently the storage of these objects is not optimal
     * and so this method may change.
     * @param __cb The callback object for the operation.
     **/
    public final void getMostRecentShareCommentLinks_async(AMD_ITimeline_getMostRecentShareCommentLinks __cb, omero.sys.Parameters p)
        throws omero.ServerError
    {
        getMostRecentShareCommentLinks_async(__cb, p, null);
    }

    public static Ice.DispatchStatus ___getMostRecentAnnotationLinks(ITimeline __obj, IceInternal.Incoming __inS, Ice.Current __current)
    {
        __checkMode(Ice.OperationMode.Idempotent, __current.mode);
        IceInternal.BasicStream __is = __inS.startReadParams();
        java.util.List<String> parentTypes;
        java.util.List<String> childTypes;
        java.util.List<String> namespaces;
        omero.sys.ParametersHolder p = new omero.sys.ParametersHolder();
        parentTypes = StringSetHelper.read(__is);
        childTypes = StringSetHelper.read(__is);
        namespaces = StringSetHelper.read(__is);
        __is.readObject(p);
        __is.readPendingObjects();
        __inS.endReadParams();
        AMD_ITimeline_getMostRecentAnnotationLinks __cb = new _AMD_ITimeline_getMostRecentAnnotationLinks(__inS);
        try
        {
            __obj.getMostRecentAnnotationLinks_async(__cb, parentTypes, childTypes, namespaces, p.value, __current);
        }
        catch(java.lang.Exception ex)
        {
            __cb.ice_exception(ex);
        }
        return Ice.DispatchStatus.DispatchAsync;
    }

    public static Ice.DispatchStatus ___getMostRecentShareCommentLinks(ITimeline __obj, IceInternal.Incoming __inS, Ice.Current __current)
    {
        __checkMode(Ice.OperationMode.Idempotent, __current.mode);
        IceInternal.BasicStream __is = __inS.startReadParams();
        omero.sys.ParametersHolder p = new omero.sys.ParametersHolder();
        __is.readObject(p);
        __is.readPendingObjects();
        __inS.endReadParams();
        AMD_ITimeline_getMostRecentShareCommentLinks __cb = new _AMD_ITimeline_getMostRecentShareCommentLinks(__inS);
        try
        {
            __obj.getMostRecentShareCommentLinks_async(__cb, p.value, __current);
        }
        catch(java.lang.Exception ex)
        {
            __cb.ice_exception(ex);
        }
        return Ice.DispatchStatus.DispatchAsync;
    }

    public static Ice.DispatchStatus ___getMostRecentObjects(ITimeline __obj, IceInternal.Incoming __inS, Ice.Current __current)
    {
        __checkMode(Ice.OperationMode.Idempotent, __current.mode);
        IceInternal.BasicStream __is = __inS.startReadParams();
        java.util.List<String> types;
        omero.sys.ParametersHolder p = new omero.sys.ParametersHolder();
        boolean merge;
        types = StringSetHelper.read(__is);
        __is.readObject(p);
        merge = __is.readBool();
        __is.readPendingObjects();
        __inS.endReadParams();
        AMD_ITimeline_getMostRecentObjects __cb = new _AMD_ITimeline_getMostRecentObjects(__inS);
        try
        {
            __obj.getMostRecentObjects_async(__cb, types, p.value, merge, __current);
        }
        catch(java.lang.Exception ex)
        {
            __cb.ice_exception(ex);
        }
        return Ice.DispatchStatus.DispatchAsync;
    }

    public static Ice.DispatchStatus ___getByPeriod(ITimeline __obj, IceInternal.Incoming __inS, Ice.Current __current)
    {
        __checkMode(Ice.OperationMode.Idempotent, __current.mode);
        IceInternal.BasicStream __is = __inS.startReadParams();
        java.util.List<String> types;
        omero.RTimeHolder start = new omero.RTimeHolder();
        omero.RTimeHolder end = new omero.RTimeHolder();
        omero.sys.ParametersHolder p = new omero.sys.ParametersHolder();
        boolean merge;
        types = StringSetHelper.read(__is);
        __is.readObject(start);
        __is.readObject(end);
        __is.readObject(p);
        merge = __is.readBool();
        __is.readPendingObjects();
        __inS.endReadParams();
        AMD_ITimeline_getByPeriod __cb = new _AMD_ITimeline_getByPeriod(__inS);
        try
        {
            __obj.getByPeriod_async(__cb, types, start.value, end.value, p.value, merge, __current);
        }
        catch(java.lang.Exception ex)
        {
            __cb.ice_exception(ex);
        }
        return Ice.DispatchStatus.DispatchAsync;
    }

    public static Ice.DispatchStatus ___countByPeriod(ITimeline __obj, IceInternal.Incoming __inS, Ice.Current __current)
    {
        __checkMode(Ice.OperationMode.Idempotent, __current.mode);
        IceInternal.BasicStream __is = __inS.startReadParams();
        java.util.List<String> types;
        omero.RTimeHolder start = new omero.RTimeHolder();
        omero.RTimeHolder end = new omero.RTimeHolder();
        omero.sys.ParametersHolder p = new omero.sys.ParametersHolder();
        types = StringSetHelper.read(__is);
        __is.readObject(start);
        __is.readObject(end);
        __is.readObject(p);
        __is.readPendingObjects();
        __inS.endReadParams();
        AMD_ITimeline_countByPeriod __cb = new _AMD_ITimeline_countByPeriod(__inS);
        try
        {
            __obj.countByPeriod_async(__cb, types, start.value, end.value, p.value, __current);
        }
        catch(java.lang.Exception ex)
        {
            __cb.ice_exception(ex);
        }
        return Ice.DispatchStatus.DispatchAsync;
    }

    public static Ice.DispatchStatus ___getEventLogsByPeriod(ITimeline __obj, IceInternal.Incoming __inS, Ice.Current __current)
    {
        __checkMode(Ice.OperationMode.Idempotent, __current.mode);
        IceInternal.BasicStream __is = __inS.startReadParams();
        omero.RTimeHolder start = new omero.RTimeHolder();
        omero.RTimeHolder end = new omero.RTimeHolder();
        omero.sys.ParametersHolder p = new omero.sys.ParametersHolder();
        __is.readObject(start);
        __is.readObject(end);
        __is.readObject(p);
        __is.readPendingObjects();
        __inS.endReadParams();
        AMD_ITimeline_getEventLogsByPeriod __cb = new _AMD_ITimeline_getEventLogsByPeriod(__inS);
        try
        {
            __obj.getEventLogsByPeriod_async(__cb, start.value, end.value, p.value, __current);
        }
        catch(java.lang.Exception ex)
        {
            __cb.ice_exception(ex);
        }
        return Ice.DispatchStatus.DispatchAsync;
    }

    private final static String[] __all =
    {
        "countByPeriod",
        "getByPeriod",
        "getEventLogsByPeriod",
        "getMostRecentAnnotationLinks",
        "getMostRecentObjects",
        "getMostRecentShareCommentLinks",
        "ice_id",
        "ice_ids",
        "ice_isA",
        "ice_ping"
    };

    public Ice.DispatchStatus __dispatch(IceInternal.Incoming in, Ice.Current __current)
    {
        int pos = java.util.Arrays.binarySearch(__all, __current.operation);
        if(pos < 0)
        {
            throw new Ice.OperationNotExistException(__current.id, __current.facet, __current.operation);
        }

        switch(pos)
        {
            case 0:
            {
                return ___countByPeriod(this, in, __current);
            }
            case 1:
            {
                return ___getByPeriod(this, in, __current);
            }
            case 2:
            {
                return ___getEventLogsByPeriod(this, in, __current);
            }
            case 3:
            {
                return ___getMostRecentAnnotationLinks(this, in, __current);
            }
            case 4:
            {
                return ___getMostRecentObjects(this, in, __current);
            }
            case 5:
            {
                return ___getMostRecentShareCommentLinks(this, in, __current);
            }
            case 6:
            {
                return ___ice_id(this, in, __current);
            }
            case 7:
            {
                return ___ice_ids(this, in, __current);
            }
            case 8:
            {
                return ___ice_isA(this, in, __current);
            }
            case 9:
            {
                return ___ice_ping(this, in, __current);
            }
        }

        assert(false);
        throw new Ice.OperationNotExistException(__current.id, __current.facet, __current.operation);
    }

    protected void __writeImpl(IceInternal.BasicStream __os)
    {
        __os.startWriteSlice(ice_staticId(), -1, true);
        __os.endWriteSlice();
    }

    protected void __readImpl(IceInternal.BasicStream __is)
    {
        __is.startReadSlice();
        __is.endReadSlice();
    }

    public static final long serialVersionUID = 0L;
}
