// **********************************************************************
//
// Copyright (c) 2003-2013 ZeroC, Inc. All rights reserved.
//
// This copy of Ice is licensed to you under the terms described in the
// ICE_LICENSE file included in this distribution.
//
// **********************************************************************
//
// Ice version 3.5.1
//
// <auto-generated>
//
// Generated from file `ITimeline.ice'
//
// Warning: do not edit this file.
//
// </auto-generated>
//

package omero.api;

/**
 * Service for the querying of OMERO metadata based on creation and
 * modification time. Currently supported types for querying include:
 * <ul>
 * <li>{@link omero.model.Annotation}</li>
 * <li>{@link omero.model.Dataset}</li>
 * <li>{@link omero.model.Image}</li>
 * <li>{@link omero.model.Project}</li>
 * <li>{@link omero.model.RenderingDef}</li>
 * </ul>
 * 
 * <h4>Return maps</h4>
 * 
 * The map return values will be indexed by the short type name above:
 * <i>Project</i>, <i>Image</i>, ... All keys which are passed in the
 * StringSet argument will be included in the returned map, even if
 * they have no values. A default value of 0 or the empty list \[]
 * will be used.
 * The only exception to this rule is that the null or empty StringSet
 * implies all valid keys.
 * 
 * <h4>Parameters</h4>
 * 
 * All methods take a omero::sys::Parameters object and will apply the filter
 * object for paging through the data in order to prevent loading too
 * many objects. If the parameters argument is null or no paging is activated,
 * then the default will be: OFFSET=0, LIMIT=50. Filter.ownerId and
 * Filter.groupId will also be AND'ed to the query if either value is present.
 * If both are null, then the current user id will be used. To retrieve for
 * all users, use <code>ownerId == rlong(-1)</code> and
 * <code>groupId == null</code>.
 * 
 * <h4>Merging</h4>
 * 
 * The methods which take a StringSet and a Parameters object, also
 * have a <i>bool merge</i> argument. This argument defines whether or
 * not the LIMIT applies to each object independently
 * (<code>["a","b"] @ 100 == 200</code>) or merges the lists together
 * chronologically (<code>["a","b"] @ 100 merged == 100</code>).
 * 
 * <h4>Time used</h4>
 * 
 * Except for Image, IObject.details.updateEvent is used in all cases
 * for determining most recent events. Images are compared via
 * Image.acquisitionDate which is unlike the other properties is
 * modifiable by the user.
 * 
 * 
 * 
 * A typical invocation might look like (in Python):
 * <pre>
 * timeline = sf.getTimelineService()
 * params = ParametersI().page(0,100)
 * types = \["Project","Dataset"])
 * map = timeline.getByPeriod(types, params, False)
 * </pre>
 * At this point, map will not contain more than 200 objects.
 * 
 * This service is defined only in Blitz and so no javadoc is available
 * in the ome.api package.
 * 
 * TODOS: binning, stateful caching, ...
 **/
public interface _ITimelineOperations extends _ServiceInterfaceOperations
{
    /**
     * Return the last LIMIT annotation __Links__ whose parent (IAnnotated)
     * matches one of the parentTypes, whose child (Annotation) matches one
     * of the childTypes (limit of one for the moment), and who namespace
     * matches via ILIKE.
     * 
     * The parents and children will be unloaded. The link will have
     * its creation/update events loaded.
     * 
     * If Parameters.theFilter.ownerId or groupId are set, they will be
     * AND'ed to the query to filter results.
     * 
     * Merges by default based on parentType.
     * @param __cb The callback object for the operation.
     * @param __current The Current object for the invocation.
     **/
    void getMostRecentAnnotationLinks_async(AMD_ITimeline_getMostRecentAnnotationLinks __cb, java.util.List<String> parentTypes, java.util.List<String> childTypes, java.util.List<String> namespaces, omero.sys.Parameters p, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Return the last LIMIT comment annotation links attached to a share by
     * __others__.
     * 
     * Note: Currently the storage of these objects is not optimal
     * and so this method may change.
     * @param __cb The callback object for the operation.
     * @param __current The Current object for the invocation.
     **/
    void getMostRecentShareCommentLinks_async(AMD_ITimeline_getMostRecentShareCommentLinks __cb, omero.sys.Parameters p, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Returns the last LIMIT objects of TYPES as ordered by
     * creation/modification times in the Event table.
     * @param __cb The callback object for the operation.
     * @param __current The Current object for the invocation.
     **/
    void getMostRecentObjects_async(AMD_ITimeline_getMostRecentObjects __cb, java.util.List<String> types, omero.sys.Parameters p, boolean merge, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Returns the given LIMIT objects of TYPES as ordered by
     * creation/modification times in the Event table, but
     * within the given time window.
     * @param __cb The callback object for the operation.
     * @param __current The Current object for the invocation.
     **/
    void getByPeriod_async(AMD_ITimeline_getByPeriod __cb, java.util.List<String> types, omero.RTime start, omero.RTime end, omero.sys.Parameters p, boolean merge, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Queries the same information as getByPeriod, but only returns the counts
     * for the given objects.
     * @param __cb The callback object for the operation.
     * @param __current The Current object for the invocation.
     **/
    void countByPeriod_async(AMD_ITimeline_countByPeriod __cb, java.util.List<String> types, omero.RTime start, omero.RTime end, omero.sys.Parameters p, Ice.Current __current)
        throws omero.ServerError;

    /**
     * Returns the EventLog table objects which are queried to produce the counts above.
     * Note the concept of <i>period inclusion</i> mentioned above.
     * 
     * WORKAROUND WARNING: this method returns non-managed EventLogs (i.e.
     * eventLog.getId() == null) for <i>Image acquisitions</i>.
     * @param __cb The callback object for the operation.
     * @param __current The Current object for the invocation.
     **/
    void getEventLogsByPeriod_async(AMD_ITimeline_getEventLogsByPeriod __cb, omero.RTime start, omero.RTime end, omero.sys.Parameters p, Ice.Current __current)
        throws omero.ServerError;
}
