// **********************************************************************
//
// Copyright (c) 2003-2013 ZeroC, Inc. All rights reserved.
//
// This copy of Ice is licensed to you under the terms described in the
// ICE_LICENSE file included in this distribution.
//
// **********************************************************************
//
// Ice version 3.5.1
//
// <auto-generated>
//
// Generated from file `RenderingEngine.ice'
//
// Warning: do not edit this file.
//
// </auto-generated>
//

package omero.api;

/**
 * Defines a service to render a given pixels set.
 * 
 * A pixels set is a <i>5D</i> array that stores the pixels data of an
 * image, that is the pixels intensity values. Every instance of this
 * service is paired up to a pixels set. Use this service to transform
 * planes within the pixels set onto an <i>RGB</i> image.
 * 
 * The RenderingEngine allows to fine-tune the settings that
 * define the transformation context &#151; that is, a specification
 * of how raw pixels data is to be transformed into an image that can
 * be displayed on screen. Those settings are referred to as rendering
 * settings or display options. After tuning those settings it is
 * possible to save them to the metadata repository so that they can
 * be used the next time the pixels set is accessed for rendering; for
 * example by another RenderingEngine instance. Note that the display
 * options are specific to the given pixels set and are experimenter
 * scoped &#151; that is, two different users can specify different
 * display options for the <i>same</i> pixels set. (A RenderingEngine
 * instance takes this into account automatically as it is always
 * bound to a given experimenter.)
 * 
 * This service is <b>thread-safe</b>.
 **/
public interface _RenderingEngineOperationsNC extends _PyramidServiceOperationsNC
{
    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings.
     * The passed argument selects a plane orthogonal to one
     * of the <i>X</i>, <i>Y</i>, or <i>Z</i> axes. How many
     * wavelengths are rendered and what color model is used
     * depends on the current rendering settings.
     * 
     * @param __cb The callback object for the operation.
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i>, or <i>Z</i> axes.
     **/
    void render_async(AMD_RenderingEngine_render __cb, omero.romio.PlaneDef def)
        throws omero.ServerError;

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings.
     * The passed argument selects a plane orthogonal to one
     * of the <i>X</i>, <i>Y</i>, or <i>Z</i> axes. How many
     * wavelengths are rendered and what color model is used
     * depends on the current rendering settings.
     * 
     * @param __cb The callback object for the operation.
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i>, or <i>Z</i> axes.
     **/
    void renderAsPackedInt_async(AMD_RenderingEngine_renderAsPackedInt __cb, omero.romio.PlaneDef def)
        throws omero.ServerError;

    /**
     * Performs a projection through selected optical sections of
     * a particular timepoint with the currently active channels
     * and renders the data for display.
     * 
     * @param __cb The callback object for the operation.
     * @param algorithm {@link ome.api.IProjection#MAXIMUM_INTENSITY},
     * {@link ome.api.IProjection#MEAN_INTENSITY} or
     * {@link ome.api.IProjection#SUM_INTENSITY}.
     * @param stepping Stepping value to use while calculating the
     * projection.
     * For example, <code>stepping=1</code> will
     * use every optical section from
     * <code>start</code> to <code>end</code>
     * where <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param start Optical section to start projecting from.
     **/
    void renderProjectedAsPackedInt_async(AMD_RenderingEngine_renderProjectedAsPackedInt __cb, omero.constants.projection.ProjectionType algorithm, int timepoint, int stepping, int start, int end)
        throws omero.ServerError;

    /**
     * Renders the data selected by <code>def</code> according to
     * the current rendering settings and compresses the resulting
     * RGBA composite image.
     * 
     * @param __cb The callback object for the operation.
     * @param def Selects a plane orthogonal to one of the
     * <i>X</i>, <i>Y</i> or <i>Z</i> axes.
     **/
    void renderCompressed_async(AMD_RenderingEngine_renderCompressed __cb, omero.romio.PlaneDef def)
        throws omero.ServerError;

    /**
     * Performs a projection through selected optical sections of
     * a particular timepoint with the currently active channels,
     * renders the data for display and compresses the resulting
     * RGBA composite image.
     * 
     * @param __cb The callback object for the operation.
     * @param algorithm {@link ome.api.IProjection#MAXIMUM_INTENSITY},
     * {@link ome.api.IProjection#MEAN_INTENSITY} or
     * {@link ome.api.IProjection#SUM_INTENSITY}.
     * @param stepping Stepping value to use while calculating the
     * projection.
     * For example, <code>stepping=1</code> will
     * use every optical section from
     * <code>start</code> to <code>end</code>
     * where <code>stepping=2</code> will use every
     * other section from <code>start</code> to
     * <code>end</code> to perform the projection.
     * @param start Optical section to start projecting from.
     **/
    void renderProjectedCompressed_async(AMD_RenderingEngine_renderProjectedCompressed __cb, omero.constants.projection.ProjectionType algorithm, int timepoint, int stepping, int start, int end)
        throws omero.ServerError;

    /**
     * Returns the id of the {@link omero.model.RenderingDef}
     * loaded by either {@link #lookupRenderingDef} or
     * {@link #loadRenderingDef}.
     * @param __cb The callback object for the operation.
     **/
    void getRenderingDefId_async(AMD_RenderingEngine_getRenderingDefId __cb)
        throws omero.ServerError;

    /**
     * Loads the Pixels set this Rendering Engine is for.
     * 
     * @param __cb The callback object for the operation.
     * @param pixelsId The pixels set ID.
     **/
    void lookupPixels_async(AMD_RenderingEngine_lookupPixels __cb, long pixelsId)
        throws omero.ServerError;

    /**
     * Loads the rendering settings associated to the specified
     * pixels set.
     * 
     * @param __cb The callback object for the operation.
     * @param pixelsId The pixels set ID.
     **/
    void lookupRenderingDef_async(AMD_RenderingEngine_lookupRenderingDef __cb, long pixelsId)
        throws omero.ServerError;

    /**
     * Loads a specific set of rendering settings that does not
     * necessarily have to be linked to the given Pixels set.
     * However, the rendering settings <b>must</b> be linked to a
     * compatible Pixels set as defined by
     * {@link omero.api.IRenderingSettings#sanityCheckPixels}.
     * 
     * @param __cb The callback object for the operation.
     * @param renderingDefId The rendering definition ID.
     **/
    void loadRenderingDef_async(AMD_RenderingEngine_loadRenderingDef __cb, long renderingDefId)
        throws omero.ServerError;

    /**
     * Informs the rendering engine that it should render a set of
     * overlays on each rendered frame. These are expected to be
     * binary masks.
     * @param __cb The callback object for the operation.
     * @deprecated This operation has been deprecated.
     **/
    void setOverlays_async(AMD_RenderingEngine_setOverlays __cb, omero.RLong tablesId, omero.RLong imageId, java.util.Map<java.lang.Long, java.lang.Integer> rowColorMap)
        throws omero.ServerError;

    /**
     * Creates an instance of the rendering engine.
     * @param __cb The callback object for the operation.
     **/
    void load_async(AMD_RenderingEngine_load __cb)
        throws omero.ServerError;

    /**
     * Specifies the model that dictates how transformed raw data
     * has to be mapped onto a color space.
     * 
     * @param __cb The callback object for the operation.
     * @param model Identifies the color space model.
     **/
    void setModel_async(AMD_RenderingEngine_setModel __cb, omero.model.RenderingModel model)
        throws omero.ServerError;

    /**
     * Returns the model that dictates how transformed raw data
     * has to be mapped onto a color space.
     * @param __cb The callback object for the operation.
     **/
    void getModel_async(AMD_RenderingEngine_getModel __cb)
        throws omero.ServerError;

    /**
     * Returns the index of the default focal section.
     * @param __cb The callback object for the operation.
     **/
    void getDefaultZ_async(AMD_RenderingEngine_getDefaultZ __cb)
        throws omero.ServerError;

    /**
     * Returns the default timepoint index.
     * @param __cb The callback object for the operation.
     **/
    void getDefaultT_async(AMD_RenderingEngine_getDefaultT __cb)
        throws omero.ServerError;

    /**
     * Sets the index of the default focal section. This index is
     * used to define a default plane.
     * 
     * @param __cb The callback object for the operation.
     * @param z The value to set.
     **/
    void setDefaultZ_async(AMD_RenderingEngine_setDefaultZ __cb, int z)
        throws omero.ServerError;

    /**
     * Sets the default timepoint index. This index is used to
     * define a default plane.
     * 
     * @param __cb The callback object for the operation.
     * @param t The value to set.
     **/
    void setDefaultT_async(AMD_RenderingEngine_setDefaultT __cb, int t)
        throws omero.ServerError;

    /**
     * Returns the {@link omero.model.Pixels} set the Rendering
     * engine is for.
     * @param __cb The callback object for the operation.
     **/
    void getPixels_async(AMD_RenderingEngine_getPixels __cb)
        throws omero.ServerError;

    /**
     * Returns the list of color models supported by the Rendering
     * engine.
     * @param __cb The callback object for the operation.
     **/
    void getAvailableModels_async(AMD_RenderingEngine_getAvailableModels __cb)
        throws omero.ServerError;

    /**
     * Returns the list of mapping families supported by the
     * Rendering engine.
     * @param __cb The callback object for the operation.
     **/
    void getAvailableFamilies_async(AMD_RenderingEngine_getAvailableFamilies __cb)
        throws omero.ServerError;

    /**
     * Sets the quantization strategy. The strategy is common to
     * all channels.
     * 
     * @param __cb The callback object for the operation.
     * @param bitResolution The bit resolution defining associated
     * to the strategy.
     **/
    void setQuantumStrategy_async(AMD_RenderingEngine_setQuantumStrategy __cb, int bitResolution)
        throws omero.ServerError;

    /**
     * Sets the sub-interval of the device space i.e. a discrete
     * sub-interval of \[0, 255].
     * 
     * @param __cb The callback object for the operation.
     * @param start The lower bound of the interval.
     **/
    void setCodomainInterval_async(AMD_RenderingEngine_setCodomainInterval __cb, int start, int end)
        throws omero.ServerError;

    /**
     * Returns the quantization object.
     * @param __cb The callback object for the operation.
     **/
    void getQuantumDef_async(AMD_RenderingEngine_getQuantumDef __cb)
        throws omero.ServerError;

    /**
     * Sets the quantization map, one per channel.
     * 
     * @param __cb The callback object for the operation.
     * @param w  The channel index.
     * @param coefficient The coefficient identifying a curve in
     * the family.
     * @param noiseReduction Pass <code>true</code> to turn the
     * noise reduction algorithm on,
     * <code>false</code> otherwise.
     **/
    void setQuantizationMap_async(AMD_RenderingEngine_setQuantizationMap __cb, int w, omero.model.Family fam, double coefficient, boolean noiseReduction)
        throws omero.ServerError;

    /**
     * Returns the family associated to the specified channel.
     * 
     * @param __cb The callback object for the operation.
     * @param w The channel index.
     **/
    void getChannelFamily_async(AMD_RenderingEngine_getChannelFamily __cb, int w)
        throws omero.ServerError;

    /**
     * Returns <code>true</code> if the noise reduction algorithm
     * used to map the pixels intensity values is turned on,
     * <code>false</code> if the algorithm is turned off. Each
     * channel has an algorithm associated to it.
     * 
     * @param __cb The callback object for the operation.
     * @param w The channel index.
     **/
    void getChannelNoiseReduction_async(AMD_RenderingEngine_getChannelNoiseReduction __cb, int w)
        throws omero.ServerError;

    void getChannelStats_async(AMD_RenderingEngine_getChannelStats __cb, int w)
        throws omero.ServerError;

    /**
     * Returns the coefficient identifying a map in the family.
     * Each channel has a map associated to it.
     * 
     * @param __cb The callback object for the operation.
     * @param w The channel index.
     **/
    void getChannelCurveCoefficient_async(AMD_RenderingEngine_getChannelCurveCoefficient __cb, int w)
        throws omero.ServerError;

    /**
     * Returns the pixels intensity interval. Each channel has a
     * pixels intensity interval associated to it.
     * 
     * @param __cb The callback object for the operation.
     * @param w The channel index.
     * @param end The upper bound of the interval.
     **/
    void setChannelWindow_async(AMD_RenderingEngine_setChannelWindow __cb, int w, double start, double end)
        throws omero.ServerError;

    /**
     * Returns the lower bound of the pixels intensity interval.
     * Each channel has a pixels intensity interval associated to
     * it.
     * 
     * @param __cb The callback object for the operation.
     * @param w The channel index.
     **/
    void getChannelWindowStart_async(AMD_RenderingEngine_getChannelWindowStart __cb, int w)
        throws omero.ServerError;

    /**
     * Returns the upper bound of the pixels intensity interval.
     * Each channel has a pixels intensity interval associated to
     * it.
     * 
     * @param __cb The callback object for the operation.
     * @param w The channel index.
     **/
    void getChannelWindowEnd_async(AMD_RenderingEngine_getChannelWindowEnd __cb, int w)
        throws omero.ServerError;

    /**
     * Sets the four components composing the color associated to
     * the specified channel.
     * 
     * @param __cb The callback object for the operation.
     * @param w The channel index.
     * @param green The green component. A value between 0 and 255.
     * @param alpha The alpha component. A value between 0 and 255.
     **/
    void setRGBA_async(AMD_RenderingEngine_setRGBA __cb, int w, int red, int green, int blue, int alpha)
        throws omero.ServerError;

    /**
     * Returns a 4D-array representing the color associated to the
     * specified channel. The first element corresponds to the red
     * component (value between 0 and 255). The second corresponds
     * to the green component (value between 0 and 255). The third
     * corresponds to the blue component (value between 0 and
     * 255). The fourth corresponds to the alpha component (value
     * between 0 and 255).
     * 
     * @param __cb The callback object for the operation.
     * @param w The channel index.
     **/
    void getRGBA_async(AMD_RenderingEngine_getRGBA __cb, int w)
        throws omero.ServerError;

    /**
     * Maps the specified channel if <code>true</code>, unmaps the
     * channel otherwise.
     * 
     * @param __cb The callback object for the operation.
     * @param w The channel index.
     **/
    void setActive_async(AMD_RenderingEngine_setActive __cb, int w, boolean active)
        throws omero.ServerError;

    /**
     * Returns <code>true</code> if the channel is mapped,
     * <code>false</code> otherwise.
     * 
     * @param __cb The callback object for the operation.
     * @param w The channel index.
     **/
    void isActive_async(AMD_RenderingEngine_isActive __cb, int w)
        throws omero.ServerError;

    void setChannelLookupTable_async(AMD_RenderingEngine_setChannelLookupTable __cb, int w, String lookup)
        throws omero.ServerError;

    void getChannelLookupTable_async(AMD_RenderingEngine_getChannelLookupTable __cb, int w)
        throws omero.ServerError;

    /**
     * Adds the context to the mapping chain. Only one context of
     * the same type can be added to the chain. The codomain
     * transformations are functions from the device space to
     * device space. Each time a new context is added, the second
     * LUT is rebuilt.
     * 
     * @param __cb The callback object for the operation.
     * @param mapCtx The context to add.
     * @deprecated This operation has been deprecated.
     **/
    void addCodomainMap_async(AMD_RenderingEngine_addCodomainMap __cb, omero.romio.CodomainMapContext mapCtx)
        throws omero.ServerError;

    /**
     * Updates the specified context. The codomain chain already
     * contains the specified context. Each time a new context is
     * updated, the second LUT is rebuilt.
     * 
     * @param __cb The callback object for the operation.
     * @param mapCtx The context to update.
     * @deprecated This operation has been deprecated.
     **/
    void updateCodomainMap_async(AMD_RenderingEngine_updateCodomainMap __cb, omero.romio.CodomainMapContext mapCtx)
        throws omero.ServerError;

    /**
     * Removes the specified context from the chain. Each time a
     * new context is removed, the second LUT is rebuilt.
     * 
     * @param __cb The callback object for the operation.
     * @param mapCtx The context to remove.
     * @deprecated This operation has been deprecated.
     **/
    void removeCodomainMap_async(AMD_RenderingEngine_removeCodomainMap __cb, omero.romio.CodomainMapContext mapCtx)
        throws omero.ServerError;

    /**
     * Adds the context to the mapping chain. Only one context of
     * the same type can be added to the chain. The codomain
     * transformations are functions from the device space to
     * device space. Each time a new context is added, the second
     * LUT is rebuilt.
     * 
     * @param __cb The callback object for the operation.
     * @param mapCtx The context to add.
     **/
    void addCodomainMapToChannel_async(AMD_RenderingEngine_addCodomainMapToChannel __cb, omero.romio.CodomainMapContext mapCtx, int w)
        throws omero.ServerError;

    /**
     * Removes the specified context from the chain. Each time a
     * new context is removed, the second LUT is rebuilt.
     * 
     * @param __cb The callback object for the operation.
     * @param mapCtx The context to remove.
     **/
    void removeCodomainMapFromChannel_async(AMD_RenderingEngine_removeCodomainMapFromChannel __cb, omero.romio.CodomainMapContext mapCtx, int w)
        throws omero.ServerError;

    /**
     * Saves the current rendering settings in the database.
     * @param __cb The callback object for the operation.
     **/
    void saveCurrentSettings_async(AMD_RenderingEngine_saveCurrentSettings __cb)
        throws omero.ServerError;

    /**
     * Saves the current rendering settings in the database
     * as a new {@link omero.model.RenderingDef} and loads the
     * object into the current {@link omero.api.RenderingEngine}.
     * @param __cb The callback object for the operation.
     **/
    void saveAsNewSettings_async(AMD_RenderingEngine_saveAsNewSettings __cb)
        throws omero.ServerError;

    /**
     * Resets the default settings i.e. the default values
     * internal to the Rendering engine. The settings will be
     * saved.
     * 
     * @param __cb The callback object for the operation.
     * @param save Pass <code>true</code> to save the settings,
     * <code>false</code> otherwise.
     **/
    void resetDefaultSettings_async(AMD_RenderingEngine_resetDefaultSettings __cb, boolean save)
        throws omero.ServerError;

    /**
     * Sets the current compression level for the service. (The
     * default is 85%)
     * 
     * @param __cb The callback object for the operation.
     * @param percentage A percentage compression level from 1.00
     * (100%) to 0.01 (1%).
     **/
    void setCompressionLevel_async(AMD_RenderingEngine_setCompressionLevel __cb, float percentage)
        throws omero.ServerError;

    /**
     * Returns the current compression level for the service.
     * @param __cb The callback object for the operation.
     **/
    void getCompressionLevel_async(AMD_RenderingEngine_getCompressionLevel __cb)
        throws omero.ServerError;

    /**
     * Returns <code>true</code> if the pixels type is signed,
     * <code>false</code> otherwise.
     * @param __cb The callback object for the operation.
     **/
    void isPixelsTypeSigned_async(AMD_RenderingEngine_isPixelsTypeSigned __cb)
        throws omero.ServerError;

    /**
     * Returns the minimum value for that channels depending on
     * the pixels type and the original range (globalmax,
     * globalmin)
     * 
     * @param __cb The callback object for the operation.
     * @param w The channel index.
     **/
    void getPixelsTypeUpperBound_async(AMD_RenderingEngine_getPixelsTypeUpperBound __cb, int w)
        throws omero.ServerError;

    /**
     * Returns the maximum value for that channels depending on
     * the pixels type and the original range (globalmax,
     * globalmin)
     * 
     * @param __cb The callback object for the operation.
     * @param w The channel index.
     **/
    void getPixelsTypeLowerBound_async(AMD_RenderingEngine_getPixelsTypeLowerBound __cb, int w)
        throws omero.ServerError;

    /**
     * Returns the list of codomain contexts for the specified
     * channel.
     * 
     * @param __cb The callback object for the operation.
     * @param w The channel index.
     **/
    void getCodomainMapContext_async(AMD_RenderingEngine_getCodomainMapContext __cb, int w)
        throws omero.ServerError;
}
