// **********************************************************************
//
// Copyright (c) 2003-2013 ZeroC, Inc. All rights reserved.
//
// This copy of Ice is licensed to you under the terms described in the
// ICE_LICENSE file included in this distribution.
//
// **********************************************************************
//
// Ice version 3.5.1
//
// <auto-generated>
//
// Generated from file `Search.ice'
//
// Warning: do not edit this file.
//
// </auto-generated>
//

package omero.api;

/**
 * Central search interface, allowing Web2.0 style queries. Each
 * {@link omero.api.Search} instance keeps up with several queries and
 * lazily-loads the results as {@link #hasNext}, {@link #next} and
 * {@link #results} are called. These queries are created by the
 * <i>by*</i> methods.
 * 
 * Each instance also has a number of settings which can all be
 * changed from their defaults via accessors, e.g.
 * {@link #setBatchSize} or {@link #setCaseSentivice}.
 * 
 * The only methods which are required for the proper functioning of a
 * {@link Search} instance are:
 * <ul>
 * <li>{@link #onlyType}, {@link #onlyTypes} OR
 * {@link #allTypes}</li>
 * <li>Any <i>by*</i> method to create a query</li>
 * </ul>
 * Use of the {@link #allTypes} method is discouraged, since it is
 * possibly very resource intensive, which is why any attempt to
 * receive results without specifically setting types or allowing all
 * is prohibited.
 * 
 * @see omero.api.IQuery
 **/
public interface _SearchOperationsNC extends _StatefulServiceInterfaceOperationsNC
{
    /**
     * Returns the number of active queries. This means that
     * {@link #activeQueries} gives the minimum number of
     * remaining calls to {@link #results} when batches are not
     * merged.
     * 
     * @param __cb The callback object for the operation.
     **/
    void activeQueries_async(AMD_Search_activeQueries __cb)
        throws omero.ServerError;

    /**
     * Sets the maximum number of results that will be returned by
     * one call to {@link #results}. If batches are not merged,
     * then results may often be less than the batch size. If
     * batches are merged, then only the last call to
     * {@link #results} can be less than batch size.
     * 
     * Note: some query types may not support batching at the
     * query level, and all instances must then be loaded into
     * memory simultaneously.
     * 
     * @param __cb The callback object for the operation.
     * @param size maximum number of results per call to
     * {@link #results}
     **/
    void setBatchSize_async(AMD_Search_setBatchSize __cb, int size)
        throws omero.ServerError;

    /**
     * Returns the current batch size. If {@link #setBatchSize}
     * has not been called, the default value will be in effect.
     * 
     * @param __cb The callback object for the operation.
     **/
    void getBatchSize_async(AMD_Search_getBatchSize __cb)
        throws omero.ServerError;

    /**
     * Set whether or not results from two separate queries can be
     * returned in the same call to {@link #results}.
     * @param __cb The callback object for the operation.
     **/
    void setMergedBatches_async(AMD_Search_setMergedBatches __cb, boolean merge)
        throws omero.ServerError;

    /**
     * Returns the current merged-batches setting. If
     * {@link #setMergedBatches} has not been called, the
     * default value will be in effect.
     * @param __cb The callback object for the operation.
     **/
    void isMergedBatches_async(AMD_Search_isMergedBatches __cb)
        throws omero.ServerError;

    /**
     * Sets the case sensitivity on all queries where
     * case-sensitivity is supported.
     * @param __cb The callback object for the operation.
     **/
    void setCaseSentivice_async(AMD_Search_setCaseSentivice __cb, boolean caseSensitive)
        throws omero.ServerError;

    /**
     * Returns the current case sensitivity setting. If
     * {@link #setCaseSentivice} has not been called, the
     * default value will be in effect.
     * @param __cb The callback object for the operation.
     **/
    void isCaseSensitive_async(AMD_Search_isCaseSensitive __cb)
        throws omero.ServerError;

    /**
     * Determines if Lucene queries should not hit the database.
     * Instead all values which are stored in the index will be
     * loaded into the object, which includes the id. However, the
     * entity will not be marked unloaded and therefore it is
     * especially important to not allow a projection-instance to
     * be saved back to the server. This can result in DATA LOSS.
     * @param __cb The callback object for the operation.
     **/
    void setUseProjections_async(AMD_Search_setUseProjections __cb, boolean useProjections)
        throws omero.ServerError;

    /**
     * Returns the current use-projection setting. If true, the
     * client must be careful with all results that are returned.
     * See {@link #setUseProjections} for more. If
     * {@link #setUseProjections} has not been called, the
     * default value will be in effect.
     * @param __cb The callback object for the operation.
     **/
    void isUseProjections_async(AMD_Search_isUseProjections __cb)
        throws omero.ServerError;

    /**
     * Determines if all results should be returned as unloaded
     * objects. This is particularly useful for creating lists for
     * further querying via {@link omero.api.IQuery}. This value
     * overrides the {@link #setUseProjections} setting.
     * @param __cb The callback object for the operation.
     **/
    void setReturnUnloaded_async(AMD_Search_setReturnUnloaded __cb, boolean returnUnloaded)
        throws omero.ServerError;

    /**
     * Returns the current return-unloaded setting. If true, all
     * returned entities will be unloaded. If
     * {@link #setReturnUnloaded} has not been called, the
     * default value will be in effect.
     * @param __cb The callback object for the operation.
     **/
    void isReturnUnloaded_async(AMD_Search_isReturnUnloaded __cb)
        throws omero.ServerError;

    /**
     * Permits full-text queries with a leading query if true.
     * 
     * @param __cb The callback object for the operation.
     **/
    void setAllowLeadingWildcard_async(AMD_Search_setAllowLeadingWildcard __cb, boolean allowLeadingWildcard)
        throws omero.ServerError;

    /**
     * Returns the current leading-wildcard setting. If false,
     * {@link #byFullText} and {@link #bySomeMustNone} will throw
     * an {@link omero.ApiUsageException}, since leading-wildcard
     * searches are quite slow. Use
     * {@link #setAllowLeadingWildcard} in order to permit this
     * usage.
     * @param __cb The callback object for the operation.
     **/
    void isAllowLeadingWildcard_async(AMD_Search_isAllowLeadingWildcard __cb)
        throws omero.ServerError;

    /**
     * Restricts the search to a single type. All return values
     * will match this type.
     * @param __cb The callback object for the operation.
     **/
    void onlyType_async(AMD_Search_onlyType __cb, String klass)
        throws omero.ServerError;

    /**
     * Restricts searches to a set of types. The entities returned
     * are guaranteed to be one of these types.
     * @param __cb The callback object for the operation.
     **/
    void onlyTypes_async(AMD_Search_onlyTypes __cb, java.util.List<String> classes)
        throws omero.ServerError;

    /**
     * Permits all types to be returned. For some types of
     * queries, this carries a performance penalty as every
     * database table must be hit.
     * @param __cb The callback object for the operation.
     **/
    void allTypes_async(AMD_Search_allTypes __cb)
        throws omero.ServerError;

    /**
     * Restricts the set of ids which will be checked.
     * This is useful for testing one of the given restrictions on
     * a reduced set of objects.
     * 
     * @param __cb The callback object for the operation.
     * @param ids Can be null, in which case the previous
     * restriction is removed.
     **/
    void onlyIds_async(AMD_Search_onlyIds __cb, java.util.List<Long> ids)
        throws omero.ServerError;

    /**
     * Uses the {@link omero.model.Details#getOwner} and
     * {@link omero.model.Details#getGroup} information to
     * restrict the entities which will be returned. If both are
     * non-null, the two restrictions are joined by an AND.
     * 
     * @param __cb The callback object for the operation.
     * @param d Can be null, in which case the previous
     * restriction is removed.
     **/
    void onlyOwnedBy_async(AMD_Search_onlyOwnedBy __cb, omero.model.Details d)
        throws omero.ServerError;

    /**
     * Uses the {@link omero.model.Details#getOwner} and
     * {@link omero.model.Details#getGroup} information to
     * restrict the entities which will be returned. If both are
     * non-null, the two restrictions are joined by an AND.
     * 
     * @param __cb The callback object for the operation.
     * @param d Can be null, in which case the previous
     * restriction is removed.
     **/
    void notOwnedBy_async(AMD_Search_notOwnedBy __cb, omero.model.Details d)
        throws omero.ServerError;

    /**
     * Restricts the time between which an entity may have been
     * created.
     * 
     * @param __cb The callback object for the operation.
     * @param start Can be null, i.e. interval open to negative
     * infinity.
     * @param stop Can be null, i.e. interval opens to positive
     * infinity.
     **/
    void onlyCreatedBetween_async(AMD_Search_onlyCreatedBetween __cb, omero.RTime start, omero.RTime stop)
        throws omero.ServerError;

    /**
     * Restricts the time between which an entity may have last
     * been modified.
     * 
     * @param __cb The callback object for the operation.
     * @param start Can be null, i.e. interval open to negative
     * infinity.
     * @param stop Can be null, i.e. interval open to positive
     * infinity.
     **/
    void onlyModifiedBetween_async(AMD_Search_onlyModifiedBetween __cb, omero.RTime start, omero.RTime stop)
        throws omero.ServerError;

    /**
     * Restricts entities by the time in which any annotation
     * (which matches the other filters) was added them. This
     * matches the {@link omero.model.Details#getCreationEvent}
     * creation event of the {@link omero..model.Annotation}.
     * 
     * @param __cb The callback object for the operation.
     * @param start Can be null, i.e. interval open to negative
     * infinity.
     * @param stop Can be null, i.e. interval open to positive
     * infinity.
     **/
    void onlyAnnotatedBetween_async(AMD_Search_onlyAnnotatedBetween __cb, omero.RTime start, omero.RTime stop)
        throws omero.ServerError;

    /**
     * Restricts entities by who has annotated them with an
     * {@link omero.model.Annotation} matching the other filters.
     * As {@link #onlyOwnedBy}, the
     * {@link omero.model.Details#getOwner} and
     * {@link omero.model.Details#getGroup} information is
     * combined with an AND condition.
     * 
     * @param __cb The callback object for the operation.
     * @param d Can be null, in which case any previous
     * restriction is removed.
     **/
    void onlyAnnotatedBy_async(AMD_Search_onlyAnnotatedBy __cb, omero.model.Details d)
        throws omero.ServerError;

    /**
     * Restricts entities by who has not annotated them with an
     * {@link omero.model.Annotation} matching the other filters.
     * As {@link #notOwnedBy}, the
     * {@link omero.model.Details#getOwner} and
     * {@link omero.model.Details#getGroup} information is
     * combined with an AND condition.
     * 
     * @param __cb The callback object for the operation.
     * @param d Can be null, in which case any previous
     * restriction is removed.
     **/
    void notAnnotatedBy_async(AMD_Search_notAnnotatedBy __cb, omero.model.Details d)
        throws omero.ServerError;

    /**
     * Restricts entities to having an
     * {@link omero.model.Annotation} of all the given types. This
     * is useful in combination with the other onlyAnnotated*
     * methods to say, e.g., only annotated with a file by user X.
     * By default, this value is <code>null</code> and imposes no
     * restriction. Passing an empty array implies an object that
     * is not annotated at all.
     * 
     * 
     * Note: If the semantics were OR, then a client would have to
     * query each class individually, and compare all the various
     * values, checking which ids are where. However, since this
     * method defaults to AND, multiple calls (optionally with
     * {@link #isMergedBatches} and {@link #isReturnUnloaded})
     * and combine the results. Duplicate ids are still possible
     * so a set of some form should be used to collect the results.
     * 
     * @param __cb The callback object for the operation.
     * @param classes Can be empty, in which case restriction is
     * removed.
     **/
    void onlyAnnotatedWith_async(AMD_Search_onlyAnnotatedWith __cb, java.util.List<String> classes)
        throws omero.ServerError;

    /**
     * A path from the target entity which will be added to the
     * current stack of order statements applied to the query.
     * 
     * @param __cb The callback object for the operation.
     * @param path Non-null.
     **/
    void addOrderByAsc_async(AMD_Search_addOrderByAsc __cb, String path)
        throws omero.ServerError;

    /**
     * A path from the target entity which will be added to the
     * current stack of order statements applied to the query.
     * 
     * @param __cb The callback object for the operation.
     * @param path Non-null.
     **/
    void addOrderByDesc_async(AMD_Search_addOrderByDesc __cb, String path)
        throws omero.ServerError;

    /**
     * Removes the current stack of order statements.
     * 
     * @param __cb The callback object for the operation.
     **/
    void unordered_async(AMD_Search_unordered __cb)
        throws omero.ServerError;

    /**
     * Queries the database for all {@link omero.model.Annotation}
     * annotations of the given types for all returned instances.
     * 
     * @param __cb The callback object for the operation.
     * @param classes Can be empty, which removes previous fetch
     * setting.
     **/
    void fetchAnnotations_async(AMD_Search_fetchAnnotations __cb, java.util.List<String> classes)
        throws omero.ServerError;

    /**
     * Adds a fetch clause for loading non-annotation fields of
     * returned entities. Each fetch is a hibernate clause in dot
     * notation.
     * 
     * @param __cb The callback object for the operation.
     * @param fetches Can be empty, which removes previous fetch
     * setting.
     **/
    void fetchAlso_async(AMD_Search_fetchAlso __cb, java.util.List<String> fetches)
        throws omero.ServerError;

    /**
     * Resets all settings (non-query state) to the original
     * default values, as if the instance had just be created.
     * @param __cb The callback object for the operation.
     **/
    void resetDefaults_async(AMD_Search_resetDefaults __cb)
        throws omero.ServerError;

    /**
     * Returns transient (without ID)
     * {@link omero.model.TagAnnotation} instances which
     * represent all the
     * {@link omero.model.TagAnnotation} tags in the given group.
     * The entities are transient and without ownership since
     * multiple users can own the same tag. This method will
     * override settings for types.
     * 
     * @param __cb The callback object for the operation.
     * @param group Can be null or empty to return all tags.
     **/
    void byGroupForTags_async(AMD_Search_byGroupForTags __cb, String group)
        throws omero.ServerError;

    /**
     * Creates a query which will return transient (without ID)
     * {@link omero.model.TagAnnotation} instances which represent
     * all the {@link omero.model.TagAnnotation} tag groups which
     * the given tag belongs to. The entities are transient and
     * without ownership since multiple users can own the same tag
     * group. This method will override settings for types.
     * 
     * @param __cb The callback object for the operation.
     * @param tag Can be null or empty to return all groups.
     **/
    void byTagForGroups_async(AMD_Search_byTagForGroups __cb, String tag)
        throws omero.ServerError;

    /**
     * Passes the query as is to the Lucene backend.
     * 
     * @param __cb The callback object for the operation.
     * @param query May not be null or of zero length.
     **/
    void byFullText_async(AMD_Search_byFullText __cb, String query)
        throws omero.ServerError;

    /**
     * Builds a Lucene query and passes it to the Lucene backend.
     * 
     * @param __cb The callback object for the operation.
     * @param fields   The fields (comma separated) to search in
     * (name, description, ...)
     * @param from     The date range from, in the form YYYYMMDD
     * (may be null)
     * @param to       The date range to (inclusive), in the form
     * YYYYMMDD (may be null)
     * @param dateType {@link #DATE_TYPE_ACQUISITION} or
     * {@link #DATE_TYPE_IMPORT}
     * @param query May not be null or of zero length.
     **/
    void byLuceneQueryBuilder_async(AMD_Search_byLuceneQueryBuilder __cb, String fields, String from, String to, String dateType, String query)
        throws omero.ServerError;

    /**
     * Returns transient (without ID)
     * {@link omero.model.TextAnnotation} instances which represent
     * terms which are similar to the given terms. For example, if
     * the argument is <i>cell</i>, one return value might have as
     * its textValue: <i>cellular</i> while another has
     * <i>cellularize</i>.
     * 
     * No filtering or fetching is performed.
     * 
     * @param __cb The callback object for the operation.
     * @param terms Cannot be empty.
     **/
    void bySimilarTerms_async(AMD_Search_bySimilarTerms __cb, java.util.List<String> terms)
        throws omero.ServerError;

    /**
     * Delegates to {@link omero.api.IQuery#findAllByQuery} method
     * to take advantage of the {@link #and}, {@link #or}, and
     * {@link #not} methods, or queue-semantics.
     * 
     * @param __cb The callback object for the operation.
     * @param query Not null.
     **/
    void byHqlQuery_async(AMD_Search_byHqlQuery __cb, String query, omero.sys.Parameters params)
        throws omero.ServerError;

    /**
     * Builds a Lucene query and passes it to {@link #byFullText}.
     * 
     * @param __cb The callback object for the operation.
     * @param some Some (at least one) of these terms must be
     * present in the document. May be null.
     * @param must All of these terms must be present in the
     * document. May be null.
     * @param none None of these terms may be present in the
     * document. May be null.
     **/
    void bySomeMustNone_async(AMD_Search_bySomeMustNone __cb, java.util.List<String> some, java.util.List<String> must, java.util.List<String> none)
        throws omero.ServerError;

    /**
     * Finds entities annotated with an
     * {@link omero.model.Annotation} similar to the example. This
     * does not use Hibernate's
     * {@link omero.api.IQuery#findByExample} Query-By-Example}
     * mechanism, since that cannot handle joins. The fields which
     * are used are:
     * <ul>
     * <li>the main content of the annotation : String,
     * {@link omero.model.OriginalFile#getId}, etc.</li>
     * </ul>
     * 
     * If the main content is <code>null</code> it is assumed to
     * be a wildcard searched, and only the type of the annotation
     * is searched. Currently, ListAnnotations are not supported.
     * 
     * 
     * @param __cb The callback object for the operation.
     * @param examples Not empty.
     **/
    void byAnnotatedWith_async(AMD_Search_byAnnotatedWith __cb, java.util.List<omero.model.Annotation> examples)
        throws omero.ServerError;

    /**
     * Removes all active queries (leaving {@link #resetDefaults}
     * settings alone), such that {@link #activeQueries} will
     * return 0.
     * @param __cb The callback object for the operation.
     **/
    void clearQueries_async(AMD_Search_clearQueries __cb)
        throws omero.ServerError;

    /**
     * Applies the next by* method to the previous by* method, so
     * that a call {@link #hasNext}, {@link #next}, or
     * {@link #results} sees only the intersection of the two
     * calls.
     * 
     * For example,
     * 
     * <pre>
     * service.onlyType(Image.class);
     * service.byFullText(&quot;foo&quot;);
     * service.intersection();
     * service.byAnnotatedWith(TagAnnotation.class);
     * </pre>
     * 
     * will return only the Images with TagAnnotations.
     * 
     * <p>
     * Calling this method overrides a previous setting of
     * {@link #or} or {@link #not}. If there is no active queries
     * (i.e. {@link #activeQueries} > 0), then an
     * {@link ApiUsageException} will be thrown.</p>
     * @param __cb The callback object for the operation.
     **/
    void and_async(AMD_Search_and __cb)
        throws omero.ServerError;

    /**
     * Applies the next by* method to the previous by* method, so
     * that a call {@link #hasNext}, {@link #next} or
     * {@link #results} sees only the union of the two calls.
     * 
     * For example,
     * 
     * <pre>
     * service.onlyType(Image.class);
     * service.byFullText(&quot;foo&quot;);
     * service.or();
     * service.onlyType(Dataset.class);
     * service.byFullText(&quot;foo&quot;);
     * </pre>
     * 
     * will return both Images and Datasets together.
     * 
     * Calling this method overrides a previous setting of
     * {@link #and} or {@link #not}. If there is no active queries
     * (i.e. {@link #activeQueries} > 0), then an
     * {@link omero.ApiUsageException} will be thrown.
     * @param __cb The callback object for the operation.
     **/
    void or_async(AMD_Search_or __cb)
        throws omero.ServerError;

    /**
     * Applies the next by* method to the previous by* method, so
     * that a call {@link #hasNext}, {@link #next}, or
     * {@link #results} sees only the intersection of the two
     * calls.
     * 
     * For example,
     * 
     * <pre>
     * service.onlyType(Image.class);
     * service.byFullText(&quot;foo&quot;);
     * service.complement();
     * service.byAnnotatedWith(TagAnnotation.class);
     * </pre>
     * 
     * will return all the Images <em>not</em> annotated with
     * TagAnnotation. <p>
     * Calling this method overrides a previous setting of
     * {@link #or} or {@link #and}. If there is no active queries
     * (i.e. {@link #activeQueries} > 0), then an
     * {@link ApiUsageException} will be thrown.
     * </p>
     * @param __cb The callback object for the operation.
     **/
    void not_async(AMD_Search_not __cb)
        throws omero.ServerError;

    /**
     * Returns <code>true</code> if another call to
     * {@link #next} is valid. A call to {@link #next} may throw
     * an exception for another reason, however.
     * @param __cb The callback object for the operation.
     **/
    void hasNext_async(AMD_Search_hasNext __cb)
        throws omero.ServerError;

    /**
     * Returns the next entity from the current query. If the
     * previous call returned the last entity from a given query,
     * the first entity from the next query will be returned and
     * {@link #activeQueries} decremented.
     * Since this method only returns the entity itself, a single
     * call to {@link #currentMetadata} may follow this call to
     * gather the extra metadata which is returned in the map via
     * {@link #results}.
     * 
     * @param __cb The callback object for the operation.
     **/
    void next_async(AMD_Search_next __cb)
        throws omero.ServerError;

    /**
     * Returns up to {@link #getBatchSize} batch size number of
     * results along with the related query metadata. If
     * {@link #isMergedBatches} batches are merged then the
     * results from multiple queries may be returned together.
     * 
     * @param __cb The callback object for the operation.
     **/
    void results_async(AMD_Search_results __cb)
        throws omero.ServerError;

    /**
     * Provides access to the extra query information (for example
     * Lucene score and boost values) for a single call to
     * {@link #next}. This method may only be called once for any
     * given call to {@link #next}.
     * @param __cb The callback object for the operation.
     **/
    void currentMetadata_async(AMD_Search_currentMetadata __cb)
        throws omero.ServerError;

    /**
     * Provides access to the extra query information (for example
     * Lucene score and boost values) for a single call to
     * {@link #results}. This method may only be called once for
     * any given call to {@link #results}.
     * @param __cb The callback object for the operation.
     **/
    void currentMetadataList_async(AMD_Search_currentMetadataList __cb)
        throws omero.ServerError;

    /**
     * Unsupported operation.
     * @param __cb The callback object for the operation.
     **/
    void remove_async(AMD_Search_remove __cb)
        throws omero.ServerError;
}
