// **********************************************************************
//
// Copyright (c) 2003-2013 ZeroC, Inc. All rights reserved.
//
// This copy of Ice is licensed to you under the terms described in the
// ICE_LICENSE file included in this distribution.
//
// **********************************************************************
//
// Ice version 3.5.1
//
// <auto-generated>
//
// Generated from file `ThumbnailStore.ice'
//
// Warning: do not edit this file.
//
// </auto-generated>
//

package omero.api;

/**
 * Provides methods for dealing with thumbnails. Provision is provided
 * to retrieve thumbnails using the on-disk cache (provided by
 * <i>ROMIO</i>) or on the fly.
 * <p>
 * NOTE: The calling order for the service is as follows:
 * <ol>
 * <li>{@link #setPixelsId}</li>
 * <li>any of the thumbnail accessor methods or
 * {@link #resetDefaults}</li>
 * </ol>
 * </p>
 **/
public interface _ThumbnailStoreOperationsNC extends _StatefulServiceInterfaceOperationsNC
{
    /**
     * This method manages the state of the service; it must be
     * invoked before using any other methods. As the
     * {@link omero.api.ThumbnailStore} relies on the
     * {@link omero.api.RenderingEngine}, a valid rendering
     * definition must be available for it to work.
     * 
     * @param __cb The callback object for the operation.
     * @param pixelsId an {@link omero.model.Pixels} id.
     **/
    void setPixelsId_async(AMD_ThumbnailStore_setPixelsId __cb, long pixelsId)
        throws omero.ServerError;

    /**
     * This returns the last available <i>in progress</i> state
     * for a thumbnail. Its return value is <b>only</b> expected
     * to be valid after the call to any of the individual
     * thumbnail retrieval methods.
     * @param __cb The callback object for the operation.
     **/
    void isInProgress_async(AMD_ThumbnailStore_isInProgress __cb)
        throws omero.ServerError;

    /**
     * This method manages the state of the service; it should be
     * invoked directly after {@link #setPixelsId}. If it is not
     * invoked with a valid rendering definition ID before using
     * the thumbnail accessor methods execution continues as if
     * <code>renderingDefId</code> were set to <code>null</code>.
     * 
     * @param __cb The callback object for the operation.
     * @param renderingDefId
     * an {@link omero.model.RenderingDef} id.
     * <code>null</code> specifies the user's currently
     * active rendering settings to be used.
     **/
    void setRenderingDefId_async(AMD_ThumbnailStore_setRenderingDefId __cb, long renderingDefId)
        throws omero.ServerError;

    /**
     * Return the id of the {@link omero.model.RenderingDef}
     * loaded in this instance.
     * @param __cb The callback object for the operation.
     **/
    void getRenderingDefId_async(AMD_ThumbnailStore_getRenderingDefId __cb)
        throws omero.ServerError;

    /**
     * Retrieves a thumbnail for a pixels set using a given set of
     * rendering settings (RenderingDef). If the thumbnail exists
     * in the on-disk cache it will be returned directly,
     * otherwise it will be created as in
     * {@link #getThumbnailDirect}, placed in the on-disk
     * cache and returned.
     * 
     * @param __cb The callback object for the operation.
     * @param sizeX the X-axis width of the thumbnail.
     * <code>null</code> specifies the default size
     * of 48.
     * @param sizeY the Y-axis width of the thumbnail.
     * <code>null</code> specifies the default size
     * of 48.
     **/
    void getThumbnail_async(AMD_ThumbnailStore_getThumbnail __cb, omero.RInt sizeX, omero.RInt sizeY)
        throws omero.ServerError;

    /**
     * Retrieves a number of thumbnails for pixels sets using
     * given sets of rendering settings (RenderingDef). If the
     * thumbnails exist in the on-disk cache they will be returned
     * directly, otherwise they will be created as in
     * {@link #getThumbnailDirect}, placed in the on-disk cache
     * and returned. Unlike the other thumbnail retrieval methods,
     * this method <b>may</b> be called without first calling
     * {@link #setPixelsId}.
     * 
     * @param __cb The callback object for the operation.
     * @param sizeX the X-axis width of the thumbnail.
     * <code>null</code> specifies the default size
     * of 48.
     * @param sizeY the Y-axis width of the thumbnail.
     * <code>null</code> specifies the default size
     * of 48.
     * @param pixelsIds the Pixels sets to retrieve thumbnails for.
     **/
    void getThumbnailSet_async(AMD_ThumbnailStore_getThumbnailSet __cb, omero.RInt sizeX, omero.RInt sizeY, java.util.List<Long> pixelsIds)
        throws omero.ServerError;

    /**
     * Retrieves a number of thumbnails for pixels sets using
     * given sets of rendering settings (RenderingDef). If the
     * Thumbnails exist in the on-disk cache they will be returned
     * directly, otherwise they will be created as in
     * {@link #getThumbnailByLongestSideDirect}. The longest
     * side of the image will be used to calculate the size for
     * the smaller side in order to keep the aspect ratio of the
     * original image. Unlike the other thumbnail retrieval
     * methods, this method <b>may</b> be called without first
     * calling {@link #setPixelsId}.
     * 
     * @param __cb The callback object for the operation.
     * @param size the size of the longest side of the thumbnail
     * requested. <code>null</code> specifies the
     * default size of 48.
     * @param pixelsIds the Pixels sets to retrieve thumbnails for.
     **/
    void getThumbnailByLongestSideSet_async(AMD_ThumbnailStore_getThumbnailByLongestSideSet __cb, omero.RInt size, java.util.List<Long> pixelsIds)
        throws omero.ServerError;

    /**
     * Retrieves a thumbnail for a pixels set using a given set of
     * rendering settings (RenderingDef). If the thumbnail exists
     * in the on-disk cache it will bereturned directly, otherwise
     * it will be created as in {@link #getThumbnailDirect},
     * placed in the on-disk cache and returned. The longest side
     * of the image will be used to calculate the size for the
     * smaller side in order to keep the aspect ratio of the
     * original image.
     * 
     * @param __cb The callback object for the operation.
     * @param size the size of the longest side of the thumbnail
     * requested. <code>null</code> specifies the
     * default size of 48.
     **/
    void getThumbnailByLongestSide_async(AMD_ThumbnailStore_getThumbnailByLongestSide __cb, omero.RInt size)
        throws omero.ServerError;

    /**
     * Retrieves a thumbnail for a pixels set using a given set of
     * rendering settings (RenderingDef). The Thumbnail will
     * always be created directly, ignoring the on-disk cache. The
     * longest side of the image will be used to calculate the
     * size for the smaller side in order to keep the aspect ratio
     * of the original image.
     * 
     * @param __cb The callback object for the operation.
     * @param size the size of the longest side of the thumbnail
     * requested. <code>null</code> specifies the
     * default size of 48.
     **/
    void getThumbnailByLongestSideDirect_async(AMD_ThumbnailStore_getThumbnailByLongestSideDirect __cb, omero.RInt size)
        throws omero.ServerError;

    /**
     * Retrieves a thumbnail for a pixels set using a given set of
     * rendering settings (RenderingDef). The Thumbnail will
     * always be created directly, ignoring the on-disk cache.
     * 
     * @param __cb The callback object for the operation.
     * @param sizeX the X-axis width of the thumbnail.
     * <code>null</code> specifies the default size
     * of 48.
     * @param sizeY the Y-axis width of the thumbnail.
     * <code>null</code> specifies the default size
     * of 48.
     **/
    void getThumbnailDirect_async(AMD_ThumbnailStore_getThumbnailDirect __cb, omero.RInt sizeX, omero.RInt sizeY)
        throws omero.ServerError;

    /**
     * Retrieves a thumbnail for a pixels set using a given set of
     * rendering settings (RenderingDef) for a particular section.
     * The Thumbnail will always be created directly, ignoring the
     * on-disk cache.
     * 
     * @param __cb The callback object for the operation.
     * @param theZ the optical section (offset across the Z-axis)
     * to use.
     * @param theT the timepoint (offset across the T-axis) to use.
     * @param sizeY the Y-axis width of the thumbnail.
     * <code>null</code> specifies the default size
     * of 48.
     **/
    void getThumbnailForSectionDirect_async(AMD_ThumbnailStore_getThumbnailForSectionDirect __cb, int theZ, int theT, omero.RInt sizeX, omero.RInt sizeY)
        throws omero.ServerError;

    /**
     * Retrieves a thumbnail for a pixels set using a given set of
     * rendering settings (RenderingDef) for a particular section.
     * The Thumbnail will always be created directly, ignoring the
     * on-disk cache. The longest side of the image will be used
     * to calculate the size for the smaller side in order to keep
     * the aspect ratio of the original image.
     * 
     * @param __cb The callback object for the operation.
     * @param theZ the optical section (offset across the Z-axis)
     * to use.
     * @param theT the timepoint (offset across the T-axis) to use.
     **/
    void getThumbnailForSectionByLongestSideDirect_async(AMD_ThumbnailStore_getThumbnailForSectionByLongestSideDirect __cb, int theZ, int theT, omero.RInt size)
        throws omero.ServerError;

    /**
     * Creates thumbnails for a pixels set using a given set of
     * rendering settings (RenderingDef) in the on-disk cache for
     * <b>every</b> sizeX/sizeY combination already cached.
     * 
     * @param __cb The callback object for the operation.
     **/
    void createThumbnails_async(AMD_ThumbnailStore_createThumbnails __cb)
        throws omero.ServerError;

    /**
     * Creates a thumbnail for a pixels set using a given set of
     * rendering settings (RenderingDef) in the on-disk cache.
     * 
     * @param __cb The callback object for the operation.
     * @param sizeX the X-axis width of the thumbnail.
     * <code>null</code> specifies the default size
     * of 48.
     * @param sizeY the Y-axis width of the thumbnail.
     * <code>null</code> specifies the default size
     * of 48.
     **/
    void createThumbnail_async(AMD_ThumbnailStore_createThumbnail __cb, omero.RInt sizeX, omero.RInt sizeY)
        throws omero.ServerError;

    /**
     * Creates thumbnails for a number of pixels sets using a
     * given set of rendering settings (RenderingDef) in the
     * on-disk cache. Unlike the other thumbnail creation methods,
     * this method <b>may</b> be called without first calling
     * {@link #setPixelsId}. This method <b>will not</b> reset or
     * modify rendering settings in any way. If rendering settings
     * for a pixels set are not present, thumbnail creation for
     * that pixels set <b>will not</b> be performed.
     * 
     * @param __cb The callback object for the operation.
     * @param size the size of the longest side of the thumbnail
     * requested. <code>null</code> specifies the
     * default size of 48.
     * @param pixelsIds the Pixels sets to retrieve thumbnails for.
     **/
    void createThumbnailsByLongestSideSet_async(AMD_ThumbnailStore_createThumbnailsByLongestSideSet __cb, omero.RInt size, java.util.List<Long> pixelsIds)
        throws omero.ServerError;

    /**
     * Checks if a thumbnail of a particular size exists for a
     * pixels set.
     * 
     * @param __cb The callback object for the operation.
     * @param sizeX the X-axis width of the thumbnail.
     * <code>null</code> specifies the default size
     * of 48.
     * @param sizeY the Y-axis width of the thumbnail.
     * <code>null</code> specifies the default size
     * of 48.
     **/
    void thumbnailExists_async(AMD_ThumbnailStore_thumbnailExists __cb, omero.RInt sizeX, omero.RInt sizeY)
        throws omero.ServerError;

    /**
     * Resets the rendering definition for the active pixels set
     * to its default settings.
     * @param __cb The callback object for the operation.
     **/
    void resetDefaults_async(AMD_ThumbnailStore_resetDefaults __cb)
        throws omero.ServerError;
}
