// **********************************************************************
//
// Copyright (c) 2003-2013 ZeroC, Inc. All rights reserved.
//
// This copy of Ice is licensed to you under the terms described in the
// ICE_LICENSE file included in this distribution.
//
// **********************************************************************
//
// Ice version 3.5.1
//
// <auto-generated>
//
// Generated from file `FS.ice'
//
// Warning: do not edit this file.
//
// </auto-generated>
//

package omero.grid.monitors;

public interface _FileServerOperationsNC
{
    /**
     * Get an absolute directory from an OMERO.fs server.
     * 
     * The returned list will contain just the file names for each directory entry.
     * 
     * An exception will be raised if the path does not exist or is inaccessible to the
     * OMERO.fs server. An exception will be raised if directory list cannot be
     * returned for any other reason.
     * 
     * @param absPath, an absolute path on the monitor's watch path (string).
     * @param filter, a filter to apply to the listing, cf. ls (string).
     * @return, a directory listing (Ice::StringSeq).
     * @throws omero::OmeroFSError
     **/
    String[] getDirectory(String absPath, String filter)
        throws omero.OmeroFSError;

    /**
     * Get an absolute directory from an OMERO.fs server.
     * 
     * The returned list will contain the file stats for each directory entry.
     * 
     * An exception will be raised if the path does not exist or is inaccessible to the
     * OMERO.fs server. An exception will be raised if directory list cannot be
     * returned for any other reason.
     * 
     * @param absPath, an absolute path on the monitor's watch path (string).
     * @param filter, a filter to apply to the listing, cf. ls (string).
     * @return, a directory listing (FileStatsList).
     * @throws omero::OmeroFSError
     **/
    FileStats[] getBulkDirectory(String absPath, String filter)
        throws omero.OmeroFSError;

    /**
     * Query the existence of a file
     * 
     * An exception will be raised if the method fails to determine the existence.
     * 
     * @param fileId, see above.
     * @return existence of file.
     * @throws omero::OmeroFSError
     **/
    boolean fileExists(String fileId)
        throws omero.OmeroFSError;

    /**
     * Get base name of a file, this is the name
     * stripped of any path, e.g. file.ext
     * 
     * An exception will be raised if the file no longer exists or is inaccessible.
     * 
     * @param fileId, see above.
     * @return base name.
     * @throws omero::OmeroFSError
     **/
    String getBaseName(String fileId)
        throws omero.OmeroFSError;

    /**
     * Get all FileStats of a file
     * 
     * An exception will be raised if the file no longer exists or is inaccessible.
     * 
     * @param fileId, see above.
     * @return file stats (FileStats).
     * @throws omero::OmeroFSError
     **/
    FileStats getStats(String fileId)
        throws omero.OmeroFSError;

    /**
     * Get size of a file in bytes
     * 
     * An exception will be raised if the file no longer exists or is inaccessible.
     * 
     * @param fileId, see above.
     * @return byte size of file (long).
     * @throws omero::OmeroFSError
     **/
    long getSize(String fileId)
        throws omero.OmeroFSError;

    /**
     * Get owner of a file
     * 
     * An exception will be raised if the file no longer exists or is inaccessible.
     * 
     * @param fileId, see above.
     * @return owner of file (string).
     * @throws omero::OmeroFSError
     **/
    String getOwner(String fileId)
        throws omero.OmeroFSError;

    /**
     * Get ctime of a file
     * 
     * An exception will be raised if the file no longer exists or is inaccessible.
     * 
     * @param fileId, see above.
     * @return ctime of file (float).
     * @throws omero::OmeroFSError
     **/
    float getCTime(String fileId)
        throws omero.OmeroFSError;

    /**
     * Get mtime of a file
     * 
     * An exception will be raised if the file no longer exists or is inaccessible.
     * 
     * @param fileId, see above.
     * @return mtime of file (float).
     * @throws omero::OmeroFSError
     **/
    float getMTime(String fileId)
        throws omero.OmeroFSError;

    /**
     * Get atime of a file
     * 
     * An exception will be raised if the file no longer exists or is inaccessible.
     * 
     * @param fileId, see above.
     * @return atime of file (float).
     * @throws omero::OmeroFSError
     **/
    float getATime(String fileId)
        throws omero.OmeroFSError;

    /**
     * Query whether file is a directory
     * 
     * An exception will be raised if the file no longer exists or is inaccessible.
     * 
     * @param fileId, see above.
     * @return true is directory (bool).
     * @throws omero::OmeroFSError
     **/
    boolean isDir(String fileId)
        throws omero.OmeroFSError;

    /**
     * Query whether file is a file
     * 
     * An exception will be raised if the file no longer exists or is inaccessible.
     * 
     * @param fileId, see above.
     * @return true if file (bool).
     * @throws omero::OmeroFSError
     **/
    boolean isFile(String fileId)
        throws omero.OmeroFSError;

    /**
     * Get SHA1 of a file
     * 
     * An exception will be raised if the file no longer exists or is inaccessible.
     * An exception will be raised if the SHA1 cannot be generated for any reason.
     * 
     * @param fileId, see above.
     * @return SHA1 hex hash digest of file (string).
     * @throws omero::OmeroFSError
     **/
    String getSHA1(String fileId)
        throws omero.OmeroFSError;

    /**
     * readBlock should open, read size bytes from offset
     * and then close the file.
     * 
     * An exception will be raised if the file no longer exists or is inaccessible.
     * An exception will be raised if the file read fails for any other reason.
     * 
     * @param fileId, see above.
     * @param offset, byte offset into file from where read should begin (long).
     * @param size, number of bytes that should be read (int).
     * @return byte sequence of upto size bytes.
     * @throws omero::OmeroFSError
     **/
    byte[] readBlock(String fileId, long offset, int size)
        throws omero.OmeroFSError;
}
