/*
 * org.openmicroscopy.shoola.agents.measurement.view.ROITable 
 *
  *------------------------------------------------------------------------------
 *  Copyright (C) 2006-2016 University of Dundee. All rights reserved.
 *
 *
 * 	This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *  
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 *------------------------------------------------------------------------------
 */
package org.openmicroscopy.shoola.agents.measurement.view;



//Java imports
import java.awt.Component;
import java.awt.Insets;
import java.awt.MouseInfo;
import java.awt.Point;
import java.awt.Rectangle;
import java.awt.Toolkit;
import java.awt.dnd.DnDConstants;
import java.awt.dnd.DragSource;
import java.awt.dnd.DragSourceDragEvent;
import java.awt.dnd.DragSourceDropEvent;
import java.awt.dnd.DragSourceEvent;
import java.awt.dnd.DragSourceListener;
import java.awt.dnd.DragSourceMotionListener;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.MouseEvent;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Comparator;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.TreeMap;
import java.util.Vector;

import javax.swing.DropMode;
import javax.swing.JFrame;
import javax.swing.JPopupMenu;
import javax.swing.JTable;
import javax.swing.ListSelectionModel;
import javax.swing.Scrollable;
import javax.swing.SwingConstants;
import javax.swing.SwingUtilities;
import javax.swing.Timer;
import javax.swing.ToolTipManager;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;
import javax.swing.event.MouseInputListener;
import javax.swing.plaf.basic.BasicTableUI;
import javax.swing.tree.TreePath;

//Third-party libraries
import org.jdesktop.swingx.JXTreeTable;
import org.jdesktop.swingx.treetable.TreeTableModel;
import org.jhotdraw.draw.Figure;

//Application-internal dependencies
import org.openmicroscopy.shoola.agents.measurement.util.roimenu.ROIPopupMenu;
import org.openmicroscopy.shoola.agents.measurement.util.roitable.ROIActionController;
import org.openmicroscopy.shoola.agents.measurement.util.roitable.ROINode;
import org.openmicroscopy.shoola.agents.measurement.util.roitable.ROINodeMap;
import org.openmicroscopy.shoola.agents.measurement.util.roitable.ROITableCellRenderer;
import org.openmicroscopy.shoola.agents.measurement.util.roitable.ROITableModel;
import org.openmicroscopy.shoola.agents.measurement.util.roitable.ROIUtil;
import org.openmicroscopy.shoola.agents.measurement.util.roitable.ROIUtil.SelectionType;
import org.openmicroscopy.shoola.agents.measurement.util.roitable.TableRowTransferHandler;
import org.openmicroscopy.shoola.agents.measurement.util.ui.ShapeRenderer;
import org.openmicroscopy.shoola.agents.util.SelectionWizard;
import org.openmicroscopy.shoola.agents.util.SelectionWizardDataSource;
import org.openmicroscopy.shoola.agents.util.ui.EditorDialog;
import org.openmicroscopy.shoola.agents.util.ui.SelectionDialog;
import org.openmicroscopy.shoola.util.roi.figures.ROIFigure;
import org.openmicroscopy.shoola.util.roi.model.ROI;
import org.openmicroscopy.shoola.util.roi.model.ROIShape;
import org.openmicroscopy.shoola.util.roi.model.annotation.AnnotationKeys;
import org.openmicroscopy.shoola.util.roi.model.annotation.MeasurementAttributes;
import org.openmicroscopy.shoola.util.ui.UIUtilities;
import org.openmicroscopy.shoola.util.ui.graphutils.ShapeType;
import org.openmicroscopy.shoola.util.ui.treetable.OMETreeTable;
import org.openmicroscopy.shoola.util.ui.treetable.renderers.BooleanCellRenderer;
import org.openmicroscopy.shoola.agents.measurement.IconManager;
import org.openmicroscopy.shoola.agents.measurement.MeasurementAgent;

import omero.gateway.model.DataObject;
import omero.gateway.model.FolderData;
import omero.gateway.util.Pojos;

/**
 * The ROITable is the class extending the JXTreeTable, this shows the 
 * ROI as the parent object and the ROIShapes belonging to the ROI as the
 * child objects. 
 *
 * @author  Jean-Marie Burel &nbsp;&nbsp;&nbsp;&nbsp;
 * 	<a href="mailto:j.burel@dundee.ac.uk">j.burel@dundee.ac.uk</a>
 * @author	Donald MacDonald &nbsp;&nbsp;&nbsp;&nbsp;
 * 	<a href="mailto:donald@lifesci.dundee.ac.uk">donald@lifesci.dundee.ac.uk</a>
 * @version 3.0
 * <small>
 * (<b>Internal version:</b> $Revision: $Date: $)
 * </small>
 * @since OME3.0
 */
public class ROITable 
	extends OMETreeTable
	implements ROIActionController, PropertyChangeListener
{

	/** The root node of the tree. */
	private ROINode			root;
	
	/** Column names of the table. */
	private Vector<String>	columnNames;
    
	/** References to all ROINodes */
	private ROINodeMap nodesMap;
	
	/** The tree model. */
	private ROITableModel	model;
	
	/** The roi popup menu creation class .*/
	private ROIPopupMenu 	popupMenu;
	
	/** Reference to the object manager. */
	private ObjectManager   manager;

	/** Flag indicating to reset the component when loading locally.*/
	private boolean reset;
	
	/** The type of action currently performed */
	private CreationActionType action;
	
	/** Holds the previously used selection, used for resetting the selection */
	private int[] previousSelectionIndices;
	
	/** Only Folders which contain this String will be displayed */
	private String folderNameFilter= "";
	
	/** If set, only Folders with the given Ids will be displayed */
	private Collection<Long> onlyShowFolderIds = new HashSet<Long>();

    /**
     * Reference to folders which have been recently modified (ROIs
     * added/removed)
     */
    private Collection<FolderData> recentlyModifiedFolders = new ArrayList<FolderData>();

    /** Name of the 'all folders' collection */
    private final String DS_ALL_NAME = "All Folders";

    /** Name of the 'displayed folders' collection */
    private final String DS_DISPLAYED_NAMED = "Displayed Folders";

    /** Name of the collection which is used as default */
    private String defaultDS = DS_DISPLAYED_NAMED;
	
    /** The renderer for the 'Show' column */
    private CheckboxRenderer checkboxRenderer = new CheckboxRenderer();
    
	// DnD Scroll
	
	/** DnD autoscroll insets (this defines the scroll sensitive area) */
    private static final int AUTOSCROLL_INSET = 10;
    
	/** DnD autoscroll timer */
    private Timer timer;
	
	/** Track the last mouse drag position */
    private Point lastPosition;
    
	/** outer DnD autoscroll rectable */
    private Rectangle outer;

    /** inner DnD autoscroll rectable */
    private Rectangle inner;
    
	/**
     * Autoscroll to position
     */
    private void autoscroll(Point position) {
        Scrollable s = (Scrollable) this;
        if (position.y < inner.y) {
            // scroll upwards
            int dy = s.getScrollableUnitIncrement(outer,
                    SwingConstants.VERTICAL, -1);
            Rectangle r = new Rectangle(inner.x, outer.y - dy, inner.width, dy);
            scrollRectToVisible(r);
        } else if (position.y > (inner.y + inner.height)) {
            // scroll downwards
            int dy = s.getScrollableUnitIncrement(outer,
                    SwingConstants.VERTICAL, 1);
            Rectangle r = new Rectangle(inner.x, outer.y + outer.height,
                    inner.width, dy);
            scrollRectToVisible(r);
        }

        if (position.x < inner.x) {
            // scroll left
            int dx = s.getScrollableUnitIncrement(outer,
                    SwingConstants.HORIZONTAL, -1);
            Rectangle r = new Rectangle(outer.x - dx, inner.y, dx, inner.height);
            scrollRectToVisible(r);
        } else if (position.x > (inner.x + inner.width)) {
            // scroll right
            int dx = s.getScrollableUnitIncrement(outer,
                    SwingConstants.HORIZONTAL, 1);
            Rectangle r = new Rectangle(outer.x + outer.width, inner.y, dx,
                    inner.height);
            scrollRectToVisible(r);
        }
    }
    
    /**
     * Updates inner/outer autoscroll regions
     */
    private void updateRegion() {
        // compute the outer
        Rectangle visible = getVisibleRect();
        outer.setBounds(visible.x, visible.y, visible.width, visible.height);

        // compute the insets
        Insets i = new Insets(0, 0, 0, 0);
        if (this instanceof Scrollable) {
            int minSize = 2 * AUTOSCROLL_INSET;

            if (visible.width >= minSize) {
                i.left = i.right = AUTOSCROLL_INSET;
            }

            if (visible.height >= minSize) {
                i.top = i.bottom = AUTOSCROLL_INSET;
            }
        }

        // set the inner from the insets
        inner.setBounds(visible.x + i.left, visible.y + i.top, visible.width
                - (i.left + i.right), visible.height - (i.top + i.bottom));
    }

	/**
	 * The constructor for the ROITable, taking the root node and
	 * column names as parameters.  
	 * 
	 * @param model the table model.
	 * @param columnNames the column names.
	 * @param manager Reference to the manager.
	 */
	ROITable(ROITableModel model, Vector columnNames, ObjectManager manager)
	{
		super(model);
		this.model = model;
		this.manager = manager;
		this.root = (ROINode) model.getRoot();
		this.columnNames = columnNames;
		ToolTipManager.sharedInstance().registerComponent(this);
		this.setAutoResizeMode(JXTreeTable.AUTO_RESIZE_ALL_COLUMNS);
		this.setRowHeight(25);
		this.nodesMap = new ROINodeMap();
		for (int i = 0 ; i < model.getColumnCount() ; i++)
			getColumn(i).setResizable(true);
		
		setDefaultRenderer(ShapeType.class, new ShapeRenderer());
		setTreeCellRenderer(new ROITableCellRenderer());
		popupMenu = new ROIPopupMenu(this);
		reset = false;
		
	    setColumnSelectionAllowed(false);
	    setRowSelectionAllowed(true);
		
	    // enable DnD
	    setUI(new CustomTableUI());
		setDragEnabled(true);
        setDropMode(DropMode.ON);
        setTransferHandler(new TableRowTransferHandler(this));

		// make sure either shapes or folders can be selected, not both
        selectionModel.addListSelectionListener(new ListSelectionListener() {
            boolean active = true;

            @Override
            public void valueChanged(ListSelectionEvent e) {
                if (!active)
                    return;

                if (ROIUtil.getSelectionType(getSelectedObjects()) == SelectionType.MIXED
                        && previousSelectionIndices != null) {
                    active = false;
                    selectionModel.clearSelection();
                    for (int i : previousSelectionIndices)
                        selectionModel.addSelectionInterval(i, i);
                    active = true;
                } else
                    previousSelectionIndices = getSelectedRows();
            }
        });
        
        // DnD Scroll
        
        // after exportAsDrag is called (see CustomTableUI), events are no longer
        // propagated to MouseListeners, so we'd have to listen to the DragSource
        DragSource.getDefaultDragSource().addDragSourceMotionListener(
                new DragSourceMotionListener() {
                    @Override
                    public void dragMouseMoved(DragSourceDragEvent e) {
                        lastPosition = MouseInfo.getPointerInfo().getLocation();
                        if (!timer.isRunning())
                            timer.start();
                    }

                });
        DragSource.getDefaultDragSource().addDragSourceListener(
                new DragSourceListener() {

                    @Override
                    public void dropActionChanged(DragSourceDragEvent dsde) {
                        // ignore
                    }

                    @Override
                    public void dragOver(DragSourceDragEvent dsde) {
                        // ignore
                    }

                    @Override
                    public void dragExit(DragSourceEvent dse) {
                        // ignore
                    }

                    @Override
                    public void dragEnter(DragSourceDragEvent dsde) {
                        // ignore
                    }

                    @Override
                    public void dragDropEnd(DragSourceDropEvent dsde) {
                        if (timer.isRunning())
                            timer.stop();
                    }
                });
        
        outer = new Rectangle();
        inner = new Rectangle();

        Toolkit t = Toolkit.getDefaultToolkit();
        Integer prop;

        ActionListener al = new ActionListener() {

            @Override
            public void actionPerformed(ActionEvent e) {
                updateRegion();
                Point componentPosition = new Point(lastPosition);
                SwingUtilities.convertPointFromScreen(componentPosition,
                        ROITable.this);
                if (outer.contains(componentPosition)
                        && !inner.contains(componentPosition)) {
                    autoscroll(componentPosition);
                }
            }
        };

        prop =  (Integer) t.getDesktopProperty("DnD.Autoscroll.interval");
        timer = new Timer(prop == null ? 100 : prop.intValue(), al);

        prop = (Integer) t.getDesktopProperty("DnD.Autoscroll.initialDelay");
        timer.setInitialDelay(prop == null ? 100 : prop.intValue());
	}

    /**
     * Invoked when the selection has changed
     * 
     * @param selection
     *            The selected Objects.
     */
	void onSelection(Collection<Object> selection) {
        popupMenu.setActionsEnabled(selection);

        if (popupMenu.isActionEnabled(CreationActionType.REMOVE_FROM_FOLDER)) {
            // disable 'remove from folder action' if rois aren't in any folders
            List<ROIShape> selectedObjects = getSelectedROIShapes();
            Map<Long, Object> inFolders = new HashMap<Long, Object>();
            for (ROIShape shape : selectedObjects) {
                for (FolderData f : shape.getROI().getFolders()) {
                    if (!inFolders.containsKey(f.getId()))
                        inFolders.put(f.getId(), f);
                }
            }
            popupMenu.enableAction(CreationActionType.REMOVE_FROM_FOLDER,
                    !inFolders.isEmpty());
        }
    }
	
	/** 
	 * Select the ROIShape in the TreeTable and move the view port of the 
	 * table to the shape selected. 
	 * @param shape
	 */
	void selectROIShape(ROIShape shape)
	{
		Collection<ROINode> nodes = nodesMap.get(shape.getROI());
		for(ROINode node : nodes) {
    		expandROIRow(node);
    		ROINode child = node.findChild(shape);
    		int row = this.getRowForPath(child.getPath());
    		this.selectionModel.addSelectionInterval(row, row);
		}
	}
	
	/**
	 * Scroll to the selected ROIShape. 
	 * @param shape see above.
	 */
	void scrollToROIShape(ROIShape shape)
	{
	    Collection<ROINode> nodes = nodesMap.get(shape.getROI());
	    ROINode child = null;
		for(ROINode node : nodes) {
    		expandROIRow(node);
    		child = node.findChild(shape);
		}
		if(child!=null)
		    this.scrollPathToVisible(child.getPath());
	}

    /** 
     * Displays the menu at the specified location if not already visible.
     * 
     * @param x The x-coordinate of the mouse click.
     * @param y The y-coordinate of the mouse click.
     */
	void showROIManagementMenu(Component c, int x, int y)
    {
        popupMenu.setActionsEnabled(getSelectedObjects());
    	JPopupMenu menu = popupMenu.getPopupMenu();
    	if (menu.isVisible()) return;
    	menu.show(c, x, y);
    }
    
	/** Refreshes the data in the table.  */
	void refresh()
	{
		this.setTreeTableModel(new ROITableModel(root, columnNames));
	}

    /**
     * Get the IDs of all expanded (leaf) folders
     * 
     * @return See above
     */
	Set<Long> getExpandedFolders() {
        Set<Long> result = new HashSet<Long>();
        for (ROINode node : nodesMap.values()) {
            if (node.isExpanded() && node.isFolderNode())
                result.add(((FolderData) node.getUserObject()).getId());
        }
        return result;
    }

    /**
     * Expand the Folder with the given IDs
     * 
     * @param ids
     *            The folder IDs
     */
	void expandFolders(Collection<Long> ids) {
        for (ROINode node : nodesMap.values()) {
            if (node.isFolderNode()
                    && ids.contains(((FolderData) node.getUserObject()).getId()))
                expandPath(node.getPath());
        }
    }
    
	/** Clears the table. */
	void clear()
	{
		int childCount = root.getChildCount();
		for (int i = 0 ; i < childCount ; i++ )
			root.remove(0);
		this.setTreeTableModel(new ROITableModel(root, columnNames));
		this.nodesMap.clear();
		this.recentlyModifiedFolders.clear();
		this.invalidate();
		this.repaint();
	}

    /**
     * Set the name filter
     * 
     * @param filter
     *            Only show folders which contain this String
     */
    public void setNameFilter(String filter) {
        this.folderNameFilter = filter.toLowerCase();
    }
    
    /**
     * Reference to the list of folder ids which should be displayed.
     * Can be empty (ie all folders shown).
     * @return See above.
     */
    public Collection<Long> getIDFilter() {
        return this.onlyShowFolderIds;
    }
	
	/**
	 * Set the value of the object at row and column to value object, 
	 * this will also expand the row of the object set, unless the ROI
	 * of the object is not visible it will then collapse the row.
	 * 
	 * @param obj see above.
	 * @param row see above.
	 * @param column see above.
	 */
	public void setValueAt(Object obj, int row, int column)
	{
		ROINode node = (ROINode) getNodeAtRow(row);
		if (node == null)
		    return;
		super.setValueAt(obj, row, column);
		ROINode expandNode;
		if (node.isROINode())
		{
			ROI roi = (ROI) node.getUserObject();
			expandNode = node;
			if (roi.isVisible() && !expandNode.isExpanded())
				expandROIRow(expandNode);
		}
		else if (node.isShapeNode())
		{
			expandNode = (ROINode) node.getParent();
			ROIShape roiShape = (ROIShape) node.getUserObject();
			if (roiShape.getROI().isVisible() && !expandNode.isExpanded())
				expandROIRow(expandNode);
		}
		
		repaint();
	}
	
	/**
	 * Adds the ROIShape to the table, placing it under the ROI the ROIShape
	 * belongs to. This method will create the ROI if it does not exist 
	 * already. This method will also collapse all the ROI in the table
	 * and expand the ROI of the ROIShape, moving the viewport to 
	 * the ROIShape.
	 *  
	 * @param shape The shape to add.
	 */
	void addROIShape(ROIShape shape)
	{
		List<ROIShape> shapeList = new ArrayList<ROIShape>();
		shapeList.add(shape);
		addROIShapeList(shapeList);
	}

	/**
	 * Adds the ROIShapes in the shapeList to the table, placing it under the 
	 * ROI the ROIShape belongs to. This method will create the ROI if it does 
	 * not exist already. This method will also collapse all the ROI in the 
	 * table  and expand the ROI of the ROIShape, moving the viewport to 
	 * the ROIShape. 
	 * 
	 * @param shapeList The collection to add.
	 */
	void addROIShapeList(List<ROIShape> shapeList)
	{
	    // store the expanded state of the nodes
	    Set<String> expandedNodeIds = new HashSet<String>();
        Collection<ROINode> tmp = new ArrayList<ROINode>();
        ROIUtil.getAllDecendants(root, tmp);
        for (ROINode n : tmp) {
            if (n.isExpanded()) {
                expandedNodeIds.add(ROIUtil.getUUID(n.getUserObject()));
            }
        }
        
        // rebuild the nodes
		ROINode parent = null;
		int childCount;
		ROINode roiShapeNode;
		ROINode newNode;
		int index;
		for (ROIShape shape : shapeList)
		{
		    if(shape.getROI().getFolders().isEmpty()) {
		        // find the ROI node
		        Collection<ROINode> nodes = nodesMap.get(shape.getROI());
	            if (nodes.isEmpty())
	            {
	                parent = new ROINode(shape.getROI());
	                parent.setExpanded(true);
	                this.nodesMap.add(parent);
	                childCount = root.getChildCount();
	                root.insert(parent, childCount);
	            }
	            else
	                parent = nodes.iterator().next();
	            
	            // get the shape node, replace if it is exists
	            // or just add new node if it does not exists yet.
	            roiShapeNode = parent.findChild(shape.getCoord3D());
	            newNode = new ROINode(shape);
	            newNode.setExpanded(true);
	            this.nodesMap.add(newNode);
	            if (roiShapeNode != null)
	            {
	                index = parent.getIndex(roiShapeNode);
	                parent.remove(shape.getCoord3D());
	                parent.insert(newNode, index);
	            }
	            else
	                parent.insert(newNode, 
	                        parent.getInsertionPoint(shape.getCoord3D()));
		    }
		    
		    else {
		        // if the ROI is organized in folders, we have to do the
		        // same like above but for each folder.
		        Collection<ROINode> nodes = nodesMap.get(shape.getROI());
		        if (nodes.isEmpty())
                {
		            Collection<ROINode> folders = findFolders(shape.getROI());
		            for (ROINode folder : folders) {
                        parent = new ROINode(shape.getROI());
                        parent.setExpanded(true);
                        nodes.add(parent);
                        this.nodesMap.add(parent);
                        childCount = folder.getChildCount();
                        folder.insert(parent, childCount);
		            }
                }
		        
                Iterator<ROINode> it = nodes.iterator();
                while(it.hasNext()) {
                    parent = it.next();
		            roiShapeNode = parent.findChild(shape.getCoord3D());
		            newNode = new ROINode(shape);
		            newNode.setExpanded(true);
		            this.nodesMap.add(newNode);
		            if (roiShapeNode != null)
		            {
		                index = parent.getIndex(roiShapeNode);
		                parent.remove(shape.getCoord3D());
		                parent.insert(newNode, index);
		            }
		            else
		                parent.insert(newNode, 
		                        parent.getInsertionPoint(shape.getCoord3D()));
                }
		    }			
		}
		model = new ROITableModel(root, columnNames);
		this.setTreeTableModel(model);
		
		// restore the expanded state
        tmp.clear();
        ROIUtil.getAllDecendants(root, tmp);
        for (ROINode n : tmp) {
            if (expandedNodeIds.contains(ROIUtil.getUUID(n)))
                expandNode(n);
        }
	}

	/** 
	 * Expands the row of the node.
	 * 
	 * @param node The selected node.
	 */
	private void expandNode(ROINode node)
	{
		if (node.getUserObject() instanceof ROI)
			expandROIRow((ROI)node.getUserObject());
	}
	
	/**
	 * Returns the ROI Shape at row index.
	 * 
	 * @param index The index of the row.
	 * @return See above.
	 */
	ROIShape getROIShapeAtRow(int index)
	{
		TreePath path = this.getPathForRow(index);
		if (path == null) return null;
		ROINode node = (ROINode)path.getLastPathComponent();
		if (node.getUserObject() instanceof ROIShape)
			return (ROIShape) node.getUserObject();
		return null;
	}
	
	/** 
	 * Expands the row with node parent.
	 * 
	 * @param parent see above.
	 */
	private void expandROIRow(ROINode parent)
	{
	    expandPath(parent.getPath());
	}
	
	/** 
	 * Expands the row with ROI.
	 * 
	 * @param roi see above.
	 */
	private void expandROIRow(ROI roi)
	{
		Collection<ROINode> nodes = nodesMap.get(roi);
		for(ROINode node : nodes)
		    this.expandROIRow(node);
	}
	
	/**
	 * Removes the ROIShape from the table, and delete the ROI if the 
	 * ROIShape was the last ROIShape in the ROI.
	 * 
	 * @param shape see above.
	 */
	void removeROIShape(ROIShape shape)
	{
	    Collection<ROINode> nodes = nodesMap.get(shape.getROI());
        for(ROINode node : nodes) {
    		ROINode child = node.findChild(shape);
    		if (child != null) {
        		node.remove(child);
        		if (node.getChildCount() == 0)
    			node.getParent().remove(node);
    		}
        }
		this.setTreeTableModel(new ROITableModel(root, columnNames));
	}
	
    /**
     * Overridden to undo the setting of the default renderers
     */
    public void setTreeTableModel(TreeTableModel model) {
        super.setTreeTableModel(model);
        setDefaultRenderer(Boolean.class, checkboxRenderer);
    }
    
    /**
     * Determines if the given Folder should be displayed or not, taking the
     * different filtering options into account
     * 
     * @param folder
     *            The Folder to check
     * @return See above.
     */
    private boolean displayFolder(FolderData folder) {
        return (checkIDFilter(folder) && checkNameFilter(folder));
    }

    /**
     * Checks if the folder's ID is in the list of folders to display
     * 
     * @param folder
     *            The {@link FolderData} to check
     * @return <code>true</code> if the list of folders to display contains the
     *         folder's id or if the list doesn't exist
     */
    private boolean checkIDFilter(FolderData folder) {
        return onlyShowFolderIds == null
                || onlyShowFolderIds.contains(folder.getId());
    }

    /**
     * Checks if the folder's (or one of its parent folder's) name contains the
     * name filter String.
     * 
     * @param folder
     *            The {@link FolderData} to check
     * @return <code>true</code> if the folder's (or one of its parent folder's)
     *         name contains the name filter String.
     */
    private boolean checkNameFilter(FolderData folder) {
        boolean match = folder.getName().toLowerCase()
                .contains(folderNameFilter);
        if (match || folder.getParentFolder() == null)
            return match;

        return checkNameFilter(folder.getParentFolder());
    }
    
 	/**
     * Finds the ROI Folder nodes of the ROI.
     * Folders which don't exist yet, will be created.
     * 
     * @param roi The ROI
     * @return The folder nodes this ROI is part of
     */
    public Collection<ROINode> findFolders(ROI roi) {
        if(roi.getFolders().isEmpty())
            return Collections.EMPTY_LIST;
        
        Collection<ROINode> insertInto = new ArrayList<ROINode>();
        
        for (FolderData f : roi.getFolders()) {
            if (displayFolder(f)) {
                ROINode node = nodesMap.findFolderNode(f);
                if (node == null) {
                    node = new ROINode(f);
                    nodesMap.add(node);
                    handleParentFolderNodes(node);
                }
                insertInto.add(node);
            }
        }
        
        return insertInto;
    }
    
    /**
     * Adds the node to the parent; will create the parent hierarchy if it
     * doesn't exist yet.
     * 
     * @param node
     *            The Node
     */
    private void handleParentFolderNodes(ROINode node) {
        FolderData parentFolder = ((FolderData) node.getUserObject())
                .getParentFolder();
        if (parentFolder == null) {
            root.insert(node,
                    root.getInsertionPoint((FolderData) node.getUserObject()));
            return;
        }

        ROINode parent = nodesMap.findFolderNode(parentFolder);
        if (parent == null) {
            parent = new ROINode(parentFolder);
            nodesMap.add(parent);
            parent.insert(node, 0);
            handleParentFolderNodes(parent);
        } else if (parent.findChild((FolderData) node.getUserObject()) == null) {
            parent.insert(node,
                    parent.getInsertionPoint((FolderData) node.getUserObject()));
        }
    }

    /**
     * Initializes the Folder nodes, independently from the ROIs
     * 
     * @param folders
     *            The folders
     */
    void initFolders(Collection<FolderData> folders) {
        for (FolderData f : folders) {
            if (displayFolder(f)) {
                ROINode node = nodesMap.findFolderNode(f);
                if (node == null) {
                    node = new ROINode(f);
                    nodesMap.add(node);
                    handleParentFolderNodes(node);
                }
            }
        }
        model = new ROITableModel(root, columnNames);
        this.setTreeTableModel(model);
    }
	
	/**
	 * Create a list of all the roi and roishapes selected in the table.
	 * This will only list an roi even if the roi and roishapes are selected.
	 * @return see above.
	 */
    Collection<Object> getSelectedObjects()
	{
		int [] selectedRows = this.getSelectedRows();
		TreeMap<Long, Object> roiMap = new TreeMap<Long, Object>(); 
		List selectedList = new ArrayList();
		Object nodeObject;
		ROI roi;
		for (int i = 0 ; i < selectedRows.length ; i++)
		{	
            ROINode node = (ROINode) getNodeAtRow(selectedRows[i]);
            if (node == null)
                continue;
			nodeObject = node.getUserObject();
			if (nodeObject instanceof ROI)
			{
				roi = (ROI) nodeObject;
				roiMap.put(roi.getID(), roi);
				selectedList.add(roi);
			}
		}
		ROIShape roiShape;
		FolderData folder;
		for (int i = 0 ; i < selectedRows.length ; i++)
		{	
		    ROINode node = (ROINode) getNodeAtRow(selectedRows[i]);
		    if (node == null)
                continue;
			nodeObject = node.getUserObject();
			if (nodeObject instanceof ROIShape)
			{
				roiShape = (ROIShape) nodeObject;
				if (!roiMap.containsKey(roiShape.getID()))
					selectedList.add(roiShape);
			}
			
			else if (nodeObject instanceof FolderData)
            {
			    folder = (FolderData) nodeObject;
                selectedList.add(folder);
            }
		}
		
		return selectedList;
	}
	
	/**
	 * Returns the roishapes of the selected objects, this method will split ROI
	 * into their respective ROIshapes. 
	 * 
	 * @return see above.
	 */
    private List<ROIShape> getSelectedROIShapes()
	{
		int [] selectedRows = this.getSelectedRows();
		TreeMap<Long, Object> roiMap = new TreeMap<Long, Object>(); 
		List<ROIShape> selectedList = new ArrayList<ROIShape>();
		Object nodeObject;
		ROI roi;
		Iterator<ROIShape> shapeIterator;
		for (int i = 0 ; i < selectedRows.length ; i++)
		{	
		    ROINode node = (ROINode) this.getNodeAtRow(selectedRows[i]);
            if (node == null)
                continue;
            nodeObject = node.getUserObject();
			if (nodeObject instanceof ROI)
			{
				roi = (ROI) nodeObject;
				if (roi.isClientSide()) reset = true;
				roiMap.put(roi.getID(), roi);
				shapeIterator = roi.getShapes().values().iterator();
				while (shapeIterator.hasNext())
					selectedList.add(shapeIterator.next());
			}
		}
		ROIShape roiShape;
		for (int i = 0 ; i < selectedRows.length ; i++)
		{	
		    ROINode node = (ROINode) this.getNodeAtRow(selectedRows[i]);
            if (node == null)
                continue;
            nodeObject = node.getUserObject();
			if (nodeObject instanceof ROIShape)
			{
				roiShape = (ROIShape) nodeObject;
				roi = roiShape.getROI();
				if (roi.getShapes().size() == 1) reset = true;
				if (!roiMap.containsKey(roiShape.getID()))
					selectedList.add(roiShape);
			}
		}

		if (selectedList.size() == 0) {//check model
			Collection<Figure> figures = manager.getSelectedFigures();
			if (figures != null && figures.size() > 0) {
				Iterator<Figure> i = figures.iterator();
				Figure figure;
				while (i.hasNext()) {
					figure = i.next();
					if (figure instanceof ROIFigure) {
						selectedList.add(((ROIFigure) figure).getROIShape());
					}
				}
			}
		}
		return selectedList;
	}
	
	/**
     * Get the selected Folders
     * @return see above.
     */
    private List<FolderData> getSelectedFolders()
    {
        List<FolderData> result = new ArrayList<FolderData>();
        int [] selectedRows = this.getSelectedRows();
        for (int i = 0 ; i < selectedRows.length ; i++)
        {
            ROINode node = (ROINode) this.getNodeAtRow(selectedRows[i]);
            if (node == null)
                continue;
            Object nodeObject = node.getUserObject();
            if (nodeObject instanceof FolderData)
            {
                result.add((FolderData)nodeObject);
            }
        }
        return result;
    }
	
	/**
	 * Duplicates the ROI
	 * @see ROIActionController#duplicateROI()
	 */
    public void duplicateROI()
	{
		manager.showReadyMessage();
		List<ROIShape> selectedObjects = getSelectedROIShapes();
		if (ROIUtil.onSeparatePlanes(selectedObjects) && ROIUtil.haveSameID(selectedObjects))
			manager.duplicateROI(ROIUtil.getSameID(selectedObjects), selectedObjects );
		else
			manager.showMessage("Duplicate: ROIs must be from the same ROI " +
					"and on separate planes.");
	}

	/** 
	 * Merges the ROI.
	 * @see ROIActionController#mergeROI()
	 */
    public void mergeROI()
	{
		manager.showReadyMessage();
		List<ROIShape> selectedObjects = getSelectedROIShapes();
		if (ROIUtil.onSeparatePlanes(selectedObjects) && selectedObjects.size() > 1)
		{
			manager.mergeROI(ROIUtil.getIDList(selectedObjects), selectedObjects);
		} else
			manager.showMessage("Merge: ROIs must be on separate " +
			"planes and must include more than one.");	
	}

    /**
     * Propagates the ROI.
     * 
     * @see ROIActionController#propagateROI()
     */
    public void propagateROI() {
        manager.showReadyMessage();
        ROI roi = null;
        for (int i : getSelectedRows()) {
            ROINode n = (ROINode) this.getNodeAtRow(i);
            if (n == null)
                continue;
            Object obj = n.getUserObject();
            if (roi != null) {
                if (n.isROINode()) {
                    if (((ROI) obj).getID() != roi.getID()) {
                        manager.showMessage("Propagate: Only one ROI may be "
                                + "propagated at a time.");
                        return;
                    }
                } else if (n.isShapeNode()) {
                    if (((ROIShape) obj).getROI().getID() != roi.getID()) {
                        manager.showMessage("Propagate: Only one ROI may be "
                                + "propagated at a time.");
                        return;
                    }
                } else {
                    manager.showMessage("Propagate: No ROI selected.");
                    return;
                }
            } else {
                if (n.isROINode())
                    roi = (ROI) obj;
                else if (n.isShapeNode())
                    roi = ((ROIShape) obj).getROI();
                else {
                    manager.showMessage("Propagate: No ROI selected.");
                    return;
                }
            }
        }

        if (roi != null)
            manager.propagateROI(roi);
        else {
            manager.showMessage("Propagate: No ROI selected.");
            return;
        }
    }

	/** 
	 * Splits the ROI.
	 * 
	 * @see ROIActionController#splitROI()
	 */
	public void splitROI()
	{
		manager.showReadyMessage();
		List<ROIShape> selectedObjects = getSelectedROIShapes();
		if (ROIUtil.onSeparatePlanes(selectedObjects) && ROIUtil.haveSameID(selectedObjects))
			manager.splitROI(ROIUtil.getSameID(selectedObjects), selectedObjects);
		else
			manager.showMessage("Split: ROIs must be from the same ROI and " +
			"on separate planes.");
	}
	
	/** 
	 * Deletes the ROIs. 
	 * 
	 *  @see ROIActionController#deleteROI()
	 */
	public void deleteROI()
	{
		List<ROIShape> selectionList = getSelectedROIShapes();
		manager.deleteROIShapes(selectionList);
		if (reset) manager.reset();
		reset = false;
	}
	
	/** 
	 * Calculates statistics.
	 * @see ROIActionController#calculateStats()
	 */
	public void calculateStats()
	{
		manager.showReadyMessage();
		List<ROIShape> selectedObjects = getSelectedROIShapes();
		if (ROIUtil.onSeparatePlanes(selectedObjects) && ROIUtil.haveSameID(selectedObjects))
			manager.calculateStats(selectedObjects);
		else
			manager.showMessage("Calculate: ROIs must be from the same ROI " +
					"and on separate planes.");
	}
	
    /**
     * Extending the mouse pressed event to show menu.
     * 
     * @param e
     *            mouse event.
     */
    protected void onMousePressed(MouseEvent e) {
        if (MeasurementViewerControl.isRightClick(e)) {
            // consider right click also as selection click before handling the
            // popup menu
            int row = rowAtPoint(e.getPoint());
            ListSelectionModel m = getSelectionModel();
            if (!m.isSelectedIndex(row)) {
                if (e.isControlDown())
                    m.addSelectionInterval(row, row);
                else if (e.isShiftDown())
                    m.addSelectionInterval(m.getAnchorSelectionIndex(), row);
                else {
                    getSelectionModel().clearSelection();
                    m.addSelectionInterval(row, row);
                }
            }

            onSelection(getSelectedObjects());
            showROIManagementMenu(this, e.getX(), e.getY());
        }
    }

	/**
	 * Overridden to display the tool tip.
	 * @see JXTreeTable#getToolTipText(MouseEvent)
	 */
	public String getToolTipText(MouseEvent e)
	{
		TreePath path = getPathForLocation(e.getX(), e.getY());
		if (path == null) return "";
		int row = getRowForPath(path);
		if (row < 0) return "";
		ROINode node = (ROINode) getNodeAtRow(row);
		if (node == null) return "";
		Object object = node.getUserObject();
		if (node.isROINode()) {
			ROI roi = (ROI) object;
			return AnnotationKeys.TEXT.get(roi);
		} else if (node.isShapeNode()) {
			ROIShape s = (ROIShape) object;
			return ""+s.getFigure().getAttribute(MeasurementAttributes.TEXT);
		}
		else if(node.isFolderNode()) {
		    return "";
		}
		return "";
	}
    
	/** 
     * Loads the tags. 
     * 
     *  @see ROIActionController#loadTags()
     */
    public void loadTags() {
        manager.loadTags();
    }
    
    /**
     * Checks if the user is allowed to create folders
     * 
     * @return See above.
     */
    public boolean canCreateFolder() {
        return manager.canCreateFolder();
    }

    @Override
    public void addToFolder() {
        action = CreationActionType.ADD_TO_FOLDER;
        
        SelectionWizardDataSource dsAll = new SelectionWizardDataSource(
                DS_ALL_NAME);
        SelectionWizardDataSource dsDisplayed = new SelectionWizardDataSource(
                DS_DISPLAYED_NAMED);
        for (FolderData f : manager.getFolders()) {
            if (f.canLink()) {
                dsAll.getData().add(f);
                if (displayFolder(f))
                    dsDisplayed.getData().add(f);
            }
        }

        // preserve the previous user selection (first item is selected by
        // default)
        SelectionWizardDataSource[] ds = new SelectionWizardDataSource[2];
        if (defaultDS.equals(DS_ALL_NAME)) {
            ds[0] = dsAll;
            ds[1] = dsDisplayed;
        } else {
            ds[0] = dsDisplayed;
            ds[1] = dsAll;
        }
            
        SelectionWizard wiz = new SelectionWizard(null, null, FolderData.class, canCreateFolder(), MeasurementAgent.getUserDetails(), ds);
        wiz.setTitle("Add to ROI Folders", "Select the Folders to add the ROI(s) to", IconManager.getInstance().getIcon(IconManager.ROIFOLDER));
        wiz.addPropertyChangeListener(this);
        UIUtilities.centerAndShow(wiz);
    }

    @Override
    public void removeFromFolder() {
        action = CreationActionType.REMOVE_FROM_FOLDER;
        List<ROIShape> selectedObjects = getSelectedROIShapes();
        Map<Long, Object> inFolders = new HashMap<Long, Object>();
        for (ROIShape shape : selectedObjects) {
            for (FolderData f : shape.getROI().getFolders()) {
                if (!inFolders.containsKey(f.getId()))
                    inFolders.put(f.getId(), f);
            }
        }
        
        SelectionWizard wiz = new SelectionWizard(null, inFolders.values(),
                FolderData.class, MeasurementAgent.getUserDetails());
        wiz.setTitle("Remove from ROI Folders",
                "Select the Folders to remove the ROI(s) from", IconManager
                        .getInstance().getIcon(IconManager.ROIFOLDER));
        wiz.addPropertyChangeListener(this);
        UIUtilities.centerAndShow(wiz);
    }
    
    @Override
    public void createFolder() {
        action = CreationActionType.CREATE_FOLDER;
        DataObject obj = new FolderData();
        EditorDialog d = new EditorDialog((JFrame) null, obj, false);
        d.addPropertyChangeListener(this);
        UIUtilities.centerAndShow(d);
    }
    
    @Override
    public void deleteFolder() {
        action = CreationActionType.DELETE_FOLDER;
        List<FolderData> selection = getSelectedFolders();
        manager.deleteFolders(selection);
    }
    
    @Override
    public void editFolder() {
        action = CreationActionType.EDIT_FOLDER;
        
        List<FolderData> selection = getSelectedFolders();
        if(selection.size()==1) {
            DataObject obj = selection.get(0);
            EditorDialog d = new EditorDialog((JFrame) null, obj, false, EditorDialog.EDIT_TYPE);
            d.addPropertyChangeListener(this);
            UIUtilities.centerAndShow(d);
        }
    }
    
    @Override
    public void moveFolder() {
        action = CreationActionType.MOVE_FOLDER;

        // subnodes and direct parent nodes of the selected nodes have to 
        // be excluded from the available nodes
        Set<Long> excludeIds = new HashSet<Long>();
        for (FolderData f : getSelectedFolders()) {
            excludeIds.add(f.getId());
            if (f.getParentFolder() != null)
                excludeIds.add(f.getParentFolder().getId());
            ROINode fnode = nodesMap.findFolderNode(f);
            Collection<ROINode> subNodes = new ArrayList<ROINode>();
            ROIUtil.getAllDecendants(fnode, subNodes);
            for (ROINode subNode : subNodes)
                if (subNode.isFolderNode())
                    excludeIds.add(((FolderData) subNode.getUserObject())
                            .getId());
        }

        Collection<DataObject> tmp = new ArrayList<DataObject>();
        for (FolderData folder : manager.getFolders()) {
            if (!excludeIds.contains(folder.getId()) && folder.canLink())
                tmp.add(folder);
        }

        SelectionDialog d = new SelectionDialog(tmp, "Destination Folder",
                "Move to selected Folder:", true);
        d.addPropertyChangeListener(this);
        UIUtilities.centerAndShow(d);
    }
    
    /**
     * Get the Folders which have been modified recently (by an add to/remove
     * from folder action)
     */
    Collection<FolderData> getRecentlyModifiedFolders() {
        return recentlyModifiedFolders;
    }

    private void addRecentlyModifiedFolder(FolderData f) {
        this.recentlyModifiedFolders.add(f);
        this.onlyShowFolderIds.add(f.getId());
    }

    private void addRecentlyModifiedFolder(Collection<FolderData> f) {
        this.recentlyModifiedFolders.addAll(f);
        this.onlyShowFolderIds.addAll(Pojos.extractIds(f));
    }
    
    @Override
    public void propertyChange(PropertyChangeEvent evt) {
        String name = evt.getPropertyName();
        
        if (SelectionWizard.DATASOURCE_PROPERTY.equals(name)) {
            this.defaultDS = ((SelectionWizardDataSource) evt.getNewValue())
                    .getName();
        }
        
        if (SelectionWizard.SELECTED_ITEMS_PROPERTY.equals(name)) {

            List<ROIShape> selectedObjects = getSelectedROIShapes();
           
            Collection<FolderData> folders = Collections.EMPTY_LIST;
            Map<Class<?>, Collection<FolderData>> m = (Map<Class<?>, Collection<FolderData>>) evt
                    .getNewValue();
            if (m == null || m.size() != 1)
                return;
            folders = m.get(FolderData.class);

            if (folders.isEmpty())
                return;

            addRecentlyModifiedFolder(folders);
            
            if (action==CreationActionType.ADD_TO_FOLDER) {
                manager.addRoisToFolder(selectedObjects, folders);
            } else if(action==CreationActionType.REMOVE_FROM_FOLDER){
                manager.removeRoisFromFolder(selectedObjects, folders);
            }
        }
        
        if (EditorDialog.CREATE_NO_PARENT_PROPERTY.equals(name)
                || EditorDialog.CREATE_PROPERTY.equals(name)
                && action == CreationActionType.CREATE_FOLDER) {
            FolderData parentFolder = null;
            List<FolderData> sel = getSelectedFolders();
            if (sel.size() == 1 && action != CreationActionType.EDIT_FOLDER)
                parentFolder = sel.get(0);

            FolderData folder = (FolderData) evt.getNewValue();
            if (parentFolder != null) {
                folder.setParentFolder(parentFolder.asFolder());
                addRecentlyModifiedFolder(parentFolder);
            }

            if (getSelectedROIShapes().isEmpty())
                manager.saveROIFolders(Collections.singleton(folder));
            else
                manager.addRoisToFolder(getSelectedROIShapes(),
                        Collections.singleton(folder));
        }
        
        if (SelectionDialog.OBJECT_SELECTION_PROPERTY.equals(name)) {
            // exclude child nodes
            Collection<Long> excludeIds = nodesMap
                    .getChildFolderIds(getSelectedFolders());

            FolderData target = (FolderData) evt.getNewValue();
            addRecentlyModifiedFolder(target);

            Collection<FolderData> toSave = new ArrayList<FolderData>();
            for (FolderData folder : getSelectedFolders()) {
                if (!excludeIds.contains(folder.getId())) {
                    folder.setParentFolder(target.asFolder());
                    toSave.add(folder);
                }
            }
            manager.saveROIFolders(toSave);
        }

        if (SelectionDialog.NONE_SELECTION_PROPERTY.equals(name)) {
            // exclude child nodes
            Collection<Long> excludeIds = nodesMap
                    .getChildFolderIds(getSelectedFolders());

            Collection<FolderData> toSave = new ArrayList<FolderData>();
            for (FolderData folder : getSelectedFolders()) {
                if (!excludeIds.contains(folder.getId())) {
                    folder.setParentFolder(null);
                    toSave.add(folder);
                }
            }
            manager.saveROIFolders(toSave);
        }
    }

    /**
     * Handles drag and drop actions
     * 
     * @param rows
     *            The dragged rows
     * @param destination
     *            The location where the rows had been dragged to
     */
    public void handleDragAndDrop(int[] rows, int destination) {
        if (manager.getState() != MeasurementViewer.READY)
            return;
        
        List<ROINode> objects = new ArrayList<ROINode>();
        for (int i = 0; i < rows.length; i++) {
            if (rows[i] == destination)
                return;
            
            ROINode n = (ROINode) getNodeAtRow(rows[i]);
            if (n != null)
                objects.add(n);
        }

        ROINode target = (ROINode) getNodeAtRow(destination);
        if (target == null) {
            if (objects.iterator().next().isFolderNode()) {
                Collection<FolderData> toSave = new ArrayList<FolderData>();
                for (ROINode n : dropChildFolderNodes(objects)) {
                    FolderData folder = (FolderData) n.getUserObject();
                    folder.setParentFolder(null);
                    toSave.add(folder);
                }
                manager.saveROIFolders(toSave);
            } else if (objects.iterator().next().isShapeNode()) {
                List<ROIShape> rois = new ArrayList<ROIShape>();
                for (ROINode n : objects) {
                    rois.add((ROIShape) n.getUserObject());
                }
                manager.moveROIsToFolder(rois, Collections.EMPTY_LIST);
            } else if (objects.iterator().next().isROINode()) {
                List<ROIShape> rois = new ArrayList<ROIShape>();
                for (ROINode n : objects) {
                    ROI r = (ROI) n.getUserObject();
                    rois.addAll(r.getShapes().values());
                }
                manager.moveROIsToFolder(rois, Collections.EMPTY_LIST);
            }
            return;
        }
        
        if (!target.isFolderNode())
            return;

        // remove the nodes from the selection which are already part of
        // the target node
        Iterator<ROINode> it = objects.iterator();
        while (it.hasNext()) {
            ROINode n = it.next();
            for (int i = 0; i < target.getChildCount(); i++) {
                if (n == target.getChildAt(i)) {
                    it.remove();
                    break;
                }
            }
        }
        
        FolderData targetFolder = (FolderData) target.getUserObject();

        if (objects.iterator().next().isFolderNode()) {

            List<FolderData> folders = new ArrayList<FolderData>(objects.size());
            for (ROINode n : dropChildFolderNodes(objects)) {
                FolderData f = (FolderData) n.getUserObject();
                f.setParentFolder(targetFolder.asFolder());
                folders.add(f);
            }
            addRecentlyModifiedFolder(targetFolder);
            manager.saveROIFolders(folders);
        } else if (objects.iterator().next().isShapeNode()) {
            List<ROIShape> rois = new ArrayList<ROIShape>();
            for (ROINode n : objects) {
                rois.add((ROIShape) n.getUserObject());
            }
            addRecentlyModifiedFolder(targetFolder);
            manager.moveROIsToFolder(rois,
                    Collections.singletonList(targetFolder));
        } else if (objects.iterator().next().isROINode()) {
            List<ROIShape> rois = new ArrayList<ROIShape>();
            for (ROINode n : objects) {
                ROI r = (ROI) n.getUserObject();
                rois.addAll(r.getShapes().values());
            }
            addRecentlyModifiedFolder(targetFolder);
            manager.moveROIsToFolder(rois,
                    Collections.singletonList(targetFolder));
        }
    }
    
    /**
     * Returns a List of ROINodes with top level nodes only. E. g. Consider a
     * branch A -> B -> C, if objects contains node B and C, this method will
     * return node B only (as C is a child of B).
     * 
     * @param objects
     *            The nodes to check
     * @return See above
     */
    private List<ROINode> dropChildFolderNodes(List<ROINode> objects) {

        List<ROINode> sorted = new ArrayList<ROINode>();
        for (ROINode n : objects) {
            if (n.isFolderNode())
                sorted.add(n);
        }

        Collections.sort(sorted, new Comparator<ROINode>() {
            @Override
            public int compare(ROINode o1, ROINode o2) {
                return o1.getPath().getPathCount()
                        - o2.getPath().getPathCount();
            }
        });

        List<ROINode> result = new ArrayList<ROINode>();
        for (ROINode n1 : sorted) {

            boolean contains = false;
            for (ROINode n2 : sorted) {
                if (n2 == n1)
                    continue;

                if (n2.getPath().isDescendant(n1.getPath())) {
                    contains = true;
                    break;
                }
            }

            if (!contains)
                result.add(n1);
        }

        return result;
    }
    
    /**
     * The default drag behavior - if multiselection is enabled - is to extend
     * the selection. To prevent that, we have to override the TableUI. This
     * workaround is based on the forum post:
     * https://community.oracle.com/thread/1361004
     */
    class CustomTableUI extends BasicTableUI {
        
        @Override
        protected MouseInputListener createMouseInputListener() {
            return new MouseInputHandler() {

                public void mousePressed(MouseEvent e) {
                    Point origin = e.getPoint();
                    int row = table.rowAtPoint(origin);
                    int column = table.columnAtPoint(origin);
                    if (row != -1 && column != -1) {
                        if (!table.isCellSelected(row, column)) {
                            super.mousePressed(e);
                        }
                    }
                }

                @Override
                public void mouseDragged(MouseEvent e) {
                    super.mouseDragged(e);
                    table.getTransferHandler().exportAsDrag(table, e,
                            DnDConstants.ACTION_MOVE);
                }

                @Override
                public void mouseReleased(MouseEvent e) {
                    super.mouseReleased(e);
                    timer.stop();
                }

                @Override
                public void mouseClicked(MouseEvent e) {
                    super.mouseClicked(e);
                }

                @Override
                public void mouseEntered(MouseEvent e) {
                    super.mouseEntered(e);
                }

                @Override
                public void mouseExited(MouseEvent e) {
                    super.mouseExited(e);
                }

                @Override
                public void mouseMoved(MouseEvent e) {
                    super.mouseMoved(e);
                }
                
            };
        }

    }

    /**
     * Customized {@link BooleanCellRenderer} which is en-/disabled depending on
     * the state of the {@link ROINode} it represents
     */
    class CheckboxRenderer extends BooleanCellRenderer {
        @Override
        public Component getTableCellRendererComponent(JTable table,
                Object value, boolean isSelected, boolean hasFocus, int row,
                int column) {
            Component c = super.getTableCellRendererComponent(table, value,
                    isSelected, hasFocus, row, column);
            ROINode node = (ROINode) ROITable.this.getNodeAtRow(row);
            if (node != null) {
                c.setEnabled(node.isShowEnabled());
            }
            return c;
        }
    }
}

